#
# spec file for package kernel-vanilla
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# needssslcertforbuild


%define srcversion 4.12
%define patchversion 4.12.14
%define variant %{nil}
%define vanilla_only 0

%include %_sourcedir/kernel-spec-macros

%define build_flavor	vanilla
%define build_default	("%build_flavor" == "default")
%define build_vanilla	("%build_flavor" == "vanilla")

%if ! %build_vanilla
%define src_install_dir /usr/src/linux-%kernelrelease%variant
%else
%define src_install_dir /usr/src/linux-%kernelrelease-vanilla
%endif
%define obj_install_dir /usr/src/linux-%kernelrelease%variant-obj
%define rpm_install_dir %buildroot%obj_install_dir
%define kernel_build_dir %my_builddir/linux-%srcversion/linux-obj

%if 0%{?_project:1} && ( %(echo %_project | egrep -x -f %_sourcedir/release-projects | grep -v ^PTF | grep -vc openSUSE) || %(echo %_project | grep -Ec "^(Devel:)?Kernel:") )
	%define klp_symbols 1
%endif

%(chmod +x %_sourcedir/{guards,apply-patches,check-for-config-changes,group-source-files.pl,split-modules,modversions,kabi.pl,mkspec,compute-PATCHVERSION.sh,arch-symbols,log.sh,try-disable-staging-driver,compress-vmlinux.sh,mkspec-dtb,check-module-license,klp-symbols,splitflist,mergedep,moddep,modflist,kernel-subpackage-build})

%global cpu_arch %(%_sourcedir/arch-symbols %_target_cpu)
%define cpu_arch_flavor %cpu_arch/%build_flavor

# Define some CONFIG variables as rpm macros as well. (rpm cannot handle
# defining them all at once.)
%define config_vars CONFIG_MODULES CONFIG_MODULE_SIG CONFIG_KMSG_IDS CONFIG_SUSE_KERNEL_SUPPORTED CONFIG_EFI_STUB
%{expand:%(eval "$(test -n "%cpu_arch_flavor" && tar -xjf %_sourcedir/config.tar.bz2 --to-stdout config/%cpu_arch_flavor)"; for config in %config_vars; do echo "%%global $config ${!config:-n}"; done)}
%define split_extra (%CONFIG_MODULES == "y" && %CONFIG_SUSE_KERNEL_SUPPORTED == "y")

%ifarch %ix86 x86_64
%define install_vdso 1
%else
%define install_vdso 0
%endif

Name:           kernel-vanilla
Summary:        The Standard Kernel - without any SUSE patches
License:        GPL-2.0
Group:          System/Kernel
Version:        4.12.14
%if 0%{?is_kotd}
Release:        lp150.12.76.1.g172ca35
%else
Release:        lp150.12.76.1
%endif
Url:            http://www.kernel.org/
BuildRequires:  bc
BuildRequires:  bison
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  flex
# Cannot test %%CONFIG_GCC_PLUGINS here because the buildservice parser
# does not expand %%(...)
%if "%build_flavor" == "syzkaller"
# Needed by scripts/gcc-plugin.sh
BuildRequires:  gcc-c++
BuildRequires:  gcc-devel
%endif
%if 0%{?suse_version} > 1310
BuildRequires:  hmaccalc
%endif
BuildRequires:  libopenssl-devel
BuildRequires:  modutils
# Used to sign the kernel in the buildservice
BuildRequires:  openssl
BuildRequires:  pesign-obs-integration
# for objtool
BuildRequires:  libelf-devel
Provides:       %name = %version-%source_rel
# bnc#901925
Provides:       %name-%version-%source_rel
Provides:       %{name}_%_target_cpu = %version-%source_rel
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
# In SLE11, kernel-$flavor complemented kernel-$flavor-base. With SLE12,
# kernel-$flavor itself contains all the needed files and kernel-$flavor-base
# is a subset that can replace kernel-$flavor in some scenarios. We need to
# obsolete the -base subpackage from SLE11, so that the base files are not
# owned by multiple packages now. The dependency is not correct wrt openSUSE
# 11.2 - 11.4, but we primarily care about the supported upgrade path.
Obsoletes:      %name-base < 3.1
Recommends: kernel-firmware
# The following is copied to the -base subpackage as well
# BEGIN COMMON DEPS
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv

%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%ifarch %arm
BuildRequires:  u-boot-tools
%endif

Obsoletes:      microcode_ctl

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 4
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-172ca35fe5f35b6aa250c773fc1943deedcbaa81
Provides:       kernel-srchash-172ca35fe5f35b6aa250c773fc1943deedcbaa81
# END COMMON DEPS
Provides:       %name-srchash-172ca35fe5f35b6aa250c773fc1943deedcbaa81
%obsolete_rebuilds %name
Source0:        http://www.kernel.org/pub/linux/kernel/v4.x/linux-%srcversion.tar.xz
Source2:        source-post.sh
Source3:        kernel-source.rpmlintrc
Source8:        devel-pre.sh
Source9:        devel-post.sh
Source10:       preun.sh
Source11:       postun.sh
Source12:       pre.sh
Source13:       post.sh
Source14:       series.conf
Source16:       guards
Source17:       apply-patches
Source21:       config.conf
Source23:       supported.conf
Source33:       check-for-config-changes
Source35:       group-source-files.pl
Source36:       README.PATCH-POLICY.SUSE
Source37:       README.SUSE
Source38:       README.KSYMS
Source39:       config-options.changes.txt
Source40:       source-timestamp
Source46:       split-modules
Source47:       modversions
Source48:       macros.kernel-source
Source49:       kernel-module-subpackage
Source50:       kabi.pl
Source51:       mkspec
Source52:       kernel-source%variant.changes
Source53:       kernel-source.spec.in
Source54:       kernel-binary.spec.in
Source55:       kernel-syms.spec.in
Source56:       kernel-docs.spec.in
Source57:       kernel-cert-subpackage
Source58:       constraints.in
Source60:       config.sh
Source61:       compute-PATCHVERSION.sh
Source62:       old-flavors
Source63:       arch-symbols
Source64:       package-descriptions
Source65:       kernel-spec-macros
Source67:       log.sh
Source68:       host-memcpy-hack.h
Source69:       try-disable-staging-driver
Source70:       kernel-obs-build.spec.in
Source71:       kernel-obs-qa.spec.in
Source72:       compress-vmlinux.sh
Source73:       dtb.spec.in.in
Source74:       mkspec-dtb
Source75:       release-projects
Source76:       check-module-license
Source77:       klp-symbols
Source78:       modules.fips
Source79:       splitflist
Source80:       mergedep
Source81:       moddep
Source82:       modflist
Source83:       kernel-subpackage-build
Source84:       kernel-subpackage-spec
Source85:       kernel-default-base.spec.txt
Source100:      config.tar.bz2
Source101:      config.addon.tar.bz2
Source102:      patches.arch.tar.bz2
Source103:      patches.drivers.tar.bz2
Source104:      patches.fixes.tar.bz2
Source105:      patches.rpmify.tar.bz2
Source106:      patches.suse.tar.bz2
Source108:      patches.addon.tar.bz2
Source109:      patches.kernel.org.tar.bz2
Source110:      patches.apparmor.tar.bz2
Source111:      patches.rt.tar.bz2
Source113:      patches.kabi.tar.bz2
Source114:      patches.drm.tar.bz2
Source120:      kabi.tar.bz2
Source121:      sysctl.tar.bz2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 armv7hl ppc64le s390x x86_64
%define kmp_target_cpu %_target_cpu
%ifarch %ix86
# Only i386/default supports i586, mark other flavors' packages as i686
%if ! %build_default
BuildArch:      i686
# KMPs are always built as i586, because rpm does not allow to build
# subpackages for different architectures. Therefore, we change the
# /usr/src/linux-obj/<arch> symlink to i586.
%define kmp_target_cpu i586
%endif
%endif

# These files are found in the kernel-source package:
NoSource:       0
NoSource:       2
NoSource:       3
NoSource:       8
NoSource:       9
NoSource:       10
NoSource:       11
NoSource:       12
NoSource:       13
NoSource:       14
NoSource:       16
NoSource:       17
NoSource:       21
NoSource:       23
NoSource:       33
NoSource:       35
NoSource:       36
NoSource:       37
NoSource:       38
NoSource:       39
NoSource:       40
NoSource:       46
NoSource:       47
NoSource:       48
NoSource:       49
NoSource:       50
NoSource:       51
NoSource:       52
NoSource:       53
NoSource:       54
NoSource:       55
NoSource:       56
NoSource:       57
NoSource:       58
NoSource:       60
NoSource:       61
NoSource:       62
NoSource:       63
NoSource:       64
NoSource:       65
NoSource:       67
NoSource:       68
NoSource:       69
NoSource:       70
NoSource:       71
NoSource:       72
NoSource:       73
NoSource:       74
NoSource:       75
NoSource:       76
NoSource:       77
NoSource:       78
NoSource:       79
NoSource:       80
NoSource:       81
NoSource:       82
NoSource:       83
NoSource:       84
NoSource:       85
NoSource:       100
NoSource:       101
NoSource:       102
NoSource:       103
NoSource:       104
NoSource:       105
NoSource:       106
NoSource:       108
NoSource:       109
NoSource:       110
NoSource:       111
NoSource:       113
NoSource:       114
NoSource:       120
NoSource:       121

# The following KMPs have been integrated into the kernel package,
# grouped by the last product that contained them.
# Usage: obsolete_kmp <basename> <upper bound of shipped versions>
# Note that KMPs embed the version of the kernel built against, that's why
# the _3 suffix for 2.6.x-based KMPs
%define obsolete_kmp() Obsoletes: %1-kmp-%build_flavor <= %2 \
Provides: %1-kmp = %2 \
Provides: %1-kmp-%build_flavor = %2
# sles10 / 10.3
%obsolete_kmp iwlwifi 1.3.27_3
%obsolete_kmp ipw3945 1.2.2_3
# sled10 / 11.0
%obsolete_kmp uvcvideo r200_3
# sle11-ga
%obsolete_kmp enic 0.0.1_3
%obsolete_kmp fnic 1.0.0_3
%obsolete_kmp brocade-bfa 1.1.0.2_3
%obsolete_kmp kvm 78.2.6.30.1_3
%obsolete_kmp perfmon 2_3
%obsolete_kmp iwlagn-2-6-27 1.0_3
%obsolete_kmp msi-wmi 1.0_3
# 11.1
%obsolete_kmp quickcam 0.6.7
# sle11-sp1
%obsolete_kmp   wacom 0.8.1_3
%obsolete_kmp   btrfs 0_3
%obsolete_kmp   brocade-bna 2.1.0.0_3
%obsolete_kmp   hyper-v 0_3
%obsolete_kmp   intel-e1000e 2.2.14
Obsoletes:      firewire <= 3.0
Provides:       firewire = 3.0
%obsolete_kmp   firewire 3.0
%obsolete_kmp   iwlagn 3.0
Obsoletes:      compat-ath9k <= 3.0
Provides:       compat-ath9k = 3.0
%obsolete_kmp   compat-ath9k 3.0
%obsolete_kmp   realtek-r8192ce_pci 2.6.0005_3
%obsolete_kmp   realtek-r8192se_pci 2.6.0019.1207.2010_3
%obsolete_kmp   rt3090 2.4.0.4_3
%obsolete_kmp   rt3592 2.4.1.1_3
%obsolete_kmp   rt5390 2.4.0.4_3
%obsolete_kmp   ath3k 1.0_3
%obsolete_kmp	compat-wireless 3.12
%obsolete_kmp	rts5229 1.08
%obsolete_kmp	rts_pstor 1.11
# sle12-sp1 / Leap 42.1
%obsolete_kmp	xen 4.6.1
%obsolete_kmp	compat-wireless 4.4
# TW 4.8
%obsolete_kmp	ftsteutates 20160601
# SLE12-SP3 / Leap 42.3
%obsolete_kmp   drm 4.12

# Will modules not listed in supported.conf abort the kernel build (0/1)?
%define supported_modules_check 1

%description
The standard kernel - without any SUSE patches


%source_timestamp
%prep
if ! [ -e %{S:0} ]; then
    echo "The %name-%version.nosrc.rpm package does not contain the" \
	 "complete sources. Please install kernel-source-%version.src.rpm."
    exit 1
fi

SYMBOLS=
if test -e %_sourcedir/extra-symbols; then
	SYMBOLS=$(cat %_sourcedir/extra-symbols)
	echo "extra symbol(s):" $SYMBOLS
fi

# Unpack all sources and patches
%setup -q -c -T -a 0 -a 100 -a 101 -a 102 -a 103 -a 104 -a 105 -a 106 -a 108 -a 109 -a 110 -a 111 -a 113 -a 114 -a 120 -a 121

mkdir -p %kernel_build_dir

# Generate a list of modules with their support status marking
%_sourcedir/guards --list --with-guards <%_sourcedir/supported.conf | \
awk '
	/\+external / {
		print $(NF) " external";
		next;
	}
	/^-/ {
		print $(NF) " no";
		next;
	}
	{
		print $(NF);
	}
' >%kernel_build_dir/Module.supported
subpackages=(
	base
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	cluster-md-kmp dlm-kmp gfs2-kmp kselftests-kmp ocfs2-kmp reiserfs-kmp
%endif
)
for package in "${subpackages[@]}"; do
	%_sourcedir/guards --default=0 "$package" \
		<%_sourcedir/supported.conf | sed 's,.*/,,; s,\.ko$,,' | \
		sort -u >%kernel_build_dir/Module."$package"
done

cd linux-%srcversion

%_sourcedir/apply-patches \
%if %{build_vanilla}
	--vanilla \
%endif
	%_sourcedir/series.conf .. $SYMBOLS

cd %kernel_build_dir

# Override the timestamp 'uname -v' reports with the source timestamp and
# the commit hash.
date=$(head -n 1 %_sourcedir/source-timestamp)
commit=$(sed -n 's/GIT Revision: //p' %_sourcedir/source-timestamp)
cat > .kernel-binary.spec.buildenv <<EOF
export KBUILD_BUILD_TIMESTAMP="$(LANG=C date -d "$date") (${commit:0:7})"
export KBUILD_VERBOSE=0
export KBUILD_SYMTYPES=1
export KBUILD_OVERRIDE=1
export KBUILD_BUILD_USER=geeko
export KBUILD_BUILD_HOST=buildhost
export HOST_EXTRACFLAGS="-include %_sourcedir/host-memcpy-hack.h"
EOF
source .kernel-binary.spec.buildenv

if [ -f %_sourcedir/localversion ] ; then
    cat %_sourcedir/localversion > localversion
fi

vanilla_base="default"
%ifarch %ix86
vanilla_base="pae"
%endif
if ! grep -q CONFIG_MMU= "%my_builddir/config/%cpu_arch_flavor"; then
cp "%my_builddir/config/%cpu_arch/$vanilla_base" .config
../scripts/kconfig/merge_config.sh -m .config \
                                   %my_builddir/config/%cpu_arch_flavor
else
cp %my_builddir/config/%cpu_arch_flavor .config
fi
if test -e %my_builddir/config.addon/%cpu_arch_flavor; then
	# FIXME: config.addon doesn't affect the %CONFIG_ macros defined at
	# the top of the specfile
	../scripts/kconfig/merge_config.sh -m .config %my_builddir/config.addon/%cpu_arch_flavor
fi

CONFIG_SUSE_KERNEL_RELEASED="--disable CONFIG_SUSE_KERNEL_RELEASED"
%if 0%{?_project:1}
if echo %_project | egrep -qx -f %_sourcedir/release-projects; then
	CONFIG_SUSE_KERNEL_RELEASED="--enable CONFIG_SUSE_KERNEL_RELEASED"
fi
%endif

../scripts/config \
	--set-str CONFIG_LOCALVERSION -%source_rel-%build_flavor \
	--enable  CONFIG_SUSE_KERNEL \
	$CONFIG_SUSE_KERNEL_RELEASED \
%if 0%{?__debug_package:1}
	--enable  CONFIG_DEBUG_INFO
%else
	--disable CONFIG_DEBUG_INFO
%endif

case %cpu_arch in
    x86_64 | i386)
        MAKE_ARGS="$MAKE_ARGS ARCH=x86"
        ;;
    ppc*)
        MAKE_ARGS="$MAKE_ARGS ARCH=powerpc"
        ;;
    s390x)
        MAKE_ARGS="$MAKE_ARGS ARCH=s390"
        ;;
    arm64)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm64"
        ;;
    armv*)
        MAKE_ARGS="$MAKE_ARGS ARCH=arm"
        ;;
    *)
        MAKE_ARGS="$MAKE_ARGS ARCH=%cpu_arch"
        ;;
esac

makeoutputsync=
if make --output-sync --help >/dev/null 2>&1 ; then
        makeoutputsync=--output-sync
else
        echo make does not support --output-sync flag. Build messages may be mangled. 1>&2
fi
MAKE_ARGS="$MAKE_ARGS $makeoutputsync %{?_smp_mflags}"
echo export MAKE_ARGS=\""$MAKE_ARGS"\" >> .kernel-binary.spec.buildenv

KERN_DIRS="-C .. O=$PWD"
if test -e %_sourcedir/TOLERATE-UNKNOWN-NEW-CONFIG-OPTIONS; then
    yes '' | make oldconfig $MAKE_ARGS $KERN_DIRS
else
    cp .config .config.orig
    if test -f ../scripts/kconfig/Makefile && \
       grep -q syncconfig ../scripts/kconfig/Makefile; then
        syncconfig="syncconfig"
    else
        syncconfig="silentoldconfig"
    fi
    make $syncconfig $MAKE_ARGS $KERN_DIRS < /dev/null
    %_sourcedir/check-for-config-changes .config.orig .config
    rm .config.orig
fi

make prepare $MAKE_ARGS
make scripts $MAKE_ARGS
krel=$(make -s kernelrelease $MAKE_ARGS)

if [ "$krel" != "%kernelrelease-%build_flavor" ]; then
    echo "Kernel release mismatch: $krel != %kernelrelease-%build_flavor" >&2
    exit 1
fi

make clean $MAKE_ARGS

rm -f source
find . ! -type d ! -name 'Module.base' ! -name 'Module.*-kmp' -printf '%%P\n' \
	> %my_builddir/obj-files

%build
cd %kernel_build_dir
source .kernel-binary.spec.buildenv

# create *.symref files in the tree
if test -e %my_builddir/kabi/%cpu_arch/symtypes-%build_flavor; then
    %_sourcedir/modversions --unpack . < $_
fi

# copy module signing certificate(s). We use the default path and trick
# certs/Makefile to not regenerate the certificate. It is done this way so
# that the kernel-source package can be rebuilt even without the certificate
mkdir -p certs
for f in %_sourcedir/*.crt; do
    if ! test -e "$f"; then
        continue
    fi
    touch certs/x509.genkey
    cat "$f" >>certs/signing_key.pem
done

%if %CONFIG_KMSG_IDS == "y"
    chmod +x ../scripts/kmsg-doc
    MAKE_ARGS="$MAKE_ARGS D=2"
%endif

mkdir -p %_topdir/OTHER
log=%_topdir/OTHER/make-stderr.log
while true; do
    make all $MAKE_ARGS 2> >(tee "$log")
    if test "${PIPESTATUS[0]}" -eq 0; then
        break
    fi
    # In the linux-next and vanilla branches, we try harder to build a
    # package.
    if test 0%vanilla_only -gt 0 &&
			%_sourcedir/try-disable-staging-driver "$log"; then
        echo "Retrying make"
    else
        exit 1
    fi
done

# Generate list of symbols that are used to create kernel livepatches
%if 0%{?klp_symbols}
	%_sourcedir/klp-symbols . Symbols.list
%endif

%install

# sign the modules, firmware and possibly the kernel in the buildservice
BRP_PESIGN_FILES=""
%if %CONFIG_EFI_STUB == "y"
BRP_PESIGN_FILES="/boot/vmlinuz-%kernelrelease-%build_flavor"
%endif
%if %CONFIG_MODULE_SIG == "y"
BRP_PESIGN_FILES="$BRP_PESIGN_FILES *.ko"
%endif
%ifarch %ix86
# XXX: do not sign on x86, as the repackaging changes kernel-pae
# from i686 to i586
BRP_PESIGN_FILES=""
%endif
export BRP_PESIGN_FILES

# get rid of /usr/lib/rpm/brp-strip-debug
# strip removes too much from the vmlinux ELF binary
export NO_BRP_STRIP_DEBUG=true
export STRIP_KEEP_SYMTAB='*/vmlinux-*'

# /lib/modules/%kernelrelease-%build_flavor/source points to the source
# directory installed by kernel-devel. The kernel-%build_flavor-devel package
# has a correct dependency on kernel-devel, but the brp check does not see
# kernel-devel during build.
export NO_BRP_STALE_LINK_ERROR=yes

cd %kernel_build_dir
source .kernel-binary.spec.buildenv

mkdir -p %buildroot/boot
# (Could strip out non-public symbols.)
cp -p System.map %buildroot/boot/System.map-%kernelrelease-%build_flavor

add_vmlinux()
{
    local vmlinux=boot/vmlinux-%kernelrelease-%build_flavor

    cp vmlinux %buildroot/$vmlinux
    # make sure that find-debuginfo.sh picks it up. In the filelist, we
    # mark the file 0644 again
    chmod +x %buildroot/$vmlinux
    if test $1 == "--compressed"; then
        # avoid using the gzip -n option to make kdump happy (bnc#880848#c20)
        ts="$(head -n1 %_sourcedir/source-timestamp)"
        touch -d "$ts" %buildroot/$vmlinux
        touch %buildroot/$vmlinux.gz
%if 0%{?__debug_package:1}
        # compress the vmlinux image after find-debuginfo.sh has processed it
%global __debug_install_post %__debug_install_post \
%_sourcedir/compress-vmlinux.sh %buildroot/boot/vmlinux-%kernelrelease-%build_flavor
%else
        %_sourcedir/compress-vmlinux.sh %buildroot/$vmlinux
%endif
        ghost_vmlinux=true
    else
        ghost_vmlinux=false
    fi
}

# architecture specifics
%ifarch %ix86 x86_64
    add_vmlinux --compressed
    image=bzImage
    cp -p arch/x86/boot/$image %buildroot/boot/vmlinuz-%kernelrelease-%build_flavor
    image=vmlinuz
%endif
%ifarch ppc ppc64 ppc64le
    add_vmlinux
    image=vmlinux
%endif
%ifarch s390 s390x
    add_vmlinux --compressed
    cp -p arch/s390/boot/image %buildroot/boot/image-%kernelrelease-%build_flavor
    image=image
    if test -e arch/s390/boot/kerntypes.o; then
        cp -p arch/s390/boot/kerntypes.o %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor
    elif test -x "$(which dwarfextract 2>/dev/null)"; then
	dwarfextract vmlinux %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor || echo "dwarfextract failed ($?)"
    fi
%if %CONFIG_KMSG_IDS == "y"
    mkdir -p %buildroot/usr/share/man/man9
    find man -name '*.9' -exec install -m 644 -D '{}' %buildroot/usr/share/man/man9/ ';'
%endif
%endif
%ifarch %arm
    add_vmlinux --compressed
    image=zImage
    cp -p arch/arm/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif
%ifarch aarch64
    add_vmlinux --compressed
    image=Image
    cp -p arch/arm64/boot/$image %buildroot/boot/$image-%kernelrelease-%build_flavor
%endif

if test -x /usr/lib/rpm/pesign/gen-hmac; then
	$_ -r %buildroot /boot/$image-%kernelrelease-%build_flavor
fi

# Package the compiled-in certificates as DER files in /etc/uefi/certs
# and have mokutil enroll them when the kernel is installed
certs=()
if test %CONFIG_MODULE_SIG = "y"; then
    for f in %_sourcedir/*.crt; do
            if ! test -s "$f"; then
                    continue
            fi
            h=$(openssl x509 -inform PEM -fingerprint -noout -in "$f")
            test -n "$h"
            cert=/etc/uefi/certs/$(echo "$h" | \
                sed -rn 's/^SHA1 Fingerprint=//; T; s/://g; s/(.{8}).*/\1/p').crt
            if test -e %buildroot/"$cert"; then
                    continue
            fi
            mkdir -p %buildroot/etc/uefi/certs
            openssl x509 -inform PEM -in "$f" -outform DER -out %buildroot/"$cert"
            certs=("${certs[@]}" "$cert")
    done
fi

for sub in '-base' '' '-extra'; do
    case "$sub" in
    '-base' | '') base_package=1 ;;
    *) base_package=0 ;;
    esac
    for script in preun postun pre post devel-pre devel-post; do
        if test %build_flavor = "zfcpdump"; then
            : >%my_builddir/$script$sub.sh
            continue
        fi
        sed -e "s:@KERNELRELEASE@:%kernelrelease:g" \
            -e "s:@IMAGE@:$image:g" \
            -e "s:@FLAVOR""@:%build_flavor:g" \
            -e "s:@SUBPACKAGE@:%name$sub:g" \
            -e "s:@BASE_PACKAGE@:$base_package:g" \
            -e "s:@RPM_VERSION_RELEASE@:%version-%release:g" \
            -e "s:@RPM_TARGET_CPU@:%_target_cpu:g" \
	    -e "s:@CPU_ARCH_FLAVOR@:%cpu_arch_flavor:g" \
            -e "s:@SRCVARIANT@:%variant:g" \
            %_sourcedir/$script.sh > %my_builddir/$script$sub.sh
        if test "$base_package" -eq 1 -a "${#certs[@]}" -gt 0; then
            case "$script" in
            preun | postun | post)
                # Copy the respective scriptlet from kernel-cert-subpackage
                sed "1,/^%%$script / d; /^%%[^%%]/,\$ d; s:@CERTS@:${certs[*]}:g" \
                    %_sourcedir/kernel-cert-subpackage \
                    >>"%my_builddir/$script$sub.sh"
            esac
        fi
	# Do an exit 0 at the end of each scriptlet. If the last real command
	# in the scriptlet (e.g. update-bootloader call, see bnc#809617)
	# returns an error, we do not want to amplify the damage by leaving
	# the system in an inconsistent state.
	echo "exit 0" >>"%my_builddir/$script$sub.sh"
    done
done

%if %build_vanilla
# keep this -suffix list in sync with post.sh and postun.sh
suffix=-%build_flavor
%endif
ln -s $image$suffix %buildroot/boot/$image$suffix
ln -s initrd$suffix %buildroot/boot/initrd$suffix

cp -p .config %buildroot/boot/config-%kernelrelease-%build_flavor
sysctl_file=%buildroot/boot/sysctl.conf-%kernelrelease-%build_flavor
for file in %my_builddir/sysctl/{defaults,%cpu_arch/arch-defaults,%cpu_arch_flavor}; do
	if [ -f "$file" ]; then
		cat "$file"
	fi
done | sed '1i # Generated file - do not edit.' >$sysctl_file
if [ ! -s $sysctl_file ]; then
	rm $sysctl_file
fi

%if %install_vdso
# Install the unstripped vdso's that are linked in the kernel image
make vdso_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot
rm -rf %buildroot/lib/modules/%kernelrelease-%build_flavor/vdso/.build-id
%endif

# Create a dummy initrd with roughly the size the real one will have.
# That way, YaST will know that this package requires some additional
# space in /boot.
dd if=/dev/zero of=%buildroot/boot/initrd-%kernelrelease-%build_flavor \
	bs=1024 seek=2047 count=1
# Also reserve some space for the kdump initrd
cp %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%if 0%{?suse_version} >= 1500
# Use same permissions as dracut
chmod 0600 %buildroot/boot/initrd-%kernelrelease-%build_flavor{,-kdump}
%endif

if [ %CONFIG_MODULES = y ]; then
    mkdir -p %rpm_install_dir/%cpu_arch_flavor
    mkdir -p %buildroot/usr/src/linux-obj/%cpu_arch
    ln -s %build_flavor %buildroot/usr/src/linux-obj/%cpu_arch_flavor
    install -m 755 -D -t %rpm_install_dir/%cpu_arch_flavor/scripts/mod/ scripts/mod/ksym-provides

    gzip -n -c9 < Module.symvers > %buildroot/boot/symvers-%kernelrelease-%build_flavor.gz

    make modules_install $MAKE_ARGS INSTALL_MOD_PATH=%buildroot

%ifarch s390 s390x
    if test -e arch/s390/boot/kerntypes.o; then
        :
    elif test -x "$(which dwarfextract 2>/dev/null)" -a \
	-f %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor; then
	find %buildroot -name "*.ko" > kofiles.list
	dwarfextract %buildroot/boot/Kerntypes-%kernelrelease-%build_flavor -C kofiles.list || echo "dwarfextract failed ($?)"
    fi
%endif

    # Also put the resulting file in %rpm_install_dir/%cpu_arch/%build_flavor
    # so that kernel-devel + kernel-%build_flavor is sufficient for building
    # modules that have modversions as well.
    mkdir -p %rpm_install_dir/%cpu_arch/%build_flavor
    cp Module.symvers %rpm_install_dir/%cpu_arch/%build_flavor

    # List of symbols that are used to generate kernel livepatches
    %if 0%{?klp_symbols}
        cp Symbols.list %rpm_install_dir/%cpu_arch/%build_flavor
    %endif

    # Table of types used in exported symbols (for modversion debugging).
    %_sourcedir/modversions --pack . > %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    if [ -s %buildroot/boot/symtypes-%kernelrelease-%build_flavor ]; then
	gzip -n -9 %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    else
	rm -f %buildroot/boot/symtypes-%kernelrelease-%build_flavor
    fi

    # Some architecture's $(uname -m) output is different from the ARCH
    # parameter that needs to be passed to kbuild. Create symlinks from
    # $(uname -m) to the ARCH directory.
    if [ ! -e %rpm_install_dir/%kmp_target_cpu ]; then
        ln -sf %cpu_arch %rpm_install_dir/%kmp_target_cpu
        ln -sf %cpu_arch %buildroot/usr/src/linux-obj/%kmp_target_cpu
    fi

    # We were building in %my_builddir/linux-%srcversion, but the sources will
    # later be installed in /usr/src/linux-%srcversion-%source_rel. Fix up the
    # build symlink.
    rm -f %buildroot/lib/modules/%kernelrelease-%build_flavor/{source,build}
    ln -s %src_install_dir \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/source
    ln -s %obj_install_dir/%cpu_arch/%build_flavor \
	%buildroot/lib/modules/%kernelrelease-%build_flavor/build

    # Abort if there are any undefined symbols
    msg="$(/sbin/depmod -F %buildroot/boot/System.map-%kernelrelease-%build_flavor \
			-b %buildroot -ae %kernelrelease-%build_flavor 2>&1)"
    if [ $? -ne 0 ] || echo "$msg" | grep  'needs unknown symbol'; then
	exit 1
    fi

    %_sourcedir/split-modules -d %buildroot \
	-o %my_builddir \
	-b %kernel_build_dir \
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	-e \
%endif
%if ! %supported_modules_check
	-i \
%endif
	%nil
%if ! %split_extra
    cat %my_builddir/unsupported-modules >>%my_builddir/main-modules
%endif

    # The modules.dep file is sorted randomly which produces strange file
    # checksums. As the file is not included in the resulting RPM, it's
    # pointless to rely on its contents. Replacing by zeros to make the
    # checksums always the same for several builds of the same package.
    test -s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep && \
    dd if=/dev/zero of=%buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep ibs=`stat -c%s %buildroot/lib/modules/%kernelrelease-%build_flavor/modules.dep` count=1

    res=0
    if test -e %my_builddir/kabi/%cpu_arch/symvers-%build_flavor; then
        # check for kabi changes
        %_sourcedir/kabi.pl --rules %my_builddir/kabi/severities \
            %my_builddir/kabi/%cpu_arch/symvers-%build_flavor \
            Module.symvers || res=$?
    fi
    if [ $res -ne 0 ]; then
	# %ignore_kabi_badness is defined in the Kernel:* projects in the
	# OBS to be able to build the KOTD in spite of kabi errors
	if [ 0%{?ignore_kabi_badness} -eq 0 -a \
	     ! -e %my_builddir/kabi/%cpu_arch/ignore-%build_flavor -a \
	     ! -e %_sourcedir/IGNORE-KABI-BADNESS ]; then
	    echo "Create a file IGNORE-KABI-BADNESS in the kernel-source" \
		 "directory to build this kernel even though its badness is" \
		 "higher than allowed for an official kernel."
	   exit 1
	fi
    fi

    # Check the license in each module
    if ! sh %_sourcedir/check-module-license %buildroot; then
	echo "Please fix the missing licenses!"
%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
	exit 1
%endif
    fi

    # These files are required for building external modules
    for FILE in arch/powerpc/lib/crtsavres.o arch/arm64/kernel/ftrace-mod.o arch/*/kernel/macros.s; do
	    if [ -f %kernel_build_dir/$FILE ]; then
		echo $FILE >> %my_builddir/obj-files
	    fi
    done

    tar -cf - -T %my_builddir/obj-files | \
	tar -xf - -C %rpm_install_dir/%cpu_arch_flavor
    # bnc#507084
    find %rpm_install_dir/%cpu_arch_flavor/scripts -type f -perm -111 | \
        while read f; do
            case "$(file -b "$f")" in
            ELF\ *\ executable*)
                strip "$f"
            esac
        done
    # Recreate the generated Makefile with correct path
    sh ../scripts/mkmakefile ../../../%{basename:%src_install_dir} \
        %rpm_install_dir/%cpu_arch_flavor \
        $(echo %srcversion | sed -r 's/^([0-9]+)\.([0-9]+).*/\1 \2/')
fi

rm -rf %{buildroot}/lib/firmware

add_dirs_to_filelist() {
    sed -rn '
        # print file name
        p
        # remove filelist macros
        s:%%[a-z]+(\([^)]+\))? ?::g
        # add %%dir prefix
        s:^:%%dir :
        # print all parents
        :a
            # skip directories owned by other packages
            s:^%%dir (/boot|/etc|/lib/(modules|firmware)|/usr/src)/[^/]+$::
            s:/[^/]+$::p
        ta
    ' "$@" | sort -u
}

# Collect the file lists.
shopt -s nullglob dotglob
> %my_builddir/kernel-devel.files
for file in %buildroot/boot/symtypes* %buildroot/lib/modules/*/{build,source}; do
	f=${file##%buildroot}
	echo "$f"
done | add_dirs_to_filelist >%my_builddir/kernel-devel.files

{   cd %buildroot
    for f in boot/*; do
        if test -L "$f"; then
            echo "%%ghost /$f"
            continue
        elif test ! -f "$f"; then
            continue
        fi
        case "$f" in
        boot/initrd-*)
            echo "%%ghost /$f"
            continue
            ;;
        boot/vmlinux-*.gz)
            ;;
        boot/vmlinux-*)
            if $ghost_vmlinux; then
                echo "%%ghost /$f"
                continue
            fi
            ;;
        boot/symtypes*)
            continue
            ;;
        esac
        echo "%%attr(0644, root, root) /$f"
    done

    if [ %CONFIG_MODULES = y ]; then
	find lib/modules/%kernelrelease-%build_flavor \
	    -type d -o \
	    \( -path '*/modules.*' ! -path '*/modules.order' \
	     ! -path '*/modules.builtin' \) -printf '%%%%ghost /%%p\n' \
	       -o -name '*.ko' -prune -o -type f -printf '/%%p\n'
	cat %my_builddir/base-modules
    fi
    if test %CONFIG_MODULE_SIG = "y" -a -d etc/uefi/certs; then
        find etc/uefi/certs -type f -printf '/%%p\n'
    fi
    if test -d lib/firmware/%kernelrelease-%build_flavor; then
        echo "%%dir /lib/firmware/%kernelrelease-%build_flavor"
        cat %my_builddir/base-firmware
    fi
    if [ -e .%_docdir/%name ]; then
	echo "%%doc %_docdir/%name"
    fi
} | sort -u | add_dirs_to_filelist >%my_builddir/kernel-base.files

{
    add_dirs_to_filelist %my_builddir/{kernel-base.files,main-modules}
    if test -d %buildroot/lib/firmware/%kernelrelease-%build_flavor; then
	echo "/lib/firmware/%kernelrelease-%build_flavor"
    fi
} > %my_builddir/kernel-main.files
%if %split_extra
    add_dirs_to_filelist %my_builddir/unsupported-modules > %my_builddir/kernel-extra.files

%if 0%{?sle_version} >= 150000
    # By default, loading unsupported modules is disabled on SLE through
    # /etc/modprobe.d/10-unsupported-modules.conf from the suse-module-tools
    # package.
    # modules in kernel-$flavor-extra don't have the supported flag set,
    # yet loading them should be possible if the package is installed.
    # CAUTION PACKAGERS: The file content below must not change between
    # kernel versions, otherwise file conflicts might arise with
    # multiversion(kernel).

    mkdir -p %buildroot/etc/modprobe.d
    cat >%buildroot/etc/modprobe.d/20-kernel-%{build_flavor}-extra.conf <<EOF
# This file overrides the default from 10-unsupported-modules.conf.
# This is necessary to load kernel modules from the
# kernel-%{build_flavor}-extra package.
#
# WARNING: loading unsupported modules may compromise SLE support.
# Please read the comments in 10-unsupported-modules.conf.
allow_unsupported_modules 1
EOF
    echo "%%dir /etc/modprobe.d" >> %my_builddir/kernel-extra.files
    echo '%%config(noreplace) /etc/modprobe.d/20-kernel-%{build_flavor}-extra.conf' >> %my_builddir/kernel-extra.files
%endif
%endif
for f in %my_builddir/*-kmp-modules; do
	f2=${f%%-modules}.files
	add_dirs_to_filelist "$f" >"$f2"
done

if [ %CONFIG_MODULES = y ]; then
  install -m 644 %_sourcedir/modules.fips %{buildroot}/lib/modules/%kernelrelease-%build_flavor/modules.fips
  echo /lib/modules/%kernelrelease-%build_flavor/modules.fips >> %my_builddir/kernel-base.files
  echo /lib/modules/%kernelrelease-%build_flavor/modules.fips >> %my_builddir/kernel-main.files
fi

# Hardlink duplicate files automatically (from package fdupes): It doesn't save
# much, but it keeps rpmlint from breaking the package build. Note that we skip
# /usr/src/linux-obj intentionally, to not accidentally break timestamps there
%fdupes $RPM_BUILD_ROOT/lib

%preun -f preun.sh

%postun -f postun.sh

%pre -f pre.sh

%post -f post.sh

%files -f kernel-main.files
%defattr(-, root, root)

%if %CONFIG_MODULES == "y"
%package base
Summary:        The Standard Kernel - without any SUSE patches - base modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       kernel-base = %version-%source_rel
Provides:       multiversion(kernel)
Conflicts:      %name = %version-%source_rel
Requires(pre):  coreutils awk
# For /usr/lib/module-init-tools/weak-modules2
Requires(post): suse-module-tools
# For depmod (modutils is a dependency provided by both module-init-tools and
# kmod-compat)
Requires(post): modutils
# This Requires is wrong, because the post/postun scripts have a
# test -x update-bootloader, having perl-Bootloader is not a hard requirement.
# But, there is no way to tell rpm or yast to schedule the installation
# of perl-Bootloader before kernel-binary.rpm if both are in the list of
# packages to install/update. Likewise, this is true for mkinitrd.
# Need a perl-Bootloader with /usr/lib/bootloader/bootloader_entry
Requires(post): perl-Bootloader >= 0.4.15
%if %build_vanilla
Requires(post): mkinitrd
%else
# Require a mkinitrd that can handle usbhid/hid-generic built-in (bnc#773559)
Requires(post): mkinitrd >= 2.7.1
%endif
# Install the package providing /etc/SuSE-release early enough, so that
# the grub entry has correct title (bnc#757565)
Requires(post): distribution-release
# Do not install p-b and mkinitrd for the install check, the %post script is
# able to handle this
#!BuildIgnore: perl-Bootloader mkinitrd distribution-release
# Remove some packages that are installed automatically by the build system,
# but are not needed to build the kernel
#!BuildIgnore: autoconf automake gettext-runtime libtool cvs gettext-tools udev insserv

%ifarch s390 s390x
%if %build_vanilla && 0%{?suse_version} < 1130
BuildRequires:  dwarfextract
%endif
%endif
%ifarch %arm
BuildRequires:  u-boot-tools
%endif

Obsoletes:      microcode_ctl

# Force bzip2 instead of lzma compression to
# 1) allow install on older dist versions, and
# 2) decrease build times (bsc#962356)
%define _binary_payload w9.bzdio
# Do not recompute the build-id of vmlinux in find-debuginfo.sh (bsc#964063)
%undefine _unique_build_ids
%define _no_recompute_build_ids 1
# prevent usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
%undefine _unique_debug_names
# dead network if installed on SLES10, otherwise it will work (mostly)
Conflicts:      sysfsutils < 2.0
Conflicts:      apparmor-profiles <= 2.1
Conflicts:      apparmor-parser < 2.3
# root-lvm only works with newer udevs
Conflicts:      udev < 118
Conflicts:      lvm2 < 2.02.33
# Interface to hv_kvp_daemon changed
Conflicts:      hyper-v < 4
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif
Provides:       kernel = %version-%source_rel
Provides:       kernel-%build_flavor-base-srchash-172ca35fe5f35b6aa250c773fc1943deedcbaa81
Provides:       kernel-srchash-172ca35fe5f35b6aa250c773fc1943deedcbaa81

%obsolete_rebuilds %name-base
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description base
The standard kernel - without any SUSE patches

This package contains only the base modules, required in all installs.


%source_timestamp
%preun base -f preun-base.sh

%postun base -f postun-base.sh

%pre base -f pre-base.sh

%post base -f post-base.sh

%files base -f kernel-base.files
%defattr(-, root, root)
%endif

%package extra
Summary:        The Standard Kernel - without any SUSE patches - Unsupported kernel modules
Group:          System/Kernel
Url:            http://www.kernel.org/
Provides:       %name-extra_%_target_cpu = %version-%source_rel
Provides:       kernel-extra = %version-%source_rel
Provides:       multiversion(kernel)
Requires:       %{name}_%_target_cpu = %version-%source_rel
Requires(pre):  coreutils awk
Requires(post): modutils
Requires(post): perl-Bootloader
Requires(post): mkinitrd
%obsolete_rebuilds %name-extra
Supplements:    packageand(product(SLED):%{name}_%_target_cpu)
Supplements:    packageand(product(sle-we):%{name}_%_target_cpu)
%ifarch %ix86
Conflicts:      libc.so.6()(64bit)
%endif

%description extra
The standard kernel - without any SUSE patches

This package contains additional modules not supported by Novell.


%source_timestamp
%preun extra -f preun-extra.sh

%postun extra -f postun-extra.sh

%pre extra -f pre-extra.sh

%post extra -f post-extra.sh

%if %split_extra

%files extra -f kernel-extra.files
%defattr(-, root, root)
%endif

%if %CONFIG_KMSG_IDS == "y"

%package man
Summary:        The collection of man pages generated by the kmsg script
Group:          System/Kernel

%description man
This package includes the man pages that have been generated from the
kmsg message documentation comments.


%source_timestamp
%files man
%defattr(-,root,root)
/usr/share/man/man9/*
%endif

%package devel
Summary:        Development files necessary for building kernel modules
Group:          Development/Sources
Provides:       %name-devel = %version-%source_rel
Provides:       multiversion(kernel)
%if ! %build_vanilla
Requires:       kernel-devel%variant = %version-%source_rel
Recommends:     make
Recommends:     gcc
Recommends:     perl
# for objtool
Requires:	libelf-devel
Supplements:    packageand(%name:kernel-devel%variant)
%else
Requires:       kernel-source-vanilla = %version-%source_rel
Supplements:    packageand(%name:kernel-source-vanilla)
%endif
%obsolete_rebuilds %name-devel
PreReq:         coreutils

%description devel
This package contains files necessary for building kernel modules (and
kernel module packages) against the %build_flavor flavor of the kernel.


%source_timestamp

%if %CONFIG_MODULES == "y"

%pre devel -f devel-pre.sh

%post devel -f devel-post.sh

%files devel -f kernel-devel.files
%defattr(-,root,root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir /usr/src/linux-obj
%dir /usr/src/linux-obj/%cpu_arch
%ghost /usr/src/linux-obj/%cpu_arch_flavor
%obj_install_dir/%cpu_arch_flavor
%exclude %obj_install_dir/%cpu_arch_flavor/Symbols.list
%if %kmp_target_cpu != %cpu_arch
%obj_install_dir/%kmp_target_cpu
/usr/src/linux-obj/%kmp_target_cpu
%endif

%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
%package livepatch
Summary:        Metapackage to pull in matching kernel-livepatch package
Group:          System/Kernel
Requires:       kernel-livepatch-%(echo %version-%source_rel | sed 'y/\./_/')-%build_flavor
Provides:	kernel-default-kgraft = %version
Provides:	kernel-xen-kgraft = %version
Provides:       multiversion(kernel)
Obsoletes:	kernel-default-kgraft < %version
Obsoletes:	kernel-xen-kgraft < %version

%description livepatch
This is a metapackage that pulls in the matching kernel-livepatch package for a
given kernel version. The advantage of the metapackage is that its name is
static, unlike the kernel-livepatch-<kernel-version>-flavor package names.

%files livepatch
# rpmlint complains about empty packages, so lets own something
%defattr(-, root, root)
%dir /lib/modules/%kernelrelease-%build_flavor
%endif

%if 0%{?klp_symbols}

%package livepatch-devel
Summary:	Kernel symbols file used during livepatch development
Group:		System/Kernel
Provides:	klp-symbols = %version

%description livepatch-devel
This package brings a file named Symbols.list, which contains a list of all
kernel symbols and its respective kernel object . This list is to be used by
the klp-convert tool, which helps livepatch developers by enabling automatic
symbol resolution.

%files livepatch-devel
%defattr(-, root, root)
%dir %obj_install_dir
%dir %obj_install_dir/%cpu_arch
%dir %obj_install_dir/%cpu_arch_flavor/
%obj_install_dir/%cpu_arch_flavor/Symbols.list

%endif

%if %CONFIG_SUSE_KERNEL_SUPPORTED == "y"
%package -n cluster-md-kmp-%build_flavor
Summary:        Clustering support for MD devices
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       cluster-md-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n cluster-md-kmp-%build_flavor
Clustering support for MD devices. This enables locking and
synchronization across multiple systems on the cluster, so all
nodes in the cluster can access the MD devices simultaneously.

%post -n cluster-md-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=cluster-md-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n cluster-md-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n cluster-md-kmp-%build_flavor
nvr=cluster-md-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n cluster-md-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=cluster-md-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n cluster-md-kmp-%build_flavor -f cluster-md-kmp.files
%defattr(-, root, root)

%package -n dlm-kmp-%build_flavor
Summary:        DLM kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       dlm-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4

%description -n dlm-kmp-%build_flavor
DLM stands for Distributed Lock Manager, a means to synchronize access to
shared resources over the cluster.

%post -n dlm-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=dlm-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n dlm-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n dlm-kmp-%build_flavor
nvr=dlm-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n dlm-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=dlm-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n dlm-kmp-%build_flavor -f dlm-kmp.files
%defattr(-, root, root)

%package -n gfs2-kmp-%build_flavor
Summary:        GFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       gfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n gfs2-kmp-%build_flavor
GFS2 is Global Filesystem, a shared device filesystem.

%post -n gfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=gfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n gfs2-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n gfs2-kmp-%build_flavor
nvr=gfs2-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n gfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=gfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n gfs2-kmp-%build_flavor -f gfs2-kmp.files
%defattr(-, root, root)

%package -n kselftests-kmp-%build_flavor
Summary:        Kernel sefltests
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       kselftests-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4

%description -n kselftests-kmp-%build_flavor
This package contains kernel modules which are part of the upstream kernel
selftest effort. kselftest is the name of the upstream kernel target to build
and run all selftests. You can also run each test individually from the
respective upstream tools/testing/selftests/ directory, this package is
intended to be used using individial upstream selftest scripts given only
select supported selftest drivers are enabled.

It should always be possible to always run the latest linux-next version of the
selftest scripts and tests against any older kernel selftest driver.  Certain
tests facilities may be backported onto older kernels to enable further
testing.

Selftests also provide for a vehicle or proof of concept issues to be
reproduced, verified and corrected.

Selftest drivers are intended to be supported only in testing and QA
environments, they are not intended to be run on production systems.

%post -n kselftests-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=kselftests-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n kselftests-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n kselftests-kmp-%build_flavor
nvr=kselftests-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n kselftests-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=kselftests-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n kselftests-kmp-%build_flavor -f kselftests-kmp.files
%defattr(-, root, root)

%package -n ocfs2-kmp-%build_flavor
Summary:        OCFS2 kernel modules
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       ocfs2-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4
Requires:       dlm-kmp-%build_flavor = %version-%release

%description -n ocfs2-kmp-%build_flavor
OCFS2 is the Oracle Cluster Filesystem, a filesystem for shared devices
accessible simultaneously from multiple nodes of a cluster.

%post -n ocfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=ocfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n ocfs2-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n ocfs2-kmp-%build_flavor
nvr=ocfs2-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n ocfs2-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=ocfs2-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n ocfs2-kmp-%build_flavor -f ocfs2-kmp.files
%defattr(-, root, root)

%package -n reiserfs-kmp-%build_flavor
Summary:        Reiserfs kernel module
Group:          System/Kernel
Requires:       %name = %version-%source_rel
Provides:       reiserfs-kmp = %version-%source_rel
Provides:       multiversion(kernel)
# tell weak-modules2 to ignore this package
Provides:       kmp_in_kernel
Requires(post): suse-module-tools >= 12.4

%description -n reiserfs-kmp-%build_flavor
The reiserfs file system is no longer supported in SLE15.  This package
provides the reiserfs module for the installation system.

%post -n reiserfs-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=reiserfs-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	rpm -ql "$nvr" | INITRD_IN_POSTTRANS=1 /bin/bash -${-/e/} "$wm2" \
	--add-kernel-modules %kernelrelease-%build_flavor
fi

%posttrans -n reiserfs-kmp-%build_flavor
%{?regenerate_initrd_posttrans}

%preun -n reiserfs-kmp-%build_flavor
nvr=reiserfs-kmp-%build_flavor-%version-%release
rpm -ql "$nvr" | grep '\.ko$' > "/var/run/rpm-$nvr-modules"

%postun -n reiserfs-kmp-%build_flavor
wm2=/usr/lib/module-init-tools/weak-modules2
nvr=reiserfs-kmp-%build_flavor-%version-%release
if test -x "$wm2"; then
	/bin/bash -${-/e/} "$wm2" < "/var/run/rpm-$nvr-modules" \
	--remove-kernel-modules %kernelrelease-%build_flavor
fi
rm -f "/var/run/rpm-$nvr-modules"

%files -n reiserfs-kmp-%build_flavor -f reiserfs-kmp.files
%defattr(-, root, root)

%endif # %CONFIG_SUSE_KERNEL_SUPPORTED
%endif # %CONFIG_MODULES

%changelog
* Mon Oct  7 2019 jgross@suse.com
- xen/xenbus: fix self-deadlock after killing user process
  (bsc#1065600).
- commit 76e2ca6
* Mon Oct  7 2019 pvorel@suse.cz
- alarmtimer: Use EOPNOTSUPP instead of ENOTSUPP (bsc#1151680).
- commit dc03fff
* Mon Oct  7 2019 jgross@suse.com
- xen-netfront: do not use ~0U as error return value for
  xennet_fill_frags() (bsc#1065600).
- commit f1c5e2e
* Fri Oct  4 2019 wqu@suse.com
- btrfs: qgroup: Fix reserved data space leak if we have  multiple
  reserve calls (bsc#1152975).
- commit dd30f55
* Fri Oct  4 2019 wqu@suse.com
- btrfs: qgroup: Fix the wrong target io_tree when freeing
  reserved data space (bsc#1152974).
- commit c3a2587
* Fri Oct  4 2019 wqu@suse.com
- btrfs: relocation: fix use-after-free on dead relocation  roots
  (bsc#1152972).
- commit 24ae263
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/irq: Don't WARN continuously in arch_local_irq_restore()
  (bsc#1065729).
- powerpc/module64: Fix comment in R_PPC64_ENTRY handling
  (bsc#1065729).
- powerpc: Drop page_is_ram() and walk_system_ram_range()
  (bsc#1065729).
- powerpc/powernv/npu: Remove obsolete comment about
  TCE_KILL_INVAL_ALL (bsc#1065729).
- powerpc/irq: drop arch_early_irq_init() (bsc#1065729).
- powerpc/mm: Use memblock API for PPC32 page_is_ram
  (bsc#1065729).
- powerpc/mm: Simplify page_is_ram by using memblock_is_memory
  (bsc#1065729).
- commit d2ea316
* Thu Oct  3 2019 pmladek@suse.com
- blacklist.conf: There are too many locks involved and the race is rather
  theoretical. Better to do not play with matches (bsc#1152325)
- Delete
  patches.suse/ftrace-x86-remove-possible-deadlock-between-register_kprobe-and-ftrace_run_update_code.patch.
- Delete
  patches.suse/module-fix-livepatch-ftrace-module-text-permissions-race.patch.
- commit 3ca917a
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/pseries/memory-hotplug: Fix return value type of
  find_aa_index (bsc#1065729).
- commit fea5480
* Thu Oct  3 2019 msuchanek@suse.de
- blacklist.conf: Add fixes for unsupported ppc features.
  813af51f5d30 powerpc/boot: Set target when cross-compiling for clang
  aea447141c7e powerpc: Disable -Wbuiltin-requires-header when setjmp is
  a521c44c3ded powerpc/book3e: drop mmu_get_tsize()
- commit 1c86730
* Thu Oct  3 2019 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix lockdep warning when entering the guest
  (bsc#1061840).
- commit 096c2a9
* Thu Oct  3 2019 msuchanek@suse.de
- powerpc/pseries: Call H_BLOCK_REMOVE when supported
  (bsc#1109158).
- powerpc/pseries: Read TLB Block Invalidate Characteristics
  (bsc#1109158).
- commit ed9227d
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/powernv: Fix compile without CONFIG_TRACEPOINTS
  (bsc#1065729).
- commit 9467589
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/xive: Fix bogus error code returned by OPAL
  (bsc#1065729).
- powerpc/powernv: move OPAL call wrapper tracing and interrupt
  handling to C (bsc#1065729).
- commit 8fcebeb
* Wed Oct  2 2019 msuchanek@suse.de
- blacklist.conf: Add duplicate commit id.
- commit 0b5d9ab
* Wed Oct  2 2019 msuchanek@suse.de
- net/ibmvnic: prevent more than one thread from running in reset
  (bsc#1152457 ltc#174432).
- net/ibmvnic: unlock rtnl_lock in reset so linkwatch_event can
  run (bsc#1152457 ltc#174432).
- commit f425435
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/mm: Fixup tlbie vs mtpidr/mtlpidr ordering issue on
  POWER9 (bsc#1152161 ltc#181664).
- commit 1b17584
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/book3s64/radix: Rename CPU_FTR_P9_TLBIE_BUG feature flag
  (bsc#1152161 ltc#181664).
- commit 2a753e0
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/book3s64/mm: Don't do tlbie fixup for some hardware
  revisions (bsc#1152161 ltc#181664).
- commit e22d3e6
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/mm/radix: implement LPID based TLB flushes to be used by KVM
  (bsc#1152161 ltc#181664).
- Refresh patches.suse/powerpc-64s-Remove-POWER9-DD1-support.patch.
- commit 1f54c64
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/64s/radix: Fix MADV_[FREE|DONTNEED] TLB flush miss
  problem with THP (bsc#1152161 ltc#181664).
- commit d7b6f7c
* Wed Oct  2 2019 jslaby@suse.cz
- ppp: Fix memory leak in ppp_write (git-fixes).
- commit b2ea0ab
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/64s/radix: Improve TLB flushing for page table freeing (bsc#1152161 ltc#181664).
- Refresh patches.suse/powerpc-mm-Fix-typo-in-comments.patch.
- Refresh patches.suse/powerpc-mm-Fixup-tlbie-vs-store-ordering-issue-on-PO.patch.
- Refresh patches.suse/powerpc-mm-Workaround-Nest-MMU-bug-with-TLB-invalida.patch.
- Refresh patches.suse/powerpc-mm-radix-Move-the-functions-that-does-the-ac.patch.
- commit 90cdc09
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/64s/radix: Optimize flush_tlb_range (bsc#1152161 ltc#181664).
- Refresh patches.suse/powerpc-mm-Fixup-tlbie-vs-store-ordering-issue-on-PO.patch.
- Refresh patches.suse/powerpc-mm-Workaround-Nest-MMU-bug-with-TLB-invalida.patch.
- Refresh patches.suse/powerpc-mm-radix-Move-the-functions-that-does-the-ac.patch.
- commit 80c5a9e
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/64s/radix: Implement _tlbie(l)_va_range flush functions (bsc#1152161 ltc#181664).
- Refresh patches.suse/powerpc-mm-Fixup-tlbie-vs-store-ordering-issue-on-PO.patch.
- Refresh patches.suse/powerpc-mm-Workaround-Nest-MMU-bug-with-TLB-invalida.patch.
- Refresh patches.suse/powerpc-mm-radix-Move-the-functions-that-does-the-ac.patch.
- commit ab2f8fa
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/64s/radix: Improve preempt handling in TLB code (bsc#1152161 ltc#181664).
- Refresh patches.suse/powerpc-64s-radix-Optimize-TLB-range-flush-barriers.patch.
- Refresh patches.suse/powerpc-mm-Fixup-tlbie-vs-store-ordering-issue-on-PO.patch.
- Refresh patches.suse/powerpc-mm-Workaround-Nest-MMU-bug-with-TLB-invalida.patch.
- Refresh patches.suse/powerpc-mm-radix-Drop-unneeded-NULL-check.patch.
- Delete patches.suse/powerpc-64s-radix-Fix-preempt-imbalance-in-TLB-flush.patch.
- blacklist.conf: Add the above.
- commit b3a8f87
* Wed Oct  2 2019 msuchanek@suse.de
- powerpc/mm/radix: Drop unneeded NULL check (bsc#1152161
  ltc#181664).
- commit 60ee413
* Wed Oct  2 2019 lhenriques@suse.com
- ceph: use ceph_evict_inode to cleanup inode's resource
  (bsc#1148133).
- commit 92df5d8
* Wed Oct  2 2019 neilb@suse.de
- SUNRPC: Handle connection breakages correctly in call_status()
  (git-fixes).
- NFS: Remove redundant semicolon (git-fixes).
- commit 1992d65
* Tue Oct  1 2019 mwilck@suse.com
- scsi: scsi_dh_rdac: zero cdb in send_mode_select()
  (bsc#1149313).
- commit 1ec727d
* Tue Oct  1 2019 oneukum@suse.com
- b2c2-flexcop-usb: add sanity checking (bsc#1146540
  CVE-2019-15291).
- commit d70fc3e
* Tue Oct  1 2019 oneukum@suse.com
- mmc: sdhci-msm: fix mutex while in spinlock (bsc#1142635).
- commit 3f5a2a5
* Tue Oct  1 2019 oneukum@suse.com
- blacklist.conf: prerequisites would break kABI
- commit 8bef1d9
* Tue Oct  1 2019 oneukum@suse.com
- mmc: sdhci-of-arasan: Do now show error message in case of
  deffered probe (bsc#1119086).
- commit 0925906
* Tue Oct  1 2019 neilb@suse.de
- Fix kabi for: NFSv4: Fix OPEN / CLOSE race (git-fixes).
- commit fd35a80
* Mon Sep 30 2019 bp@suse.de
- blacklist.conf:
  1b7aebf04876 x86/cacheinfo: Fix a -Wtype-limits warning
- commit fb4c6c4
* Mon Sep 30 2019 pmladek@suse.com
- blacklist.conf: vsprintf: depends on a huge clean up; it is just
  nice to have check
- commit 4581364
* Mon Sep 30 2019 ohering@suse.de
- PCI: hv: Detect and fix Hyper-V PCI domain number collision
  (bsc#1150423).
- commit 867295f
* Mon Sep 30 2019 pmladek@suse.com
- printk: fix printk_time race (bsc#1152466).
- commit 73baed0
* Mon Sep 30 2019 pmladek@suse.com
- Refresh
  patches.suse/panic-avoid-deadlocks-in-re-entrant-console-drivers.patch.
- commit b935bdf
* Mon Sep 30 2019 pmladek@suse.com
- printk: Do not lose last line in kmsg buffer dump (bsc#1152460).
- commit dfb2aad
* Mon Sep 30 2019 pmladek@suse.com
- printk/panic: Avoid deadlock in printk() after stopping CPUs
  by NMI (bsc#1148712).
- commit fc39dab
* Fri Sep 27 2019 bp@suse.de
- x86/tls: Fix possible spectre-v1 in do_get_thread_area()
  (bsc#1114279).
- commit d41bded
* Fri Sep 27 2019 bp@suse.de
- blacklist.conf:
  cae5ec342645 x86/speculation/mds: Fix comment
  693713cbdb3a x86: Hide the int3_emulate_call/jmp functions from UML
- commit bb37420
* Fri Sep 27 2019 mkoutny@suse.com
- blacklist.conf: Add cgroup task listing patches
  They fix psuedozombies listing issues which we don't have in 4.12
  (bsc#1146664).
- commit 9984d9b
* Fri Sep 27 2019 jroedel@suse.de
- KVM: coalesced_mmio: add bounds checking (CVE-2019-14821
  bcs#1151350).
- commit 9f2c41d
* Fri Sep 27 2019 dwagner@suse.de
- scsi: qla2xxx: Downgrade driver to 10.01.00.19-k
  There are upstream bug reports against 10.01.00.19-k which haven't
  been resolved. Also the newer version failed to get a proper review.
  For time being it's better to got with the older version and do not
  introduce new bugs.
- Delete
  patches.suse/scsi-qla2xxx-Add-error-handling-for-PLOGI-ELS-passth.patch.
- Delete
  patches.suse/scsi-qla2xxx-Capture-FW-dump-on-MPI-heartbeat-stop-e.patch.
- Delete
  patches.suse/scsi-qla2xxx-Check-for-MB-timeout-while-capturing-IS.patch.
- Delete
  patches.suse/scsi-qla2xxx-Dual-FCP-NVMe-target-port-support.patch.
- Delete patches.suse/scsi-qla2xxx-Fix-N2N-link-reset.patch.
- Delete patches.suse/scsi-qla2xxx-Fix-N2N-link-up-fail.patch.
- Delete
  patches.suse/scsi-qla2xxx-Fix-stale-mem-access-on-driver-unload.patch.
- Delete
  patches.suse/scsi-qla2xxx-Fix-unbound-sleep-in-fcport-delete-path.patch.
- Delete
  patches.suse/scsi-qla2xxx-Improve-logging-for-scan-thread.patch.
- Delete
  patches.suse/scsi-qla2xxx-Optimize-NPIV-tear-down-process.patch.
- Delete
  patches.suse/scsi-qla2xxx-Set-remove-flag-for-all-VP.patch.
- Delete
  patches.suse/scsi-qla2xxx-Silence-fwdump-template-message.patch.
- Delete
  patches.suse/scsi-qla2xxx-Update-driver-version-to-10.01.00.20-k.patch.
- commit 1c425a3
* Fri Sep 27 2019 mbenes@suse.cz
- livepatch: Nullify obj->mod in klp_module_coming()'s error path
  (bsc#1071995 fate#323487).
- commit fd16e8e
* Fri Sep 27 2019 bp@suse.de
- blacklist.conf: 459e3a21535a gcc-9: properly declare the {pv,hv}clock_page storage
- commit 73936ac
* Fri Sep 27 2019 ptesarik@suse.cz
- Refresh patches with upstream status.
- commit 0e18baf
* Thu Sep 26 2019 bp@suse.de
- Refresh
  patches.suse/0001-x86-speculation-Prepare-entry-code-for-Spectre-v1-sw.patch.
- Refresh
  patches.suse/0002-x86-speculation-Enable-Spectre-v1-swapgs-mitigations.patch.
- Refresh
  patches.suse/x86-speculation-swapgs-exclude-ATOMs-from-speculating-through-SWAPGS.patch.
- commit 74df0fe
* Thu Sep 26 2019 dwagner@suse.de
- qla2xxx: remove SGI SN2 support (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Fix gnl.l memory leak on adapter init failure
  (bsc#1123034 bsc#1131304 bsc#1127988).
- Refresh scsi-qla2xxx-Correct-error-handling-during-initializ.patch
- scsi: qla2xxx: Fix possible fcport null-pointer dereferences
  (bsc#1123034 bsc#1131304 bsc#1127988).
- commit c15b1d3
* Thu Sep 26 2019 bp@suse.de
- EDAC/amd64: Decode syndrome before translating address
  (bsc#1114279).
- commit b995a6d
* Thu Sep 26 2019 dwagner@suse.de
- Refresh scsi-qla2xxx-Capture-FW-dump-on-MPI-heartbeat-stop-e.patch
  882ffc9f07fb ("scsi: qla2xxx: Capture FW dump on MPI heartbeat stop
  event (bsc#1123034 bsc#1131304 bsc#1127988).") placed the
  "vha->hw->fw_dump_mpi = 0" assigment into the __CHECKER__
  section. Upstream placed the assigment before this section.
- commit 28a90c4
* Thu Sep 26 2019 bp@suse.de
- blacklist.conf: Blacklist some
  8faa1cf6ed82 EDAC/altera: Use the proper type for the IRQ status bits
  Driver disabled in .config.
  f8be8e568022 EDAC/amd64: Recognize DRAM device type ECC capability
  Belongs into 15SP1, blacklist here.
- commit 4cf20eb
* Thu Sep 26 2019 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.20-k
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Set remove flag for all VP (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Improve logging for scan thread (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Dual FCP-NVMe target port support (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Check for MB timeout while capturing ISP27/28xx
  FW dump (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Capture FW dump on MPI heartbeat stop event
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add error handling for PLOGI ELS passthrough
  (bsc#1123034 bsc#1131304 bsc#1127988).
- commit eb3d766
* Thu Sep 26 2019 dwagner@suse.de
- Refresh: patches.suse/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch
- commit b19d49f
* Thu Sep 26 2019 jslaby@suse.cz
- ipv6/addrconf: allow adding multicast addr if IFA_F_MCAUTOJOIN
  is set (networking-stable-19_08_28).
- net/smc: make sure EPOLLOUT is raised
  (networking-stable-19_08_28).
- tcp: make sure EPOLLOUT wont be missed
  (networking-stable-19_08_28).
- commit 6d8d1db
* Thu Sep 26 2019 dwagner@suse.de
- scsi: qla2xxx: Remove WARN_ON_ONCE in qla2x00_status_cont_entry() (bsc#1123034 bsc#1131304 bsc#1127988).
- commit 8ada42a
* Thu Sep 26 2019 dwagner@suse.de
- scsi: qla2xxx: Fix Nport ID display value (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix N2N link up fail (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Fix N2N link reset (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Optimize NPIV tear down process (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix stale mem access on driver unload
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix unbound sleep in fcport delete path
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Silence fwdump template message (bsc#1123034
  bsc#1131304 bsc#1127988).
- commit 73ca1b4
* Thu Sep 26 2019 jslaby@suse.cz
- net/packet: fix race in tpacket_snd()
  (networking-stable-19_08_21).
- sctp: fix the transport error_count check
  (networking-stable-19_08_21).
- net/mlx5e: Only support tx/rx pause setting for port owner
  (networking-stable-19_08_21).
- net/mlx5e: Use flow keys dissector to parse packets for ARFS
  (networking-stable-19_08_21).
- team: Add vlan tx offload to hw_enc_features
  (networking-stable-19_08_21).
- bonding: Add vlan tx offload to hw_enc_features
  (networking-stable-19_08_21).
- xen/netback: Reset nr_frags before freeing skb
  (networking-stable-19_08_21).
- commit 62e2750
* Wed Sep 25 2019 bp@suse.de
- x86/fpu: Add FPU state copying quirk to handle XRSTOR failure
  on Intel Skylake CPUs (bsc#1151955).
- commit 0a9d814
* Wed Sep 25 2019 jack@suse.cz
- quota: fix wrong condition in is_quota_modification()
  (bsc#1152026).
- commit 095a54b
* Wed Sep 25 2019 jack@suse.cz
- ext4: fix warning inside ext4_convert_unwritten_extents_endio
  (bsc#1152025).
- commit ef7a3bd
* Wed Sep 25 2019 jack@suse.cz
- ext4: set error return correctly when ext4_htree_store_dirent
  fails (bsc#1152024).
- commit 2af17f9
* Wed Sep 25 2019 mwilck@suse.com
- Refresh patches.suse/0001-qla2xxx-Mask-off-Scope-bits-in-retry-delay.patch.
  Fix minor difference to upstream code.
- commit 81b7c69
* Wed Sep 25 2019 mwilck@suse.com
- scsi: qla2xxx: Fix comment in MODULE_PARM_DESC in qla2xxx (bsc#1123034 bsc#1131304 bsc#1127988).
- commit dc1d180
* Wed Sep 25 2019 mwilck@suse.com
- scsi: qla2xxx: Remove set but not used variable 'ptr_dma' (bsc#1123034 bsc#1131304 bsc#1127988).
- commit d66db00
* Wed Sep 25 2019 mwilck@suse.com
- scsi: qla2xxx: Use dma_pool_zalloc() (bsc#1123034 bsc#1131304 bsc#1127988).
  Refresh
  patches.suse/scsi-qla2xxx-Use-get-put_unaligned-where-appropriate.patch
  and patches.suse/scsi-qla2xxx-Let-the-compiler-check-the-type-of-the-.patch
  to apply cleanly after this addition.
- commit 3b46ec1
* Wed Sep 25 2019 mwilck@suse.com
- Refresh patches.suse/scsi-qla2xxx-Move-marker-request-behind-QPair.patch.
  Add a minor change from upstream merge commit 92fff53b7191.
  This is a trivial change; qla2x00_get_sp() would have set
  sp->fcport = fcport, so the two are equal.
- commit bcfc6fb
* Wed Sep 25 2019 mwilck@suse.com
- Refresh patches.suse/scsi-qla2xxx-fix-driver-unload-by-shutting-down-chip.patch.
  There is a backport error in a102af629d1c, caused by the fact that this patch
  was added to series.conf before 2ce87cc5b269 ("qla2xxx: Fix memory corruption
  during hba reset test"). As a consequence, qla2x00_wait_for_sess_deletion()
  could be called too early.
  Refresh patches.suse/scsi-qla2xxx-Add-Device-ID-for-ISP28XX.patch.
  Amend the patch to apply cleanly after the previous commit.
- commit 56f4ed1
* Wed Sep 25 2019 bp@suse.de
- blacklist.conf: b63f20a778c8 x86/retpoline: Don't clobber RFLAGS during CALL_NOSPEC on i386
  A 32-bit fix.
- commit d1fbc8b
* Wed Sep 25 2019 jslaby@suse.cz
- atm: iphase: Fix Spectre v1 vulnerability
  (networking-stable-19_08_08).
- net: bridge: mcast: don't delete permanent entries when fast
  leave is enabled (networking-stable-19_08_08).
- net: fix ifindex collision during namespace removal
  (networking-stable-19_08_08).
- mvpp2: refactor MTU change code (networking-stable-19_08_08).
- net: bridge: delete local fdb on device init failure
  (networking-stable-19_08_08).
- net: sched: Fix a possible null-pointer dereference in
  dequeue_func() (networking-stable-19_08_08).
- net/mlx5e: Prevent encap flow counter update async to user query
  (networking-stable-19_08_08).
- net/mlx5: Use reversed order when unregister devices
  (networking-stable-19_08_08).
- ip6_tunnel: fix possible use-after-free on xmit
  (networking-stable-19_08_08).
- bnx2x: Disable multi-cos feature (networking-stable-19_08_08).
- ife: error out when nla attributes are empty
  (networking-stable-19_08_08).
- commit cc74b59
* Wed Sep 25 2019 neilb@suse.de
- pNFS/flexfiles: Turn off soft RPC calls (git-fixes).
- NFS: Ensure O_DIRECT reports an error if the bytes read/written
  is 0 (git-fixes).
- NFSv4/pnfs: Fix a page lock leak in nfs_pageio_resend()
  (git-fixes).
- NFS: Fix regression whereby fscache errors are appearing on
  'nofsc' mounts (git-fixes).
- NFSv4: Fix an Oops in nfs4_do_setattr (git-fixes).
- NFSv4: Fix a potential sleep while atomic in nfs4_do_reclaim()
  (git-fixes).
- NFSv4: Check the return value of update_open_stateid()
  (git-fixes).
- NFSv4.1: Only reap expired delegations (git-fixes).
- NFSv4.1: Fix open stateid recovery (git-fixes).
- NFSv4: Fix delegation state recovery (git-fixes).
- pnfs/flexfiles: Fix PTR_ERR() dereferences in
  ff_layout_track_ds_error (git-fixes).
- NFSv4: Handle the special Linux file open access mode
  (git-fixes).
- NFSv4.1: Again fix a race where CB_NOTIFY_LOCK fails to wake
  a waiter (git-fixes).
- SUNRPC fix regression in umount of a secure mount (git-fixes).
- SUNRPC/nfs: Fix return value for nfs4_callback_compound()
  (git-fixes).
- NFS4: Fix v4.0 client state corruption when mount (git-fixes).
- PNFS fallback to MDS if no deviceid found (git-fixes).
- NFS: Don't interrupt file writeout due to fatal errors
  (git-fixes).
- nfsd: Don't release the callback slot unless it was actually
  held (git-fixes).
- NFS: Forbid setting AF_INET6 to "struct sockaddr_in"->sin_family
  (git-fixes).
- NFSv4: Fix lookup revalidate of regular files (git-fixes).
- NFS: Refactor nfs_lookup_revalidate() (git-fixes).
- NFS: Don't open code clearing of delegation state (git-fixes).
- NFSv4: Only pass the delegation to setattr if we're sending
  a truncate (git-fixes).
- NFSv4: Fix OPEN / CLOSE race (git-fixes).
- commit c801fd8
* Tue Sep 24 2019 msuchanek@suse.de
- Update patches.suse/powerpc-powernv-Return-for-invalid-IMC-domain.patch
  (bsc#1054914, fate#322448, git-fixes).
- commit 75ee7f9
* Tue Sep 24 2019 bp@suse.de
- x86/CPU/AMD: Clear RDRAND CPUID bit on AMD family 15h/16h
  (bsc#1114279).
- commit 0822f0e
* Tue Sep 24 2019 msuchanek@suse.de
- powerpc/powernv/ioda2: Allocate TCE table levels on demand
  for default DMA window (bsc#1061840).
- commit 7aed3d9
* Tue Sep 24 2019 fdmanana@suse.com
- Btrfs: fix use-after-free when using the tree modification log
  (bsc#1151891).
- commit 8c9d1a1
* Tue Sep 24 2019 sschricker@suse.de
- kABI: media: em28xx: fix handler for vidioc_s_input() (bsc#1051510).
  fixes kABI
- commit d681754
* Tue Sep 24 2019 sschricker@suse.de
- kABI: media: em28xx: stop rewriting device's struct (bsc#1051510).
  fixes kABI
- commit efcb30a
* Tue Sep 24 2019 dwagner@suse.de
- scsi: qla2xxx: Update driver version to 10.01.00.19-k
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix stale session (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Fix stuck login session (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Fix driver reload for ISP82xx (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix flash read for Qlogic ISPs (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix message indicating vectors used by driver
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: fix spelling mistake "initializatin" ->
  "initialization" (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix a recently introduced kernel warning
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: cleanup trace buffer initialization (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: qla2x00_alloc_fw_dump: set ha->eft (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix a NULL pointer dereference (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Simplify qla24xx_async_abort_cmd() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove two superfluous if-tests (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Introduce qla2x00_els_dcmd2_free() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Inline the qla2x00_fcport_event_handler()
  function (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Report invalid mailbox status codes (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove superfluous sts_entry_* casts (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Let the compiler check the type of the SCSI
  command context pointer (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Complain if sp->done() is not called from the
  completion path (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Make sure that aborted commands are freed
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Introduce qla2xxx_get_next_handle() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Modify NVMe include directives (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Make qlt_handle_abts_completion() more robust
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix a race condition between aborting and
  completing a SCSI command (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Introduce the function qla2xxx_init_sp()
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Enable type checking for the SRB free and done
  callback functions (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Rework key encoding in qlt_find_host_by_d_id()
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Set the responder mode if appropriate for ELS
  pass-through IOCBs (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Make it explicit that ELS pass-through IOCBs
  use little endian (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Check secondary image if reading the primary
  image fails (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Change the return type of
  qla24xx_read_flash_data() (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Introduce the be_id_t and le_id_t data types
  for FC src/dst IDs (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Complain if a soft reset fails (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use memcpy() and strlcpy() instead of strcpy()
  and strncpy() (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Check the PCI info string output buffer size
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Complain if waiting for pending commands times
  out (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Declare fourth qla2x00_set_model_info() argument
  const (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Always check the qla2x00_wait_for_hba_online()
  return value (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Suppress multiple Coverity complaint about
  out-of-bounds accesses (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Suppress a Coveritiy complaint about integer
  overflow (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove unreachable code from qla83xx_idc_lock()
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix qla24xx_process_bidir_cmd() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Simplify a debug statement (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove dead code (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Complain if parsing the version string fails
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Complain if a mailbox command times out
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use strlcpy() instead of strncpy() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Do not corrupt vha->plogi_ack_list (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Report the firmware status code if a mailbox
  command fails (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix session lookup in qlt_abort_work()
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Simplify qla24xx_abort_sp_done() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove two superfluous tests (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove a superfluous pointer check (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Simplify qlt_lport_dump() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Reduce the number of casts in GID list code
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Verify locking assumptions at runtime
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Change data_dsd into an array (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Declare qla_tgt_cmd.cdb const (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Reduce the scope of three local variables in
  qla2xxx_queuecommand() (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Change the return type
  of qla2x00_update_ms_fdmi_iocb() into void (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Declare the fourth ql_dump_buffer() argument
  const (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove a superfluous forward declaration
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove an include directive from qla_mr.c
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Include the <asm/unaligned.h> header file from
  qla_dsd.h (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use tabs instead of spaces for indentation
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Improve Linux kernel coding style conformance
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Really fix qla2xxx_eh_abort() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Make qla2x00_abort_srb() again decrease the sp
  reference count (bsc#1123034 bsc#1131304 bsc#1127988).
- qla2xxx: kABI fixes for v10.01.00.18-k (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Update driver version to 10.01.00.18-k
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Allow NVMe IO to resume with short cable pull
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix hang in fcport delete path (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use common update-firmware-options routine for
  ISP27xx+ (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix NVMe port discovery after a short device
  port loss (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Correct error handling during initialization
  failures (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Retry fabric Scan on IOCB queue full (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix premature timer expiration (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix Relogin to prevent modifying scan_state flag
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Reject EH_{abort|device_reset|target_request}
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Skip FW dump on LOOP initialization error
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use Correct index for Q-Pair array (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix abort timeout race condition (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix different size DMA Alloc/Unmap (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix DMA unmap leak (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Replace vmalloc + memset with vzalloc
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove unnecessary null check (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: move IO flush to the front of NVME rport
  unregistration (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix NVME cmd and LS cmd timeout race condition
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: on session delete, return nvme cmd (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix kernel crash after disconnecting NVMe devices
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: remove double assignment in qla2x00_update_fcport
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix hardlockup in abort command during driver
  remove (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Avoid that lockdep complains about unsafe
  locking in tcm_qla2xxx_close_session() (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Fix hardirq-unsafe locking (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Complain loudly about reference count underflow
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use __le64 instead of uint32_t for sending DMA
  addresses to firmware (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Introduce the dsd32 and dsd64 data structures
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Check the size of firmware data structures at
  compile time (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Pass little-endian values to the firmware
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix race conditions in the code for aborting
  SCSI commands (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use an on-stack completion in
  qla24xx_control_vp() (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Make qla24xx_async_abort_cmd() static
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove unnecessary locking from the target code
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove qla_tgt_cmd.released (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Complain if a command is released that is owned
  by the firmware (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: target: Fix offline port handling and host
  reset handling (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Simplify qlt_send_term_imm_notif() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix use-after-free issues in
  qla2xxx_qpair_sp_free_dma() (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Fix a qla24xx_enable_msix() error path
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Avoid that qla2x00_mem_free() crashes if called
  twice (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Make qla2x00_mem_free() easier to verify
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Increase the size of the mailbox arrays from
  4 to 8 (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Log the status code if a firmware command fails
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Avoid that Coverity complains about dereferencing
  a NULL rport pointer (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove the fcport test from qla_nvme_abort_work()
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Uninline qla2x00_init_timer() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Move qla2x00_is_reserved_id() from qla_inline.h
  into qla_init.c (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Move qla2x00_clear_loop_id() from qla_inline.h
  into qla_init.c (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove a set-but-not-used variable (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Declare qla2x00_find_new_loop_id() static
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Move qla2x00_set_reserved_loop_ids() definition
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Silence Successful ELS IOCB message (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix read offset in qla24xx_load_risc_flash()
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Move qla2x00_set_fcport_state() from a .h into
  a .c file (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove two superfluous casts (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove qla_tgt_cmd.data_work and
  qla_tgt_cmd.data_work_free (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Move the <linux/io-64-nonatomic-lo-hi.h>
  include directive (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Declare qla24xx_build_scsi_crc_2_iocbs() static
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Move the port_state_str definition from a .h
  to a .c file (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Insert spaces where required (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix formatting of pointer types (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Leave a blank line after declarations
  (bsc#1123034 bsc#1131304 bsc#1127988).
- Refresh patches.suse/qla2xxx-Enable-T10-DIF-with-FC-NVMe-enabled.patch
- scsi: qla2xxx: Use tabs to indent code (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: scsi_transport_fc: nvme: display FC-NVMe port roles
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: tcm_qla2xxx: Minimize #include directives (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Unregister resources in the opposite order of
  the registration order (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use get/put_unaligned where appropriate
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Make qla2x00_process_response_queue() easier
  to read (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Reduce the number of forward declarations
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Declare local symbols static (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use ARRAY_SIZE() in the definition of
  QLA_LAST_SPEED (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove a comment that refers to the SCSI host
  lock (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: fix spelling mistake "alredy" -> "already"
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove useless set memory to zero use memset()
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Update driver version to 10.01.00.16-k
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Change abort wait_loop from msleep to
  wait_event_timeout (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix driver unload when FC-NVMe LUNs are connected
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Cleanup redundant qla2x00_abort_all_cmds during
  unload (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Set remote port devloss timeout to 0 (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Cleanup fcport memory to prevent leak
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use mutex protection during
  qla2x00_sysfs_read_fw_dump() (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Fix fw dump corruption (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Further limit FLASH region write access from
  SysFS (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Disable T10-DIF feature with FC-NVMe during probe
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Increase the max_sgl_segments to 1024
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Reset the FCF_ASYNC_{SENT|ACTIVE} flags
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Set the qpair in SRB to NULL when SRB is released
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Set the SCSI command result before calling the
  command done (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Simplify conditional check again (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix a small typo in qla_bsg.c (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix comment alignment in qla_bsg.c (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Update driver version to 10.01.00.15-k
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Secure flash update support for ISP28XX
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add 28xx flash primary/secondary status/image
  mechanism (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Simplification of register address used in
  qla_tmpl.c (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Correction and improvement to fwdt processing
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Update flash read/write routine (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add support for multiple fwdump
  templates/segments (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Cleanups for NVRAM/Flash read/write path
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Correctly report max/min supported speeds
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add Serdes support for ISP28XX (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add Device ID for ISP28XX (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix routine qla27xx_dump_{mpi|ram}() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Remove FW default template (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add fw_attr and port_no SysFS node (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix NULL pointer crash due to stale CPUID
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: check for kstrtol() failure (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: avoid printf format warning (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Avoid PCI IRQ affinity mapping when multiqueue
  is not supported (bsc#1123034 bsc#1131304 bsc#1127988).
- Refresh patches.suse/qla2xxx-allow-irqbalance-control-in-non-MQ-mode.patch
- scsi: qla2xxx: Update driver version to 10.00.00.14-k
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add new FW dump template entry types (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix code indentation for qla27xx_fwdt_entry
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Move marker request behind QPair (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Prevent SysFS access when chip is down
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add support for setting port speed (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Prevent multiple ADISC commands per session
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Check for FW started flag before aborting
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix unload when NVMe devices are configured
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add First Burst support for FC-NVMe devices
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix LUN discovery if loop id is not assigned
  yet by firmware (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: remove redundant null check on pointer sess
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Move debug messages before sending srb preventing
  panic (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Update driver version to 10.00.00.13-k
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Use complete switch scan for RSCN events
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix fw options handle eh_bus_reset() (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Restore FAWWPN of Physical Port only for loop
  down (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Prevent memory leak for CT req/rsp allocation
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix SRB allocation flag to avoid sleeping in
  IRQ context (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: allow session delete to finish before create
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: fix fcport null pointer access (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: flush IO on chip reset or sess delete
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix session cleanup hang (bsc#1123034 bsc#1131304
  bsc#1127988).
- scsi: qla2xxx: Change default ZIO threshold (bsc#1123034
  bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add pci function reset support (bsc#1123034
  bsc#1131304 bsc#1127988).
- Refresh patches.suse/scsi-qla2xxx-Add-cleanup-for-PCI-EEH-recovery.patch
- scsi: qla2xxx: no need to check return value of debugfs_create
  functions (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix DMA error when the DIF sg buffer crosses
  4GB boundary (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Add protection mask module parameters
  (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: Fix panic from use after free in
  qla2x00_async_tm_cmd (bsc#1123034 bsc#1131304 bsc#1127988).
- scsi: qla2xxx: deadlock by configfs_depend_item (bsc#1123034
  bsc#1131304 bsc#1127988).
- commit 891f737
* Tue Sep 24 2019 dwagner@suse.de
- Remove patches.kabi/kABI-fixes-for-qla2xxx-Fix-inconsistent-DMA-mem-allo.patch
  The qla2xxx driver has been whitelisted by 1d5e8aad6de2
  ("kabi/severities: ignore qla2xxx as all symbols are internal")
- commit 6ab8ff8
* Tue Sep 24 2019 hare@suse.de
- Refresh patches.suse/null_blk-wire-up-timeouts.patch.
- commit 0488e25
* Tue Sep 24 2019 hare@suse.de
- block: fix timeout changes for legacy request drivers
  (bsc#1149446).
- null_blk: complete requests from ->timeout (bsc#1149446).
- null_blk: wire up timeouts (bsc#1149446).
- commit 1c7642d
* Tue Sep 24 2019 hare@suse.de
- nvme: fix multipath crash when ANA is deactivated (bsc#1149446).
- nvme-rdma: fix a NULL deref when an admin connect times out
  (bsc#1149446).
- nvme-rdma: fix timeout handler (bsc#1149446).
- nvme-rdma: centralize admin/io queue teardown sequence
  (bsc#1142076).
- nvme-rdma: centralize controller setup sequence (bsc#1142076).
- nvme-rdma: unquiesce queues when deleting the controller
  (bsc#1142076).
- nvme-rdma: support up to 4 segments of inline data
  (bsc#1142076).
- nvme-rdma: Allow DELETING state change failure in
  (bsc#1104967,FATE#325924).
- commit d93d360
* Tue Sep 24 2019 hare@suse.de
- libiscsi: don't try to bypass SCSI EH (bsc#1142076).
- scsi_transport_fc: complete requests from ->timeout
  (bsc#1142076).
- commit ffe813a
* Tue Sep 24 2019 hare@suse.de
- nvme: return BLK_EH_DONE from ->timeout (bsc#1142076).
- commit 09d3f8f
* Tue Sep 24 2019 hare@suse.de
- block: kABI fixes for BLK_EH_DONE renaming (bsc#1142076).
- block: rename BLK_EH_NOT_HANDLED to BLK_EH_DONE (bsc#1142076).
- Refresh
  patches.suse/s390-sles15-dasd-fix-deadlock-in-dasd_times_out.patch.
- commit 2d28590
* Tue Sep 24 2019 neilb@suse.de
- md/raid6: Set R5_ReadError when there is read failure on parity
  disk (git-fixes).
- commit ccb3493
* Tue Sep 24 2019 neilb@suse.de
- md: don't report active array_state until after
  revalidate_disk() completes (git-fixes).
- md: only call set_in_sync() when it is expected to succeed
  (git-fixes).
- commit 7bcfc53
* Mon Sep 23 2019 msuchanek@suse.de
- kabi/severities: Whitelist a couple of xive functions
  xive_cleanup_irq_data and xive_native_populate_irq_data are exported by
  the xive interupt controller driver and used by KVM. I don't expect any
  out-of-tree driver can sanely use these.
- commit f7ed153
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/radix: Fix memory hotplug section page table
  creation (bsc#1065729).
- commit e1331b1
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/xmon: Fix opcode being uninitialized in
  print_insn_powerpc (bsc#1065729).
- powerpc/64: Make sys_switch_endian() traceable (bsc#1065729).
- commit 5877a4a
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/bpf: use unsigned division instruction for 64-bit
  operations (bsc#1065729).
- powerpc: bpf: Fix generation of load/store DW instructions
  (bsc#1065729).
- commit 08d29de
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/pseries: Fix cpu_hotplug_lock acquisition in
  resize_hpt() (bsc#1065729).
- commit 9071fce
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/xive: Implement get_irqchip_state method for XIVE to
  fix shutdown race (bsc#1065729).
- commit 378f7a9
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/ptrace: Simplify vr_get/set() to avoid GCC warning
  (bsc#1148868).
- commit 2b40c83
* Mon Sep 23 2019 msuchanek@suse.de
- tpm_tis_core: Set TPM_CHIP_FLAG_IRQ before probing for
  interrupts (bsc#1082555).
- commit a6234e6
* Mon Sep 23 2019 msuchanek@suse.de
- powerpc/64s/radix: Fix memory hot-unplug page table split
  (bsc#1065729).
- KVM: PPC: Book3S: Fix incorrect guest-to-user-translation
  error handling (bsc#1061840).
- powerpc/powernv/ioda: Fix race in TCE level allocation
  (bsc#1061840).
- KVM: PPC: Book3S HV: Don't lose pending doorbell request on
  migration on P9 (bsc#1061840).
- KVM: PPC: Book3S HV: Check for MMU ready on piggybacked virtual
  cores (bsc#1061840).
- KVM: PPC: Book3S HV: Don't push XIVE context when not using
  XIVE device (bsc#1061840).
- KVM: PPC: Book3S HV: Fix race in re-enabling XIVE escalation
  interrupts (bsc#1061840).
- KVM: PPC: Book3S HV: XIVE: Free escalation interrupts before
  disabling the VP (bsc#1061840).
- KVM: PPC: Book3S HV: Handle virtual mode in XIVE VCPU push code
  (bsc#1061840).
- commit bd15b15
* Mon Sep 23 2019 tiwai@suse.de
- slip: make slhc_free() silently accept an error pointer
  (bsc#1051510).
- slip: sl_alloc(): remove unused parameter "dev_t line"
  (bsc#1051510).
- commit af4b048
* Mon Sep 23 2019 tiwai@suse.de
- drivers: thermal: int340x_thermal: Fix sysfs race condition
  (bsc#1051510).
- commit 0d5c18e
* Mon Sep 23 2019 tiwai@suse.de
- USB: usbcore: Fix slab-out-of-bounds bug during device reset
  (bsc#1051510).
- commit 78a6126
* Mon Sep 23 2019 tiwai@suse.de
- media: ov6650: Move v4l2_clk_get() to ov6650_video_probe()
  helper (bsc#1051510).
- commit 8e4fc49
* Mon Sep 23 2019 tiwai@suse.de
- media: mc-device.c: don't memset __user pointer contents
  (bsc#1051510).
- commit dcb05a3
* Mon Sep 23 2019 tiwai@suse.de
- media: vb2: Fix videobuf2 to map correct area (bsc#1051510).
- commit 59e953d
* Mon Sep 23 2019 tiwai@suse.de
- media: tm6000: double free if usb disconnect while streaming
  (bsc#1051510).
- commit 186de44
* Mon Sep 23 2019 tiwai@suse.de
- libertas_tf: Use correct channel range in lbtf_geo_init
  (bsc#1051510).
- commit 6e3091e
* Mon Sep 23 2019 tiwai@suse.de
- gpio: Move gpiochip_lock/unlock_as_irq to gpio/driver.h
  (bsc#1051510).
- commit 1b0ac8e
* Mon Sep 23 2019 tiwai@suse.de
- gpio: fix line flag validation in lineevent_create
  (bsc#1051510).
- gpio: fix line flag validation in linehandle_create
  (bsc#1051510).
- commit 4140de0
* Mon Sep 23 2019 tiwai@suse.de
- gpiolib: only check line handle flags once (bsc#1051510).
- Refresh patches.suse/gpioib-do-not-free-unrequested-descriptors.
- commit 741767a
* Mon Sep 23 2019 tiwai@suse.de
- clk: at91: fix update bit maps on CFG_MOR write (bsc#1051510).
- clk: sunxi-ng: v3s: add missing clock slices for MMC2 module
  clocks (bsc#1051510).
- clk: sunxi-ng: v3s: add the missing PLL_DDR1 (bsc#1051510).
- commit 5f13c10
* Mon Sep 23 2019 jroedel@suse.de
- iommu/dma: Fix for dereferencing before null checking
  (bsc#1151667).
- commit 8f846ef
* Mon Sep 23 2019 tiwai@suse.de
- sky2: Disable MSI on yet another ASUS boards (P6Xxxx)
  (bsc#1051510).
- commit b478556
* Mon Sep 23 2019 tiwai@suse.de
- r8152: Set memory to all 0xFFs on failed reg reads
  (bsc#1051510).
- commit 6a3c2b7
* Mon Sep 23 2019 tiwai@suse.de
- power: reset: gpio-restart: Fix typo when gpio reset is not
  found (bsc#1051510).
- power: supply: Init device wakeup after device_add()
  (bsc#1051510).
- commit d9a28d6
* Mon Sep 23 2019 tiwai@suse.de
- phy: renesas: rcar-gen3-usb2: Disable clearing VBUS in
  over-current (bsc#1051510).
- commit 8fe4116
* Mon Sep 23 2019 tiwai@suse.de
- Revert "mwifiex: fix system hang problem after resume"
  (bsc#1051510).
- commit 82c939e
* Mon Sep 23 2019 tiwai@suse.de
- mtd: spi-nor: Fix Cadence QSPI RCU Schedule Stall (bsc#1051510).
- commit 3703ea0
* Mon Sep 23 2019 tiwai@suse.de
- media: technisat-usb2: break out of loop at end of buffer
  (bsc#1051510).
- commit fbd5a3c
* Mon Sep 23 2019 tiwai@suse.de
- isdn/capi: check message length in capi_write() (bsc#1051510).
- commit 405ba39
* Mon Sep 23 2019 tiwai@suse.de
- bcma: fix incorrect update of BCMA_CORE_PCI_MDIO_DATA
  (bsc#1051510).
- commit bc4252b
* Mon Sep 23 2019 jthumshirn@suse.de
- blk-mq: Fix memory leak in blk_mq_init_allocated_queue error
  handling (bsc#1151610).
- commit cc60339
* Mon Sep 23 2019 msuchanek@suse.de
- Refresh sorted patches.
- Refresh patches.suse/powerpc-dump-kernel-log-before-carrying-out-fadump-o.patch with upstrem status.
- commit f6a052e
* Mon Sep 23 2019 tzimmermann@suse.de
- video: ssd1307fb: Start page range at page_offset (bsc#1113722)
- commit 70abc1f
* Mon Sep 23 2019 tzimmermann@suse.de
- drm/imx: Drop unused imx-ipuv3-crtc.o build (bsc#1113722)
- commit dc547ac
* Mon Sep 23 2019 tzimmermann@suse.de
- drm/i915: Fix various tracepoints for gen2 (bsc#1113722)
- commit b7723c4
* Mon Sep 23 2019 jgross@suse.com
- xen-netfront: do not assume sk_buff_head list is empty in
  error handling (bsc#1065600).
- commit 4343701
* Mon Sep 23 2019 sschricker@suse.de
- media: Revert "[media] marvell-ccic: reset ccic phy when stop
  streaming for stability" (bsc#1051510).
- commit 84e25e7
* Mon Sep 23 2019 sschricker@suse.de
- media: marvell-ccic: don't generate EOF on parallel bus
  (bsc#1051510).
- commit 966c34c
* Mon Sep 23 2019 neilb@suse.de
- nfsd: degraded slot-count more gracefully as allocation nears
  exhaustion (bsc#1150381).
- nfsd: handle drc over-allocation gracefully (bsc#1150381).
- nfsd: Fix overflow causing non-working mounts on 1 TB machines
  (bsc#1150381).
- nfsd: fix performance-limiting session calculation
  (bsc#1150381).
- nfsd: give out fewer session slots as limit approaches
  (bsc#1150381).
- nfsd: increase DRC cache limit (bsc#1150381).
- commit 1a96b8c
* Mon Sep 23 2019 neilb@suse.de
- git-sort: add nfsd maintainers git tree
  This allows git-sort to handle patches queued for nfsd.
- commit ec6f7e4
* Fri Sep 20 2019 jack@suse.cz
- Remove unused function in patches.suse/ext4-unsupported-features.patch.
- commit b2f6d95
* Fri Sep 20 2019 sschricker@suse.de
- media: ov6650: Fix sensor possibly not detected on probe
  (bsc#1051510).
- commit 2a23bd0
* Fri Sep 20 2019 mbenes@suse.cz
- Update
  patches.suse/tracing-Fix-crash-when-it-fails-to-alloc-ring-buffer.patch
  (bsc#1120097 CVE-2017-18595 bsc#1149555).
- Update
  patches.suse/tracing-Fix-possible-double-free-on-failure-of-alloc.patch
  (bsc#1120214 CVE-2017-18595 bsc#1149555).
- commit 6040815
* Fri Sep 20 2019 hare@suse.de
- blk-mq: kABI fixes for blk-mq.h (bsc#1137959).
- commit fd2ff8e
* Fri Sep 20 2019 hare@suse.de
- blk-mq: insert rq with DONTPREP to hctx dispatch list when
  requeue (bsc#1137959).
- commit 8b3257c
* Fri Sep 20 2019 hare@suse.de
- blk-mq: punt failed direct issue to dispatch list (bsc#1137959).
- commit d9cd2bd
* Fri Sep 20 2019 hare@suse.de
- blk-mq: don't allocate driver tag upfront for flush rq
  (bsc#1137959).
- Refresh
  patches.suse/blk-mq-remove-synchronize_rcu-from-blk_mq_del_queue_.patch.
- commit 8e2a4fd
* Fri Sep 20 2019 hare@suse.de
- blk-mq: move blk_mq_put_driver_tag*() into blk-mq.h
  (bsc#1137959).
- Refresh patches.suse/blk-mq-fix-sysfs-inflight-counter.patch.
- commit 7e431dd
* Fri Sep 20 2019 hare@suse.de
- blk-mq-sched: decide how to handle flush rq via RQF_FLUSH_SEQ
  (bsc#1137959).
- Refresh
  patches.suse/blk-mq-remove-synchronize_rcu-from-blk_mq_del_queue_.patch.
- commit 67e1414
* Fri Sep 20 2019 hare@suse.de
- blk-flush: use blk_mq_request_bypass_insert() (bsc#1137959).
- commit 16dda6f
* Fri Sep 20 2019 jack@suse.cz
- Update patches.suse/ext4-unsupported-features.patch
  (fate#317919, SLE-8615, bsc#1149651, SLE-9243).
- commit 9348c99
* Fri Sep 20 2019 hare@suse.de
- blk-flush: don't run queue for requests bypassing flush
  (bsc#1137959).
- blk-mq: put the driver tag of nxt rq before first one is
  requeued (bsc#1137959).
- commit c4843ab
* Fri Sep 20 2019 acho@suse.com
- Update
  patches.suse/Bluetooth-Align-minimum-encryption-key-size-for-LE-a.patch
  (bsc#1051510 CVE-2019-9506 bsc#1137865 bsc#1146042).
- Update
  patches.suse/Bluetooth-Fix-faulty-expression-for-minimum-encrypti.patch
  (bsc#1140328 CVE-2019-9506 bsc#1137865 bsc#1146042).
- Update
  patches.suse/Bluetooth-Fix-regression-with-minimum-encryption-key.patch
  (bsc#1135556 CVE-2019-9506 bsc#1137865 bsc#1146042).
- Update patch reference for Bluetooth security issue
  (CVE-2019-9506, bsc#1137865, bsc#1146042)
- commit 1bb9cd5
* Fri Sep 20 2019 hare@suse.de
- nvme: remove ns sibling before clearing path (bsc#1140155).
- commit b24c3f9
* Thu Sep 19 2019 sschricker@suse.de
- media: replace strcpy() by strscpy() (bsc#1051510).
- commit 8f592a3
* Thu Sep 19 2019 tiwai@suse.de
- ath9k: dynack: fix possible deadlock in ath_dynack_node_{de}init
  (bsc#1051510).
- nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds
  (bsc#1051510).
- mac80211: minstrel_ht: fix per-group max throughput rate
  initialization (bsc#1051510).
- crypto: cavium/zip - Add missing single_release() (bsc#1051510).
- crypto: skcipher - Unmap pages after an external error
  (bsc#1051510).
- crypto: caam - free resources in case caam_rng registration
  failed (bsc#1051510).
- crypto: caam - fix concurrency issue in givencrypt descriptor
  (bsc#1051510).
- crypto: qat - Silence smp_processor_id() warning (bsc#1051510).
- crypto: ccp - Reduce maximum stack usage (bsc#1051510).
- mic: avoid statically declaring a 'struct device' (bsc#1051510).
- iio: dac: ad5380: fix incorrect assignment to val (bsc#1051510).
- gpiolib: acpi: Add gpiolib_acpi_run_edge_events_on_boot option
  and blacklist (bsc#1051510).
- Input: elan_i2c - remove Lenovo Legion Y7000 PnpID
  (bsc#1051510).
- commit 278f999
* Thu Sep 19 2019 sschricker@suse.de
- media: em28xx: stop rewriting device's struct (bsc#1051510).
- commit 6488bc5
* Thu Sep 19 2019 sschricker@suse.de
- media: em28xx: fix handler for vidioc_s_input() (bsc#1051510).
- commit dde40de
* Wed Sep 18 2019 tiwai@suse.de
- ACPI / property: Fix acpi_graph_get_remote_endpoint() name in
  kerneldoc (bsc#1051510).
- ACPI / PCI: fix acpi_pci_irq_enable() memory leak (bsc#1051510).
- ACPI: custom_method: fix memory leaks (bsc#1051510).
- PM: sleep: Fix possible overflow in pm_system_cancel_wakeup()
  (bsc#1051510).
- dmaengine: iop-adma.c: fix printk format warning (bsc#1051510).
- dmaengine: dw: platform: Switch to
  acpi_dma_controller_register() (bsc#1051510).
- leds: trigger: gpio: GPIO 0 is valid (bsc#1051510).
- leds: leds-lp5562 allow firmware files up to the maximum length
  (bsc#1051510).
- media: atmel: atmel-isi: fix timeout value for stop streaming
  (bsc#1051510).
- media: fdp1: Reduce FCP not found message level to debug
  (bsc#1051510).
- media: dib0700: fix link error for dibx000_i2c_set_speed
  (bsc#1051510).
- platform/x86: pmc_atom: Add Siemens SIMATIC IPC227E to
  critclk_systems DMI table (bsc#1051510).
- regulator: lm363x: Fix off-by-one n_voltages for lm3632
  ldo_vpos/ldo_vneg (bsc#1051510).
- hwmon: (shtc1) fix shtc1 and shtw1 id mask (bsc#1051510).
- hwmon: (lm75) Fix write operations for negative temperatures
  (bsc#1051510).
- commit cf741d5
* Wed Sep 18 2019 hare@suse.de
- nvme-rdma: stop admin queue before freeing it (bsc#1140155).
- Refresh
  patches.suse/nvme-rdma-fix-possible-free-of-a-non-allocated-async.patch.
- commit 0b513fe
* Wed Sep 18 2019 tiwai@suse.de
- Move the nvme upstreamed patch into sorted section
- commit 1cced01
* Wed Sep 18 2019 tiwai@suse.de
- Modify the patch description not to confuse our scripts
  The patch
  patches.suse/revert-scsi-ufs-disable-vccq-if-it-s-not-needed-by-ufs-device
  contained the patch conflict markers in its description and this confused
  some scripts.  Slightly modify (add a space) to avoid the confusion.
- commit c1c1b4a
* Wed Sep 18 2019 tiwai@suse.de
- Refresh the upstreamed mwifiex security fix, move to sorted section
- commit bd90eae
* Wed Sep 18 2019 tiwai@suse.de
- ASoC: wm8988: fix typo in wm8988_right_line_controls
  (bsc#1051510).
- ASoC: sun4i-i2s: RX and TX counter registers are swapped
  (bsc#1051510).
- ASoC: Intel: Baytrail: Fix implicit fallthrough warning
  (bsc#1051510).
- ASoC: wm8737: Fix copy-paste error in wm8737_snd_controls
  (bsc#1051510).
- ASoC: es8328: Fix copy-paste error in es8328_right_line_controls
  (bsc#1051510).
- ALSA: aoa: onyx: always initialize register read value
  (bsc#1051510).
- ALSA: firewire-tascam: check intermediate state of clock status
  and retry (bsc#1051510).
- ALSA: firewire-tascam: handle error code when getting current
  source of clock (bsc#1051510).
- commit 7a3274e
* Tue Sep 17 2019 mkubecek@suse.cz
- bonding/802.3ad: fix slave link initialization transition states
  (bsc#1137069 bsc#1141013).
- bonding/802.3ad: fix link_failure_count tracking (bsc#1137069
  bsc#1141013).
- bonding: set default miimon value for non-arp modes if not set
  (bsc#1137069 bsc#1141013).
- bonding: speed/duplex update at NETDEV_UP event (bsc#1137069
  bsc#1141013).
- commit df6116d
* Tue Sep 17 2019 tiwai@suse.de
- vhost: make sure log_num < in_num (bsc#1150112,CVE-2019-14835).
- commit b68beb0
* Tue Sep 17 2019 tzimmermann@suse.de
- drm/i915: Restore relaxed padding (OCL_OOB_SUPPRES_ENABLE) for skl+ (bsc#1142635)
- commit 700d2e9
* Tue Sep 17 2019 jdelvare@suse.de
- nvmem: Use the same permissions for eeprom as for nvmem
  (git-fixes).
- eeprom: at24: make spd world-readable again (git-fixes).
- commit 8b5e393
* Mon Sep 16 2019 fdmanana@suse.com
- Btrfs: do not abort transaction at btrfs_update_root() after
  failure to COW path (bsc#1150933).
- commit 7ea9d0d
* Mon Sep 16 2019 fdmanana@suse.com
- Btrfs: fix assertion failure during fsync and use of stale
  transaction (bsc#1150562).
- commit 25aef77
* Mon Sep 16 2019 tiwai@suse.de
- Update tags of upstreamed ibmvnic patches
- commit 8a435ac
* Mon Sep 16 2019 jdelvare@suse.de
- secure boot lockdown: Fix-up backport of /dev/mem access restriction
  The upstream-submitted patch set has evolved over time, align our
  patches (contents and description) to reflect the current status as
  far as /dev/mem access is concerned.
- commit 6ab83e9
* Mon Sep 16 2019 ptesarik@suse.cz
- Move
  patches.suse/KVM-X86-Reduce-the-overhead-when-lapic_timer_advance.patch
  into the sorted section.
- commit 52c3d4c
* Mon Sep 16 2019 jroedel@suse.de
- iommu/amd: Fix race in increase_address_space() (bsc#1150860).
- iommu/amd: Flush old domains in kdump kernel (bsc#1150861).
- commit be77ff3
* Mon Sep 16 2019 jthumshirn@suse.de
- blacklist.conf: blacklist 73df167c819e s390/zcrypt: remove the exporting of ap_query_configuration
- commit 7e43372
* Sun Sep 15 2019 tiwai@suse.de
- Revert "Bluetooth: validate BLE connection interval updates"
  (bsc#1051510).
- commit b690434
* Sun Sep 15 2019 tiwai@suse.de
- blacklist.conf: Add reverted drm/i915 entries
- commit 506d5fa
* Fri Sep 13 2019 msuchanek@suse.de
- powerpc/powernv: Flush console before platform error reboot (bsc#1149940 ltc#179958).
- Refresh patches.suse/powerpc-pseries-Flush-SLB-contents-on-SLB-MCE-errors.patch.
- Refresh patches.suse/powerpc-64s-consolidate-MCE-counter-increment.patch.
- commit a8b84bd
* Fri Sep 13 2019 msuchanek@suse.de
- powerpc/powernv: Use kernel crash path for machine checks (bsc#1149940 ltc#179958).
- Refresh patches.suse/powerpc-Deliver-SEGV-signal-on-pkey-violation.patch.
- commit 41366ee
* Fri Sep 13 2019 msuchanek@suse.de
- powerpc/pseries, ps3: panic flush kernel messages before
  halting system (bsc#1149940 ltc#179958).
- powerpc/pseries: correctly track irq state in default idle
  (bsc#1150727 ltc#178925).
- commit 6cbd692
* Fri Sep 13 2019 lma@suse.com
- KVM: X86: Reduce the overhead when lapic_timer_advance is
  disabled (bsc#1149083).
- commit 004104f
* Fri Sep 13 2019 ptesarik@suse.cz
- Refresh
  patches.suse/0001-iwlwifi-fw-use-helper-to-determine-whether-to-dump-p.patch.
- commit 09132ae
* Thu Sep 12 2019 lduncan@suse.com
- Add some qedf commits to blacklist file (bsc#1149976)
- commit ad7f2e8
* Thu Sep 12 2019 lduncan@suse.com
- scsi: qedf: Update the version to 8.42.3.0 (bsc#1149976).
- scsi: qedf: Fix race betwen fipvlan request and response path
  (bsc#1149976).
- scsi: qedf: Use discovery list to traverse rports (bsc#1149976).
- scsi: qedf: Decrease the LL2 MTU size to 2500 (bsc#1149976).
- scsi: qedf: Check for module unloading bit before processing
  link update AEN (bsc#1149976).
- scsi: qedf: Initiator fails to re-login to switch after link
  down (bsc#1149976).
- scsi: qedf: Add debug information for unsolicited processing
  (bsc#1149976).
- scsi: qedf: Add support for 20 Gbps speed (bsc#1149976).
- scsi: qedf: Add shutdown callback handler (bsc#1149976).
- scsi: qedf: Update module description string (bsc#1149976).
- scsi: qedf: Stop sending fipvlan request on unload
  (bsc#1149976).
- scsi: qedf: Print message during bailout conditions
  (bsc#1149976).
- scsi: qedf: remove set but not used variables (bsc#1149976).
- scsi: qedf: Update the driver version to 8.37.25.20
  (bsc#1149976).
- scsi: qedf: Check both the FCF and fabric ID before servicing
  clear virtual link (bsc#1149976).
- scsi: qedf: Check for link state before processing LL2 packets
  and send fipvlan retries (bsc#1149976).
- commit edee027
* Thu Sep 12 2019 sschricker@suse.de
- blacklist.conf: blacklist usb-c tcpm patch
- commit cef523e
* Thu Sep 12 2019 oneukum@suse.com
- Update
  patches.suse/USB-yurex-Fix-protection-fault-after-device-removal.patch
  (bsc#1146361 CVE-2019-15216).
- commit 9f9b329
* Thu Sep 12 2019 jgross@suse.com
- x86/entry/64/compat: Fix stack switching for XEN PV
  (bsc#1108382).
- commit 1230401
* Wed Sep 11 2019 palcantara@suse.de
- cifs: handle netapp error codes (bsc#1136261).
- commit a4c55b8
* Wed Sep 11 2019 tbogendoerfer@suse.de
- Update
  patches.suse/fm10k-Fix-a-potential-NULL-pointer-dereference.patch
  (bsc#1051510 bsc#1149612 CVE-2019-15924).
  Added CVE number.
- commit b01b6c4
* Wed Sep 11 2019 firo.yang@suse.com
- blk-wbt: Avoid lock contention and thundering herd issue in
  wbt_wait (bsc#1141543).
- commit 85c3f55
* Tue Sep 10 2019 tiwai@suse.de
- HID: cp2112: prevent sleeping function called from invalid
  context (bsc#1051510).
- wimax/i2400m: fix a memory leak bug (bsc#1051510).
- cx82310_eth: fix a memory leak bug (bsc#1051510).
- Bluetooth: btqca: Add a short delay before downloading the NVM
  (bsc#1051510).
- lan78xx: Fix memory leaks (bsc#1051510).
- liquidio: add cleanup in octeon_setup_iq() (bsc#1051510).
- spi: bcm2835aux: fix corruptions for longer spi transfers
  (bsc#1051510).
- spi: bcm2835aux: remove dangerous uncontrolled read of fifo
  (bsc#1051510).
- spi: bcm2835aux: unifying code between polling and interrupt
  driven code (bsc#1051510).
- commit 5fea6f2
* Tue Sep 10 2019 lduncan@suse.com
- scsi: qedi: remove declaration of nvm_image from stack
  (git-fixes).
- commit cf36782
* Tue Sep 10 2019 oneukum@suse.com
- Update
  patches.suse/0001-usb-usbmon-Read-text-within-supplied-buffer-size.patch
  (bsc#1150025 CVE-2019-9456).
  Added CVE
- commit 7b005aa
* Tue Sep 10 2019 sschricker@suse.de
- Refresh
  patches.suse/0001-iwlwifi-dbg-split-iwl_fw_error_dump-to-two-functions.patch.
  Original backport was wrong, fw_error_dump used without allocation.
- commit 703cfd3
* Tue Sep 10 2019 hare@suse.de
- blk-mq: backport fixes for blk_mq_complete_e_request_sync()
  (bsc#1145661).
- commit a78db03
* Tue Sep 10 2019 sschricker@suse.de
- iwlwifi: fw: use helper to determine whether to dump paging
  (bsc#1106434).
  Patch needed to be adjusted, because our tree doesn't have the global variable
  IWL_FW_ERROR_DUMP_PAGING
- commit 16bc427
* Tue Sep 10 2019 hare@suse.de
- nvme: cancel request synchronously (bsc#1145661).
- blk-mq: introduce blk_mq_complete_request_sync() (bsc#1145661).
- commit be2a321
* Tue Sep 10 2019 sschricker@suse.de
- iwlwifi: fix bad dma handling in page_mem dumping flow
  (bsc#1120902).
- commit adbc3e6
* Tue Sep 10 2019 msuchanek@suse.de
- powerpc: dump kernel log before carrying out fadump or kdump
  (bsc#1149940 ltc#179958).
- commit c8bead4
* Tue Sep 10 2019 msuchanek@suse.de
- Refresh patches with upstream status.
- commit c8e87ea
* Tue Sep 10 2019 hare@suse.de
- Refresh
  patches.suse/nvme-multipath-fix-ana-log-nsid-lookup-when-nsid-is-.patch.
- scripts/git_sort/git_sort.py:
- commit 6256d05
* Tue Sep 10 2019 hare@suse.de
- nvme-multipath: relax ANA state check (bsc#1123105).
- Delete
  patches.suse/nvme-schedule-requeue-whenever-a-LIVE-state-is-enter.patch.
- commit b1415e9
* Tue Sep 10 2019 hare@suse.de
- nvme-fc: fix module unloads while lports still pending
  (bsc#1150033).
- commit 0030228
* Mon Sep  9 2019 msuchanek@suse.de
- net/ibmvnic: Fix missing { in __ibmvnic_reset (bsc#1149652
  ltc#179635).
- commit 602733d
* Mon Sep  9 2019 msuchanek@suse.de
- net/ibmvnic: free reset work of removed device from queue
  (bsc#1149652 ltc#179635).
- ibmvnic: Do not process reset during or after device removal
  (bsc#1149652 ltc#179635).
- commit b05eda9
* Mon Sep  9 2019 lhenriques@suse.com
- Update
  patches.suse/ceph-remove-request-from-waiting-list-before-unregister.patch
  (bsc#1148133 bsc#1138539).
- commit 00e13f8
* Mon Sep  9 2019 tzimmermann@suse.de
- drm/i915: Don't deballoon unused ggtt drm_mm_node in linux guest (bsc#1142635)
- commit 662cb21
* Sun Sep  8 2019 tiwai@suse.de
- scsi: sd: Quiesce warning if device does not report optimal
  I/O size (git-fixes).
- commit 4d227c6
* Sat Sep  7 2019 tiwai@suse.de
- Revert patches.suse/0001-blk-wbt-Avoid-lock-contention-and-thundering-herd-is.patch (bsc#1141543)
  As we see stalls / crashes recently with the relevant code path, revert
  this patch tentatively.
- commit c8f11b1
* Fri Sep  6 2019 lduncan@suse.com
- Add 3 not-needeed commits to blacklist.conf from git-fixes.
- commit 735de86
* Fri Sep  6 2019 lduncan@suse.com
- scsi: sr: Avoid that opening a CD-ROM hangs with runtime power
  management enabled (git-fixes).
- Refresh
  patches.suse/scsi-sr-wait-for-the-medium-to-become-ready.patch.
- commit 9ec2045
* Fri Sep  6 2019 lduncan@suse.com
- scsi: virtio_scsi: don't send sc payload with tmfs (git-fixes).
- commit be1c4bf
* Fri Sep  6 2019 lduncan@suse.com
- scsi: sd: Fix a race between closing an sd device and sd I/O
  (git-fixes).
- commit 8f5e62e
* Fri Sep  6 2019 lduncan@suse.com
- scsi: sd: Optimal I/O size should be a multiple of physical
  block size (git-fixes).
- scsi: cxlflash: Prevent deadlock when adapter probe fails
  (git-fixes).
- scsi: sd: Fix cache_type_store() (git-fixes).
- scsi: sd: Defer spinning up drive while SANITIZE is in progress
  (git-fixes).
- scsi: sd_zbc: Fix potential memory leak (git-fixes).
- scsi: bfa: convert to strlcpy/strlcat (git-fixes).
- scsi: use dma_get_cache_alignment() as minimum DMA alignment
  (git-fixes).
- scsi: ufs: fix wrong command type of UTRD for UFSHCI v2.1
  (git-fixes).
- commit deec538
* Fri Sep  6 2019 msuchanek@suse.de
- powerpc/tm: Fix restoring FP/VMX facility incorrectly on
  interrupts (CVE-2019-15031 bsc#1149713).
- powerpc/tm: Fix FP/VMX unavailable exceptions inside a
  transaction (CVE-2019-15030 bsc#1149713).
- commit 0b51abd
* Fri Sep  6 2019 tiwai@suse.de
- keys: Fix missing null pointer check in
  request_key_auth_describe() (bsc#1051510).
- commit 8fb27bb
* Fri Sep  6 2019 tiwai@suse.de
- watchdog: bcm2835_wdt: Fix module autoload (bsc#1051510).
- watchdog: fix compile time error of pretimeout governors
  (bsc#1051510).
- commit ded5db7
* Fri Sep  6 2019 tiwai@suse.de
- USB: storage: ums-realtek: Whitelist auto-delink support
  (bsc#1051510).
- USB: storage: ums-realtek: Update module parameter description
  for auto_delink_en (bsc#1051510).
- usb: host: ohci: fix a race condition between shutdown and irq
  (bsc#1051510).
- usb-storage: Add new JMS567 revision to unusual_devs
  (bsc#1051510).
- usb: chipidea: udc: don't do hardware access if gadget has
  stopped (bsc#1051510).
- usb: host: fotg2: restart hcd after port reset (bsc#1051510).
- usb: gadget: composite: Clear "suspended" on reset/disconnect
  (bsc#1051510).
- commit ea861f6
* Fri Sep  6 2019 tiwai@suse.de
- mmc: core: Fix init of SD cards reporting an invalid VDD range
  (bsc#1051510).
- commit c999d41
* Fri Sep  6 2019 tiwai@suse.de
- intel_th: pci: Add Tiger Lake support (bsc#1051510).
- intel_th: pci: Add support for another Lewisburg PCH
  (bsc#1051510).
- commit 7b5b3ce
* Fri Sep  6 2019 tiwai@suse.de
- i2c: piix4: Fix port selection for AMD Family 16h Model 30h
  (bsc#1051510).
- i2c: emev2: avoid race when unregistering slave client
  (bsc#1051510).
- commit 3807a4a
* Fri Sep  6 2019 tiwai@suse.de
- Revert "cfg80211: fix processing world regdomain when non
  modular" (bsc#1051510).
- commit df69fa0
* Fri Sep  6 2019 tiwai@suse.de
- Drop an ASoC fix that was reverted in 4.14.y stable
- commit 5dddfc0
* Fri Sep  6 2019 ptesarik@suse.cz
- Refresh
  patches.suse/crypto-ccp-Ignore-unconfigured-CCP-device-on-suspend.patch.
- commit 23b4ba5
* Fri Sep  6 2019 jlee@suse.com
- ACPICA: Increase total number of possible Owner IDs
  (bsc#1148859).
- commit 4ee4651
* Fri Sep  6 2019 tiwai@suse.de
- ALSA: hda: kabi workaround for generic parser flag
  (bsc#1051510).
- commit b9ae4e4
* Fri Sep  6 2019 tiwai@suse.de
- ALSA: hda/realtek - Fix the problem of two front mics on a
  ThinkCentre (bsc#1051510).
- ALSA: hda/realtek - Fix overridden device-specific
  initialization (bsc#1051510).
- ALSA: hda - Fix potential endless loop at applying quirks
  (bsc#1051510).
- commit 79578b1
* Fri Sep  6 2019 firo.yang@suse.com
- blk-wbt: Avoid lock contention and thundering herd issue in
  wbt_wait (bsc#1141543).
- commit a9a1f2a
* Thu Sep  5 2019 tiwai@suse.de
- Update patch reference for CIFS security issue (CVE-2019-15920, bsc#1149626)
- commit a1da6e9
* Thu Sep  5 2019 tiwai@suse.de
- Update patch reference for netlink security issue (CVE-2019-15921, bsc#1149602)
- commit 853f899
* Thu Sep  5 2019 tiwai@suse.de
- rsi: add fix for crash during assertions
  (CVE-2018-21008,bsc#1149591).
- commit a7d4c26
* Thu Sep  5 2019 tiwai@suse.de
- Update patch reference for cifs security issue (CVE-2019-15919, bsc#1149552)
- commit 2c7d41a
* Thu Sep  5 2019 tiwai@suse.de
- Update patch reference for BT security matter (CVE-2019-15917, bsc#1149539)
- commit 8e349ee
* Thu Sep  5 2019 tiwai@suse.de
- Update patch references for ath6kl security matter (CVE-2019-15926, bsc#1149527)
- commit d442f4a
* Thu Sep  5 2019 tiwai@suse.de
- Update patch reference for USB-audio security matter (CVE-2019-15927, bsc#1149522)
- commit d55fe63
* Thu Sep  5 2019 jroedel@suse.de
- kvm/x86: Move MSR_IA32_ARCH_CAPABILITIES to array emulated_msrs
  (bsc#1134881 bsc#1134882).
- commit 3ea1de5
* Thu Sep  5 2019 jlee@suse.com
- Update config files. (bsc#1145687)
  Add the following kernel config to ARM64:
  CONFIG_ACPI_PCI_SLOT=y
  CONFIG_HOTPLUG_PCI_ACPI=y
- commit 6cbb147
* Thu Sep  5 2019 msuchanek@suse.de
- powerpc/xmon: Add a dump of all XIVE interrupts (bsc#1142019).
- powerpc/xive: Fix dump of XIVE interrupt under pseries
  (bsc#1142019).
- powerpc/xmon: Check for HV mode when dumping XIVE info from OPAL
  (bsc#1142019).
- commit 8c4905a
* Wed Sep  4 2019 mbenes@suse.cz
- ftrace: Check for successful allocation of hash (bsc#1149424).
- commit 51371b7
* Wed Sep  4 2019 tiwai@suse.de
- Refresh patches.suse/supported-flag-wildcards: fix up references
- commit 7db373b
* Wed Sep  4 2019 mbenes@suse.cz
- ftrace: Check for empty hash and comment the race with
  registering probes (bsc#1149418).
- commit b0a7e90
* Wed Sep  4 2019 mbenes@suse.cz
- ftrace: Fix NULL pointer dereference in t_probe_next()
  (bsc#1149413).
- commit 62b7991
* Wed Sep  4 2019 tiwai@suse.de
- VMCI: Release resource if the work is already queued
  (bsc#1051510).
- commit cdeec63
* Wed Sep  4 2019 tiwai@suse.de
- USB: cdc-wdm: fix race between write and disconnect due to
  flag abuse (bsc#1051510).
- usb: host: xhci: rcar: Fix typo in compatible string matching
  (bsc#1051510).
- commit c194437
* Wed Sep  4 2019 tiwai@suse.de
- test_firmware: fix a memory leak bug (bsc#1051510).
- commit 39763a7
* Wed Sep  4 2019 tiwai@suse.de
- scripts/decode_stacktrace.sh: prefix addr2line with
  $CROSS_COMPILE (bsc#1051510).
- scripts/checkstack.pl: Fix arm64 wrong or unknown architecture
  (bsc#1051510).
- scripts/gdb: fix lx-version string output (bsc#1051510).
- scripts/decode_stacktrace: only strip base path when a prefix
  of the path (bsc#1051510).
- commit de6197f
* Wed Sep  4 2019 tiwai@suse.de
- samples, bpf: fix to change the buffer size for read()
  (bsc#1051510).
- samples: mei: use /dev/mei0 instead of /dev/mei (bsc#1051510).
- rtc: pcf8523: don't return invalid date when battery is low
  (bsc#1051510).
- commit d64864a
* Wed Sep  4 2019 tiwai@suse.de
- mmc: sdhci-of-at91: add quirk for broken HS200 (bsc#1051510).
- mpls: fix warning with multi-label encap (bsc#1051510).
- commit f180985
* Wed Sep  4 2019 tiwai@suse.de
- batman-adv: Only read OGM2 tvlv_len after buffer len check
  (bsc#1051510).
- batman-adv: Only read OGM tvlv_len after buffer len check
  (bsc#1051510).
- batman-adv: fix uninit-value in batadv_netlink_get_ifindex()
  (bsc#1051510).
- mac80211: fix possible sta leak (bsc#1051510).
- libata: add SG safety checks in SFF pio transfers (bsc#1051510).
- libata: have ata_scsi_rw_xlat() fail invalid passthrough
  requests (bsc#1051510).
- can: peak_usb: force the string buffer NULL-terminated
  (bsc#1051510).
- can: sja1000: force the string buffer NULL-terminated
  (bsc#1051510).
- isdn: hfcsusb: Fix mISDN driver crash caused by transfer buffer
  on the stack (bsc#1051510).
- isdn: mISDN: hfcsusb: Fix possible null-pointer dereferences
  in start_isoc_chain() (bsc#1051510).
- HID: hiddev: do cleanup in failure of opening a device
  (bsc#1051510).
- HID: Add 044f:b320 ThrustMaster, Inc. 2 in 1 DT (bsc#1051510).
- kconfig/[mn]conf: handle backspace (^H) key (bsc#1051510).
- gpio: mxs: Get rid of external API call (bsc#1051510).
- gpio: pxa: handle corner case of unprobed device (bsc#1051510).
- i2c: qup: fixed releasing dma without flush operation completion
  (bsc#1051510).
- commit 84a9af1
* Wed Sep  4 2019 mhocko@suse.com
- x86/ptrace: Fix possible spectre-v1 in ptrace_get_debugreg()
  (bnc#1149376, CVE-2019-15902).
- commit b08113e
* Wed Sep  4 2019 jthumshirn@suse.de
- Btrfs: add one more sanity check for shared ref type
  (bsc#1149325).
- Btrfs: remove BUG_ON in __add_tree_block (bsc#1149325).
- Btrfs: remove BUG() in add_data_reference (bsc#1149325).
- Btrfs: remove BUG() in print_extent_item (bsc#1149325).
- Btrfs: remove BUG() in btrfs_extent_inline_ref_size
  (bsc#1149325).
- Btrfs: convert to use btrfs_get_extent_inline_ref_type
  (bsc#1149325).
- Btrfs: add a helper to retrive extent inline ref type
  (bsc#1149325).
- commit cfb980a
* Wed Sep  4 2019 vbabka@suse.cz
- mm/memcontrol.c: fix use after free in mem_cgroup_iter()
  (bsc#1149224, VM Functionality).
- commit ac66c64
* Tue Sep  3 2019 tiwai@suse.de
- Fix patch tags (references, patch-mainline) for legacy patches
  so that now all patches.suse/* pass check-patchhdr tests
- commit 192eaa2
* Tue Sep  3 2019 msuchanek@suse.de
- powerpc/fadump: when fadump is supported register the fadump
  sysfs files (bsc#1146352).
- commit 841a3ce
* Tue Sep  3 2019 vbabka@suse.cz
- mm/vmscan.c: fix trying to reclaim unevictable LRU page
  (bsc#1149214, VM Functionality).
- commit 6a7c2cb
* Tue Sep  3 2019 oneukum@suse.com
- iwlwifi: dbg: split iwl_fw_error_dump to two functions
  (bsc#1119086).
- commit 1d624ef
* Tue Sep  3 2019 vbabka@suse.cz
- blacklist.conf: blacklist several MM git-fixes suggestions, with reasons
- commit 428ccb6
* Tue Sep  3 2019 vbabka@suse.cz
- mm, page_owner: handle THP splits correctly (bsc#1149197,
  VM Debugging Functionality).
- commit a83b4e4
* Tue Sep  3 2019 lhenriques@suse.com
- ceph: hold i_ceph_lock when removing caps for freeing inode
  (bsc#1148133).
- commit 629b4f4
* Tue Sep  3 2019 tiwai@suse.de
- Rename patches to the unified patches.suse directory
  To adapt the directory structure like master/stable/SLE15-SP2 branches.
  No code change by this action at all.
- commit 7cc35ba
* Mon Sep  2 2019 tiwai@suse.de
- blacklist.conf: Add an entry for CVE that is needed only for SLE15-SP1+
- commit c68886c
* Mon Sep  2 2019 tiwai@suse.de
- ASoC: Fail card instantiation if DAI format setup fails
  (bsc#1051510).
- commit a3eaad8
* Mon Sep  2 2019 jroedel@suse.de
- KVM: x86: Don't update RIP or do single-step on faulting
  emulation (bsc#1149104).
- PCI: PM/ACPI: Refresh all stale power state data in
  pci_pm_complete() (bsc#1149106).
- iommu/amd: Move iommu_init_pci() to .init section (bsc#1149105).
- commit 17b069a
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/nouveau: Don't retry infinitely when receiving no data on i2c (bsc#1142635)
- commit 46e796d
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/mediatek: mtk_drm_drv.c: Add of_node_put() before goto (bsc#1142635)
- commit 98b8c4a
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/mediatek: use correct device to import PRIME buffers (bsc#1142635)
- commit 1e19002
* Mon Sep  2 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Fix various tracepoints for gen2'
- commit 38319ef
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/i915: Fix wrong escape clock divisor init for GLK (bsc#1142635)
- commit c80e12d
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/rockchip: Suspend DP late (bsc#1142635)
- commit 1089448
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/i915/perf: ensure we keep a reference on the driver (bsc#1142635)
- commit 7bd2cc2
* Mon Sep  2 2019 tzimmermann@suse.de
- gpu: ipu-v3: ipu-ic: Fix saturation bit offset in TPMEM (bsc#1142635)
- commit 7ac15a8
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/msm/mdp5: Fix mdp5_cfg_init error return (bsc#1142635)
- commit b980f78
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/imx: only send event on crtc disable if kept disabled (bsc#1135642)
- commit b07f744
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/imx: notify drm core before sending event during crtc disable (bsc#1135642)
- commit 9612fe4
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/etnaviv: add missing failure path to destroy suballoc (bsc#1135642)
- commit 514d0e0
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/vmwgfx: fix a warning due to missing dma_parms (bsc#1135642)
- commit e42b762
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/vmwgfx: Use the backdoor port if the HB port is not available (bsc#1135642)
- commit ef3cc96
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/mediatek: call mtk_dsi_stop() after mtk_drm_crtc_atomic_disable() (bsc#1135642)
- commit eddd851
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/mediatek: clear num_pipes when unbind driver (bsc#1135642)
- commit 41d1d1c
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/mediatek: call drm_atomic_helper_shutdown() when unbinding driver (bsc#1135642)
- commit e1a36d5
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/mediatek: unbind components in mtk_drm_unbind() (bsc#1135642)
- commit a2c6951
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/mediatek: fix unbind functions (bsc#1135642)
- commit cab18d8
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/amdgpu/psp: move psp version specific function pointers to (bsc#1135642)
- commit 30a932b
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/udl: move to embedding drm device inside udl device. (bsc#1113722)
- commit d5b1803
* Mon Sep  2 2019 tzimmermann@suse.de
- drm/udl: introduce a macro to convert dev to udl. (bsc#1113722)
- commit ecbbcc3
* Mon Sep  2 2019 jslaby@suse.cz
- ipip: validate header length in ipip_tunnel_xmit (git-fixes).
- commit 09a79ed
* Mon Sep  2 2019 mkubecek@suse.cz
- tcp: fix tcp_rtx_queue_tail in case of empty retransmit queue
  (CVE-2019-11477 bsc#1137586 bsc#1139751).
- move core networking kabi patches to the end of the section
- commit cc9fad9
* Mon Sep  2 2019 mkubecek@suse.cz
- xfrm: policy: Fix out-of-bound array accesses in
  __xfrm_policy_unlink (CVE-2019-15666 bsc#1148394).
- commit a9a90f0
* Sat Aug 31 2019 ailiopoulos@suse.com
- xfs: don't trip over uninitialized buffer on extent read of
  corrupted inode (bsc#1149053).
- commit c9da56d
* Fri Aug 30 2019 tiwai@suse.de
- octeon_mgmt: Fix MIX registers configuration on MTU setup
  (bsc#1051510).
- commit eea7d06
* Fri Aug 30 2019 tiwai@suse.de
- phy: renesas: rcar-gen2: Fix memory leak at error paths
  (bsc#1051510).
- phy: qcom-qusb2: Fix crash if nvmem cell not specified
  (bsc#1051510).
- commit 9e7fa12
* Fri Aug 30 2019 tiwai@suse.de
- rpmsg: smd: fix memory leak on channel create (bsc#1051510).
- rpmsg: smd: do not use mananged resources for endpoints and
  channels (bsc#1051510).
- rpmsg: added MODULE_ALIAS for rpmsg_char (bsc#1051510).
- commit d7c0ba2
* Fri Aug 30 2019 tiwai@suse.de
- rslib: Fix handling of of caller provided syndrome
  (bsc#1051510).
- rslib: Fix decoding of shortened codes (bsc#1051510).
- rsi: improve kernel thread handling to fix kernel panic
  (bsc#1051510).
- commit c4cce46
* Fri Aug 30 2019 tiwai@suse.de
- st_nci_hci_connectivity_event_received: null check the
  allocation (bsc#1051510).
- st21nfca_connectivity_event_received: null check the allocation
  (bsc#1051510).
- commit ef2a23a
* Fri Aug 30 2019 lduncan@suse.com
- Add unneeded git-fixes patches to blacklist.
- commit 32de733
* Fri Aug 30 2019 lduncan@suse.com
- scsi: sd: use mempool for discard special page (git-fixes).
- commit cad43a5
* Fri Aug 30 2019 neilb@suse.com
- NFS: Cleanup if nfs_match_client is interrupted (bsc#1134291).
- NFS: Fix a double unlock from nfs_match,get_client
  (bsc#1134291).
- NFS: make nfs_match_client killable (bsc#1134291).
- commit 45fc7a3
* Fri Aug 30 2019 lduncan@suse.com
- scsi: ufs: Fix NULL pointer dereference in
  ufshcd_config_vreg_hpm() (git-fixes).
- commit 65ae829
* Thu Aug 29 2019 lduncan@suse.com
- fix struct ufs_req removal of unused field (git-fixes).
- Revert "scsi: ufs: disable vccq if it's not needed by UFS
  device" (git-fixes).
- commit de6b9e1
* Thu Aug 29 2019 msuchanek@suse.de
- scsi: cxlflash: Mark expected switch fall-throughs
  (bsc#1148868).
- commit 6e0c73b
* Thu Aug 29 2019 msuchanek@suse.de
- ibmveth: Convert multicast list size for little-endian system
  (bsc#1061843).
- Refresh patches.suse/ibmveth-Update-ethtool-settings-to-reflect-virtual-p.patch.
- commit 256fe94
* Thu Aug 29 2019 oneukum@suse.com
- Update
  patches.drivers/USB-sisusbvga-fix-oops-in-error-path-of-sisusb_probe.patch
  (bsc#1146524 CVE-2019-15219).
  Added CVE
- commit 97dc108
* Wed Aug 28 2019 lduncan@suse.com
- scsi: esp_scsi: Track residual for PIO transfers (git-fixes)
  Also, mitigate kABI changes.
- commit e73b6be
* Wed Aug 28 2019 msuchanek@suse.de
- Revert "Do not enforce patch directories yet."
  Prepare to merge all patches to patches.suse.
- commit b886694
* Wed Aug 28 2019 jack@suse.cz
- blacklist.conf: Blacklist b5e02b484d6f
- commit 4f11966
* Wed Aug 28 2019 jack@suse.cz
- vfs: fix page locking deadlocks when deduping files
  (bsc#1148619).
- commit d37851d
* Wed Aug 28 2019 jack@suse.cz
- udf: Fix incorrect final NOT_ALLOCATED (hole) extent length
  (bsc#1148617).
- commit 2b252d1
* Wed Aug 28 2019 jack@suse.cz
- ext4: use jbd2_inode dirty range scoping (bsc#1148616).
- commit 12b3b4c
* Wed Aug 28 2019 jack@suse.cz
- jbd2: introduce jbd2_inode dirty range scoping (bsc#1148616).
- commit 5432bdc
* Wed Aug 28 2019 jack@suse.cz
- mm: add filemap_fdatawait_range_keep_errors() (bsc#1148616).
- commit d4658a8
* Wed Aug 28 2019 jack@suse.cz
- blacklist.conf: Blacklist 4e19d6b65fb4
- commit 5cf149d
* Wed Aug 28 2019 jack@suse.cz
- blacklist.conf: Blacklist 2e5384036277 and 02b016ca7f99
- commit 69ccf52
* Wed Aug 28 2019 vbabka@suse.cz
- blacklist.conf: add two commits suggested by git-fixes
- commit e79e5d9
* Wed Aug 28 2019 vbabka@suse.cz
- mm: do not stall register_shrinker() (bsc#1104902, VM
  Performance).
- commit e53832c
* Wed Aug 28 2019 vbabka@suse.cz
- mm: page_mapped: don't assume compound page is huge or THP
  (bsc#1148574, VM Functionality).
- commit 7d7c483
* Wed Aug 28 2019 tiwai@suse.de
- mwifiex: Fix three heap overflow at
  parsing element in cfg80211_ap_settings
  (CVE-2019-14814,bsc#1146512,CVE-2019-14815,bsc#1146514,CVE-2019-14816,bsc#1146516).
- commit 3d20ec5
* Wed Aug 28 2019 jslaby@suse.cz
- net: sched: verify that q!=NULL before setting q->flags
  (git-fixes).
- net: Fix netdev_WARN_ONCE macro (git-fixes).
- commit 824e4ec
* Wed Aug 28 2019 vbabka@suse.cz
- mm/mlock.c: mlockall error for flag MCL_ONFAULT (bsc#1148527,
  VM Functionality).
- commit e12a969
* Wed Aug 28 2019 vbabka@suse.cz
- mm/mlock.c: change count_mm_mlocked_page_nr return type
  (bsc#1148527, VM Functionality).
- commit 3830f43
* Wed Aug 28 2019 jthumshirn@suse.de
- rename patches according to their names in SLE15-SP1.
- commit ee1f8f0
* Wed Aug 28 2019 jslaby@suse.cz
- net: Introduce netdev_*_once functions
  (networking-stable-19_07_25).
- commit 92e5672
* Wed Aug 28 2019 oneukum@suse.com
- carl9170: fix misuse of device driver API (bsc#1142635).
- commit f2e9e8d
* Wed Aug 28 2019 oneukum@suse.com
- blacklist.conf: only logged messages
- commit 7edba04
* Wed Aug 28 2019 oneukum@suse.com
- p54usb: Fix race between disconnect and firmware loading
  (bsc#1146526 CVE-2019-15220).
- commit a52b2b6
* Wed Aug 28 2019 jslaby@suse.cz
- netrom: hold sock when setting skb->destructor
  (networking-stable-19_07_25).
- vrf: make sure skb->data contains ip header to make routing
  (networking-stable-19_07_25).
- net: bcmgenet: use promisc for unsupported filters
  (networking-stable-19_07_25).
- net_sched: unset TCQ_F_CAN_BYPASS when adding filters
  (networking-stable-19_07_25).
- caif-hsi: fix possible deadlock in cfhsi_exit_module()
  (networking-stable-19_07_25).
- net: neigh: fix multiple neigh timer scheduling
  (networking-stable-19_07_25).
- net/mlx5e: IPoIB, Add error path in mlx5_rdma_setup_rn
  (networking-stable-19_07_25).
- tcp: Reset bytes_acked and bytes_received when disconnecting
  (networking-stable-19_07_25).
- bonding: validate ip header before check IPPROTO_IGMP
  (networking-stable-19_07_25).
- rxrpc: Fix send on a connected, but unbound socket
  (networking-stable-19_07_25).
- net: bridge: stp: don't cache eth dest pointer before skb pull
  (networking-stable-19_07_25).
- net: bridge: mcast: fix stale ipv6 hdr pointer when handling
  v6 query (networking-stable-19_07_25).
- net: bridge: mcast: fix stale nsrcs pointer in igmp3/mld2
  report handling (networking-stable-19_07_25).
- netrom: fix a memory leak in nr_rx_frame()
  (networking-stable-19_07_25).
- ipv4: don't set IPv6 only flags to IPv4 addresses
  (networking-stable-19_07_25).
- net: openvswitch: fix csum updates for MPLS actions
  (networking-stable-19_07_25).
- net: dsa: mv88e6xxx: wait after reset deactivation
  (networking-stable-19_07_25).
- bnx2x: Prevent ptp_task to be rescheduled indefinitely
  (networking-stable-19_07_25).
- igmp: fix memory leak in igmpv3_del_delrec()
  (networking-stable-19_07_25).
- net: make skb_dst_force return true when dst is refcounted
  (networking-stable-19_07_25).
- commit e44b93f
* Wed Aug 28 2019 msuchanek@suse.de
- powerpc/fsl: Update Spectre v2 reporting (bsc#1131107).
- Refresh patches.arch/powerpc-security-Fix-spectre_v2-reporting.patch.
- commit 4c5194e
* Wed Aug 28 2019 msuchanek@suse.de
- powerpc/64s: support nospectre_v2 cmdline option (bsc#1131107).
- commit 073289a
* Wed Aug 28 2019 msuchanek@suse.de
- powerpc/security: Show powerpc_security_features in debugfs
  (bsc#1131107).
- commit 1958fa2
* Wed Aug 28 2019 msuchanek@suse.de
- powerpc/fsl: Add nospectre_v2 command line argument (bsc#1131107).
- Refresh patches.arch/powerpc-speculation-support-mitigations-cmdline-option.patch.
- commit 21aaf15
* Wed Aug 28 2019 lduncan@suse.com
- scsi: core: Fix race on creating sense cache (git-fixes).
- scsi: libfc: fix null pointer dereference on a null lport
  (git-fixes).
- scsi: megaraid_sas: Fix calculation of target ID (git-fixes).
- scsi: mac_scsi: Fix pseudo DMA implementation, take 2
  (git-fixes).
- scsi: mac_scsi: Increase PIO/PDMA transfer length threshold
  (git-fixes).
- scsi: NCR5380: Always re-enable reselection interrupt
  (git-fixes).
- Revert "scsi: ncr5380: Increase register polling limit"
  (git-fixes).
- scsi: ufs: Avoid runtime suspend possibly being blocked forever
  (git-fixes).
- scsi: smartpqi: unlock on error in
  pqi_submit_raid_request_synchronous() (git-fixes).
- scsi: ufs: Check that space was properly alloced in
  copy_query_response (git-fixes).
- scsi: libsas: delete sas port if expander discover failed
  (git-fixes).
- scsi: scsi_dh_alua: Fix possible null-ptr-deref (git-fixes).
- scsi: bnx2fc: fix incorrect cast to u64 on shift operation
  (git-fixes).
- scsi: qla2xxx: Avoid that qlt_send_resp_ctio() corrupts memory
  (git-fixes).
- scsi: qla2xxx: Fix error handling in qlt_alloc_qfull_cmd()
  (git-fixes).
- scsi: qla2xxx: Fix a format specifier (git-fixes).
- scsi: qla2xxx: Update two source code comments (git-fixes).
- scsi: ufs: Fix RX_TERMINATION_FORCE_ENABLE define value
  (git-fixes).
- scsi: qla2xxx: Fix device staying in blocked state (git-fixes).
- scsi: qedf: remove memset/memcpy to nfunc and use func instead
  (git-fixes).
- scsi: qla2xxx: Unregister chrdev if module initialization fails
  (git-fixes).
- scsi: qla4xxx: avoid freeing unallocated dma memory (git-fixes).
- scsi: core: set result when the command cannot be dispatched
  (git-fixes).
- scsi: aacraid: Fix performance issue on logical drives
  (git-fixes).
- scsi: aacraid: Fix missing break in switch statement
  (git-fixes).
- scsi: libsas: Fix rphy phy_identifier for PHYs with end devices
  attached (git-fixes).
- scsi: aic94xx: fix module loading (git-fixes).
- scsi: isci: initialize shost fully before calling
  scsi_add_host() (git-fixes).
- scsi: core: Synchronize request queue PM status only on
  successful resume (git-fixes).
- scsi: megaraid: fix out-of-bound array accesses (git-fixes).
- scsi: bnx2fc: Fix NULL dereference in error handling
  (git-fixes).
- scsi: raid_attrs: fix unused variable warning (git-fixes).
- scsi: qla2xxx: Fix an endian bug in fcpcmd_is_corrupted()
  (git-fixes).
- scsi: aic94xx: fix an error code in aic94xx_init() (git-fixes).
- commit 4450608
* Wed Aug 28 2019 lduncan@suse.com
- scsi: fas216: fix sense buffer initialization (git-fixes).
- commit d2f7d7c
* Tue Aug 27 2019 tiwai@suse.de
- ALSA: seq: Fix potential concurrent access to the deleted pool
  (bsc#1051510).
- ALSA: line6: Fix memory leak at line6_init_pcm() error path
  (bsc#1051510).
- commit 66bd261
* Tue Aug 27 2019 tiwai@suse.de
- Move upstreamed nvme fix into sorted section
- commit ec1fcd6
* Tue Aug 27 2019 osalvador@suse.de
- mm/hotplug: fix offline undo_isolate_page_range() (bsc#1148196,
  VM Functionality).
- commit 70a79d6
* Tue Aug 27 2019 bp@suse.de
- Move patches to the sorted section.
- Refresh
  patches.arch/0001-x86-speculation-Prepare-entry-code-for-Spectre-v1-sw.patch.
- Refresh
  patches.suse/x86-cpufeatures-Carve-out-CQM-features-retrieval.patch.
- Refresh
  patches.suse/x86-cpufeatures-Combine-word-11-and-12-into-a-new-sc.patch.
- Refresh
  patches.suse/x86-cpufeatures-Enumerate-the-new-AVX512-BFLOAT16-in.patch.
- Refresh
  patches.suse/x86-topology-Add-CPUID.1F-multi-die-package-support.patch.
- commit 7153216
* Tue Aug 27 2019 vbabka@suse.cz
- mm/list_lru.c: fix memory leak in __memcg_init_list_lru_node
  (bsc#1148379, VM Functionality).
- commit ca01c4e
* Tue Aug 27 2019 aaptel@suse.com
- Refresh
  patches.fixes/cifs-do-not-return-atime-less-than-mtime.patch.
  4.12 doesn't have use timespec64 yet for inode [amc]time.
- commit 4f84a09
* Tue Aug 27 2019 vbabka@suse.cz
- mm/memory.c: recheck page table entry with page table lock held
  (bsc#1148363, VM Functionality).
- commit 1bb3033
* Tue Aug 27 2019 vbabka@suse.cz
- blacklist.conf: add trivial entries for SLAB, SLUB, and bsc#1148303 comment 1
- commit fc0cecb
* Tue Aug 27 2019 lhenriques@suse.com
- libceph: fix PG split vs OSD (re)connect race (bsc#1148133).
- ceph: don't try fill file_lock on unsuccessful GETFILELOCK reply
  (bsc#1148133).
- ceph: fix buffer free while holding i_ceph_lock in fill_inode()
  (bsc#1148133).
- ceph: fix buffer free while holding i_ceph_lock in
  __ceph_build_xattrs_blob() (bsc#1148133).
- ceph: fix buffer free while holding i_ceph_lock in
  __ceph_setxattr() (bsc#1148133).
- libceph: allow ceph_buffer_put() to receive a NULL ceph_buffer
  (bsc#1148133).
- commit b497133
* Tue Aug 27 2019 colyli@suse.de
- dm table: fix invalid memory accesses with too high sector
  number (git fixes).
- dm space map metadata: fix missing store of apply_bops()
  return value (git fixes).
- dm btree: fix order of block initialization in
  btree_split_beneath (git fixes).
- dm raid: add missing cleanup in raid_ctr() (git fixes).
- dm zoned: fix potential NULL dereference in dmz_do_reclaim()
  (git fixes).
- dm zoned: properly handle backing device failure (git fixes).
- dm zoned: improve error handling in i/o map code (git fixes).
- dm zoned: improve error handling in reclaim (git fixes).
- dm kcopyd: always complete failed jobs (git fixes).
- Revert "dm bufio: fix deadlock with loop device" (git fixes).
- loop: set PF_MEMALLOC_NOIO for the worker thread (git fixes).
- nbd: replace kill_bdev() with __invalidate_device() again
  (git fixes).
- bcache: fix possible memory leak in bch_cached_dev_run()
  (git fixes).
- dm zoned: fix zone state management race (git fixes).
- dm bufio: fix deadlock with loop device (git fixes).
- nilfs2: do not use unexported cpu_to_le32()/le32_to_cpu()
  in uapi header (git fixes).
- block, documentation: Fix wbt_lat_usec documentation (git
  fixes).
- dm log writes: make sure super sector log updates are written
  in order (git fixes).
- blk-mq: Fix spelling in a source code comment (git fixes).
- bio: fix improper use of smp_mb__before_atomic() (git fixes).
- dm delay: fix a crash when invalid device is specified
  (git fixes).
- dm cache metadata: Fix loading discard bitset (git fixes).
- dm zoned: Fix zone report handling (git fixes).
- dm zoned: Silence a static checker warning (git fixes).
- include/linux/bitops.h: sanitize rotate primitives (git fixes).
- md/raid: raid5 preserve the writeback action after the parity
  check (git fixes).
- md: add mddev->pers to avoid potential NULL pointer dereference
  (git fixes).
- smpboot: Place the __percpu annotation correctly (git fixes).
- dm table: propagate BDI_CAP_STABLE_WRITES to fix sporadic
  checksum errors (git fixes).
- dm: revert 8f50e358153d ("dm: limit the max bio size as
  BIO_MAX_PAGES * PAGE_SIZE") (git fixes).
- dm integrity: change memcmp to strncmp in dm_integrity_ctr
  (git fixes).
- dm integrity: limit the rate of error messages (git fixes).
- dm: fix to_sector() for 32bit (git fixes).
- devres: always use dev_name() in devm_ioremap_resource()
  (git fixes).
- dm thin: fix bug where bio that overwrites thin block ignores
  FUA (git fixes).
- dm crypt: don't overallocate the integrity tag space (git
  fixes).
- dm thin: fix passdown_double_checking_shared_status()
  (git fixes).
- dm crypt: fix parsing of extended IV arguments (git fixes).
- kasan: remove redundant initialization of variable 'real_size'
  (git fixes).
- commit 3ed4cbb
* Tue Aug 27 2019 oneukum@suse.com
- usb: gadget: udc: renesas_usb3: Fix sysfs interface of "role"
  (bsc#1142635).
- commit f54d38c
* Tue Aug 27 2019 lhenriques@suse.com
- ceph: remove request from waiting list before unregister
  (bsc#1148133).
- ceph: don't blindly unregister session that is in opening state
  (bsc#1148133).
- ceph: fix improper use of smp_mb__before_atomic() (bsc#1148133).
- ceph: fix "ceph.dir.rctime" vxattr value (bsc#1148133 bsc#1135219).
- ceph: silence a checker warning in mdsc_show() (bsc#1148133).
- commit b097a5c
* Tue Aug 27 2019 jack@suse.cz
- patches.fixes/block-Don-t-revalidate-bdev-of-hidden-gendisk.patch:
  Update patch metadata
- commit 84d4ac0
* Tue Aug 27 2019 jack@suse.cz
- patches.suse/mm-migrate-Fix-reference-check-race-between-__find_get_block-and-migration.patch:
  Update patch metadata.
- commit a81cc2e
* Mon Aug 26 2019 vbabka@suse.cz
- mm/hmm: fix bad subpage pointer in try_to_unmap_one
  (bsc#1148202, HMM, VM Functionality).
- commit 00ab508
* Mon Aug 26 2019 vbabka@suse.cz
- mm/migrate.c: initialize pud_entry in migrate_vma()
  (bsc#1148198, HMM, VM Functionality).
- commit 69e9c3c
* Mon Aug 26 2019 vbabka@suse.cz
- mm/page_alloc.c: fix calculation of pgdat->nr_zones
  (bsc#1148192, VM Functionality).
- commit 1e427e5
* Mon Aug 26 2019 jslaby@suse.cz
- crypto: ccp - Ignore unconfigured CCP device on suspend/resume
  (bnc#1145934).
- commit 0c22d13
* Mon Aug 26 2019 ailiopoulos@suse.com
- Update
  patches.fixes/xfs-fix-missing-ILOCK-unlock-when-xfs_setattr_nonsiz.patch
  (bsc#1148032, bsc#1148093, CVE-2019-15538).
- commit ee9764b
* Mon Aug 26 2019 tiwai@suse.de
- Update reference for ath6kl fix (CVE-2019-15290,bsc#1146543).
- commit 637ad3b
* Mon Aug 26 2019 tiwai@suse.de
- Fix a NULL-ptr-deref bug in ath6kl_usb_alloc_urb_from_pipe
  (CVE-2019-15098,bsc#1146378).
- commit cdac0a6
* Mon Aug 26 2019 jthumshirn@suse.de
- nvme: introduce NVME_QUIRK_IGNORE_DEV_SUBNQN (bsc#1146938).
- commit a84bc8e
* Mon Aug 26 2019 bpoirier@suse.com
- tcp: reset sk_send_head in tcp_write_queue_purge (bsc#1146589
  CVE-2019-15239).
- commit 8e3f3fe
* Mon Aug 26 2019 tiwai@suse.de
- gpio: Fix build error of function redefinition (bsc#1051510).
- gpiolib: never report open-drain/source lines as 'input'
  to user-space (bsc#1051510).
- staging: comedi: dt3000: Fix rounding up of timer divisor
  (bsc#1051510).
- staging: comedi: dt3000: Fix signed integer overflow 'divider *
  base' (bsc#1051510).
- compat_ioctl: pppoe: fix PPPOEIOCSFWD handling (bsc#1051510).
- coredump: split pipe command whitespace before expanding
  template (bsc#1051510).
- can: m_can: implement errata "Needless activation of MRAF irq"
  (bsc#1051510).
- can: mcp251x: add support for mcp25625 (bsc#1051510).
- commit 5f9daf9
* Mon Aug 26 2019 tiwai@suse.de
- iio: adc: max9611: Fix temperature reading in probe
  (bsc#1051510).
- USB: serial: option: add the BroadMobi BM818 card (bsc#1051510).
- USB: serial: option: Add Motorola modem UARTs (bsc#1051510).
- USB: serial: option: add D-Link DWM-222 device ID (bsc#1051510).
- USB: serial: option: Add support for ZTE MF871A (bsc#1051510).
- USB: core: Fix races in character device registration and
  deregistraion (bsc#1051510).
- Input: iforce - add sanity checks (bsc#1051510).
- Input: kbtab - sanity check for endpoint type (bsc#1051510).
- net: usb: pegasus: fix improper read if get_registers() fail
  (bsc#1051510).
- HID: hiddev: avoid opening a disconnected device (bsc#1051510).
- HID: holtek: test for sanity of intfdata (bsc#1051510).
- commit b2ad825
* Sun Aug 25 2019 ailiopoulos@suse.com
- xfs: don't crash on null attr fork xfs_bmapi_read (bsc#1148035).
- commit 527c60c
* Sun Aug 25 2019 ailiopoulos@suse.com
- xfs: remove more ondisk directory corruption asserts
  (bsc#1148034).
- commit 307da1f
* Sun Aug 25 2019 ailiopoulos@suse.com
- fs: xfs: xfs_log: Don't use KM_MAYFAIL at xfs_log_reserve()
  (bsc#1148033).
- commit 1bf8e6b
* Sun Aug 25 2019 ailiopoulos@suse.com
- xfs: fix missing ILOCK unlock when xfs_setattr_nonsize fails
  due to EDQUOT (bsc#1148032).
- commit 2c4862c
* Sun Aug 25 2019 ailiopoulos@suse.com
- fs/xfs: Fix return code of xfs_break_leased_layouts()
  (bsc#1148031).
- commit be52cec
* Fri Aug 23 2019 tiwai@suse.de
- Update config files: correct vanilla configs
- commit f890c54
* Fri Aug 23 2019 palcantara@suse.de
- Delete
  patches.fixes/0001-CIFS-Fix-NULL-pointer-deref-on-SMB2_tcon-failure.patch.
- Delete
  patches.fixes/0001-CIFS-dump-IPC-tcon-in-debug-proc-file.patch.
- Delete patches.fixes/0001-CIFS-make-IPC-a-regular-tcon.patch.
- Delete
  patches.fixes/0001-CIFS-use-tcon_ipc-instead-of-use_ipc-parameter-of-SM.patch.
- Delete
  patches.fixes/0001-CIFS-zero-sensitive-data-when-freeing.patch.
- Delete
  patches.fixes/0001-Fix-SMB3.1.1-guest-authentication-to-Samba.patch.
- Delete
  patches.fixes/0001-Fix-encryption-labels-and-lengths-for-SMB3.1.1.patch.
- Delete
  patches.fixes/0001-SMB-Validate-negotiate-to-protect-against-downgrade-.patch.
- Delete
  patches.fixes/0001-SMB3-Don-t-ignore-O_SYNC-O_DSYNC-and-O_DIRECT-flags.patch.
- Delete
  patches.fixes/0001-SMB3-Warn-user-if-trying-to-sign-connection-that-aut.patch.
- Delete patches.fixes/0001-SMB3-handle-new-statx-fields.patch.
- Delete
  patches.fixes/0001-cifs-Check-for-timeout-on-Negotiate-stage.patch.
- Delete
  patches.fixes/0001-cifs-Fix-autonegotiate-security-settings-mismatch.patch.
- Delete
  patches.fixes/0001-cifs-Fix-missing-put_xid-in-cifs_file_strict_mmap.patch.
- Delete
  patches.fixes/0001-cifs-Fix-stack-out-of-bounds-in-smb-2-3-_create_leas.patch.
- Delete
  patches.fixes/0001-cifs-Select-all-required-crypto-modules.patch.
- Delete
  patches.fixes/0001-cifs-check-MaxPathNameComponentLength-0-before-using.patch.
- Delete patches.fixes/0001-cifs-check-kmalloc-before-use.patch.
- Delete
  patches.fixes/0001-cifs-check-rsp-for-NULL-before-dereferencing-in-SMB2.patch.
- Delete
  patches.fixes/0001-cifs-fix-NULL-deref-in-SMB2_read.patch.
- Delete
  patches.fixes/0001-cifs-release-auth_key.response-for-reconnect.patch.
- Delete
  patches.fixes/0001-cifs-release-cifs-root_cred-after-exit_cifs.patch.
- Delete
  patches.fixes/0001-cifs-store-the-leaseKey-in-the-fid-on-SMB2_open.patch.
- Delete
  patches.fixes/CIFS-511c54a2f69195b28afb9dd119f03787b1625bb4-adds-a-check-for-sess.patch.
- Delete
  patches.fixes/CIFS-Do-not-count-ENODATA-as-failure-for-query-direc.patch.
- Delete
  patches.fixes/CIFS-Do-not-hide-EINTR-after-sending-network-packets.patch.
- Delete
  patches.fixes/CIFS-Do-not-reconnect-TCP-session-in-add_credits.patch.
- Delete
  patches.fixes/CIFS-Do-not-reset-lease-state-to-NONE-on-lease-break.patch.
- Delete
  patches.fixes/CIFS-Fix-adjustment-of-credits-for-MTU-requests.patch.
- Delete
  patches.fixes/CIFS-Fix-credit-calculation-for-encrypted-reads-with.patch.
- Delete
  patches.fixes/CIFS-Fix-credits-calculations-for-reads-with-errors.patch.
- Delete
  patches.fixes/CIFS-Fix-error-mapping-for-SMB2_LOCK-command-which-c.patch.
- Delete
  patches.fixes/CIFS-Fix-possible-hang-during-async-MTU-reads-and-wr.patch.
- Delete
  patches.fixes/CIFS-Fix-read-after-write-for-files-with-read-cachin.patch.
- Delete patches.fixes/CIFS-add-sha512-secmech.patch.
- Delete
  patches.fixes/CIFS-don-t-log-STATUS_NOT_FOUND-errors-for-DFS.patch.
- Delete
  patches.fixes/CIFS-fix-POSIX-lock-leak-and-invalid-ptr-deref.patch.
- Delete patches.fixes/CIFS-fix-circular-locking-dependency.patch.
- Delete
  patches.fixes/CIFS-fix-sha512-check-in-cifs_crypto_secmech_release.patch.
- Delete
  patches.fixes/CIFS-fix-wrapping-bugs-in-num_entries.patch.
- Delete
  patches.fixes/CIFS-implement-v3.11-preauth-integrity.patch.
- Delete
  patches.fixes/CIFS-keep-FileInfo-handle-live-during-oplock-break.patch.
- Delete
  patches.fixes/CIFS-make-nodfs-mount-opt-a-superblock-flag.patch.
- Delete
  patches.fixes/CIFS-refactor-crypto-shash-sdesc-allocation-free.patch.
- Delete
  patches.fixes/SMB-fix-leak-of-validate-negotiate-info-response-buf.patch.
- Delete
  patches.fixes/SMB-fix-validate-negotiate-info-uninitialised-memory.patch.
- Delete
  patches.fixes/SMB3-Add-support-for-multidialect-negotiate-SMB2.1-a.patch.
- Delete
  patches.fixes/SMB3-Backup-intent-flag-missing-for-directory-opens-.patch.
- Delete patches.fixes/SMB3-Enable-encryption-for-SMB3.1.1.patch.
- Delete
  patches.fixes/SMB3-Fix-3.11-encryption-to-Windows-and-handle-encry.patch.
- Delete
  patches.fixes/SMB3-Fix-SMB3.1.1-guest-mounts-to-Samba.patch.
- Delete patches.fixes/SMB3-Fix-endian-warning.patch.
- Delete
  patches.fixes/SMB3-Fix-length-checking-of-SMB3.11-negotiate-reques.patch.
- Delete
  patches.fixes/SMB3-Improve-security-move-default-dialect-to-SMB3-f.patch.
- Delete
  patches.fixes/SMB3-Remove-ifdef-since-SMB3-and-later-now-STRONGLY-.patch.
- Delete
  patches.fixes/SMB3-Validate-negotiate-request-must-always-be-signe.patch.
- Delete
  patches.fixes/SMB3.1.1-dialect-is-no-longer-experimental.patch.
- Delete patches.fixes/SMB311-Fix-reconnect.patch.
- Delete
  patches.fixes/SMB311-Improve-checking-of-negotiate-security-contex.patch.
- Delete
  patches.fixes/cifs-Add-support-for-reading-attributes-on-SMB2.patch.
- Delete
  patches.fixes/cifs-Add-support-for-writing-attributes-on-SMB2.patch.
- Delete
  patches.fixes/cifs-Do-not-modify-mid-entry-after-submitting-I-O-in.patch.
- Delete
  patches.fixes/cifs-Don-t-log-confusing-message-on-reconnect-by-default.patch.
- Delete
  patches.fixes/cifs-Don-t-log-expected-error-on-DFS-referral-request.patch.
- Delete
  patches.fixes/cifs-Fix-infinite-loop-when-using-hard-mount-.patch.
- Delete patches.fixes/cifs-Fix-memory-leak-in-smb2_set_ea.patch.
- Delete
  patches.fixes/cifs-Fix-potential-OOB-access-of-lock-element-array.patch.
- Delete
  patches.fixes/cifs-Fix-separator-when-building-path-from-dentry.patch.
- Delete
  patches.fixes/cifs-Fix-use-after-free-of-a-mid_q_entry.patch.
- Delete
  patches.fixes/cifs-For-SMB2-security-informaion-query-check-for-mi.patch.
- Delete
  patches.fixes/cifs-OFD-locks-do-not-conflict-with-eachothers.patch.
- Delete
  patches.fixes/cifs-Tree-connect-for-SMB3.1.1-must-be-signed-for-non-enc.patch.
- Delete
  patches.fixes/cifs-Use-ULL-suffix-for-64-bit-constant.patch.
- Delete
  patches.fixes/cifs-Use-smb-2-3-and-cifsacl-mount-options-getacl-fu.patch.
- Delete
  patches.fixes/cifs-Use-smb-2-3-and-cifsacl-mount-options-setacl-fu.patch.
- Delete
  patches.fixes/cifs-add-missing-debug-entries-for-kconfig-options.patch.
- Delete
  patches.fixes/cifs-add-missing-support-for-ACLs-in-SMB-3.11.patch.
- Delete
  patches.fixes/cifs-allow-guest-mounts-to-work-for-smb3.11.patch.
- Delete
  patches.fixes/cifs-connect-to-servername-instead-of-IP-for-IPC-sha.patch.
- Delete
  patches.fixes/cifs-do-not-allow-creating-sockets-except-with-SMB1-posix-exensions.patch.
- Delete
  patches.fixes/cifs-don-t-dereference-smb_file_target-before-null-c.patch.
- Delete patches.fixes/cifs-fix-memory-leak-in-SMB2_open-.patch.
- Delete
  patches.fixes/cifs-fix-return-value-for-cifs_listxattr.patch.
- Delete patches.fixes/cifs-hide-unused-functions.patch.
- Delete
  patches.fixes/cifs-integer-overflow-in-in-SMB2_ioctl.patch.
- Delete
  patches.fixes/cifs-invalidate-cache-when-we-truncate-a-file.patch.
- Delete
  patches.fixes/cifs-prevent-integer-overflow-in-nxt_dir_entry.patch.
- Delete
  patches.fixes/cifs-prototype-declaration-and-definition-for-smb-2-.patch.
- Delete
  patches.fixes/cifs-prototype-declaration-and-definition-to-set-acl.patch.
- Delete
  patches.fixes/cifs-silence-compiler-warnings-showing-up-with-gcc-8.patch.
- Delete
  patches.fixes/cifs-smb2ops-Fix-listxattr-when-there-are-no-EAs.patch.
- Delete patches.fixes/cifs-xattr-hide-unused-functions.patch.
- Delete
  patches.fixes/fix-smb3-encryption-breakage-when-CONFIG_DEBUG_SG-y.patch.
- Delete patches.fixes/fs-cifs-require-sha512.patch.
- Delete
  patches.fixes/smb2-fix-missing-files-in-root-share-directory-listing.patch.
- Delete
  patches.fixes/smb3-Do-not-send-SMB3-SET_INFO-if-nothing-changed.patch.
- Delete
  patches.fixes/smb3-Fix-root-directory-when-server-returns-inode-nu.patch.
- Delete
  patches.fixes/smb3-allow-stats-which-track-session-and-share-recon.patch.
- Delete
  patches.fixes/smb3-check-for-and-properly-advertise-directory-leas.patch.
- Delete
  patches.fixes/smb3-directory-sync-should-not-return-an-error.patch.
- Delete
  patches.fixes/smb3-do-not-attempt-cifs-operation-in-smb3-query-inf.patch.
- Delete
  patches.fixes/smb3-don-t-request-leases-in-symlink-creation-and-qu.patch.
- Delete
  patches.fixes/smb3-enumerating-snapshots-was-leaving-part-of-the-d.patch.
- Delete
  patches.fixes/smb3-fill-in-statfs-fsid-and-correct-namelen.patch.
- Delete
  patches.fixes/smb3-fix-reset-of-bytes-read-and-written-stats.patch.
- Delete patches.fixes/smb3-fix-various-xid-leaks.patch.
- Delete
  patches.fixes/smb3-on-kerberos-mount-if-server-doesn-t-specify-aut.patch.
- Delete
  patches.fixes/smb3-on-reconnect-set-PreviousSessionId-field.patch.
- Delete
  patches.fixes/smb3-remove-noisy-warning-message-on-mount.patch.
- Delete
  patches.fixes/smb3-simplify-code-by-removing-CONFIG_CIFS_SMB311.patch.
- Delete
  patches.suse/cifs-Always-resolve-hostname-before-reconnecting.patch.
- Delete
  patches.suse/cifs-Fix-NULL-pointer-dereference-of-devname.patch.
- Delete patches.suse/cifs-fix-set-info.patch.
- Update config files.
- commit e581c26
* Fri Aug 23 2019 colyli@suse.de
- Update patches.fixes/MD-fix-invalid-stored-role-for-a-disk-try2.patch
  (bsc#1143765).
- commit 34aad22
* Fri Aug 23 2019 hare@suse.de
- scsi: qla2xxx: Add cleanup for PCI EEH recovery (bsc#1129424).
- commit c414f17
* Fri Aug 23 2019 hare@suse.de
- nvme-core: Fix extra device_put() call on error path
  (bsc#1142541).
- commit d0ca8a3
* Fri Aug 23 2019 hare@suse.de
- nvme: change locking for the per-subsystem controller list
  (bsc#1142541).
- Refresh
  patches.fixes/nvme-fix-memory-leak-caused-by-incorrect-subsystem-free.patch.
- commit 5145006
* Thu Aug 22 2019 bp@suse.de
- x86/unwind: Add hardcoded ORC entry for NULL (bsc#1114279).
- commit 7b43378
* Thu Aug 22 2019 oneukum@suse.com
- Update
  patches.drivers/USB-rio500-fix-memory-leak-in-close-after-disconnect.patch
  (bsc#1051510 bsc#1146391 CVE-2019-15212).
- Update
  patches.drivers/USB-rio500-refuse-more-than-one-device-at-a-time.patch
  (bsc#1051510 bsc#1146391 CVE-2019-15212).
  Added CVE number
- commit 26c322a
* Thu Aug 22 2019 tiwai@suse.de
- Update patch tag for an already backported fix (CVE-2019-15292,bsc#1146678)
- commit 3fb5876
* Thu Aug 22 2019 tiwai@suse.de
- media: usb:zr364xx:Fix KASAN:null-ptr-deref Read in
  zr364xx_vidioc_querycap (CVE-2019-15217,bsc#1146547).
- commit 0cafaf1
* Thu Aug 22 2019 tiwai@suse.de
- media: radio-raremono: change devm_k*alloc to k*alloc
  (CVE-2019-15211,bsc#1146519).
- commit 418ad9b
* Wed Aug 21 2019 msuchanek@suse.de
- powerpc/rtas: use device model APIs and serialization during
  LPM (bsc#1144123 ltc#178840).
- commit 9cbdd0c
* Wed Aug 21 2019 tiwai@suse.de
- Yet another patch tag update for security fix (CVE-2019-15214,bsc#1146550)
- commit 9d5b64b
* Wed Aug 21 2019 tiwai@suse.de
- Update patch tags for already present securiy fixes (CVE-2019-15221,bsc#1146529,CVE-2019-15222,bsc#1146531)
- commit a8305b2
* Wed Aug 21 2019 bp@suse.de
- blacklist.conf:
  a9d57ef15cbe x86/retpolines: Disable switch jump tables when retpolines are enabled
- commit afa99a4
* Wed Aug 21 2019 bp@suse.de
- x86/unwind: Handle NULL pointer calls better in frame unwinder
  (bsc#1114279).
- commit f3e381b
* Wed Aug 21 2019 lhenriques@suse.com
- ceph: clean up ceph.dir.pin vxattr name sizeof() (bsc#1146346).
- ceph: support getting ceph.dir.pin vxattr (bsc#1146346).
- ceph: support versioned reply (bsc#1146346).
- ceph: decode feature bits in session message (bsc#1146346).
- ceph: support cephfs' own feature bits (bsc#1146346).
- ceph: always get rstat from auth mds (bsc#1146346).
- ceph: use bit flags to define vxattr attributes (bsc#1146346).
- commit 3b8d335
* Wed Aug 21 2019 hare@suse.de
- nvme-multipath: fix ana log nsid lookup when nsid is not found
  (bsc#1141554).
- commit 1d6ec2f
* Wed Aug 21 2019 hare@suse.de
- nvme: Return BLK_STS_TARGET if the DNR bit is set (bsc#1142076).
- commit c4afaf4
* Wed Aug 21 2019 msuchanek@suse.de
- libnvdimm/pfn: Store correct value of npfns in namespace
  superblock (bsc#1146381 ltc#180720).
- commit e703307
* Wed Aug 21 2019 msuchanek@suse.de
- powerpc: Allow flush_(inval_)dcache_range to work across ranges
  >4GB (bsc#1146575 ltc#180764).
- commit 1af9ac2
* Wed Aug 21 2019 oneukum@suse.com
- Update
  patches.drivers/media-usb-siano-Fix-general-protection-fault-in-smsu.patch
  (bsc#1051510 bsc#1146413 CVE-2019-15218).
  Added CVE number
- commit 7715a12
* Wed Aug 21 2019 oneukum@suse.com
- Update
  patches.fixes/0001-media-cpia2_usb-first-wake-up-then-free-in-disconnec.patch
  (bsc#1135642 bsc#1146425 CVE-2019-15215).
  Added CVE number
- commit b8d5415
* Wed Aug 21 2019 oneukum@suse.com
- HID: wacom: correct misreported EKR ring values (bsc#1142635).
- commit fff2c8e
* Wed Aug 21 2019 oneukum@suse.com
- HID: wacom: Correct distance scale for 2nd-gen Intuos devices
  (bsc#1142635).
- commit 938b6bc
* Wed Aug 21 2019 bp@suse.de
- blacklist.conf:
  ce02ef06fcf7 x86, retpolines: Raise limit for generating indirect calls from switch-case
- commit 58b4712
* Wed Aug 21 2019 palcantara@suse.de
- blacklist.conf: Add 33da8e7c814f ("signal: Allow cifs and drbd to receive their terminating signals")
- commit 7cf0c17
* Wed Aug 21 2019 lduncan@suse.com
- scsi: qedi: remove memset/memcpy to nfunc and use func instead
  (bsc#1146399 CVE-2019-15090).
- commit 6174892
* Tue Aug 20 2019 msuchanek@suse.de
- ibmvnic: Unmap DMA address of TX descriptor buffers after use
  (bsc#1146351 ltc#180726).
- commit 3b35ec5
* Tue Aug 20 2019 msuchanek@suse.de
- powerpc/fadump: use kstrtoint to handle sysfs store
  (bsc#1146376).
- Refresh patches.arch/powerpc-fadump-re-register-firmware-assisted-dump-if.patch.
- commit f2d2536
* Tue Aug 20 2019 oneukum@suse.com
- USB: CDC: fix sanity checks in CDC union parser (bsc#1142635).
- commit ea8f734
* Tue Aug 20 2019 oneukum@suse.com
- usb: cdc-acm: make sure a refcount is taken early enough
  (bsc#1142635).
- commit f73861c
* Tue Aug 20 2019 ailiopoulos@suse.com
- xfs: clear sb->s_fs_info on mount failure (bsc#1146285,
  CVE-2018-20976).
- commit 8cdb4f1
* Tue Aug 20 2019 ailiopoulos@suse.com
- nvme-multipath: revalidate nvme_ns_head gendisk in
  nvme_validate_ns (bsc#1120876).
- commit 40c0bfb
* Mon Aug 19 2019 tiwai@suse.de
- blacklist.conf: Remove the backported entry for i2c-core
- commit a2925e1
* Mon Aug 19 2019 tiwai@suse.de
- i2c: core-smbus: prevent stack corruption on read I2C_BLOCK_DATA
  (CVE-2017-18551,bsc#1146163).
- commit 8a3a796
* Mon Aug 19 2019 jroedel@suse.de
- iommu/dma: Handle SG length overflow better (bsc#1146084).
- commit aa7828b
* Mon Aug 19 2019 jroedel@suse.de
- KVM: x86: fix backward migration with async_PF (bsc#1146074).
- commit 1780c7c
* Mon Aug 19 2019 tiwai@suse.de
- blacklist.conf: Add a CVE entry that is valid only for SLE15-SP1+
- commit 1dc95cb
* Mon Aug 19 2019 nborisov@suse.com
- blacklist.conf: Add invalid btrfs commits
- commit e2305c6
* Sun Aug 18 2019 tiwai@suse.de
- iio: adc: max9611: Fix misuse of GENMASK macro (bsc#1051510).
- usb: usbfs: fix double-free of usb memory upon submiturb error
  (bsc#1051510).
- Input: synaptics - enable RMI mode for HP Spectre X360
  (bsc#1051510).
- mac80211: don't WARN on short WMM parameters from AP
  (bsc#1051510).
- HID: sony: Fix race condition between rumble and device remove
  (bsc#1051510).
- mac80211: don't warn about CW params when not using them
  (bsc#1051510).
- drivers/pps/pps.c: clear offset flags in PPS_SETPARAMS ioctl
  (bsc#1051510).
- commit ad7168f
* Sun Aug 18 2019 tiwai@suse.de
- crypto: ccp - Validate buffer lengths for copy operations
  (bsc#1051510).
- Refresh
  patches.fixes/crypto-ccp-Fix-3DES-complaint-from-ccp-crypto-module.patch.
- Refresh
  patches.fixes/crypto-ccp-gcm-use-const-time-tag-comparison.patch.
- commit ad0fc3d
* Sun Aug 18 2019 tiwai@suse.de
- crypto: ccp - Add support for valid authsize values less than 16
  (bsc#1051510).
- drm: silence variable 'conn' set but not used (bsc#1051510).
- commit e51846e
* Sun Aug 18 2019 tiwai@suse.de
- ALSA: hda - Add a generic reboot_notify (bsc#1051510).
- ALSA: hda - Let all conexant codec enter D3 when rebooting
  (bsc#1051510).
- ALSA: hda - Fix a memory leak bug (bsc#1051510).
- ALSA: hda - Apply workaround for another AMD chip 1022:1487
  (bsc#1051510).
- commit 5a16838
* Sat Aug 17 2019 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-add-missing-inode-version-ctime-and-mtime-upda.patch.
- commit caa1588
* Fri Aug 16 2019 tiwai@suse.de
- ALSA: usb-audio: Fix a stack buffer overflow bug in
  check_input_term (CVE-2019-15118,bsc#1145922).
- ALSA: usb-audio: Fix an OOB bug in parse_audio_mixer_unit
  (CVE-2019-15117,bsc#1145920).
- commit c68760f
* Fri Aug 16 2019 fdmanana@suse.com
- Btrfs: fix fsync not persisting dentry deletions due to inode
  evictions (bsc#1145942).
- commit 2b9288a
* Fri Aug 16 2019 fdmanana@suse.com
- Btrfs: fix data loss after inode eviction, renaming it, and
  fsync it (bsc#1145941).
- commit 94c1da3
* Fri Aug 16 2019 fdmanana@suse.com
- Btrfs: fix incremental send failure after deduplication
  (bsc#1145940).
- commit e44b16e
* Fri Aug 16 2019 fdmanana@suse.com
- Btrfs: fix race leading to fs corruption after transaction abort
  (bsc#1145937).
- commit fc04aaf
* Fri Aug 16 2019 fdmanana@suse.com
- Btrfs: add missing inode version, ctime and mtime updates when
  punching hole (bsc#1140487).
- commit 7426909
* Fri Aug 16 2019 palcantara@suse.de
- SMB3: Kernel oops mounting a encryptData share with
  CONFIG_DEBUG_VIRTUAL (bsc#1144333).
- commit 87dae80
* Fri Aug 16 2019 palcantara@suse.de
- smb3: send CAP_DFS capability during session setup
  (bsc#1144333).
- commit 0280850
* Fri Aug 16 2019 palcantara@suse.de
- SMB3: Fix potential memory leak when processing compound chain
  (bsc#1144333).
- commit 6f104b1
* Fri Aug 16 2019 palcantara@suse.de
- SMB3: Fix deadlock in validate negotiate hits reconnect
  (bsc#1144333).
- commit 0d88c19
* Fri Aug 16 2019 palcantara@suse.de
- cifs: fix rmmod regression in cifs.ko caused by force_sig
  changes (bsc#1144333).
- commit 76f5281
* Fri Aug 16 2019 bp@suse.de
- x86/speculation/mds: Apply more accurate check on hypervisor
  platform (bsc#1114279).
- commit 8a1df40
* Fri Aug 16 2019 bp@suse.de
- x86/boot: Fix memory leak in default_get_smp_config()
  (bsc#1114279).
- commit 648370e
* Fri Aug 16 2019 bp@suse.de
- cpu/speculation: Warn on unsupported mitigations= parameter
  (bsc#1114279).
- commit a78bef0
* Fri Aug 16 2019 bp@suse.de
- x86/speculation: Allow guests to use SSBD even if host does not
  (bsc#1114279).
- commit 66db1d6
* Fri Aug 16 2019 fyang@suse.com
- xfrm: Fix NULL pointer dereference in xfrm_input when
  skb_dst_force clears the dst_entry (bsc#1143300).
- xfrm: Fix bucket count reported to userspace (bsc#1143300).
- xfrm: Fix error return code in xfrm_output_one() (bsc#1143300).
- xfrm: Fix NULL pointer dereference when skb_dst_force clears
  the dst_entry (bsc#1143300).
- commit 8597a81
* Thu Aug 15 2019 tbogendoerfer@suse.de
- IB/mlx5: Fix MR registration flow to use UMR properly
  (bsc#1093205 bsc#1145678).
- net/mlx4_core: Zero out lkey field in SW2HW_MPT fw command
  (bsc#1145678).
- commit 6ffe96c
* Thu Aug 15 2019 nborisov@suse.com
- xfs: fix semicolon.cocci warnings (bsc#1145235).
- commit acbefc7
* Thu Aug 15 2019 nborisov@suse.com
- xfs: eliminate duplicate icreate tx reservation functions
  (bsc#1145235).
- xfs: refactor inode chunk alloc/free tx reservation
  (bsc#1145235).
- xfs: include an allocfree res for inobt modifications
  (bsc#1145235).
- xfs: truncate transaction does not modify the inobt
  (bsc#1145235).
- xfs: fix up agi unlinked list reservations (bsc#1145235).
- xfs: include inobt buffers in ifree tx log reservation
  (bsc#1145235).
- xfs: print transaction log reservation on overrun (bsc#1145235).
- commit 82d0f2c
* Thu Aug 15 2019 neilb@suse.com
- NFS: Fix the inode request accounting when pages have
  subrequests (bsc#1140012).
- commit ff722c4
* Wed Aug 14 2019 nborisov@suse.com
- xfs: dump transaction usage details on log reservation overrun
  (bsc#1145235).
- xfs: refactor xlog_cil_insert_items() to facilitate transaction
  dump (bsc#1145235).
- xfs: separate shutdown from ticket reservation print helper
  (bsc#1145235).
- commit 2eb4a53
* Wed Aug 14 2019 msuchanek@suse.de
- Rename patch to same nam as in SLE15 SP1.
- commit ee7b95e
* Tue Aug 13 2019 jroedel@suse.de
- KVM: LAPIC: Fix pending interrupt in IRR blocked by software
  disable LAPIC (bsc#1145408).
- KVM: x86: degrade WARN to pr_warn_ratelimited (bsc#1145409).
- commit 653821c
* Tue Aug 13 2019 jroedel@suse.de
- Fix kABI after KVM fixes
- commit 14d35d2
* Tue Aug 13 2019 jroedel@suse.de
- KVM: Fix leak vCPU's VMCS value into other pCPU (bsc#1145388).
- KVM: nVMX: do not use dangling shadow VMCS after guest reset
  (bsc#1145390).
- KVM: x86/vPMU: refine kvm_pmu err msg when event creation failed
  (bsc#1145397).
- KVM: x86: Unconditionally enable irqs in guest context
  (bsc#1145396).
- kvm: nVMX: Remove unnecessary sync_roots from handle_invept
  (bsc#1145391).
- KVM: nVMX: allow setting the VMFUNC controls MSR (bsc#1145389).
- KVM: VMX: check CPUID before allowing read/write of IA32_XSS
  (bsc#1145394).
- KVM: nVMX: Use adjusted pin controls for vmcs02 (bsc#1145392).
- KVM: VMX: Always signal #GP on WRMSR to MSR_IA32_CR_PAT with
  bad value (bsc#1145393).
- KVM: VMX: Fix handling of #MC that occurs during VM-Entry
  (bsc#1145395).
- commit 6dd2efc
* Tue Aug 13 2019 tiwai@suse.de
- mfd: intel-lpss: Add Intel Comet Lake PCI IDs (jsc#SLE-4875).
- mmc: sdhci-pci: Add support for Intel CML (jsc#SLE-4875).
- mmc: sdhci-pci: Add support for Intel ICP (jsc#SLE-4875).
- commit 24d868c
* Mon Aug 12 2019 msuchanek@suse.de
- powerpc/perf: Add constraints for power9 l2/l3 bus events
  (bsc#1056686).
- powerpc/perf: Cleanup cache_sel bits comment (bsc#1056686).
- powerpc/perf: Update perf_regs structure to include SIER
  (bsc#1056686).
- powerpc/perf: Fix thresholding counter data for unknown type
  (bsc#1056686).
- commit 97adfd9
* Mon Aug 12 2019 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix CR0 setting in TM emulation
  (bsc#1061840).
- powerpc/powernv: Return for invalid IMC domain (bsc1054914,
  fate#322448, git-fixes).
- powerpc/book3s/64: check for NULL pointer in pgd_alloc()
  (FATE#322447, bsc#1078248, git-fixes).
- powerpc/perf: Remove PM_BR_CMPL_ALT from power9 event list
  (fate#321438, bsc#1047238, bsc#1056686).
- commit ddac941
* Mon Aug 12 2019 msuchanek@suse.de
- blacklist.conf: Add unnecessary powerpc commits.
  5564597d51c8 powerpc: Fix COFF zImage booting on old powermacs
  fe60522ec600 powerpc/function_graph: Simplify with
  function_graph_enter()
  73aca179d78e powerpc/modules: Fix crashes by adding CONFIG_RELOCATABLE
  to vermagic
  8adddf349fda powerpc/mm/radix: Make Radix require HUGETLB_PAGE
  3e3ebed3fef4 powerpc/lib: only build ldstfp.o when CONFIG_PPC_FPU is set
  d065ee93aab6 powerpc: drop unused GENERIC_CSUM Kconfig item
  2b874a5c7b75 powerpc/configs: Don't enable PPC_EARLY_DEBUG in defconfigs
- commit 7a3e64c
* Mon Aug 12 2019 msuchanek@suse.de
- powerpc/mm: Handle page table allocation failures (bsc#1065729).
- powerpc/64s: Include cpu header (bsc#1065729).
- powerpc/pseries: add missing cpumask.h include file
  (bsc#1065729).
- powerpc/powernv/opal-dump : Use IRQ_HANDLED instead of numbers
  in interrupt handler (bsc#1065729).
- powerpc/lib: Fix feature fixup test of external branch
  (bsc#1065729).
- commit e10f278
* Mon Aug 12 2019 msuchanek@suse.de
- tpm: Fix TPM 1.2 Shutdown sequence to prevent future TPM
  operations (bsc#1082555).
- tpm: Fix off-by-one when reading binary_bios_measurements
  (bsc#1082555).
- tpm/tpm_i2c_atmel: Return -E2BIG when the transfer is incomplete
  (bsc#1082555).
- tpm: Unify the send callback behaviour (bsc#1082555).
- tpm: vtpm_proxy: Suppress error logging when in closed state
  (bsc#1082555).
- commit b4884c0
* Mon Aug 12 2019 tiwai@suse.de
- Move the driver core glue dir fix patch into sorted section
- commit 891c859
* Mon Aug 12 2019 tiwai@suse.de
- PCI: Restore Resizable BAR size bits correctly for 1MB BARs
  (bsc#1143841).
- commit 82f85e6
* Mon Aug 12 2019 tiwai@suse.de
- qede: fix write to free'd pointer error and double free of ptp
  (bsc#1051510).
- commit eded727
* Mon Aug 12 2019 tiwai@suse.de
- regulator: qcom_spmi: Fix math of
  spmi_regulator_set_voltage_time_sel (bsc#1051510).
- commit e34e318
* Mon Aug 12 2019 tiwai@suse.de
- sis900: fix TX completion (bsc#1051510).
- commit 935ad98
* Mon Aug 12 2019 tiwai@suse.de
- watchdog: f71808e_wdt: fix F81866 bit operation (bsc#1051510).
- watchdog: core: fix null pointer dereference when releasing cdev
  (bsc#1051510).
- commit c5d723e
* Mon Aug 12 2019 tiwai@suse.de
- Update kabi files: import from 4.12.14-lp150.12.70.1
- commit 6e67e01
* Mon Aug 12 2019 tiwai@suse.de
- Update kabi files: import from 4.12.14-150.32.1
- commit 60ce7e4
* Mon Aug 12 2019 tiwai@suse.de
- ehea: Fix a copy-paste err in ehea_init_port_res (bsc#1051510).
- commit 0935127
* Mon Aug 12 2019 mbenes@suse.cz
- objtool: Add rewind_stack_do_exit() to the noreturn list
  (bsc#1145302).
- commit 40ff441
* Mon Aug 12 2019 mbenes@suse.cz
- objtool: Support GCC 9 cold subfunction naming scheme
  (bsc#1145300).
- Refresh
  patches.suse/objtool-fix-segfault-in-cold-detection-with-ffunction-sections.patch.
- commit 43e6529
* Mon Aug 12 2019 mbenes@suse.cz
- blacklist.conf: 684fb246578b ("objtool: Add machine_real_restart() to the noreturn list")
  Not needed. Clang fix. Moreover CONFIG_CC_OPTIMIZE_FOR_SIZE is disabled
  on x86.
- commit ecb73ea
* Mon Aug 12 2019 msuchanek@suse.de
- s390/dasd: fix endless loop after read unit address
  configuration (bsc#1144912 LTC#179907).
- commit e9df314
* Mon Aug 12 2019 msuchanek@suse.de
- powerpc/xive: Fix loop exit-condition in
  xive_find_target_in_mask() (FATE#322438, bsc#1085030,
  bsc#1145189, LTC#179762).
- commit b010257
* Mon Aug 12 2019 msuchanek@suse.de
- blacklist.conf: Add CVE entry only needed for SLE15-SP1+.
- commit e10899c
* Mon Aug 12 2019 tiwai@suse.de
- usb: iowarrior: fix deadlock on disconnect (bsc#1051510).
- usb: yurex: Fix use-after-free in yurex_delete (bsc#1051510).
- usb: host: xhci-rcar: Fix timeout in xhci_suspend()
  (bsc#1051510).
- drm/vmwgfx: fix memory leak when too many retries have occurred
  (bsc#1051510).
- mmc: cavium: Add the missing dma unmap when the dma has finished
  (bsc#1051510).
- mmc: cavium: Set the correct dma max segment size for mmc_host
  (bsc#1051510).
- crypto: ccp - Ignore tag length when decrypting GCM ciphertext
  (bsc#1051510).
- crypto: ccp - Fix oops by properly managing allocated structures
  (bsc#1051510).
- hwmon: (nct7802) Fix wrong detection of in4 presence
  (bsc#1051510).
- iwlwifi: mvm: fix an out-of-bound access (bsc#1051510).
- iwlwifi: don't unmap as page memory that was mapped as single
  (bsc#1051510).
- HID: Add quirk for HP X1200 PIXART OEM mouse (bsc#1051510).
- gpio: gpio-omap: add check for off wake capable gpios
  (bsc#1051510).
- fsl/fman: Use GFP_ATOMIC in {memac,tgec}_add_hash_mac_address()
  (bsc#1051510).
- commit ac68b04
* Mon Aug 12 2019 tiwai@suse.de
- ASoC: dapm: Fix handling of custom_stop_condition on DAPM
  graph walks (bsc#1051510).
- commit e7114cb
* Mon Aug 12 2019 tiwai@suse.de
- ALSA: firewire: fix a memory leak bug (bsc#1051510).
- sound: fix a memory leak bug (bsc#1051510).
- ALSA: hda - Workaround for crackled sound on AMD controller
  (1022:1457) (bsc#1051510).
- ALSA: hiface: fix multiple memory leak bugs (bsc#1051510).
- ALSA: hda - Don't override global PCM hw info flag
  (bsc#1051510).
- commit c7a724d
* Sun Aug 11 2019 msuchanek@suse.de
- Rename patches to same name as SLE15-SP1.
- commit 99bb37a
* Fri Aug  9 2019 mfleming@suse.de
- sched/fair: Don't free p->numa_faults with concurrent readers
  (bsc#1144920).
- sched/fair: Use RCU accessors consistently for ->numa_group
  (bsc#1144920).
- Refresh
  patches.kabi/sched-numa-Remove-redundant-field-kabi.patch.
- commit 4a868ba
* Fri Aug  9 2019 tiwai@suse.de
- Revert i915 userptr page lock patch (bsc#1145051)
  This patch potentially causes a deadlock between kcompactd, as reported on
  5.3-rc3.  Revert it until a proper fix is found.
- commit a0f837d
* Fri Aug  9 2019 tbogendoerfer@suse.de
- Revert "net: ena: ethtool: add extra properties retrieval via
  get_priv_flags" (bsc#1139020 bsc#1139021).
- net: ena: Fix bug where ring allocation backoff stopped too late
  (bsc#1139020 bsc#1139021).
- net: ena: update driver version from 2.0.3 to 2.1.0 (bsc#1139020
  bsc#1139021).
- net: ena: remove inline keyword from functions in *.c
  (bsc#1139020 bsc#1139021).
- net: ena: add ethtool function for changing io queue sizes
  (bsc#1139020 bsc#1139021).
- net: ena: allow queue allocation backoff when low on memory
  (bsc#1139020 bsc#1139021).
- net: ena: make ethtool show correct current and max queue sizes
  (bsc#1139020 bsc#1139021).
- net: ena: enable negotiating larger Rx ring size (bsc#1139020
  bsc#1139021).
- net: ena: add MAX_QUEUES_EXT get feature admin command
  (bsc#1139020 bsc#1139021).
- net: ena: use dev_info_once instead of static variable
  (bsc#1139020 bsc#1139021).
- net: ena: add good checksum counter (bsc#1139020 bsc#1139021).
- net: ena: optimise calculations for CQ doorbell (bsc#1139020
  bsc#1139021).
- net: ena: add support for changing max_header_size in LLQ mode
  (bsc#1139020 bsc#1139021).
- net: ena: allow automatic fallback to polling mode (bsc#1139020
  bsc#1139021).
- net: ena: add newline at the end of pr_err prints (bsc#1139020
  bsc#1139021).
- net: ena: arrange ena_probe() function variables in reverse
  christmas tree (bsc#1139020 bsc#1139021).
- net: ena: replace free_tx/rx_ids union with single free_ids
  field in ena_ring (bsc#1139020 bsc#1139021).
- net: ena: ethtool: add extra properties retrieval via
  get_priv_flags (bsc#1139020 bsc#1139021).
- net: ena: add handling of llq max tx burst size (bsc#1139020
  bsc#1139021).
- net: ena: gcc 8: fix compilation warning (bsc#1139020
  bsc#1139021).
- net: ena: fix ena_com_fill_hash_function() implementation
  (bsc#1139020 bsc#1139021).
- net: ena: improve latency by disabling adaptive interrupt
  moderation by default (bsc#1139020 bsc#1139021).
- net: ena: fix incorrect test of supported hash function
  (bsc#1139020 bsc#1139021).
- net: ena: fix: Free napi resources when ena_up() fails
  (bsc#1139020 bsc#1139021).
- net: ena: fix: set freed objects to NULL to avoid failing
  future allocations (bsc#1139020 bsc#1139021).
- net: ena: fix swapped parameters when calling
  ena_com_indirect_table_fill_entry (bsc#1139020 bsc#1139021).
- commit 33a5137
* Fri Aug  9 2019 jgross@suse.com
- xen/swiotlb: fix condition for calling
  xen_destroy_contiguous_region() (bsc#1065600).
- commit 11cdb50
* Fri Aug  9 2019 nborisov@suse.com
- btrfs: start readahead also in seed devices (bsc#1144886).
- btrfs: clean up pending block groups when transaction commit
  aborts (bsc#1050911).
- btrfs: handle delayed ref head accounting cleanup in abort
  (bsc#1050911).
- btrfs: add cleanup_ref_head_accounting helper (bsc#1050911).
- btrfs: fix pinned underflow after transaction aborted
  (bsc#1050911).
- btrfs: Fix delalloc inodes invalidation during transaction abort
  (bsc#1050911).
- btrfs: Split btrfs_del_delalloc_inode into 2 functions
  (bsc#1050911).
- commit 639f03f
* Fri Aug  9 2019 fdmanana@suse.com
- Btrfs: prevent send failures and crashes due to concurrent
  relocation (bsc#1145059).
- commit 5a92881
* Fri Aug  9 2019 fdmanana@suse.com
- btrfs: track running balance in a simpler way (bsc#1145059).
- commit 23ac173
* Fri Aug  9 2019 fdmanana@suse.com
- Btrfs: fix race between send and deduplication that lead to
  failures and crashes (bsc#1145059).
- commit 468ea05
* Fri Aug  9 2019 ptesarik@suse.cz
- s390/cio: fix ccw_device_start_timeout API (bsc#1142109
  LTC#179339).
- commit 28183d1
* Fri Aug  9 2019 jack@suse.cz
- jbd2: flush_descriptor(): Do not decrease buffer head's ref
  count (bsc#1143843).
- commit 7c44fcd
* Fri Aug  9 2019 jroedel@suse.de
- kABI: Fix kABI for 'struct amd_iommu' (bsc#1145010).
- commit 5dc829e
* Fri Aug  9 2019 jroedel@suse.de
- mm/vmalloc: Sync unmappings in __purge_vmap_area_lazy()
  (bsc#1118689).
- x86/mm: Sync also unmappings in vmalloc_sync_all()
  (bsc#1118689).
- x86/mm: Check for pfn instead of page in vmalloc_sync_one()
  (bsc#1118689).
- iommu/amd: Add support for X2APIC IOMMU interrupts
  (bsc#1145010).
- commit 9f468a3
* Fri Aug  9 2019 msuchanek@suse.de
- supported.conf: Add missing modules (bsc#1066369).
- rpm/kernel-binary.spec.in: Enable missing modules check.
- commit cf09d01
* Fri Aug  9 2019 msuchanek@suse.de
- supported.conf: Sort alphabetically, align comments.
- commit ed3dca2
* Fri Aug  9 2019 colyli@suse.de
- Delete for bsc#1144979: bcache: kernel oops on reading sysfs cache_mode file
  patches.suse/0031-bcache-use-sysfs_match_string-instead-of-__sysfs_mat.patch.
- Refresh for the above change,
  patches.suse/0032-bcache-add-return-value-check-to-bch_cached_dev_run.patch.
- commit 191d6c3
* Thu Aug  8 2019 bp@suse.de
- blacklist.conf: c1887159eb48 x86/boot/64: Add missing fixup_pointer() for next_early_pgt access
  Clang fix.
- commit 66b1028
* Thu Aug  8 2019 bp@suse.de
- blacklist.conf: 81c7ed296dcd x86/boot/64: Fix crash if kernel image crosses page table boundary
  We don't support 5LEVEL page tables.
- commit ce968f5
* Thu Aug  8 2019 bp@suse.de
- x86/microcode: Fix the microcode load on CPU hotplug for real
  (bsc#1114279).
- Refresh patches.kabi/kabi-x86-microcode-hotplug-state-fix.patch.
- commit f40f8ea
* Thu Aug  8 2019 ptesarik@suse.cz
- s390/qeth: cancel cmd on early error (bsc#1142109 LTC#179339).
- commit 5724a7b
* Thu Aug  8 2019 ptesarik@suse.cz
- s390/qeth: simplify reply object handling (bsc#1142109
  LTC#179339).
- commit 4da951d
* Thu Aug  8 2019 ptesarik@suse.cz
- s390/qeth: fix request-side race during cmd IO timeout
  (bsc#1142109 LTC#179339).
- Refresh
  patches.arch/s390-sles15-17-02-02-s390-qeth-sanitize-strings-in-debug-messages.patch.
- commit 9e0538c
* Thu Aug  8 2019 ptesarik@suse.cz
- s390/qeth: release cmd buffer in error paths (bsc#1142109
  LTC#179339).
- s390/qeth: avoid control IO completion stalls (bsc#1142109
  LTC#179339).
- commit 4f6b2c5
* Thu Aug  8 2019 bp@suse.de
- blacklist.conf: 6ae865615fc4 x86/uaccess: Dont leak the AC flag into __put_user() argument evaluation
  We don't use UBSAN.
- commit f015af1
* Thu Aug  8 2019 yousaf.kaukab@suse.com
- irqchip/gic-v3-its: fix build warnings (bsc#1144880).
- commit 95644b2
* Thu Aug  8 2019 jroedel@suse.de
- Refresh patches.arch/0003-dma-introduce-dma_max_mapping_size.
- Refresh patches.kabi/0001-kABI-Preserve-kABI-for-dma_max_mapping_size.patch.
  The sev_dma_ops also need the max_mapping_size member set.
- commit a33e0bb
* Thu Aug  8 2019 ptesarik@suse.cz
- supported.conf: Remove duplicate drivers/ata/libahci_platform
- commit 44cefd2
* Thu Aug  8 2019 yousaf.kaukab@suse.com
- PM / devfreq: rk3399_dmc: Pass ODT and auto power down
  parameters to TF-A (bsc#1144718,bsc#1144813).
- PM / devfreq: rockchip-dfi: Move GRF definitions to a common
  place (bsc#1144718,bsc#1144813).
- PM / devfreq: rk3399_dmc: remove unneeded semicolon
  (bsc#1144718,bsc#1144813).
- PM / devfreq: rk3399_dmc: fix spelling mistakes
  (bsc#1144718,bsc#1144813).
- PM / devfreq: rk3399_dmc: do not print error when get supply
  and clk defer (bsc#1144718,bsc#1144813).
- PM / devfreq: rk3399_dmc: remove wait for dcf irq event
  (bsc#1144718,bsc#1144813).
- clk: bulk: silently error out on EPROBE_DEFER
  (bsc#1144718,bsc#1144813).
- soc: rockchip: power-domain: Use of_clk_get_parent_count()
  instead of open coding (bsc#1144718,bsc#1144813).
- clk: rockchip: assign correct id for pclk_ddr and hclk_sd in
  rk3399 (bsc#1144718,bsc#1144813).
- clk: rockchip: Add 1.6GHz PLL rate for rk3399
  (bsc#1144718,bsc#1144813).
- soc: rockchip: power-domain: Add a sanity check on pd->num_clks
  (bsc#1144718,bsc#1144813).
- soc: rockchip: power-domain: use clk_bulk APIs
  (bsc#1144718,bsc#1144813).
- clk: Export clk_bulk_prepare() (bsc#1144813).
- clk: add clk_bulk_get accessories (bsc#1144813).
- commit 3313421
* Thu Aug  8 2019 tiwai@suse.de
- drm/i915/userptr: Acquire the page lock around set_page_dirty()
  (bsc#1051510).
- drm/nouveau: fix memory leak in nouveau_conn_reset()
  (bsc#1051510).
- commit 6ff4907
* Wed Aug  7 2019 ohering@suse.de
- move irq_data_get_effective_affinity_mask prior the sorted section
- commit 9619a1c
* Wed Aug  7 2019 tiwai@suse.de
- can: peak_usb: pcan_usb_pro: Fix info-leaks to USB devices
  (bsc#1051510).
- can: peak_usb: pcan_usb_fd: Fix info-leaks to USB devices
  (bsc#1051510).
- can: peak_usb: fix potential double kfree_skb() (bsc#1051510).
- can: rcar_canfd: fix possible IRQ storm on high load
  (bsc#1051510).
- HID: wacom: fix bit shift for Cintiq Companion 2 (bsc#1051510).
- drm: msm: Fix add_gpu_components (bsc#1051510).
- clk: renesas: cpg-mssr: Fix reset control race condition
  (bsc#1051510).
- mmc: dw_mmc: Fix occasional hang after tuning on eMMC
  (bsc#1051510).
- gpiolib: fix incorrect IRQ requesting of an active-low lineevent
  (bsc#1051510).
- ISDN: hfcsusb: checking idx of ep configuration (bsc#1051510).
- ACPI: fix false-positive -Wuninitialized warning (bsc#1051510).
- dmaengine: rcar-dmac: Reject zero-length slave DMA requests
  (bsc#1051510).
- drivers/rapidio/devices/rio_mport_cdev.c: NUL terminate some
  strings (bsc#1051510).
- mfd: hi655x-pmic: Fix missing return value check for
  devm_regmap_init_mmio_clk (bsc#1051510).
- mfd: arizona: Fix undefined behavior (bsc#1051510).
- mfd: core: Set fwnode for created devices (bsc#1051510).
- media: pvrusb2: use a different format for warnings
  (bsc#1051510).
- media: au0828: fix null dereference in error path (bsc#1051510).
- commit 871aece
* Wed Aug  7 2019 nsaenzjulienne@suse.de
- Refresh patches.fixes/bonding-Force-slave-speed-check-after-link-state-rec.patch
- commit 7225894
* Wed Aug  7 2019 tiwai@suse.de
- Update patch-mainline tag for mwifiex fix
- commit f5aabef
* Wed Aug  7 2019 oneukum@suse.com
- mac80211: fix possible memory leak in ieee80211_assign_beacon
  (bsc#1142635).
- commit 2b9b16e
* Wed Aug  7 2019 oneukum@suse.com
- iwlwifi: pcie: don't service an interrupt that was masked
  (bsc#1142635).
- commit c06b2b7
* Wed Aug  7 2019 nsaenzjulienne@suse.de
- Refresh patches.drivers/hid-input-fix-a4tech-horizontal-wheel-custom-usage.patch
- commit 376aba6
* Wed Aug  7 2019 oneukum@suse.com
- iwlwifi: pcie: fix ALIVE interrupt handling for gen2 devices
  w/o MSI-X (bsc#1142635).
- commit c92b5b1
* Wed Aug  7 2019 oneukum@suse.com
- iwlwifi: mvm: fix version check for GEO_TX_POWER_LIMIT support
  (bsc#1142635).
- iwlwifi: mvm: don't send GEO_TX_POWER_LIMIT on version < 41
  (bsc#1142635).
- commit af6af13
* Wed Aug  7 2019 tiwai@suse.de
- sky2: Disable MSI on ASUS P6T (bsc#1142496).
- ata: libahci: do not complain in case of deferred probe
  (bsc#1051510).
- commit d95c462
* Wed Aug  7 2019 bpoirier@suse.com
- qlge: Refill empty buffer queues from wq (bsc#1106061).
- qlge: Refill rx buffers up to multiple of 16 (bsc#1106061).
- qlge: Update buffer queue prod index despite oom (bsc#1106061).
- qlge: Replace memset with assignment (bsc#1106061).
- qlge: Remove useless memset (bsc#1106061).
- qlge: Remove qlge_bq.len & size (bsc#1106061).
- qlge: Factor out duplicated expression (bsc#1106061).
- qlge: Remove rx_ring.type (bsc#1106061).
- qlge: Fix dma_sync_single calls (bsc#1106061).
- qlge: Deduplicate rx buffer queue management (bsc#1106061).
- qlge: Remove useless dma synchronization calls (bsc#1106061).
- qlge: Remove rx_ring.sbq_buf_size (bsc#1106061).
- qlge: Remove bq_desc.maplen (bsc#1106061).
- qlge: Deduplicate lbq_buf_size (bsc#1106061).
- qlge: Remove page_chunk.last_flag (bsc#1106061).
- qlge: Remove irq_cnt (bsc#1106061).
- qlge: Fix irq masking in INTx mode (bsc#1106061).
- commit 1050948
* Tue Aug  6 2019 ohering@suse.de
- Add mainline tag to storvsc_ringbuffer_size patch
- commit e4862df
* Tue Aug  6 2019 msuchanek@suse.de
- Update patches.arch/powerpc-pseries-Fix-xive-off-command-line.patch
  (FATE#322438, bsc#1085030, bsc#1144518, LTC#178833).
- commit c3b0fa1
* Tue Aug  6 2019 mbenes@suse.cz
- tracing: Fix header include guards in trace event headers
  (bsc#1144474).
- commit 45fe8c0
* Tue Aug  6 2019 nsaenzjulienne@suse.de
- cpufreq: dt: Try freeing static OPPs only if we have added them
  (jsc#SLE-7294).
- PM / OPP: OF: Use pr_debug() instead of pr_err() while adding
  OPP table (jsc#SLE-7294).
- commit 7ca0aa7
* Tue Aug  6 2019 msuchanek@suse.de
- powerpc/pseries: Fix xive=off command line (FATE#322438,
  bsc#1085030, git-fixes).
- commit 62c9388
* Tue Aug  6 2019 msuchanek@suse.de
- Refresh patches.fixes/fs-dax-deposit-pagetable-even-when-installing-zero-page.patch
- commit 2ec6206
* Mon Aug  5 2019 msuchanek@suse.de
- Refresh sorted section.
- commit 7b2a8cd
* Mon Aug  5 2019 bp@suse.de
- EDAC: Fix global-out-of-bounds write when setting
  edac_mc_poll_msec (bsc#1114279).
- commit 8668fda
* Mon Aug  5 2019 msuchanek@suse.de
- powerpc/kdump: Handle crashkernel memory reservation failure
  (bsc#1143466 LTC#179600).
- commit 96d99bf
* Mon Aug  5 2019 ohering@suse.de
- PCI: hv: Fix panic by calling hv_pci_remove_slots() earlier
  (bsc#1142701).
- commit a4b75ac
* Mon Aug  5 2019 jslaby@suse.cz
- af_packet: Block execution of tasks waiting for transmit to
  complete in AF_PACKET (networking-stable-19_07_02).
- sctp: change to hold sk after auth shkey is created successfully
  (networking-stable-19_07_02).
- bonding: Always enable vlan tx offload
  (networking-stable-19_07_02).
- tipc: change to use register_pernet_device
  (networking-stable-19_07_02).
- net: stmmac: set IC bit when transmitting frames with HW
  timestamp (networking-stable-19_07_02).
- net: stmmac: fixed new system time seconds value calculation
  (networking-stable-19_07_02).
- tun: wake up waitqueues after IFF_UP is set
  (networking-stable-19_07_02).
- net: remove duplicate fetch in sock_getsockopt
  (networking-stable-19_07_02).
- commit f58bed8
* Sat Aug  3 2019 tiwai@suse.de
- libata: zpodd: Fix small read overflow in zpodd_get_mech_type()
  (bsc#1051510).
- ACPI: PM: Fix regression in acpi_device_set_power()
  (bsc#1051510).
- ALSA: usb-audio: Fix gpf in snd_usb_pipe_sanity_check
  (bsc#1051510).
- ALSA: pcm: fix lost wakeup event scenarios in snd_pcm_drain
  (bsc#1051510).
- commit 43b7a1d
* Fri Aug  2 2019 ptesarik@suse.cz
- s390/qdio: handle PENDING state for QEBSM devices (bsc#1142117
  bsc#1142118 bsc#1142119 LTC#179329 LTC#179330 LTC#179331).
- commit 9f57b12
* Fri Aug  2 2019 nsaenzjulienne@suse.de
- clk: raspberrypi: register platform device for
  raspberrypi-cpufreq (jsc#SLE-7294).
- firmware: raspberrypi: register clk device (jsc#SLE-7294).
- clk: bcm283x: add driver interfacing with Raspberry Pi's firmware (jsc#SLE-7294).
- Update config files
- Update supported.conf
- clk: bcm2835: remove pllb (jsc#SLE-7294).
- cpufreq: add driver for Raspberry Pi (jsc#SLE-7294).
- Update config files
- Update supported.conf
- commit 6a8534d
* Thu Aug  1 2019 tiwai@suse.de
- Move upstreamed BT fix into sorted section
- commit e4632df
* Thu Aug  1 2019 tiwai@suse.de
- lib/bitmap.c: make bitmap_parselist() thread-safe and much
  faster (bsc#1143507).
- commit a2a3983
* Thu Aug  1 2019 nmoreychaisemartin@suse.com
- nvme: fix possible use-after-free in connect error flow (bsc#1139500, bsc#1140426)
- commit 716a051
* Thu Aug  1 2019 tonyj@suse.de
- powerpc/perf: Add mem access events to sysfs (FATE#326869,
  bsc#1124370).
- commit 571ef6a
* Wed Jul 31 2019 lyan@suse.com
- KVM: arm/arm64: Fix VMID alloc race by reverting to lock-less
  (bsc#1133021).
- commit eca90ee
* Wed Jul 31 2019 lyan@suse.com
- ARM: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bsc#1133021).
- ARM: KVM: report support for SMCCC_ARCH_WORKAROUND_1
  (bsc#1133021).
- KVM/Eventfd: Avoid crash when assign and deassign specific
  eventfd in parallel (bsc#1133021).
- KVM: Reject device ioctls from processes other than the VM's
  creator (bsc#1133021).
- KVM: arm/arm64: Close VMID generation race (bsc#1133021).
- KVM: arm/arm64: Convert kvm_host_cpu_state to a static per-cpu
  allocation (bsc#1133021).
- KVM: arm/arm64: Drop resource size check for GICV window
  (bsc#1133021).
- KVM: arm/arm64: Fix lost IRQs from emulated physcial timer
  when blocked (bsc#1133021).
- KVM: arm/arm64: Handle CPU_PM_ENTER_FAILED (bsc#1133021).
- KVM: arm/arm64: Reduce verbosity of KVM init log (bsc#1133021).
- KVM: arm/arm64: Set dist->spis to NULL after kfree
  (bsc#1133021).
- KVM: arm/arm64: Skip updating PMD entry if no change
  (bsc#1133021).
- KVM: arm/arm64: Skip updating PTE entry if no change
  (bsc#1133021).
- KVM: arm/arm64: vgic: Add missing irq_lock to
  vgic_mmio_read_pending (bsc#1133021).
- KVM: arm/arm64: vgic: Fix kvm_device leak in vgic_its_destroy
  (bsc#1133021).
- KVM: arm/arm64: vgic-its: Fix potential overrun in
  vgic_copy_lpi_list (bsc#1133021).
- KVM: arm64: Fix caching of host MDCR_EL2 value (bsc#1133021).
- KVM: mmu: Fix overlap between public and private memslots
  (bsc#1133021).
- arm64: KVM: Fix architecturally invalid reset value for
  FPEXC32_EL2 (bsc#1133021).
- kvm: Disallow wraparound in kvm_gfn_to_hva_cache_init
  (bsc#1133021).
- kvm: arm/arm64: vgic-v3: Tighten synchronization for guests
  using v2 on v3 (bsc#1133021).
- Refresh
  patches.fixes/0001-KVM-arm-arm64-Properly-protect-VGIC-locks-from-IRQs.patch.
  patches.arch/kvm-make-vm-ioctl-do-valloc-for-some-archs
- commit b82550c
* Wed Jul 31 2019 tiwai@suse.de
- acpi/arm64: ignore 5.1 FADTs that are reported as 5.0
  (bsc#1051510).
- commit 8c9daa7
* Wed Jul 31 2019 tiwai@suse.de
- 9p/xen: Add cleanup path in p9_trans_xen_init (bsc#1051510).
- 9p/virtio: Add cleanup path in p9_virtio_init (bsc#1051510).
- 9p: pass the correct prototype to read_cache_page (bsc#1051510).
- net/9p: include trans_common.h to fix missing prototype warning
  (bsc#1051510).
- 9p: p9dirent_read: check network-provided name length
  (bsc#1051510).
- 9p/rdma: remove useless check in cm_event_handler (bsc#1051510).
- 9p: acl: fix uninitialized iattr access (bsc#1051510).
- 9p/rdma: do not disconnect on down_interruptible EAGAIN
  (bsc#1051510).
- 9p/xen: fix check for xenbus_read error in front_probe
  (bsc#1051510).
- commit c3770e6
* Wed Jul 31 2019 oneukum@suse.com
- PCI: xilinx-nwl: Fix Multi MSI data programming (bsc#1142635).
- commit 2c2cee4
* Wed Jul 31 2019 tiwai@suse.de
- tty/ldsem, locking/rwsem: Add missing ACQUIRE to read_failed
  sleep loop (bsc#1051510).
- tty: serial: msm_serial: avoid system lockup condition
  (bsc#1051510).
- tty/serial: digicolor: Fix digicolor-usart already registered
  warning (bsc#1051510).
- tty: max310x: Fix invalid baudrate divisors calculator
  (bsc#1051510).
- commit 5b689d2
* Wed Jul 31 2019 tiwai@suse.de
- tua6100: Avoid build warnings (bsc#1051510).
- commit 5fe29d6
* Wed Jul 31 2019 tiwai@suse.de
- usb: wusbcore: fix unbalanced get/put cluster_id (bsc#1051510).
- usb: Handle USB3 remote wakeup for LPM enabled devices correctly
  (bsc#1051510).
- usb: core: hub: Disable hub-initiated U1/U2 (bsc#1051510).
- commit 1d9328c
* Wed Jul 31 2019 tiwai@suse.de
- serial: 8250: Fix TX interrupt handling condition (bsc#1051510).
- commit 9d23e7a
* Wed Jul 31 2019 oneukum@suse.com
- PCI: qcom: Ensure that PERST is asserted for at least 100 ms
  (bsc#1142635).
- commit 7c6a153
* Wed Jul 31 2019 tiwai@suse.de
- regmap: fix bulk writes on paged registers (bsc#1051510).
- commit b2ad701
* Wed Jul 31 2019 tiwai@suse.de
- pinctrl: rockchip: fix leaked of_node references (bsc#1051510).
- pinctrl: pistachio: fix leaked of_node references (bsc#1051510).
- commit f2615e5
* Wed Jul 31 2019 tiwai@suse.de
- nfc: fix potential illegal memory access (bsc#1051510).
- commit eea437f
* Wed Jul 31 2019 tiwai@suse.de
- media: coda: increment sequence offset for the last returned
  frame (bsc#1051510).
- media: coda: fix last buffer handling in V4L2_ENC_CMD_STOP
  (bsc#1051510).
- media: coda: fix mpeg2 sequence number handling (bsc#1051510).
- media: wl128x: Fix some error handling in
  fm_v4l2_init_video_device() (bsc#1051510).
- media: staging: media: davinci_vpfe: - Fix for memory leak if
  decoder initialization fails (bsc#1051510).
- media: coda: Remove unbalanced and unneeded mutex unlock
  (bsc#1051510).
- media: media_device_enum_links32: clean a reserved field
  (bsc#1051510).
- media: vpss: fix a potential NULL pointer dereference
  (bsc#1051510).
- media: dvb: usb: fix use after free in dvb_usb_device_exit
  (bsc#1051510).
- commit cce0303
* Wed Jul 31 2019 tiwai@suse.de
- media: hdpvr: fix locking and a missing msleep (bsc#1051510).
- media: spi: IR LED: add missing of table registration
  (bsc#1051510).
- commit 3175953
* Wed Jul 31 2019 tiwai@suse.de
- mailbox: handle failed named mailbox channel request
  (bsc#1051510).
- commit 60da685
* Wed Jul 31 2019 tiwai@suse.de
- macsec: fix checksumming after decryption (bsc#1051510).
- macsec: fix use-after-free of skb during RX (bsc#1051510).
- macsec: let the administrator set UP state even if lowerdev
  is down (bsc#1051510).
- macsec: update operstate when lower device changes
  (bsc#1051510).
- commit aba8a32
* Wed Jul 31 2019 tiwai@suse.de
- libata: don't request sense data on !ZAC ATA devices
  (bsc#1051510).
- commit 165118b
* Wed Jul 31 2019 tiwai@suse.de
- iio: iio-utils: Fix possible incorrect mask calculation
  (bsc#1051510).
- commit a88c729
* Wed Jul 31 2019 tiwai@suse.de
- hpet: Fix division by zero in hpet_time_div() (bsc#1051510).
- commit bfebe33
* Wed Jul 31 2019 tiwai@suse.de
- Input: alps - fix a mismatch between a condition check and
  its comment (bsc#1051510).
- Input: alps - don't handle ALPS cs19 trackpoint-only device
  (bsc#1051510).
- Input: synaptics - whitelist Lenovo T580 SMBus intertouch
  (bsc#1051510).
- intel_th: pci: Add Ice Lake NNPI support (bsc#1051510).
- gpio: omap: ensure irq is enabled before wakeup (bsc#1051510).
- Input: trackpoint - only expose supported controls for Elan,
  ALPS and NXP (bsc#1051510).
- commit 21bf098
* Wed Jul 31 2019 tiwai@suse.de
- drm/msm: Depopulate platform on probe failure (bsc#1051510).
- drm/virtio: Add memory barriers for capset cache (bsc#1051510).
- drm/crc-debugfs: User irqsafe spinlock in drm_crtc_add_crc_entry
  (bsc#1051510).
- drm/bridge: sii902x: pixel clock unit is 10kHz instead of 1kHz
  (bsc#1051510).
- drm/bridge: tc358767: read display_props in get_modes()
  (bsc#1051510).
- commit acc8448
* Wed Jul 31 2019 tiwai@suse.de
- drm/panel: simple: Fix panel_simple_dsi_probe (bsc#1051510).
- commit 890763d
* Wed Jul 31 2019 tiwai@suse.de
- Documentation/networking: fix default_ttl typo in mpls-sysctl
  (bsc#1051510).
- Documentation: Add nospectre_v1 parameter (bsc#1051510).
- commit 3774cea
* Wed Jul 31 2019 tiwai@suse.de
- dma-buf: balance refcount inbalance (bsc#1051510).
- commit 314dd8d
* Wed Jul 31 2019 tiwai@suse.de
- crypto: talitos - fix skcipher failure due to wrong output IV
  (bsc#1051510).
- commit 9ad83fe
* Wed Jul 31 2019 tiwai@suse.de
- Bluetooth: 6lowpan: search for destination address in all peers
  (bsc#1051510).
- Bluetooth: Add SMP workaround Microsoft Surface Precision
  Mouse bug (bsc#1051510).
- Bluetooth: validate BLE connection interval updates
  (bsc#1051510).
- Bluetooth: Check state in l2cap_disconnect_rsp (bsc#1051510).
- Bluetooth: hci_bcsp: Fix memory leak in rx_skb (bsc#1051510).
- commit 595fdb0
* Wed Jul 31 2019 tiwai@suse.de
- hwmon: (nct6775) Fix register address and added missed tolerance
  for nct6106 (bsc#1051510).
- commit 979031c
* Wed Jul 31 2019 tiwai@suse.de
- firmware: ti_sci: Always request response from firmware
  (bsc#1051510).
- commit a183abe
* Wed Jul 31 2019 tiwai@suse.de
- efi/bgrt: Drop BGRT status field reserved bits check
  (bsc#1051510).
- commit 0debfe5
* Wed Jul 31 2019 tiwai@suse.de
- eCryptfs: fix a couple type promotion bugs (bsc#1051510).
- commit b6f5263
* Wed Jul 31 2019 tiwai@suse.de
- blacklist.conf: add superfluous ASoC entries
- commit 56ab50a
* Wed Jul 31 2019 acho@suse.com
- driver core: Fix use-after-free and double free on glue
  directory (bsc#1131281).
- commit 78880d7
* Wed Jul 31 2019 tiwai@suse.de
- ACPI/IORT: Fix off-by-one check in iort_dev_find_its_id()
  (bsc#1051510).
- af_key: fix leaks in key_pol_get_resp and dump_sp (bsc#1051510).
- commit 5daa6d3
* Wed Jul 31 2019 acho@suse.com
- Bluetooth: hci_uart: check for missing tty operations
  (CVE-2019-10207 bsc#1142857 bsc#1123959).
- commit d0754de
* Tue Jul 30 2019 nborisov@suse.com
- btrfs: use GFP_KERNEL in init_ipath (bsc#1086103).
- btrfs: scrub: add memalloc_nofs protection around init_ipath
  (bsc#1086103).
- commit 7470d5f
* Tue Jul 30 2019 ptesarik@suse.cz
- s390/zcrypt: Fix wrong dispatching for control domain CPRBs
  (bsc#1137811 LTC#178088).
- commit 79fa234
* Tue Jul 30 2019 tbogendoerfer@suse.de
- IB/mlx5: Fix leaking stack memory to userspace (bsc#1143045
  CVE-2018-20855).
- commit 1773cb4
* Tue Jul 30 2019 mkubecek@suse.cz
- tcp: be more careful in tcp_fragment() (CVE-2019-11478
  bsc#1137586 bsc#1139751).
- Refresh
  patches.kabi/kabi-drop-LINUX_MIB_TCPWQUEUETOOBIG-snmp-counter.patch
- commit 01d7aff
* Tue Jul 30 2019 mhocko@suse.com
- Refresh
  patches.arch/0002-x86-speculation-Enable-Spectre-v1-swapgs-mitigations.patch.
- commit a498c6b
* Mon Jul 29 2019 tiwai@suse.de
- mwifiex: fix 802.11n/WPA detection (CVE-2019-3846,bsc#1136424).
- commit 4f04ac3
* Mon Jul 29 2019 ptesarik@suse.cz
- s390/qeth: be drop monitor friendly (bsc#1142220 LTC#179335).
- commit d36fb72
* Mon Jul 29 2019 vbabka@suse.cz
- x86, mm: fix fast GUP with hyper-based TLB flushing (VM
  Functionality, bsc#1140903).
- commit 0d4f36e
* Mon Jul 29 2019 mhocko@suse.com
- x86/speculation/swapgs: Exclude ATOMs from speculation through
  SWAPGS (bsc#1139358, CVE-2019-1125).
- Refresh
  patches.arch/0001-x86-speculation-Prepare-entry-code-for-Spectre-v1-sw.patch.
- commit 057096c
* Mon Jul 29 2019 tiwai@suse.de
- Correct the CVE and bug reference for a floppy security fix (CVE-2019-14284,bsc#1143189)
  A dedicated CVE was already assigned
- commit b35cae3
* Mon Jul 29 2019 tiwai@suse.de
- floppy: fix out-of-bounds read in copy_buffer
  (CVE-2019-14283,bsc#1143191).
- floppy: fix div-by-zero in setup_format_params
  (CVE-2019-14283,bsc#1143191).
- commit 4becf9e
* Mon Jul 29 2019 jthumshirn@suse.de
- nvme: fix memory leak caused by incorrect subsystem free
  (bsc#1143185).
- commit 55e0f8d
* Mon Jul 29 2019 ptesarik@suse.cz
- net/af_iucv: remove GFP_DMA restriction for HiperTransport
  (bsc#1142112 bsc#1142221 LTC#179334 LTC#179332).
- commit 9402a68
* Mon Jul 29 2019 tiwai@suse.de
- usb: pci-quirks: Correct AMD PLL quirk detection (bsc#1051510).
- commit 9981a0b
* Mon Jul 29 2019 mkubecek@suse.cz
- sctp: silence warns on sctp_stream_init allocations
  (bsc#1083710).
- commit 688c1be
* Sat Jul 27 2019 ailiopoulos@suse.com
- xfs: don't overflow xattr listent buffer (bsc#1143105).
- commit ef88108
* Sat Jul 27 2019 tiwai@suse.de
- ALSA: hda - Add a conexant codec entry to let mute led work
  (bsc#1051510).
- ALSA: compress: Be more restrictive about when a drain is
  allowed (bsc#1051510).
- ALSA: compress: Don't allow paritial drain operations on
  capture streams (bsc#1051510).
- ALSA: compress: Prevent bypasses of set_params (bsc#1051510).
- ALSA: compress: Fix regression on compressed capture streams
  (bsc#1051510).
- ALSA: line6: Fix a typo (bsc#1051510).
- ALSA: line6: Fix wrong altsetting for LINE6_PODHD500_1
  (bsc#1051510).
- commit ae9e6c6
* Fri Jul 26 2019 lyan@suse.com
- KVM: arm/arm64: vgic-its: Take the srcu lock when parsing the
  memslots (bsc#1133021).
- KVM: arm/arm64: vgic-its: Take the srcu lock when writing to
  guest memory (bsc#1133021).
- commit 71f3007
* Fri Jul 26 2019 colyli@suse.de
- Update References field to
  patches.suse/0275-bcache-never-writeback-a-discard-operation.patch
  (bsc#1130972, bsc#1102247).
- commit fece483
* Fri Jul 26 2019 ohering@suse.de
- PCI: hv: Fix return value check in hv_pci_assign_slots()
  (bsc#1142701).
- commit b1f308c
* Fri Jul 26 2019 ohering@suse.de
- PCI: hv: Fix a use-after-free bug in hv_eject_device_work()
  (bsc#1142701).
- PCI: hv: Add pci_destroy_slot() in pci_devices_present_work(),
  if necessary (bsc#1142701).
- PCI: hv: Add hv_pci_remove_slots() when we unload the driver
  (bsc#1142701).
- PCI: hv: Fix a memory leak in hv_eject_device_work()
  (bsc#1142701).
- PCI: hv: support reporting serial number as slot information
  (bsc#1142701).
- PCI: hv: Remove unused reason for refcount handler
  (bsc#1142701).
- commit 5c04ed0
* Fri Jul 26 2019 fdmanana@suse.com
- Btrfs: fix race between block group removal and block group
  allocation (bsc#1143003).
- commit 805c7d6
* Fri Jul 26 2019 tbogendoerfer@suse.de
- bnx2x: Prevent load reordering in tx completion processing
  (bsc#1142868).
- commit 55eef5c
* Fri Jul 26 2019 jthumshirn@suse.de
- Refresh patches.fixes/drivers-base-introduce-kill_device.patch.
- Refresh
  patches.fixes/libnvdimm-bus-prevent-duplicate-device_unregister-calls.patch.
  Update Commit IDs
- commit df1507f
* Fri Jul 26 2019 fyang@suse.com
- fork, memcg: fix cached_stacks case (bsc#1134097).
- fork, memcg: fix crash in free_thread_stack on memcg charge fail
  (bsc#1134097).
- commit 5777e9c
* Thu Jul 25 2019 msuchanek@suse.de
- kernel: jump label transformation performance (bsc#1137534 bsc#1137535
  LTC#178058 LTC#178059).
- commit 94ca19e
* Thu Jul 25 2019 msuchanek@suse.de
- Refresh patches.arch/powerpc-Fix-check-for-copy-paste-instructions-in-ali.patch
  Fix broken backport.
- commit 737a123
* Thu Jul 25 2019 msuchanek@suse.de
- powerpc/64s/radix: Introduce local single page ceiling for TLB range
  flush (bsc#1055117 bsc#1152161 ltc#181664).
- Refresh patches.suse/powerpc-mm-Workaround-Nest-MMU-bug-with-TLB-invalida.patch.
- commit 9a6b5c8
* Thu Jul 25 2019 oneukum@suse.com
- Input: tm2-touchkey - acknowledge that setting brightness is
  a blocking call (bsc#1129770).
- commit 5aea138
* Wed Jul 24 2019 msuchanek@suse.de
- powerpc/mm/radix: Use the right page size for vmemmap mapping
  (bsc#1055117 bsc#1142685 LTC#179509 FATE#327775).
- powerpc/mm/hash/4k: Don't use 64K page size for vmemmap with
  4K pagesize (bsc#1142685 LTC#179509 FATE#327775).
- commit c04ad6a
* Wed Jul 24 2019 tiwai@suse.de
- Add the cherry-picked commit for the existing patch
  Refresh:
  patches.drivers/platform-x86-asus-wmi-Only-Tell-EC-the-OS-will-handl.patch
- commit da39a47
* Wed Jul 24 2019 tiwai@suse.de
- Fix kABI for asus-wmi quirk_entry field addition (bsc#1051510).
- commit 955a98c
* Wed Jul 24 2019 tiwai@suse.de
- platform/x86: asus-wmi: Only Tell EC the OS will handle display
  hotkeys from asus_nb_wmi (bsc#1051510).
- commit 667495a
* Wed Jul 24 2019 tiwai@suse.de
- platform/x86: asus-nb-wmi: Support ALS on the Zenbook UX430UQ
  (bsc#1051510).
- commit c48812e
* Wed Jul 24 2019 tiwai@suse.de
- e1000e: start network tx queue only when link is up
  (bsc#1051510).
- Revert "e1000e: fix cyclic resets at link up with active tx"
  (bsc#1051510).
- commit 87c75a8
* Wed Jul 24 2019 oneukum@suse.com
- blacklist.conf: kABI
- commit 2cff6dd
* Wed Jul 24 2019 oneukum@suse.com
- blacklist.conf: this is supposed to speed up things but invalidates
  testing
- commit b8dc286
* Wed Jul 24 2019 oneukum@suse.com
- blacklist.conf: would remove an ioctl
- commit 044bc6e
* Wed Jul 24 2019 oneukum@suse.com
- blacklist.conf: cosmetic change only
- commit a98fb29
* Wed Jul 24 2019 msuchanek@suse.de
- scsi: ibmvfc: fix WARN_ON during event pool release (bsc#1137458
  LTC#178093).
- commit 40bd8b6
* Wed Jul 24 2019 lduncan@suse.com
- scsi: megaraid_sas: return error when create DMA pool failed
  (CVE-2019-11810 bsc#1134399).
- commit 7142e60
* Tue Jul 23 2019 msuchanek@suse.de
- bonding: Force slave speed check after link state recovery
  for 802.3ad (bsc#1137584).
- commit ed149f2
* Tue Jul 23 2019 palcantara@suse.de
- cifs: update internal module number (bsc#1144333).
- commit 986284a
* Tue Jul 23 2019 palcantara@suse.de
- cifs: flush before set-info if we have writeable handles (bsc#1144333).
- commit b4d735e
* Tue Jul 23 2019 palcantara@suse.de
- smb3: optimize open to not send query file internal info (bsc#1144333).
- commit e2b707f
* Tue Jul 23 2019 palcantara@suse.de
- CIFS: fix deadlock in cached root handling (bsc#1144333).
- commit 8be25d5
* Tue Jul 23 2019 palcantara@suse.de
- smb3: smbdirect no longer experimental (bsc#1144333).
- commit e20fcc7
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix crash in smb2_compound_op()/smb2_set_next_command() (bsc#1144333).
- commit 84ba586
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix crash in cifs_dfs_do_automount (bsc#1144333).
- commit f139553
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix parsing of symbolic link error response (bsc#1144333).
- commit f589a16
* Tue Jul 23 2019 palcantara@suse.de
- cifs: refactor and clean up arguments in the reparse point parsing (bsc#1144333).
- commit 19e2523
* Tue Jul 23 2019 palcantara@suse.de
- SMB3: query inode number on open via create context (bsc#1144333).
- commit baf32d4
* Tue Jul 23 2019 palcantara@suse.de
- smb3: Send netname context during negotiate protocol (bsc#1144333).
- commit a9b9aca
* Tue Jul 23 2019 palcantara@suse.de
- smb3: do not send compression info by default (bsc#1144333).
- commit adf25ef
* Tue Jul 23 2019 palcantara@suse.de
- smb3: add new mount option to retrieve mode from special ACE (bsc#1144333).
- commit ca8c013
* Tue Jul 23 2019 palcantara@suse.de
- smb3: Allow query of symlinks stored as reparse points (bsc#1144333).
- commit 298d366
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Fix a race condition with cifs_echo_request (bsc#1144333).
- commit d8c6924
* Tue Jul 23 2019 palcantara@suse.de
- cifs: always add credits back for unsolicited PDUs (bsc#1144333).
- commit 4fdd365
* Tue Jul 23 2019 palcantara@suse.de
- fs: cifs: cifsssmb: Change return type of convert_ace_to_cifs_ace (bsc#1144333).
- commit 9ffd824
* Tue Jul 23 2019 palcantara@suse.de
- add some missing definitions (bsc#1144333).
- commit 1bdcd1a
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix typo in debug message with struct field ia_valid (bsc#1144333).
- commit e4ba220
* Tue Jul 23 2019 palcantara@suse.de
- smb3: minor cleanup of compound_send_recv (bsc#1144333).
- commit db4e54c
* Tue Jul 23 2019 palcantara@suse.de
- CIFS: Fix module dependency (bsc#1144333).
- commit 874c4a4
* Tue Jul 23 2019 palcantara@suse.de
- cifs: simplify code by removing CONFIG_CIFS_ACL ifdef   (bsc#1144333). - Update config files.
- commit 49ca0c7
* Tue Jul 23 2019 mhocko@suse.com
- x86/speculation: Prepare entry code for Spectre v1 swapgs
  mitigations (bsc#1139358, CVE-2019-1125).
- x86/speculation: Enable Spectre v1 swapgs mitigations
  (bsc#1139358, CVE-2019-1125).
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/x86-cpufeatures-Combine-word-11-and-12-into-a-new-sc.patch.
- Refresh
  patches.suse/x86-cpufeatures-Enumerate-the-new-AVX512-BFLOAT16-in.patch.
- commit 479b935
* Tue Jul 23 2019 jgross@suse.com
- xen: let alloc_xenballooned_pages() fail if not enough memory
  free (bsc#1142450 XSA-300).
- commit 78512f3
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Fix check for matching with existing mount (bsc#1144333).
- commit ff08ee2
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Properly handle auto disabling of serverino option (bsc#1144333).
- commit c6295b2
* Tue Jul 23 2019 palcantara@suse.de
- smb3: if max_credits is specified then display it in /proc/mounts (bsc#1144333).
- commit 03f8033
* Tue Jul 23 2019 palcantara@suse.de
- Fix match_server check to allow for auto dialect negotiate (bsc#1144333).
- commit d0ad70d
* Tue Jul 23 2019 palcantara@suse.de
- cifs: add missing GCM module dependency (bsc#1144333).
- commit 7379156
* Tue Jul 23 2019 palcantara@suse.de
- SMB3.1.1: Add GCM crypto to the encrypt and decrypt functions (bsc#1144333).
- commit 609cdad
* Tue Jul 23 2019 palcantara@suse.de
- SMB3: Add SMB3.1.1 GCM to negotiated crypto algorigthms (bsc#1144333).
- commit 35322f3
* Tue Jul 23 2019 palcantara@suse.de
- fs: cifs: Drop unlikely before IS_ERR(_OR_NULL) (bsc#1144333).
- commit e4904e7
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Use kmemdup in SMB2_ioctl_init() (bsc#1144333).
- commit 9a7e082
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix crash querying symlinks stored as reparse-points (bsc#1144333).
- commit e1d9262
* Tue Jul 23 2019 palcantara@suse.de
- treewide: Replace GPLv2 boilerplate/reference with SPDX - rule 231 (bsc#1144333).
- commit 4b6e977
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix GlobalMid_Lock bug in cifs_reconnect (bsc#1144333).
- commit b3593b6
* Tue Jul 23 2019 palcantara@suse.de
- SMB3: retry on STATUS_INSUFFICIENT_RESOURCES instead of failing write (bsc#1144333).
- commit 18095f8
* Tue Jul 23 2019 palcantara@suse.de
- cifs: add spinlock for the openFileList to cifsInodeInfo (bsc#1144333).
- commit 7ad2b35
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix panic in smb2_reconnect (bsc#1144333).
- commit bee1af6
* Tue Jul 23 2019 palcantara@suse.de
- CIFS: cifs_read_allocate_pages: don't iterate through whole page array on ENOMEM (bsc#1144333).
- commit fca893c
* Tue Jul 23 2019 palcantara@suse.de
- dfs_cache: fix a wrong use of kfree in flush_cache_ent() (bsc#1144333).
- commit 8f1ff22
* Tue Jul 23 2019 palcantara@suse.de
- fs/cifs/smb2pdu.c: fix buffer free in SMB2_ioctl_free (bsc#1144333).
- commit 1cd210c
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix memory leak of pneg_inbuf on -EOPNOTSUPP ioctl case (bsc#1144333).
- commit 67d46c6
* Tue Jul 23 2019 palcantara@suse.de
- signal/cifs: Fix cifs_put_tcp_session to call send_sig instead of force_sig (bsc#1144333).
- commit ac48d1f
* Tue Jul 23 2019 palcantara@suse.de
- cifs: add support for SEEK_DATA and SEEK_HOLE (bsc#1144333).
- commit 0f11421
* Tue Jul 23 2019 palcantara@suse.de
- Fixed https://bugzilla.kernel.org/show_bug.cgi?id=202935 allow write on the same file (bsc#1144333).
- commit 7748fed
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Allocate memory for all iovs in smb2_ioctl (bsc#1144333).
- commit 5f81833
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Don't match port on SMBDirect transport (bsc#1144333).
- commit 051316f
* Tue Jul 23 2019 palcantara@suse.de
- cifs:smbd Use the correct DMA direction when sending data (bsc#1144333).
- commit 4d76c3a
* Tue Jul 23 2019 palcantara@suse.de
- cifs:smbd When reconnecting to server, call smbd_destroy() after all MIDs have been called (bsc#1144333).
- commit 6452a9b
* Tue Jul 23 2019 palcantara@suse.de
- smb3: trivial cleanup to smb2ops.c (bsc#1144333).
- commit 80746c4
* Tue Jul 23 2019 palcantara@suse.de
- cifs: cleanup smb2ops.c and normalize strings (bsc#1144333).
- commit 68b4575
* Tue Jul 23 2019 palcantara@suse.de
- smb3: display session id in debug data (bsc#1144333).
- commit ff1be03
* Tue Jul 23 2019 palcantara@suse.de
- cifs: update module internal version number (bsc#1144333).
- commit b15e93d
* Tue Jul 23 2019 palcantara@suse.de
- SMB3: Clean up query symlink when reparse point (bsc#1144333).
- commit 263d56b
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix strcat buffer overflow and reduce raciness in smb21_set_oplock_level() (bsc#1144333).
- commit 20d16b3
* Tue Jul 23 2019 palcantara@suse.de
- Negotiate and save preferred compression algorithms (bsc#1144333).
- commit 2f9136f
* Tue Jul 23 2019 palcantara@suse.de
- cifs: rename and clarify CIFS_ASYNC_OP and CIFS_NO_RESP (bsc#1144333).
- commit b844fff
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix credits leak for SMB1 oplock breaks (bsc#1144333).
- commit c9b3aea
* Tue Jul 23 2019 palcantara@suse.de
- smb3: Add protocol structs for change notify support (bsc#1144333).
- commit 19f6994
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix smb3_zero_range for Azure (bsc#1144333).
- commit 2d61900
* Tue Jul 23 2019 palcantara@suse.de
- cifs: zero-range does not require the file is sparse (bsc#1144333).
- commit 4580e2d
* Tue Jul 23 2019 palcantara@suse.de
- Add new flag on SMB3.1.1 read (bsc#1144333).
- commit bad960f
* Tue Jul 23 2019 palcantara@suse.de
- cifs: add fiemap support (bsc#1144333).
- commit 83181db
* Tue Jul 23 2019 palcantara@suse.de
- SMB3: Add defines for new negotiate contexts (bsc#1144333).
- commit 9bbe6f7
* Tue Jul 23 2019 palcantara@suse.de
- cifs: fix bi-directional fsctl passthrough calls (bsc#1144333).
- commit 0fd12f5
* Tue Jul 23 2019 palcantara@suse.de
- cifs: smbd: take an array of reqeusts when sending upper layer data (bsc#1144333).
- commit 0bb2ab5
* Tue Jul 23 2019 palcantara@suse.de
- SMB3: Add handling for different FSCTL access flags (bsc#1144333).
- commit dbdf4ee
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Add support for FSCTL passthrough that write data to the server (bsc#1144333).
- commit b35bcfe
* Tue Jul 23 2019 palcantara@suse.de
- cifs: Call MID callback before destroying transport (bsc#1144333).
- commit 39e15e8
* Tue Jul 23 2019 palcantara@suse.de
- cifs: smbd: Retry on memory registration failure (bsc#1144333).
- commit f8f5ad4
* Tue Jul 23 2019 palcantara@suse.de
- cifs: smbd: Indicate to retry on transport sending failure (bsc#1144333).
- commit d10678b
* Tue Jul 23 2019 palcantara@suse.de
- cifs: smbd: Return EINTR when interrupted (bsc#1144333).
- commit 88cf401
* Tue Jul 23 2019 palcantara@suse.de
- cifs: smbd: Don't destroy transport on RDMA disconnect (bsc#1144333).
- commit b0ccc81
* Tue Jul 23 2019 palcantara@suse.de
- smbd: Make upper layer decide when to destroy the transport (bsc#1144333).
- commit f5d568d
* Tue Jul 23 2019 palcantara@suse.de
- SMB3: update comment to clarify enumerating snapshots (bsc#1144333).
- commit 8510c32
* Tue Jul 23 2019 palcantara@suse.de
- CIFS: check CIFS_MOUNT_NO_DFS when trying to reuse existing sb (bsc#1144333).
- commit db230f1
* Mon Jul 22 2019 palcantara@suse.de
- CIFS: Show locallease in /proc/mounts for cifs shares mounted with locallease feature (bsc#1144333).
- commit 0864b55
* Mon Jul 22 2019 palcantara@suse.de
- cifs: Fix DFS cache refresher for DFS links (bsc#1144333).
- commit e9bae57
* Mon Jul 22 2019 palcantara@suse.de
- cifs: don't use __constant_cpu_to_le32() (bsc#1144333).
- commit ffc448e
* Mon Jul 22 2019 palcantara@suse.de
- SMB3: Track total time spent on roundtrips for each SMB3 command (bsc#1144333).
- commit 8a3179e
* Mon Jul 22 2019 palcantara@suse.de
- cifs: fix page reference leak with readv/writev (bsc#1144333).
- commit fbb8472
* Mon Jul 22 2019 palcantara@suse.de
- cifs: do not attempt cifs operation on smb2+ rename error (bsc#1144333).
- commit 5ebac84
* Mon Jul 22 2019 palcantara@suse.de
- cifs: fix memory leak in SMB2_read (bsc#1144333).
- commit d5acd73
* Mon Jul 22 2019 palcantara@suse.de
- CIFS: keep FileInfo handle live during oplock break (bsc#1106284, bsc#1131565, bsc#1144333).
- commit 83e4054
* Mon Jul 22 2019 palcantara@suse.de
- cifs: fix handle leak in smb2_query_symlink() (bsc#1144333).
- commit 4beb6c4
* Mon Jul 22 2019 palcantara@suse.de
- cifs: Fix lease buffer length error (bsc#1144333).
- commit 9e69c1d
* Mon Jul 22 2019 palcantara@suse.de
- cifs: Fix use-after-free in SMB2_read (bsc#1144333).
- commit 082bb78
* Mon Jul 22 2019 palcantara@suse.de
- cifs: Fix use-after-free in SMB2_write (bsc#1144333).
- commit 2ba4a61
* Mon Jul 22 2019 palcantara@suse.de
- smb3: allow more detailed protocol info on open files for debugging (bsc#1144333).
- commit 596e8f1
* Mon Jul 22 2019 msuchanek@suse.de
- powerpc/tm: Fix oops on sigreturn on systems without TM
  (bsc#1142265 CVE-2019-13648).
- commit 1b520d8
* Mon Jul 22 2019 tiwai@suse.de
- Input: gtco - bounds check collection indent level
  (CVE-2019-13631,bsc#1142023).
- commit 2ce2efe
* Mon Jul 22 2019 tiwai@suse.de
- VMCI: Fix integer overflow in VMCI handle arrays (bsc#1051510).
- commit 8bf4468
* Mon Jul 22 2019 tiwai@suse.de
- USB: serial: ftdi_sio: add ID for isodebug v1 (bsc#1051510).
- USB: serial: option: add support for GosunCn ME3630 RNDIS mode
  (bsc#1051510).
- commit 1da5d9b
* Mon Jul 22 2019 tiwai@suse.de
- Input: psmouse - fix build error of multiple definition
  (bsc#1051510).
- Input: synaptics - enable SMBUS on T480 thinkpad trackpad
  (bsc#1051510).
- Input: imx_keypad - make sure keyboard can always wake up system
  (bsc#1051510).
- Input: elantech - enable middle button support on 2 ThinkPads
  (bsc#1051510).
- commit 9e1c3d9
* Mon Jul 22 2019 tiwai@suse.de
- drm/nouveau/i2c: Enable i2c pads & busses during preinit
  (bsc#1051510).
- commit 45b1d4a
* Mon Jul 22 2019 tiwai@suse.de
- crypto: ccp - Fix SEV_VERSION_GREATER_OR_EQUAL (bsc#1051510).
- crypto: ccp/gcm - use const time tag comparison (bsc#1051510).
- crypto: ccp - memset structure fields to zero before reuse
  (bsc#1051510).
- crypto: crypto4xx - fix a potential double free in
  ppc4xx_trng_probe (bsc#1051510).
- commit 297f83f
* Mon Jul 22 2019 jthumshirn@suse.de
- block, bfq: NULL out the bic when it's no longer valid
  (bsc#1142359).
- commit 9ed968c
* Mon Jul 22 2019 jroedel@suse.de
- blacklist.conf: Add a5008b59cd9d dma-direct: only limit the mapping size if swiotlb could be used
- commit 26c7651
* Mon Jul 22 2019 jroedel@suse.de
- KVM: SVM: Fix detection of AMD Errata 1096 (bsc#1142354).
- commit d4bab45
* Mon Jul 22 2019 jthumshirn@suse.de
- acpi/nfit: Always dump _DSM output payload (bsc#1142351).
- commit fbdd275
* Mon Jul 22 2019 jthumshirn@suse.de
- libnvdimm/namespace: Fix label tracking error (bsc#1142350).
- commit 336ccfc
* Mon Jul 22 2019 bpoirier@suse.com
- be2net: Synchronize be_update_queues with dev_watchdog
  (bsc#1127315).
- be2net: Signal that the device cannot transmit during
  reconfiguration (bsc#1127315).
- commit a128a02
* Sun Jul 21 2019 jslaby@suse.cz
- sunhv: Fix device naming inconsistency between sunhv_console
  and sunhv_reg (networking-stable-19_06_18).
- lapb: fixed leak of control-blocks (networking-stable-19_06_18).
- neigh: fix use-after-free read in pneigh_get_next
  (networking-stable-19_06_18).
- be2net: Fix number of Rx queues used for flow hashing
  (networking-stable-19_06_18).
- vsock/virtio: set SOCK_DONE on peer shutdown
  (networking-stable-19_06_18).
- sctp: Free cookie before we memdup a new one
  (networking-stable-19_06_18).
- net: openvswitch: do not free vport if register_netdevice()
  is failed (networking-stable-19_06_18).
- ipv6: flowlabel: fl6_sock_lookup() must use atomic_inc_not_zero
  (networking-stable-19_06_18).
- commit 92c9710
* Sat Jul 20 2019 ptesarik@suse.cz
- pkey: Indicate old mkvp only if old and current mkvp are
  different (bsc#1137827 LTC#178090).
- commit dadd843
* Fri Jul 19 2019 tiwai@suse.de
- mei: me: add denverton innovation engine device IDs
  (bsc#1051510).
- mei: bus: need to unlink client before freeing (bsc#1051510).
- mei: me: add gemini lake devices id (bsc#1051510).
- commit 27fefbb
* Fri Jul 19 2019 tiwai@suse.de
- clk: rockchip: Don't yell about bad mmc phases when getting
  (bsc#1051510).
- clk: tegra210: fix PLLU and PLLU_OUT1 (bsc#1051510).
- clk: qcom: Fix -Wunused-const-variable (bsc#1051510).
- dmaengine: hsu: Revert "set HSU_CH_MTSR to memory width"
  (bsc#1051510).
- crypto: talitos - fix max key size for sha384 and sha512
  (bsc#1051510).
- commit 66dee7e
* Fri Jul 19 2019 tiwai@suse.de
- ALSA: seq: Break too long mutex context in the write loop
  (bsc#1051510).
- ALSA: hda/realtek: apply ALC891 headset fixup to one Dell
  machine (bsc#1051510).
- ALSA: hda/realtek - Fixed Headphone Mic can't record on Dell
  platform (bsc#1051510).
- commit ee65de2
* Thu Jul 18 2019 mgorman@suse.de
- mm: migrate: Fix reference check race between __find_get_block()
  and migration (bnc#1137609).
- commit 2ca7d32
* Thu Jul 18 2019 jslaby@suse.cz
- net: rds: fix memory leak in rds_ib_flush_mr_pool
  (networking-stable-19_06_09).
- ipv6: fix EFAULT on sendto with icmpv6 and hdrincl
  (networking-stable-19_06_09).
- ipv6: use READ_ONCE() for inet->hdrincl as in ipv4
  (networking-stable-19_06_09).
- ethtool: fix potential userspace buffer overflow
  (networking-stable-19_06_09).
- Fix memory leak in sctp_process_init
  (networking-stable-19_06_09).
- net/mlx4_en: ethtool, Remove unsupported SFP EEPROM high pages
  query (networking-stable-19_06_09).
- commit 15a7753
* Wed Jul 17 2019 jroedel@suse.de
- kvm: svm/avic: Do not send AVIC doorbell to self (bsc#1140133).
- commit a34d4f3
* Wed Jul 17 2019 ptesarik@suse.cz
- Refresh headers of
  patches.arch/mm-nvdimm-add-is_ioremap_addr-and-use-that-to-check-.patch.
- commit ba46f6b
* Tue Jul 16 2019 msuchanek@suse.de
- powerpc/crypto: Use cheaper random numbers for crc-vpmsum
  self-test (FATE#327696).
- commit 930a2cf
* Tue Jul 16 2019 msuchanek@suse.de
- Add support for crct10dif-vpmsum (FATE#327696).
- commit 962cbcc
* Tue Jul 16 2019 tiwai@suse.de
- usb: gadget: ether: Fix race between gether_disconnect and
  rx_submit (bsc#1051510).
- tty: serial_core: Set port active bit in uart_port_activate
  (bsc#1051510).
- tty: serial: cpm_uart - fix init when SMC is relocated
  (bsc#1051510).
- tty: rocket: fix incorrect forward declaration of 'rp_init()'
  (bsc#1051510).
- commit f9796f8
* Tue Jul 16 2019 tiwai@suse.de
- team: Always enable vlan tx offload (bsc#1051510).
- commit 017d54c
* Tue Jul 16 2019 tiwai@suse.de
- Revert "serial: 8250: Don't service RX FIFO if interrupts are
  disabled" (bsc#1051510).
- serial: uartps: Remove useless return from
  cdns_uart_poll_put_char (bsc#1051510).
- serial: uartps: Do not add a trailing semicolon to macro
  (bsc#1051510).
- serial: uartps: Fix long line over 80 chars (bsc#1051510).
- serial: uartps: Fix multiple line dereference (bsc#1051510).
- commit 65242c8
* Tue Jul 16 2019 tiwai@suse.de
- PCI: Always allow probing with driver_override (bsc#1051510).
- PCI: Return error if cannot probe VF (bsc#1051510).
- mfd: intel-lpss: Release IDA resources (bsc#1051510).
- commit 17fe5b0
* Tue Jul 16 2019 tiwai@suse.de
- ALSA: usb-audio: Cleanup DSD whitelist (bsc#1051510).
- commit 31d111a
* Tue Jul 16 2019 tiwai@suse.de
- ALSA: usb-audio: Add quirk for Focusrite Scarlett Solo
  (bsc#1051510).
- commit 2fff3db
* Tue Jul 16 2019 tiwai@suse.de
- ALSA: usb-audio: Sanity checks for each pipe and EP types
  (bsc#1051510).
- ALSA: usb-audio: Add quirk for MOTU MicroBook II (bsc#1051510).
- commit d819b43
* Tue Jul 16 2019 tiwai@suse.de
- ALSA: usb-audio: Enable .product_name override for Emagic,
  Unitor 8 (bsc#1051510).
- commit 3865597
* Tue Jul 16 2019 tiwai@suse.de
- blacklist.conf: Add reverting/reverted entries for fib_rules and seccomp
- commit 17e0ddf
* Tue Jul 16 2019 tiwai@suse.de
- drm/msm/a3xx: remove TPL1 regs from snapshot (bsc#1051510).
- drm/rockchip: Properly adjust to a true clock in adjusted_mode
  (bsc#1051510).
- drm/meson: Add support for XBGR8888 & ABGR8888 formats
  (bsc#1051510).
- commit 7db412c
* Tue Jul 16 2019 tiwai@suse.de
- crypto: ccp - Validate the the error value used to index error
  messages (bsc#1051510).
- crypto: chacha20poly1305 - fix atomic sleep when using async
  algorithm (bsc#1051510).
- crypto: ghash - fix unaligned memory access in ghash_setkey()
  (bsc#1051510).
- crypto: arm64/sha2-ce - correct digest for empty data in finup
  (bsc#1051510).
- crypto: arm64/sha1-ce - correct digest for empty data in finup
  (bsc#1051510).
- crypto: talitos - Align SEC1 accesses to 32 bits boundaries
  (bsc#1051510).
- crypto: talitos - properly handle split ICV (bsc#1051510).
- crypto: talitos - HMAC SNOOP NO AFEU mode requires SW icv
  checking (bsc#1051510).
- crypto: talitos - check data blocksize in ablkcipher
  (bsc#1051510).
- crypto: talitos - fix CTR alg blocksize (bsc#1051510).
- crypto: talitos - reduce max key size for SEC1 (bsc#1051510).
- crypto: talitos - rename alternative AEAD algos (bsc#1051510).
- crypto: ccp - Fix 3DES complaint from ccp-crypto module
  (bsc#1051510).
- crypto: ccp - fix AES CFB error exposed by new test vectors
  (bsc#1051510).
- commit c31bdf9
* Tue Jul 16 2019 jthumshirn@suse.de
- blacklist.conf: blacklist e153abc0739f ("zram: pass down the bvec we need
  to read into in the work struct")
- commit 4c1cb5d
* Tue Jul 16 2019 msuchanek@suse.de
- Rename patches to same name as SLE15 SP1.
- commit 41e129a
* Tue Jul 16 2019 msuchanek@suse.de
- mm/nvdimm: add is_ioremap_addr and use that to check ioremap
  address (bsc#1140322 LTC#176270).
- powerpc/mm: Consolidate numa_enable check and min_common_depth
  check (bsc#1140322 LTC#176270).
- powerpc/mm: Fix node look up with numa=off boot (bsc#1140322
  LTC#176270).
- powerpc/mm/drconf: Use NUMA_NO_NODE on failures instead of
  node 0 (bsc#1140322 LTC#176270).
- mm: replace all open encodings for NUMA_NO_NODE (bsc#1140322
  LTC#176270).
- commit eb30721
* Tue Jul 16 2019 ggherdovich@suse.cz
- platform/x86: intel_turbo_max_3: Remove restriction for HWP
  platforms (jsc#SLE-5439).
- commit 5359a3d
* Mon Jul 15 2019 msuchanek@suse.de
- Move patch to correct directory.
- commit 54a306a
* Mon Jul 15 2019 msuchanek@suse.de
- scripts/git_sort/git_sort.py: Add mmots tree.
- commit 08c2a80
* Mon Jul 15 2019 fdmanana@suse.com
- patches.suse/Btrfs-kill-btrfs_clear_path_blocking.patch:
  (bsc#1140139).
- commit a5cd556
* Mon Jul 15 2019 lhenriques@suse.com
- libceph: check reply num_data_items in setup_request_data()
  (bsc#1135897).
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch.
- Refresh
  patches.drivers/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- Refresh
  patches.drivers/libceph-add-support-for-write-same-requests.patch.
- commit ca2351e
* Mon Jul 15 2019 lyan@suse.com
- KVM: s390: kABI Workaround for 'lowcore' (bsc#1119222).
- commit f5c46ac
* Mon Jul 15 2019 lhenriques@suse.com
- libceph: preallocate message data items (bsc#1135897).
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch.
- Refresh
  patches.drivers/libceph-add-scatterlist-messenger-data-type.patch.
- Refresh
  patches.drivers/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- Refresh
  patches.drivers/libceph-add-support-for-write-same-requests.patch.
- commit ac80fb5
* Mon Jul 15 2019 tiwai@suse.de
- Fix kABI breakage by mwifiex security fix
  (CVE-2019-3846,bsc#1136424).
- commit 304447b
* Mon Jul 15 2019 tiwai@suse.de
- wil6210: fix potential out-of-bounds read (bsc#1051510).
- commit d05bdaa
* Mon Jul 15 2019 msuchanek@suse.de
- powerpc/watchpoint: Restore NV GPRs while returning from
  exception (bsc#1140945 bsc#1141401 bsc#1141402 bsc#1141452
  bsc#1141453 bsc#1141454 LTC#178983 LTC#179191 LTC#179192
  LTC#179193 LTC#179194 LTC#179195).
- commit 599f587
* Mon Jul 15 2019 tiwai@suse.de
- platform/x86: pmc_atom: Add CB4063 Beckhoff Automation board
  to critclk_systems DMI table (bsc#1051510).
- staging: rtl8712: reduce stack usage, again (bsc#1051510).
- commit 45d1e2e
* Mon Jul 15 2019 tiwai@suse.de
- mwifiex: Don't abort on small, spec-compliant vendor IEs
  (CVE-2019-3846,bsc#1136424).
- commit 69fc498
* Mon Jul 15 2019 tiwai@suse.de
- memstick: Fix error cleanup path of memstick_init (bsc#1051510).
- mmc: sdhci-pci: Try "cd" for card-detect lookup before using
  NULL (bsc#1051510).
- commit 4752cfa
* Mon Jul 15 2019 tiwai@suse.de
- memory: tegra: Fix integer overflow on tick value calculation
  (bsc#1051510).
- commit 0bd6f51
* Mon Jul 15 2019 tiwai@suse.de
- media: v4l2: Test type instead of cfg->type in
  v4l2_ctrl_new_custom() (bsc#1051510).
- media: s5p-mfc: Make additional clocks optional (bsc#1051510).
- media: vivid: fix incorrect assignment operation when setting
  video mode (bsc#1051510).
- media: marvell-ccic: fix DMA s/g desc number calculation
  (bsc#1051510).
- commit e2ee41b
* Mon Jul 15 2019 tiwai@suse.de
- lib/scatterlist: Fix mapping iterator when sg->offset is
  greater than PAGE_SIZE (bsc#1051510).
- lib: fix stall in __bitmap_parselist() (bsc#1051510).
- commit 1f90d1e
* Mon Jul 15 2019 tiwai@suse.de
- intel_th: msu: Fix single mode with disabled IOMMU
  (bsc#1051510).
- HID: wacom: generic: read HID_DG_CONTACTMAX from any feature
  report (bsc#1051510).
- HID: wacom: correct touch resolution x/y typo (bsc#1051510).
- HID: wacom: generic: Correct pad syncing (bsc#1051510).
- HID: wacom: generic: only switch the mode on devices with LEDs
  (bsc#1051510).
- commit 61dad59
* Mon Jul 15 2019 tiwai@suse.de
- staging: comedi: dt282x: fix a null pointer deref on interrupt
  (bsc#1051510).
- staging: comedi: amplc_pci230: fix null pointer deref on
  interrupt (bsc#1051510).
- batman-adv: fix for leaked TVLV handler (bsc#1051510).
- ath6kl: add some bounds checking (bsc#1051510).
- cpufreq: brcmstb-avs-cpufreq: Fix types for voltage/frequency
  (bsc#1051510).
- cpufreq: brcmstb-avs-cpufreq: Fix initial command check
  (bsc#1051510).
- cpufreq: ppc_cbe: fix possible object reference leak
  (bsc#1051510).
- cpufreq: pmac32: fix possible object reference leak
  (bsc#1051510).
- cpufreq/pasemi: fix possible object reference leak
  (bsc#1051510).
- cpufreq: kirkwood: fix possible object reference leak
  (bsc#1051510).
- cpufreq: acpi-cpufreq: Report if CPU doesn't support boost
  technologies (bsc#1051510).
- cpufreq: Use struct kobj_attribute instead of struct global_attr
  (bsc#1051510).
- cpufreq: check if policy is inactive early in __cpufreq_get()
  (bsc#1051510).
- commit 264b5ec
* Mon Jul 15 2019 tiwai@suse.de
- ASoC: max98090: remove 24-bit format support if RJ is 0
  (bsc#1051510).
- ASoC: soc-pcm: BE dai needs prepare when pause release after
  resume (bsc#1051510).
- ASoC : cs4265 : readable register too low (bsc#1051510).
- commit 5b361be
* Mon Jul 15 2019 tiwai@suse.de
- ALSA: hda/realtek - Headphone Mic can't record after S3
  (bsc#1051510).
- commit d8759b7
* Mon Jul 15 2019 mkoutny@suse.com
- cgroup: Use css_tryget() instead of css_tryget_online() in
  task_get_css() (bsc#1141478).
- commit 19414dc
* Mon Jul 15 2019 colyli@suse.de
- bcache: add reclaimed_journal_buckets to struct cache_set
  (bsc#1140652).
- bcache: performance improvement for btree_flush_write()
  (bsc#1140652).
- bcache: fix race in btree_flush_write() (bsc#1140652).
- bcache: remove retry_flush_write from struct cache_set
  (bsc#1140652).
- bcache: add comments for mutex_lock(&b->write_lock)
  (bsc#1140652).
- bcache: only clear BTREE_NODE_dirty bit when it is set
  (bsc#1140652).
- bcache: Revert "bcache: fix high CPU occupancy during journal"
  (bsc#1140652).
- bcache: Revert "bcache: free heap cache_set->flush_btree in
  bch_journal_free" (bsc#1140652).
- bcache: shrink btree node cache after bch_btree_check()
  (bsc#1140652).
- bcache: set largest seq to ja->seq[bucket_index] in
  journal_read_bucket() (bsc#1140652).
- bcache: add code comments for journal_read_bucket()
  (bsc#1140652).
- bcache: fix potential deadlock in cached_def_free()
  (bsc#1140652).
- bcache: acquire bch_register_lock later in cached_dev_free()
  (bsc#1140652).
- bcache: acquire bch_register_lock later in
  cached_dev_detach_finish() (bsc#1140652).
- bcache: avoid a deadlock in bcache_reboot() (bsc#1140652).
- bcache: stop writeback kthread and kworker when
  bch_cached_dev_run() failed (bsc#1140652).
- bcache: destroy dc->writeback_write_wq if failed to create
  dc->writeback_thread (bsc#1140652).
- bcache: fix mistaken sysfs entry for io_error counter
  (bsc#1140652).
- bcache: add pendings_cleanup to stop pending bcache device
  (bsc#1140652).
- bcache: make bset_search_tree() be more understandable
  (bsc#1140652).
- bcache: remove "XXX:" comment line from run_cache_set()
  (bsc#1140652).
- bcache: improve error message in bch_cached_dev_run()
  (bsc#1140652).
- bcache: add more error message in bch_cached_dev_attach()
  (bsc#1140652).
- bcache: more detailed error message to bcache_device_link()
  (bsc#1140652).
- bcache: check CACHE_SET_IO_DISABLE bit in bch_journal()
  (bsc#1140652).
- bcache: check CACHE_SET_IO_DISABLE in allocator code
  (bsc#1140652).
- bcache: remove unncessary code in bch_btree_keys_init()
  (bsc#1140652).
- bcache: add return value check to bch_cached_dev_run()
  (bsc#1140652).
- bcache: use sysfs_match_string() instead of
  __sysfs_match_string() (bsc#1140652).
- bcache: remove unnecessary prefetch() in bset_search_tree()
  (bsc#1140652).
- bcache: add io error counting in write_bdev_super_endio()
  (bsc#1140652).
- bcache: ignore read-ahead request failure on backing device
  (bsc#1140652).
- bcache: avoid flushing btree node in cache_set_flush() if io
  disabled (bsc#1140652).
- Revert "bcache: set CACHE_SET_IO_DISABLE in
  bch_cached_dev_error()" (bsc#1140652).
- bcache: fix return value error in bch_journal_read()
  (bsc#1140652).
- bcache: check c->gc_thread by IS_ERR_OR_NULL in
  cache_set_flush() (bsc#1140652).
- bcache: don't set max writeback rate if gc is running
  (bsc#1140652).
- bcache: only set BCACHE_DEV_WB_RUNNING when cached device
  attached (bsc#1140652).
- bcache: fix stack corruption by PRECEDING_KEY() (bsc#1140652).
- bcache: make is_discard_enabled() static (bsc#1140652).
- bcache: remove redundant LIST_HEAD(journal) from run_cache_set()
  (bsc#1140652).
- bcache: avoid potential memleak of list of journal_replay(s)
  in the CACHE_SYNC branch of run_cache_set (bsc#1140652).
- bcache: fix wrong usage use-after-freed on keylist in
  out_nocoalesce branch of btree_gc_coalesce (bsc#1140652).
- bcache: fix failure in journal relplay (bsc#1140652).
- bcache: improve bcache_reboot() (bsc#1140652).
- bcache: add comments for closure_fn to be called in
  closure_queue() (bsc#1140652).
- bcache: Add comments for blkdev_put() in registration code path
  (bsc#1140652).
- bcache: add error check for calling register_bdev()
  (bsc#1140652).
- bcache: return error immediately in bch_journal_replay()
  (bsc#1140652).
- bcache: add comments for kobj release callback routine
  (bsc#1140652).
- bcache: add failure check to run_cache_set() for journal replay
  (bsc#1140652).
- bcache: never set KEY_PTRS of journal key to 0 in
  journal_reclaim() (bsc#1140652).
- bcache: move definition of 'int ret' out of macro read_bucket()
  (bsc#1140652).
- bcache: fix a race between cache register and cacheset
  unregister (bsc#1140652).
- bcache: Clean up bch_get_congested() (bsc#1140652).
- bcache: avoid clang -Wunintialized warning (bsc#1140652).
- bcache: fix inaccurate result of unused buckets (bsc#1140652).
- bcache: fix crashes stopping bcache device before read miss done
  (bsc#1140652).
- bcache: do not assign in if condition in bcache_device_init()
  (bsc#1140652).
- commit 624edf7
* Mon Jul 15 2019 dkirjanov@suse.com
- net/packet: fix memory leak in packet_set_ring() (git-fixes).
- pktgen: do not sleep with the thread lock held (git-fixes).
- packet: in recvmsg msg_name return at least sizeof sockaddr_ll
  (git-fixes).
- ethtool: check the return value of get_regs_len (git-fixes).
- netfilter: conntrack: fix calculation of next bucket number
  in early_drop (git-fixes).
- RDS: IB: fix 'passing zero to ERR_PTR()' warning (git-fixes).
- af_unix: remove redundant lockdep class (git-fixes).
- tcp: reduce tcp_fastretrans_alert() verbosity (git-fixes).
- commit ca77765
* Mon Jul 15 2019 mkoutny@suse.com
- blacklist.conf: Add "signal: Don't restart fork when signals come in."
- commit 5f983d8
* Mon Jul 15 2019 ghe@suse.com
- ocfs2: add first lock wait time in locking_state (bsc#1134390).
- ocfs2: add locking filter debugfs file (bsc#1134390).
- ocfs2: add last unlock times in locking_state (bsc#1134390).
- commit 0510321
* Fri Jul 12 2019 msuchanek@suse.de
- dasd_fba: Display '00000000' for zero page when dumping sense
  (bsc#11123080).
- commit dc247e1
* Fri Jul 12 2019 lhenriques@suse.com
- ceph: fix iov_iter issues in ceph_direct_read_write() (bsc#1141450).
  blacklist.conf: dropped patch from blacklist.
- commit a7ea34f
* Fri Jul 12 2019 lhenriques@suse.com
- libceph: add osd_req_op_extent_osd_data_bvecs() (bsc#1141450).
- Refresh
  patches.drivers/libceph-add-scatterlist-messenger-data-type.patch.
- commit dde9c20
* Fri Jul 12 2019 lhenriques@suse.com
- libceph: handle zero-length data items (bsc#1141450).
- commit de3f70e
* Fri Jul 12 2019 lhenriques@suse.com
- rbd: move from raw pages to bvec data descriptors (bsc#1141450).
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- Refresh
  patches.drivers/rbd-add-support-for-writesame-requests.patch.
- Refresh
  patches.drivers/rbd-export-some-functions-used-by-lio-rbd-backend.patch.
- Refresh
  patches.drivers/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 7b7c7e2
* Fri Jul 12 2019 lhenriques@suse.com
- libceph: introduce BVECS data type (bsc#1141450).
- Refresh
  patches.drivers/libceph-add-scatterlist-messenger-data-type.patch.
- commit d754c75
* Fri Jul 12 2019 lyan@suse.com
- kvm/mmu: kABI fix for *_mmu_pages changes in struct kvm_arch
  (bsc#1135335).
- commit 2ed5441
* Fri Jul 12 2019 lhenriques@suse.com
- rbd: get rid of img_req->copyup_pages (bsc#1141450).
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- Refresh patches.drivers/rbd-add-lio-specific-data-area.patch.
- Refresh
  patches.drivers/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 4baa02a
* Fri Jul 12 2019 lhenriques@suse.com
- rbd: use kmem_cache_zalloc() in rbd_img_request_create()
  (bsc#1141450).
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- commit 5ac046a
* Fri Jul 12 2019 lhenriques@suse.com
- rbd: don't NULL out ->obj_request in
  rbd_img_obj_parent_read_full() (bsc#1141450).
- commit 2a1ca03
* Fri Jul 12 2019 mbenes@suse.cz
- livepatch: Remove duplicate warning about missing reliable
  stacktrace support (bsc#1071995 fate#323487).
- commit c713cd8
* Fri Jul 12 2019 mbenes@suse.cz
- Revert "livepatch: Remove reliable stacktrace check in
  klp_try_switch_task()" (bsc#1071995 fate#323487).
- commit 8abffe1
* Fri Jul 12 2019 lhenriques@suse.com
- rbd: don't (ab)use obj_req->pages for stat requests (bsc#1141450).
- commit 5d26c3a
* Fri Jul 12 2019 lhenriques@suse.com
- rbd: remove bio cloning helpers (bsc#1141450).
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- commit 0f2b942
* Fri Jul 12 2019 lhenriques@suse.com
- libceph, rbd: new bio handling code (aka don't clone bios)
  (bsc#1141450).
- Refresh
  patches.drivers/libceph-add-scatterlist-messenger-data-type.patch.
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- Refresh
  patches.drivers/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit 12dfa12
* Fri Jul 12 2019 lhenriques@suse.com
- rbd: start enums at 1 instead of 0 (bsc#1141450).
- Refresh
  patches.drivers/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch.
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- Refresh
  patches.drivers/rbd-add-support-for-writesame-requests.patch.
- Refresh
  patches.drivers/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- commit a89ddbc
* Fri Jul 12 2019 mbenes@suse.cz
- livepatch: Use static buffer for debugging messages under rq
  lock (bsc#1071995 fate#323487).
- commit 2762e07
* Fri Jul 12 2019 jslaby@suse.cz
- net-gro: fix use-after-free read in napi_gro_frags()
  (networking-stable-19_05_31).
- net: mvpp2: fix bad MVPP2_TXQ_SCHED_TOKEN_CNTR_REG queue value
  (networking-stable-19_05_31).
- net/mlx5: Allocate root ns memory using kzalloc to match kfree
  (networking-stable-19_05_31).
- net/mlx5: Avoid double free in fs init error unwinding path
  (networking-stable-19_05_31).
- llc: fix skb leak in llc_build_and_send_ui_pkt()
  (networking-stable-19_05_31).
- net: mvneta: Fix err code path of probe
  (networking-stable-19_05_31).
- net: fec: fix the clk mismatch in failed_reset path
  (networking-stable-19_05_31).
- ipv4/igmp: fix build error if !CONFIG_IP_MULTICAST
  (networking-stable-19_05_31).
- ipv4/igmp: fix another memory leak in igmpv3_del_delrec()
  (networking-stable-19_05_31).
- bnxt_en: Fix aggregation buffer leak under OOM condition
  (networking-stable-19_05_31).
- net: stmmac: fix reset gpio free missing
  (networking-stable-19_05_31).
- ipv6: Consider sk_bound_dev_if when binding a raw socket to
  an address (networking-stable-19_05_31).
- commit 3bc60c9
* Fri Jul 12 2019 lhenriques@suse.com
- libceph, rbd, ceph: move ceph_osdc_alloc_messages() calls
  (bsc#1135897).
- Refresh
  patches.drivers/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch.
- Refresh
  patches.fixes/0001-rbd-drop-extra-rbd_img_request_get.patch.
- Refresh
  patches.fixes/0002-rbd-make-sure-pages-are-freed-by-libceph.patch.
- Refresh
  patches.fixes/rbd-copy-compare-and-write-osd-requests-before-resub.patch.
- Refresh
  patches.fixes/rbd-truncate-objects-on-cmpext-short-reads.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-cmpsetxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-getxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-setxattr.patch.
- commit 328339b
* Fri Jul 12 2019 mbenes@suse.cz
- kbuild: use -flive-patching when CONFIG_LIVEPATCH is enabled
  (bsc#1071995 fate#323487).
- commit 225bdec
* Thu Jul 11 2019 lhenriques@suse.com
- libceph: introduce alloc_watch_request() (bsc#1135897).
- commit b7132d4
* Thu Jul 11 2019 lhenriques@suse.com
- libceph: assign cookies in linger_submit() (bsc#1135897).
- commit 2ca35b3
* Thu Jul 11 2019 lhenriques@suse.com
- libceph: enable fallback to ceph_msg_new() in ceph_msgpool_get()
  (bsc#1135897).
- commit fefe07e
* Thu Jul 11 2019 lhenriques@suse.com
- libceph: don't consume a ref on pagelist in
  ceph_msg_data_add_pagelist() (bsc#1135897).
- commit 71e58ee
* Thu Jul 11 2019 lhenriques@suse.com
- libceph: introduce ceph_pagelist_alloc() (bsc#1135897).
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch.
- commit 8b2e58c
* Thu Jul 11 2019 lhenriques@suse.com
- libceph, rbd: add error handling for osd_req_op_cls_init()
  (bsc#1135897).
- commit 67234c3
* Thu Jul 11 2019 ptesarik@suse.cz
- Delete patches.fixes/s390-setup-fix-early-warning-messages (bsc#1140948).
- commit bf2abc2
* Thu Jul 11 2019 jslaby@suse.cz
- ipv4: Use return value of inet_iif() for __raw_v4_lookup in
  the while loop (git-fixes).
- commit b3c23d2
* Thu Jul 11 2019 osalvador@suse.de
- mm, page_alloc: fix has_unmovable_pages for HugePages
  (bsc#1127034).
- Refresh
  patches.fixes/0005-mm-memory_hotplug-be-more-verbose-for-memory-offline.patch.
- commit acc7b54
* Thu Jul 11 2019 oneukum@suse.com
- media: cpia2_usb: first wake up, then free in disconnect
  (bsc#1135642).
- commit 62d884c
* Wed Jul 10 2019 tiwai@suse.de
- usb: gadget: udc: lpc32xx: allocate descriptor with GFP_ATOMIC
  (bsc#1051510).
- usb: gadget: fusb300_udc: Fix memory leak of fusb300->ep[i]
  (bsc#1051510).
- commit 246a023
* Wed Jul 10 2019 tiwai@suse.de
- blacklist.conf: Add already cherry-picked commits for drm/i915
- commit f5294bb
* Wed Jul 10 2019 tiwai@suse.de
- drm/amdgpu/gfx9: use reset default for PA_SC_FIFO_SIZE
  (bsc#1051510).
- drm/i915/dmc: protect against reading random memory
  (bsc#1051510).
- commit 6b491bf
* Wed Jul 10 2019 jslaby@suse.cz
- vsock/virtio: free packets during the socket release
  (networking-stable-19_05_21).
- net: avoid weird emergency message (networking-stable-19_05_21).
- net: usb: qmi_wwan: add Telit 0x1260 and 0x1261 compositions
  (networking-stable-19_05_21).
- ppp: deflate: Fix possible crash in deflate_init
  (networking-stable-19_05_21).
- rtnetlink: always put IFLA_LINK for links with a link-netnsid
  (networking-stable-19_05_21).
- net/mlx4_core: Change the error print to info print
  (networking-stable-19_05_21).
- commit 60be362
* Wed Jul 10 2019 tiwai@suse.de
- regulator: s2mps11: Fix buck7 and buck8 wrong voltages
  (bsc#1051510).
- commit 72883d3
* Wed Jul 10 2019 tiwai@suse.de
- pwm: stm32: Use 3 cells ->of_xlate() (bsc#1111666).
- qmi_wwan: Fix out-of-bounds read (bsc#1111666).
- commit a9e87e7
* Wed Jul 10 2019 tiwai@suse.de
- PCI: Do not poll for PME if the device is in D3cold
  (bsc#1051510).
- commit d4fcd5f
* Wed Jul 10 2019 tiwai@suse.de
- mfd: hi655x: Fix regmap area declared size for hi655x
  (bsc#1051510).
- commit 624e738
* Wed Jul 10 2019 tiwai@suse.de
- irqchip/gic-v3-its: fix some definitions of inner cacheability
  attributes (bsc#1051510).
- commit bd40199
* Wed Jul 10 2019 tiwai@suse.de
- irqchip/mbigen: Don't clear eventid when freeing an MSI
  (bsc#1051510).
- commit 6a90fd2
* Wed Jul 10 2019 tiwai@suse.de
- iommu/arm-smmu: Add support for qcom,smmu-v2 variant
  (bsc#1051510).
- commit 9791296
* Wed Jul 10 2019 tiwai@suse.de
- iommu/arm-smmu-v3: Use explicit mb() when moving cons pointer
  (bsc#1051510).
- iommu/arm-smmu-v3: sync the OVACKFLG to PRIQ consumer register
  (bsc#1051510).
- commit a2d5600
* Wed Jul 10 2019 tiwai@suse.de
- gpio: omap: fix lack of irqstatus_raw0 for OMAP4 (bsc#1051510).
- staging:iio:ad7150: fix threshold mode config bit (bsc#1051510).
- commit fd92574
* Wed Jul 10 2019 jslaby@suse.cz
- bonding: fix arp_validate toggling in active-backup mode
  (networking-stable-19_05_14).
- net: seeq: fix crash caused by not set dev.parent
  (networking-stable-19_05_14).
- bridge: Fix error path for kobject_init_and_add()
  (networking-stable-19_05_14).
- packet: Fix error path in packet_init
  (networking-stable-19_05_14).
- tuntap: synchronize through tfiles array instead of
  tun->numqueues (networking-stable-19_05_14).
- ipv4: Fix raw socket lookup for local traffic
  (networking-stable-19_05_14).
- vrf: sit mtu should not be updated when vrf netdev is the link
  (networking-stable-19_05_14).
- dpaa_eth: fix SG frame cleanup (networking-stable-19_05_14).
- commit c9bd797
* Wed Jul 10 2019 mgorman@suse.de
- mm/vmscan.c: prevent useless kswapd loops (git fixes
  (mm/vmscan)).
- hugetlbfs: fix kernel BUG at fs/hugetlbfs/inode.c:444! (git
  fixes (mm/hugetlbfs)).
- hugetlbfs: dirty pages as they are added to pagecache (git fixes
  (mm/hugetlbfs)).
- commit fcdbd4c
* Wed Jul 10 2019 jroedel@suse.de
- KVM: x86: fix return value for reserved EFER (bsc#1140992).
- commit 275307e
* Wed Jul 10 2019 tiwai@suse.de
- ASoC: cx2072x: fix integer overflow on unsigned int multiply
  (bsc#1111666).
- commit 0ea6ab6
* Wed Jul 10 2019 tiwai@suse.de
- Move upstreamed ASoC patches into sorted section
- commit f6685e7
* Wed Jul 10 2019 jroedel@suse.de
- blacklist.conf: Add 9c3e922ba316 KVM: nVMX: Move guest non-reg state checks to VM-Exit path
- commit ae09496
* Wed Jul 10 2019 jroedel@suse.de
- kvm: svm/avic: fix off-by-one in checking host APIC ID
  (bsc#1140971).
- KVM: x86: Skip EFER vs. guest CPUID checks for host-initiated
  writes (bsc#1140972).
- commit 930856f
* Wed Jul 10 2019 tiwai@suse.de
- ACPI: PM: Allow transitions to D0 to occur in special cases
  (bsc#1051510).
- ACPI: PM: Avoid evaluating _PS3 on transitions from D3hot to
  D3cold (bsc#1051510).
- commit 2ae341b
* Wed Jul 10 2019 jroedel@suse.de
- blacklist.conf: Add 65fd4cb65b2d Documentation: Move L1TF to separate directory
- commit fd03e8e
* Wed Jul 10 2019 jroedel@suse.de
- Documentation: DMA-API: fix a function name of max_mapping_size
  (bsc#1140954).
- iommu: Use right function to get group for device (bsc#1140958).
- iommu/amd: Make iommu_disable safer (bsc#1140955).
- iommu/vt-d: Handle PCI bridge RMRR device scopes in
  intel_iommu_get_resv_regions (bsc#1140960).
- iommu/vt-d: Handle RMRR with PCI bridge device scopes
  (bsc#1140961).
- iommu/vt-d: Introduce is_downstream_to_pci_bridge helper
  (bsc#1140962).
- iommu/vt-d: Duplicate iommu_resv_region objects per device list
  (bsc#1140959).
- iommu: Fix a leak in iommu_insert_resv_region (bsc#1140957).
- iommu/vt-d: Remove unnecessary rcu_read_locks (bsc#1140964).
- iommu/arm-smmu: Avoid constant zero in TLBI writes
  (bsc#1140956).
- commit 0e029eb
* Tue Jul  9 2019 lyan@suse.com
- kvm: mmu: Fix overflow on kvm mmu page limit calculation
  (bsc#1135335).
- commit 64e77be
* Tue Jul  9 2019 jack@suse.cz
- dax: Fix xarray entry association for mixed mappings
  (bsc#1140893).
- commit 7914da5
* Tue Jul  9 2019 jack@suse.cz
- patches.fixes/scsi-vmw_pscsi-Fix-use-after-free-in-pvscsi_queue_lc.patch:
  Update patch metadata
- commit 9a80b82
* Tue Jul  9 2019 jack@suse.cz
- ext4: do not delete unlinked inode from orphan list on failed
  truncate (bsc#1140891).
- commit 493e396
* Tue Jul  9 2019 jack@suse.cz
- fs/ocfs2: fix race in ocfs2_dentry_attach_lock() (bsc#1140889).
- commit 0af973c
* Tue Jul  9 2019 jack@suse.cz
- Abort file_remove_privs() for non-reg. files (bsc#1140888).
- commit e522f5b
* Tue Jul  9 2019 jack@suse.cz
- fs/proc/proc_sysctl.c: Fix a NULL pointer dereference
  (bsc#1140887).
- commit 3a194bf
* Tue Jul  9 2019 jack@suse.cz
- fs/proc/proc_sysctl.c: fix NULL pointer dereference in put_links
  (bsc#1140887).
- commit 716f3c6
* Tue Jul  9 2019 jslaby@suse.cz
- ptrace: Fix ->ptracer_cred handling for PTRACE_TRACEME
  (git-fixes).
- ptrace: restore smp_rmb() in __ptrace_may_access() (git-fixes).
- signal/ptrace: Don't leak unitialized kernel memory with
  PTRACE_PEEK_SIGINFO (git-fixes).
- commit efed5b2
* Tue Jul  9 2019 jthumshirn@suse.de
- nfit/ars: Allow root to busy-poll the ARS state machine
  (bsc#1140814).
- Refresh patches.drivers/nfit-ars-avoid-stale-ars-results.patch.
- commit 3bd9146
* Tue Jul  9 2019 mkubecek@suse.cz
- kabi: handle addition of netns_ipv4::ip_id_key (CVE-2019-10638
  bsc#1140575).
- kabi: handle addition of net::hash_mix (CVE-2019-10639
  bsc#1140577).
- inet: switch IP ID generator to siphash (CVE-2019-10638
  bsc#1140575).
- netns: provide pure entropy for net_hash_mix() (CVE-2019-10639
  bsc#1140577).
- netns: get more entropy from net_hash_mix() (CVE-2019-10638
  bsc#1140575).
- commit 8c9c673
* Tue Jul  9 2019 mkubecek@suse.cz
- tcp: refine memory limit test in tcp_fragment() (CVE-2019-11478
  bsc#1137586 bsc#1139751).
- Refresh
  patches.kabi/kabi-drop-LINUX_MIB_TCPWQUEUETOOBIG-snmp-counter.patch.
- commit 18fef7f
* Mon Jul  8 2019 tiwai@suse.de
- blacklist.conf: Add kABI-breaking nfc fix
- commit c3837d8
* Mon Jul  8 2019 tiwai@suse.de
- blacklist.conf: Add unaffected nouveau build fixes
- commit b379525
* Mon Jul  8 2019 jthumshirn@suse.de
- scsi: qla2xxx: Fix abort handling in tcm_qla2xxx_write_pending()
  (bsc#1140727).
- scsi: qla2xxx: Fix incorrect region-size setting in optrom
  SYSFS routines (bsc#1140728).
- commit 631f49f
* Mon Jul  8 2019 tiwai@suse.de
- dmaengine: imx-sdma: remove BD_INTR for channel0 (bsc#1051510).
- commit 6c0c801
* Mon Jul  8 2019 tiwai@suse.de
- coresight: etm4x: Add support to enable ETMv4.2 (bsc#1051510).
- coresight: etb10: Fix handling of perf mode (bsc#1051510).
- commit bd9477a
* Mon Jul  8 2019 tiwai@suse.de
- blacklist.conf: Add an upstream fix that was reverted in 4.14.y stable
- commit 3b33a6b
* Mon Jul  8 2019 tiwai@suse.de
- staging: comedi: ni_mio_common: Fix divide-by-zero for DIO
  cmdtest (bsc#1051510).
- commit 9b8ac5d
* Mon Jul  8 2019 tiwai@suse.de
- apparmor: enforce nullbyte at end of tag string (bsc#1051510).
- clk: tegra: Fix PLLM programming on Tegra124+ when PMC overrides
  divider (bsc#1051510).
- clk: rockchip: Turn on "aclk_dmac1" for suspend on rk3288
  (bsc#1051510).
- commit bae992a
* Mon Jul  8 2019 mbenes@suse.cz
- blacklist.conf: 074376ac0e1d ("ftrace/x86: Anotate text_mutex split between ftrace_arch_code_modify_post_process() and ftrace_arch_code_modify_prepare()")
  __CHECKER__ only, so not a bug and not really needed.
- commit 6fa68b1
* Mon Jul  8 2019 mbenes@suse.cz
- blacklist.conf: 4a60aa05a063 ("objtool: Support per-function rodata sections")
  We don't build the kernel with -ffunction-sections -fdata-sections.
- commit e146141
* Mon Jul  8 2019 mbenes@suse.cz
- tracing/snapshot: Resize spare buffer if size changed
  (bsc#1140726).
- commit 275bc04
* Mon Jul  8 2019 mbenes@suse.cz
- blacklist.conf: 0c97bf863efc ("tracing: Silence GCC 9 array bounds warning")
  Compiler warning fix for gcc-9. The code itself is correct.
- commit 6c5891e
* Mon Jul  8 2019 mbenes@suse.cz
- ftrace/x86: Remove possible deadlock between register_kprobe()
  and ftrace_run_update_code() (bsc#1071995 fate#323487).
- commit c27efed
* Mon Jul  8 2019 tiwai@suse.de
- Update upstream patch tags
  Refreshed:
  patches.drivers/ibmvnic-Do-not-close-unopened-driver-during-reset.patch
  patches.drivers/ibmvnic-Fix-unchecked-return-codes-of-memory-allocat.patch
  patches.drivers/ibmvnic-Refresh-device-multicast-list-after-reset.patch
  patches.fixes/crypto-user-prevent-operating-on-larval-algorithms.patch
  patches.fixes/scsi-target-iblock-fix-overrun-in-write-same-emulation
- commit 786df26
* Mon Jul  8 2019 jthumshirn@suse.de
- libnvdimm, pfn: Fix over-trim in trim_pfn_device()
  (bsc#1140719).
- commit db6a472
* Mon Jul  8 2019 jthumshirn@suse.de
- nvme: copy MTFA field from identify controller (bsc#1140715).
- commit 092be13
* Mon Jul  8 2019 jthumshirn@suse.de
- nfit/ars: Introduce scrub_flags (jsc#SLE-5433).
- Refresh patches.kabi/kabi-protect-struct-acpi_nfit_desc.patch.
- commit 2007195
* Mon Jul  8 2019 jthumshirn@suse.de
- nfit/ars: Avoid stale ARS results (jsc#SLE-5433).
- Refresh patches.kabi/kabi-protect-struct-acpi_nfit_desc.patch.
- commit d859a90
* Mon Jul  8 2019 jthumshirn@suse.de
- sbitmap: fix improper use of smp_mb__before_atomic()
  (bsc#1140658).
- commit 7bc74cf
* Mon Jul  8 2019 jthumshirn@suse.de
- Kabi fixup blk_mq_register_dev() (bsc#1140637).
- blk-mq: free hw queue's resource in hctx's release handler
  (bsc#1140637).
- commit 0068f07
* Sat Jul  6 2019 lduncan@suse.com
- scsi: target/iblock: Fix overrun in WRITE SAME emulation
  (bsc#1140424).
- commit ba1d4c6
* Fri Jul  5 2019 tiwai@suse.de
- crypto: cryptd - Fix skcipher instance memory leak
  (bsc#1051510).
- commit 87f6ea0
* Fri Jul  5 2019 jack@suse.cz
- dm, dax: Fix detection of DAX support (bsc#1139782).
- commit 16acab4
* Fri Jul  5 2019 jthumshirn@suse.de
- Update patch mainline tags
- Refresh patches.fixes/drivers-base-introduce-kill_device.patch.
- Refresh
  patches.fixes/libnvdimm-bus-prevent-duplicate-device_unregister-calls.patch.
- commit c63ec1e
* Fri Jul  5 2019 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add nvdimm/libnvdimm-fixes
- commit c8c8479
* Fri Jul  5 2019 tiwai@suse.de
- ALSA: line6: Fix write on zero-sized buffer (bsc#1051510).
- ALSA: firewire-lib/fireworks: fix miss detection of received
  MIDI messages (bsc#1051510).
- ALSA: seq: fix incorrect order of dest_client/dest_ports
  arguments (bsc#1051510).
- ALSA: hda/realtek - Change front mic location for Lenovo M710q
  (bsc#1051510).
- ALSA: usb-audio: fix sign unintended sign extension on left
  shifts (bsc#1051510).
- ALSA: hda/realtek: Add quirks for several Clevo notebook
  barebones (bsc#1051510).
- commit 095cfae
* Thu Jul  4 2019 msuchanek@suse.de
- Add back sibling paca poiter to paca (bsc#1055117).
- commit a873261
* Thu Jul  4 2019 msuchanek@suse.de
- powerpc/64s: Remove POWER9 DD1 support (bsc#1055117, LTC#159753,
  FATE#323286, git-fixes).
- powerpc/mm/radix: Change pte relax sequence to handle nest
  MMU hang (bsc#1055117).
- powerpc/mm: Change function prototype (bsc#1055117).
- powerpc/mm/radix: Move function from radix.h to pgtable-radix.c
  (bsc#1055117).
- powerpc/mm/hugetlb: Update huge_ptep_set_access_flags to call
  __ptep_set_access_flags directly (bsc#1055117).
- commit cabc25a
* Thu Jul  4 2019 msuchanek@suse.de
- powerpc/perf: Add PM_LD_MISS_L1 and PM_BR_2PATH to power9
  event list (bsc#1137728, LTC#178106).
- Refresh patches.arch/powerpc-perf-Add-blacklisted-events-for-Power9-DD2.1.patch.
- powerpc/perf: Add POWER9 alternate PM_RUN_CYC and
  PM_RUN_INST_CMPL events (bsc#1137728, LTC#178106).
- commit 9c52368
* Thu Jul  4 2019 msuchanek@suse.de
- powerpc/rtas: retry when cpu offline races with
  suspend/migration (bsc#1140428, LTC#178808).
- commit 4e041ec
* Thu Jul  4 2019 lhenriques@suse.com
- ceph: flush dirty inodes before proceeding with remount
  (bsc#1140405).
- commit f6d4f3b
* Thu Jul  4 2019 tbogendoerfer@suse.de
- net: mvpp2: prs: Use the correct helpers when removing all
  VID filters (bsc#1098633).
- net: mvpp2: prs: Fix parser range for VID filtering
  (bsc#1098633).
- net: mvpp2: Use strscpy to handle stat strings (bsc#1098633).
- commit 8675c3d
* Thu Jul  4 2019 msuchanek@suse.de
- Revert "Sign non-x86 kernels when possible (boo#1134303)"
  This reverts commit bac621c6704610562ebd9e74ae5ad85ca8025681.
  We don't have reports of this working with all ARM architectures in all
  cases (boot, kexec, ..) so revert for now.
- commit a235183
* Thu Jul  4 2019 oneukum@suse.com
- blacklist.conf: the patch should not have gone to stable on its own
- commit e6f616f
* Thu Jul  4 2019 oneukum@suse.com
- blacklist.conf: dependencies would break kABI
- commit d3c43ce
* Thu Jul  4 2019 oneukum@suse.com
- blacklist.conf: dependencies would break kABI
- commit d98c05b
* Thu Jul  4 2019 oneukum@suse.com
- blacklist.conf: would break kABI
- commit b15afa1
* Thu Jul  4 2019 oneukum@suse.com
- blacklist.conf: would break kABI
- commit d56abbc
* Thu Jul  4 2019 hare@suse.de
- block: Fix a NULL pointer dereference in generic_make_request()
  (bsc#1139771).
- commit 977cba2
* Thu Jul  4 2019 hare@suse.de
- Reshuffle patches to match series_sort.py
- commit 2469f32
* Thu Jul  4 2019 acho@suse.com
- Bluetooth: Fix faulty expression for minimum encryption key
  size check (bsc#1140328).
- commit 4e794d5
* Thu Jul  4 2019 ddiss@suse.de
- libceph: use single request data item for cmp/setxattr (bsc#1139101).
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch
- commit 5594932
* Wed Jul  3 2019 msuchanek@suse.de
- crypto: user - prevent operating on larval algorithms
  (bsc#1133401).
- Delete patches.fixes/crypto-algapi-guard-against-uninitialized-spawn-list.patch.
- commit f1b36c6
* Wed Jul  3 2019 oneukum@suse.com
- i2c: acorn: fix i2c warning (bsc#1135642).
- commit a0b3a52
* Wed Jul  3 2019 pvorel@suse.cz
- sysctl: handle overflow in proc_get_long (bsc#1051510).
- commit c14faec
* Wed Jul  3 2019 oneukum@suse.com
- blacklist.conf: it didn't even compile
- commit 7f6d59d
* Wed Jul  3 2019 oneukum@suse.com
- blacklist.conf: build warning only, no fix
- commit c5e8109
* Wed Jul  3 2019 hare@suse.de
- drivers/base: kABI fixes for struct device_private
  (bsc#1106383).
- driver core: Probe devices asynchronously instead of the driver
  (bsc#1106383).
- device core: Consolidate locking and unlocking of parent and
  device (bsc#1106383).
- driver core: Establish order of operations for device_add and
  device_del via bitflag (bsc#1106383).
- commit 1fff851
* Wed Jul  3 2019 jthumshirn@suse.de
- drivers/base: Introduce kill_device() (bsc#1139865).
- commit 33e739c
* Wed Jul  3 2019 hare@suse.de
- Refresh patches.drivers/nvme-rdma-move-nvme_rdma_configure_admin_queue-code-.patch.
- commit 93cf9c0
* Wed Jul  3 2019 jroedel@suse.de
- Revert "svm: Fix AVIC incomplete IPI emulation" (bsc#1140133).
- svm: Fix AVIC incomplete IPI emulation (bsc#1140133).
- svm: Add warning message for AVIC IPI invalid target
  (bsc#1140133).
- commit f060d17
* Wed Jul  3 2019 jthumshirn@suse.de
- libnvdimm/bus: Prevent duplicate device_unregister() calls
  (bsc#1139865).
- commit 379ae31
* Wed Jul  3 2019 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add djbw/nvdimm nvdimm-pending.
- commit 7d6adef
* Wed Jul  3 2019 mhocko@suse.com
- Update patches.suse/do-not-default-to-ibrs-on-skl.patch
  (bsc#1068032 CVE-2017-5753 bsc#1112824 jsc#SLE-7074).
- commit 4b76649
* Wed Jul  3 2019 tiwai@suse.de
- ppp: mppe: Add softdep to arc4 (bsc#1088047).
- commit 83e2dfd
* Tue Jul  2 2019 lduncan@suse.com
- scsi: libsas: fix a race condition when smp task timeout
  (CVE-2018-20836 bsc#1134395).
- commit ef84a5a
* Tue Jul  2 2019 oneukum@suse.com
- ntp: Allow TAI-UTC offset to be set to zero (bsc#1135642).
- commit fe4b469
* Tue Jul  2 2019 ghe@suse.com
- ocfs2: try to reuse extent block in dealloc without meta_alloc
  (bsc#1128902).
- commit ede2d05
* Tue Jul  2 2019 oneukum@suse.com
- USB: serial: fix initial-termios handling (bsc#1135642).
- commit 6bf0f16
* Mon Jul  1 2019 oneukum@suse.com
- usb: dwc2: host: Fix wMaxPacketSize handling (fix webcam
  regression) (bsc#1135642).
- commit 5f24d97
* Mon Jul  1 2019 oneukum@suse.com
- usb: chipidea: udc: workaround for endpoint conflict issue
  (bsc#1135642).
- commit 6586733
* Mon Jul  1 2019 oneukum@suse.com
- Update
  patches.fixes/0001-mwifiex-Fix-heap-overflow-in-mwifiex_uap_parse_tail_.patch
  (bsc#1136935 CVE-2019-10126).
  Added CVE number
- commit 9d2dcb5
* Wed Jun 26 2019 mwilck@suse.com
- Refresh patches.fixes/scsi-Introduce-scsi_start_queue.patch
  (bsc#1119532).
- Refresh
  patches.fixes/scsi-Split-scsi_internal_device_block.patch.
  This adds the changes made by the upstream merge commit 90311148415a.
- commit cf2d9d2
* Wed Jun 26 2019 tiwai@suse.de
- mmc: core: Prevent processing SDIO IRQs when the card is
  suspended (bsc#1051510).
- commit 280e016
* Wed Jun 26 2019 tiwai@suse.de
- mac80211: drop robust management frames from unknown TA
  (bsc#1051510).
- mac80211: Do not use stack memory with scatterlist for GMAC
  (bsc#1051510).
- mac80211: handle deauthentication/disassociation from TDLS peer
  (bsc#1051510).
- commit b226a95
* Wed Jun 26 2019 tiwai@suse.de
- Input: synaptics - enable SMBus on ThinkPad E480 and E580
  (bsc#1051510).
- Input: uinput - add compat ioctl number translation for
  UI_*_FF_UPLOAD (bsc#1051510).
- commit 53b5f1d
* Wed Jun 26 2019 mhocko@suse.com
- coredump: fix race condition between collapse_huge_page()
  and core dumping (bnc#1133738, CVE-2019-11599).
- coredump: fix race condition between
  mmget_not_zero()/get_task_mm() and core dumping (bsc#1133738,
  CVE-2019-11599).
- commit 22843e7
* Wed Jun 26 2019 tiwai@suse.de
- genwqe: Prevent an integer overflow in the ioctl (bsc#1051510).
- commit 67de48a
* Wed Jun 26 2019 tiwai@suse.de
- genirq: Prevent use-after-free and work list corruption
  (bsc#1051510).
- genirq: Respect IRQCHIP_SKIP_SET_WAKE in
  irq_chip_set_wake_parent() (bsc#1051510).
- commit 604ab3b
* Wed Jun 26 2019 tiwai@suse.de
- drm/arm/hdlcd: Allow a bit of clock tolerance (bsc#1051510).
- commit 4a7767f
* Wed Jun 26 2019 tiwai@suse.de
- doc: Cope with the deprecation of AutoReporter (bsc#1051510).
- commit 07fc2ef
* Wed Jun 26 2019 tiwai@suse.de
- can: flexcan: fix timeout when set small bitrate (bsc#1051510).
- commit 0ca4456
* Wed Jun 26 2019 tiwai@suse.de
- ax25: fix inconsistent lock state in ax25_destroy_timer
  (bsc#1051510).
- commit 1024908
* Wed Jun 26 2019 tiwai@suse.de
- PCI: rpadlpar: Fix leaked device_node references in add/remove
  paths (bsc#1051510).
- commit 10134d8
* Wed Jun 26 2019 tiwai@suse.de
- PCI: PM: Skip devices in D0 for suspend-to-idle (bsc#1051510).
- commit 173e73f
* Mon Jun 24 2019 mwilck@suse.com
- scsi: core: add new RDAC LENOVO/DE_Series device (bsc#1132390).
- commit 68e4b01
* Mon Jun 24 2019 msuchanek@suse.de
- crypto: algapi - guard against uninitialized spawn list in
  crypto_remove_spawns (bsc#1133401).
- commit b90bc9f
* Mon Jun 24 2019 tiwai@suse.de
- can: purge socket error queue on sock destruct (bsc#1051510).
- can: af_can: Fix error path of can_init() (bsc#1051510).
- commit ab2392e
* Mon Jun 24 2019 tiwai@suse.de
- USB: serial: option: add Telit 0x1260 and 0x1261 compositions
  (bsc#1051510).
- USB: serial: pl2303: add Allied Telesis VT-Kit3 (bsc#1051510).
- USB: serial: option: add support for Simcom SIM7500/SIM7600
  RNDIS mode (bsc#1051510).
- USB: Fix chipmunk-like voice when using Logitech C270 for
  recording audio (bsc#1051510).
- USB: usb-storage: Add new ID to ums-realtek (bsc#1051510).
- usbnet: ipheth: fix racing condition (bsc#1051510).
- commit f1e8781
* Mon Jun 24 2019 tiwai@suse.de
- mISDN: make sure device name is NUL terminated (bsc#1051510).
- Drivers: misc: fix out-of-bounds access in function
  param_set_kgdbts_var (bsc#1051510).
- media: v4l2-ioctl: clear fields in s_parm (bsc#1051510).
- commit 3b24929
* Mon Jun 24 2019 tiwai@suse.de
- libata: Extend quirks for the ST1000LM024 drives with NOLPM
  quirk (bsc#1051510).
- commit 068c6e9
* Mon Jun 24 2019 tiwai@suse.de
- drm/i915/gvt: ignore unexpected pvinfo write (bsc#1051510).
- commit e0e908b
* Mon Jun 24 2019 tiwai@suse.de
- blacklist.conf: Add superfluous BT blacklist entry (bsc#1135556)
- commit 47a9e1a
* Mon Jun 24 2019 tiwai@suse.de
- ALSA: hda - Force polling mode on CNL for fixing codec
  communication (bsc#1051510).
- commit ef7c06b
* Mon Jun 24 2019 tiwai@suse.de
- Replace the bluetooth fix with the upstream commit (bsc#1135556)
- commit 190eab5
* Mon Jun 24 2019 ptesarik@suse.cz
- s390/qeth: fix VLAN attribute in bridge_hostnotify udev event
  (bsc#1051510).
- scsi: zfcp: fix to prevent port_remove with pure auto scan LUNs
  (only sdevs) (bsc#1051510).
- scsi: zfcp: fix missing zfcp_port reference put on -EBUSY from
  port_remove (bsc#1051510).
- scsi: zfcp: fix scsi_eh host reset with port_forced ERP for
  non-NPIV FCP devices (bsc#1051510).
- scsi: zfcp: fix rport unblock if deleted SCSI devices on
  Scsi_Host (bsc#1051510).
- vfio: ccw: only free cp on final interrupt (bsc#1051510).
- s390/qeth: fix race when initializing the IP address table
  (bsc#1051510).
- s390/virtio: handle find on invalid queue gracefully
  (bsc#1051510).
- s390/setup: fix early warning messages (bsc#1051510).
- s390/dasd: fix using offset into zero size array error
  (bsc#1051510).
- commit df28106
* Fri Jun 21 2019 msuchanek@suse.de
- ibmveth: Update ethtool settings to reflect virtual properties
  (bsc#1136157, LTC#177197).
- commit a759aea
* Fri Jun 21 2019 jslaby@suse.cz
- x86/cpufeatures: Enumerate the new AVX512 BFLOAT16 instructions
  (jsc#SLE-5382).
- x86/cpufeatures: Combine word 11 and 12 into a new scattered
  features word (jsc#SLE-5382).
  This changes definitions of some bits, but they are intended to be
  used only by the core, so hopefully, no KMP uses the definitions.
- x86/cpufeatures: Carve out CQM features retrieval
  (jsc#SLE-5382).
- commit aa0aabb
* Fri Jun 21 2019 glin@suse.com
- bpf, x64: fix stack layout of JITed bpf code (bsc#1083647).
- bpf, x64: save 5 bytes in prologue when ebpf insns came from
  cbpf (bsc#1083647).
- commit efcaeb6
* Thu Jun 20 2019 mbenes@suse.cz
- module: Fix livepatch/ftrace module text permissions race
  (bsc#1071995 fate#323487).
- commit 3eec3e8
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: rpm does not support multiline condition
- commit aceae50
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: Use -c grep option in klp project detection.
- commit 5def2a2
* Thu Jun 20 2019 msuchanek@suse.de
- kernel-binary: fix missing \
- commit 8325214
* Thu Jun 20 2019 neilb@suse.com
- Don't restrict NFSv4.2 on openSUSE (bsc#1138719).
- commit 4f6fcf9
* Wed Jun 19 2019 msuchanek@suse.de
- powerpc/pseries/dlpar: Fix a missing check in
  dlpar_parse_cc_property() (bsc#1137194, CVE-2019-12614).
- commit 0a4b38d
* Wed Jun 19 2019 tiwai@suse.de
- audit: fix a memory leak bug (bsc#1051510).
- commit 20dd9ba
* Wed Jun 19 2019 tiwai@suse.de
- af_key: unconditionally clone on broadcast (bsc#1051510).
- commit 3ddf011
* Wed Jun 19 2019 tiwai@suse.de
- 6lowpan: Off by one handling ->nexthdr (bsc#1051510).
- commit a37dca9
* Wed Jun 19 2019 tiwai@suse.de
- vlan: disable SIOCSHWTSTAMP in container (bsc#1051510).
- commit 6ec05b1
* Wed Jun 19 2019 tiwai@suse.de
- tty: max310x: Fix external crystal register setup (bsc#1051510).
- commit f04fcd0
* Wed Jun 19 2019 tiwai@suse.de
- thermal: rcar_gen3_thermal: disable interrupt in .remove
  (bsc#1051510).
- drivers: thermal: tsens: Don't print error message on
  - EPROBE_DEFER (bsc#1051510).
- tmpfs: fix uninitialized return value in shmem_link
  (bsc#1051510).
- tmpfs: fix link accounting when a tmpfile is linked in
  (bsc#1051510).
- commit 8e9ff58
* Wed Jun 19 2019 tiwai@suse.de
- soc: rockchip: Set the proper PWM for rk3288 (bsc#1051510).
- soc: mediatek: pwrap: Zero initialize rdata in pwrap_init_cipher
  (bsc#1051510).
- commit a31492b
* Wed Jun 19 2019 tiwai@suse.de
- qmi_wwan: extend permitted QMAP mux_id value range
  (bsc#1051510).
- qmi_wwan: avoid RCU stalls on device disconnect when in QMAP
  mode (bsc#1051510).
- qmi_wwan: add network device usage statistics for qmimux devices
  (bsc#1051510).
- qmi_wwan: add support for QMAP padding in the RX path
  (bsc#1051510).
- rapidio: fix a NULL pointer dereference when create_workqueue()
  fails (bsc#1051510).
- drivers/rapidio/rio_cm.c: fix potential oops in
  riocm_ch_listen() (bsc#1051510).
- drivers/rapidio/devices/rio_mport_cdev.c: fix resource leak
  in error handling path in 'rio_dma_transfer()' (bsc#1051510).
- commit 50161e7
* Wed Jun 19 2019 tiwai@suse.de
- cfg80211: fix memory leak of wiphy device name (bsc#1051510).
- commit 10e032a
* Wed Jun 19 2019 oneukum@suse.com
- USB: serial: pl2303: fix tranceiver suspend mode (bsc#1135642).
- commit 5971a4e
* Wed Jun 19 2019 oneukum@suse.com
- usb: xhci: avoid null pointer deref when bos field is NULL
  (bsc#1135642).
- commit 9a68aa9
* Wed Jun 19 2019 jdelvare@suse.de
- i2c-piix4: Add Hygon Dhyana SMBus support (FATE#327735).
- hwmon: (k10temp) Add Hygon Dhyana support (FATE#327735).
- hwmon/k10temp, x86/amd_nb: Consolidate shared device IDs
  (FATE#327735).
- hwmon: (k10temp) Support all Family 15h Model 6xh and Model
  7xh processors (FATE#327735).
- hwmon: k10temp: Support Threadripper 2920X, 2970WX; simplify
  offset table (FATE#327735).
- hwmon: (k10temp) 27C Offset needed for Threadripper2
  (FATE#327735).
- hwmon: (k10temp) Make function get_raw_temp static
  (FATE#327735).
- hwmon: (k10temp) Display both Tctl and Tdie (FATE#327735).
- hwmon: (k10temp) Add support for Stoney Ridge and Bristol
  Ridge CPUs (FATE#327735).
- hwmon: (k10temp) Use API function to access System Management
  Network (FATE#327735).
- x86/amd_nb: Add support for Raven Ridge CPUs (FATE#327735).
- hwmon: (k10temp) Fix reading critical temperature register
  (FATE#327735).
- hwmon: (k10temp) Add support for AMD Ryzen w/ Vega graphics
  (FATE#327735).
- hwmon: (k10temp) Add temperature offset for Ryzen 2700X
  (FATE#327735).
- hwmon: (k10temp) Only apply temperature offset if result is
  positive (FATE#327735).
- hwmon: (k10temp) Add temperature offset for Ryzen 1900X
  (FATE#327735).
- hwmon: (k10temp) Correct model name for Ryzen 1600X
  (FATE#327735).
- hwmon: (k10temp) Add support for temperature offsets
  (FATE#327735).
- hwmon: (k10temp) Add support for family 17h (FATE#327735).
- hwmon: (k10temp) Move chip specific code into probe function
  (FATE#327735).
- commit a0260ad
* Wed Jun 19 2019 jack@suse.cz
- scsi: vmw_pscsi: Fix use-after-free in pvscsi_queue_lck()
  (bsc#1135296).
- commit da9726e
* Wed Jun 19 2019 tiwai@suse.de
- Revert "s390/jump_label: Use "jdd" constraint on gcc9 (bsc#1138589)."
  This broke the build with older gcc instead.
- commit fc3fbab
* Tue Jun 18 2019 msuchanek@suse.de
- s390/jump_label: Use "jdd" constraint on gcc9 (bsc#1138589).
- commit 53c4fbd
* Tue Jun 18 2019 oneukum@suse.com
- Refresh
  patches.fixes/0001-mwifiex-Abort-at-too-short-BSS-descriptor-element.patch.
- Refresh
  patches.fixes/0001-mwifiex-Fix-heap-overflow-in-mwifiex_uap_parse_tail_.patch.
- Refresh
  patches.fixes/0001-mwifiex-Fix-possible-buffer-overflows-at-parsing-bss.patch.
  Now in mainline, headers fixed up
- commit 7a522c5
* Tue Jun 18 2019 mkubecek@suse.cz
- Update "SACK Panic" patches to reflect upstream state.
- squash patches.fixes/tcp-fix-fack_count-accounting-on-tcp_shift_skb_data.patch
  into patches.fixes/tcp-limit-payload-size-of-sacked-skbs.patch
  to match what stable backports do
- update upstream references:
  patches.fixes/tcp-enforce-tcp_min_snd_mss-in-tcp_mtu_probing.patch.
  patches.fixes/tcp-limit-payload-size-of-sacked-skbs.patch.
  patches.fixes/tcp-add-tcp_min_snd_mss-sysctl.patch.
  patches.fixes/tcp-tcp_fragment-should-apply-sane-memory-limits.patch.
- sort patches to proper position
- commit 1945dc3
* Tue Jun 18 2019 neilb@suse.com
- Update patches.fixes/nfsd-COPY-and-CLONE-operations-require-the-saved-fil.patch
  (git-fixes, bsc#1137103, CVE-2018-16871).
  add CVE tag
- commit 9e07b8f
* Mon Jun 17 2019 tiwai@suse.de
- Update config files: CONFIG_NVMEM_IMX_OCOTP=m for armvh7hl/lpae
- commit 3edfd41
* Mon Jun 17 2019 bp@suse.de
- EDAC/mc: Fix edac_mc_find() in case no device is found
  (bsc#1114279).
- commit e36bcd5
* Mon Jun 17 2019 hare@suse.de
- scsi: qla2xxx: Fix FC-AL connection target discovery
  (bsc#1094555).
- scsi: qla2xxx: Fix N2N target discovery with Local loop
  (bsc#1094555).
- commit 6a0cdc5
* Mon Jun 17 2019 bp@suse.de
- blacklist.conf: Documentation only
- commit 71f13a4
* Mon Jun 17 2019 bp@suse.de
- x86/speculation/mds: Revert CPU buffer clear on double fault
  exit (bsc#1114279).
- commit a17d086
* Mon Jun 17 2019 bp@suse.de
- x86/mce: Fix machine_check_poll() tests for error types
  (bsc#1114279).
- commit e55e378
* Mon Jun 17 2019 bp@suse.de
- x86/microcode: Fix the ancient deprecated microcode loading
  method (bsc#1114279).
- commit 6d600e7
* Mon Jun 17 2019 bp@suse.de
- x86/mm/mem_encrypt: Disable all instrumentation for early SME
  setup (bsc#1114279).
- commit 3448653
* Mon Jun 17 2019 tiwai@suse.de
- watchdog: imx2_wdt: Fix set_timeout for big timeout values
  (bsc#1051510).
- commit 36d29bd
* Mon Jun 17 2019 tiwai@suse.de
- video: imsttfb: fix potential NULL pointer dereferences
  (bsc#1051510).
- video: hgafb: fix potential NULL pointer dereference
  (bsc#1051510).
- virtio_console: initialize vtermno value for ports
  (bsc#1051510).
- commit 080b4ed
* Mon Jun 17 2019 tiwai@suse.de
- usb: dwc2: Fix DMA cache alignment issues (bsc#1051510).
- commit c4f5a31
* Mon Jun 17 2019 tiwai@suse.de
- spi: spi-fsl-spi: call spi_finalize_current_message() at the
  end (bsc#1051510).
- spi: bitbang: Fix NULL pointer dereference in
  spi_unregister_master (bsc#1051510).
- spi: pxa2xx: fix SCR (divisor) calculation (bsc#1051510).
- spi: tegra114: reset controller on probe (bsc#1051510).
- spi : spi-topcliff-pch: Fix to handle empty DMA buffers
  (bsc#1051510).
- spi: Fix zero length xfer bug (bsc#1051510).
- commit 67743a6
* Mon Jun 17 2019 tiwai@suse.de
- blacklist.conf: Add reverted commits
- commit 53e0469
* Mon Jun 17 2019 tiwai@suse.de
- serial: sh-sci: disable DMA for uart_console (bsc#1051510).
- commit b9c3164
* Mon Jun 17 2019 tiwai@suse.de
- qmi_wwan: Add quirk for Quectel dynamic config (bsc#1051510).
- qlcnic: Avoid potential NULL pointer dereference (bsc#1051510).
- commit 0e367f8
* Mon Jun 17 2019 tiwai@suse.de
- power: supply: max14656: fix potential use-before-alloc
  (bsc#1051510).
- PM / core: Propagate dev->power.wakeup_path when no callbacks
  (bsc#1051510).
- power: supply: sysfs: prevent endless uevent loop with
  CONFIG_POWER_SUPPLY_DEBUG (bsc#1051510).
- commit 5350e46
* Mon Jun 17 2019 tiwai@suse.de
- platform/x86: mlx-platform: Fix parent device in i2c-mux-reg
  device registration (bsc#1051510).
- platform/chrome: cros_ec_proto: check for NULL transfer function
  (bsc#1051510).
- commit 25f102b
* Mon Jun 17 2019 tiwai@suse.de
- nvmem: core: fix read buffer in place (bsc#1051510).
- nvmem: allow to select i.MX nvmem driver for i.MX 7D
  (bsc#1051510).
- nvmem: Don't let a NULL cell_id for nvmem_cell_get() crash us
  (bsc#1051510).
- nvmem: properly handle returned value nvmem_reg_read
  (bsc#1051510).
- nvmem: imx-ocotp: Update module description (bsc#1051510).
- nvmem: imx-ocotp: Enable i.MX7D OTP write support (bsc#1051510).
- nvmem: imx-ocotp: Add i.MX7D timing write clock setup support
  (bsc#1051510).
- nvmem: imx-ocotp: Move i.MX6 write clock setup to dedicated
  function (bsc#1051510).
- nvmem: imx-ocotp: Add support for banked OTP addressing
  (bsc#1051510).
- nvmem: imx-ocotp: Pass parameters via a struct (bsc#1051510).
- nvmem: imx-ocotp: Restrict OTP write to IMX6 processors
  (bsc#1051510).
- nvmem: correct Broadcom OTP controller driver writes
  (bsc#1051510).
- commit 995ba83
* Mon Jun 17 2019 tiwai@suse.de
- mmc: mmci: Prevent polling for busy detection in IRQ context
  (bsc#1051510).
- mmc: core: make pwrseq_emmc (partially) support sleepy GPIO
  controllers (bsc#1051510).
- mmc: sdhci-of-esdhc: add erratum eSDHC-A001 and A-008358 support
  (bsc#1051510).
- commit 4cc9ed1
* Mon Jun 17 2019 tiwai@suse.de
- mfd: tps65912-spi: Add missing of table registration
  (bsc#1051510).
- mfd: intel-lpss: Set the device in reset state when init
  (bsc#1051510).
- mfd: twl6040: Fix device init errors for ACCCTL register
  (bsc#1051510).
- commit 45c05ed
* Mon Jun 17 2019 tiwai@suse.de
- drbd: Avoid Clang warning about pointless switch statment
  (bsc#1051510).
- drbd: skip spurious timeout (ping-timeo) when failing promote
  (bsc#1051510).
- drbd: disconnect, if the wrong UUIDs are attached on a connected
  peer (bsc#1051510).
- drbd: narrow rcu_read_lock in drbd_sync_handshake (bsc#1051510).
- commit 1b56dd8
* Mon Jun 17 2019 msuchanek@suse.de
- powerpc/pseries: Fix oops in hotplug memory notifier
  (bsc#1138375, LTC#178204).
- commit 9d7a7e0
* Mon Jun 17 2019 msuchanek@suse.de
- powerpc/pseries/mobility: rebuild cacheinfo hierarchy
  post-migration (bsc#1138374, LTC#178199).
- powerpc/pseries/mobility: prevent cpu hotplug during DT update
  (bsc#1138374, LTC#178199).
- powerpc/cacheinfo: add cacheinfo_teardown, cacheinfo_rebuild
  (bsc#1138374, LTC#178199).
- commit 8800c92
* Mon Jun 17 2019 bpoirier@suse.com
- Update patches.fixes/0001-docs-Fix-conf.py-for-Sphinx-2.0.patch
  (bsc#1135642).
  Fix patch header.
- commit ba543a6
* Sun Jun 16 2019 tiwai@suse.de
- HID: wacom: Sync INTUOSP2_BT touch state after each frame if
  necessary (bsc#1051510).
- HID: wacom: Correct button numbering 2nd-gen Intuos Pro over
  Bluetooth (bsc#1051510).
- HID: wacom: Send BTN_TOUCH in response to INTUOSP2_BT eraser
  contact (bsc#1051510).
- HID: wacom: Don't report anything prior to the tool entering
  range (bsc#1051510).
- HID: wacom: Don't set tool type until we're in range
  (bsc#1051510).
- HID: wacom: Add support for Pro Pen slim (bsc#1051510).
- HID: wacom: Mark expected switch fall-through (bsc#1051510).
- HID: wacom: Move HID fix for AES serial number into
  wacom_hid_usage_quirk (bsc#1051510).
- commit 79b71a9
* Sun Jun 16 2019 tiwai@suse.de
- HID: wacom: Work around HID descriptor bug in DTK-2451 and
  DTH-2452 (bsc#1051510).
- HID: wacom: convert Wacom custom usages to standard HID usages
  (bsc#1051510).
- HID: wacom: Move handling of HID quirks into a dedicated
  function (bsc#1051510).
- HID: wacom: Replace touch_max fixup code with static touch_max
  definitions (bsc#1051510).
- HID: wacom: Support "in range" for Intuos/Bamboo tablets where
  possible (bsc#1051510).
- HID: wacom: wacom_wac_collection() is local to wacom_wac.c
  (bsc#1051510).
- HID: wacom: generic: add the "Report Valid" usage (bsc#1051510).
- HID: wacom: generic: Support multiple tools per report
  (bsc#1051510).
- commit 9c8c33c
* Sun Jun 16 2019 tiwai@suse.de
- HID: wacom: Add support for 3rd generation Intuos BT
  (bsc#1051510).
- Refresh
  patches.drivers/HID-wacom-bluetooth-send-exit-report-for-recent-Blue.
- commit 792a1fe
* Sun Jun 16 2019 tiwai@suse.de
- HID: wacom: Queue events with missing type/serial data for
  later processing (bsc#1051510).
- HID: wacom: Properly handle AES serial number and tool type
  (bsc#1051510).
- HID: Wacom: switch Dell canvas into highres mode (bsc#1051510).
- HID: wacom: generic: Send BTN_STYLUS3 when both barrel switches
  are set (bsc#1051510).
- Revert "HID: wacom: generic: Send BTN_TOOL_PEN in prox once
  the pen enters range" (bsc#1051510).
- HID: wacom: generic: Reset events back to zero when pen leaves
  (bsc#1051510).
- HID: wacom: generic: Send BTN_TOOL_PEN in prox once the pen
  enters range (bsc#1051510).
- HID: wacom: generic: Leave tool in prox until it completely
  leaves sense (bsc#1051510).
- commit 92be99e
* Sun Jun 16 2019 tiwai@suse.de
- HID: wacom: generic: Use generic codepath terminology in
  wacom_wac_pen_report (bsc#1051510).
- HID: wacom: Remove comparison of u8 mode with zero and simplify
  (bsc#1051510).
- HID: wacom: fix mistake in printk (bsc#1051510).
- HID: wacom: generic: Refactor generic battery handling
  (bsc#1051510).
- HID: wacom: Add ability to provide explicit battery status info
  (bsc#1051510).
- HID: wacom: generic: Report AES battery information
  (bsc#1051510).
- HID: wacom: generic: Ignore HID_DG_BATTERYSTRENTH == 0
  (bsc#1051510).
- HID: wacom: generic: Scale battery capacity measurements to
  percentages (bsc#1051510).
- commit 8ba2cf7
* Sun Jun 16 2019 tiwai@suse.de
- blacklist.conf: Add superfluous Kconfig changes in stable commits
- commit 0eb5b68
* Sun Jun 16 2019 tiwai@suse.de
- drm/i915/sdvo: Implement proper HDMI audio support for SDVO
  (bsc#1051510).
- commit 800f685
* Sun Jun 16 2019 tiwai@suse.de
- drm/i915/perf: fix whitelist on Gen10+ (bsc#1051510).
- drm/nouveau/disp/dp: respect sink limits when selecting failsafe
  link configuration (bsc#1051510).
- commit a76b3ec
* Sat Jun 15 2019 bp@suse.de
- perf tools: Add Hygon Dhyana support (fate#327735).
- commit 26d3159
* Sat Jun 15 2019 bp@suse.de
- tools/cpupower: Add Hygon Dhyana support (fate#327735).
- commit 2810ead
* Sat Jun 15 2019 bp@suse.de
- EDAC, amd64: Add Hygon Dhyana support (fate#327735).
- commit a764bc7
* Sat Jun 15 2019 bp@suse.de
- cpufreq: Add Hygon Dhyana support (fate#327735).
- commit 85f4332
* Sat Jun 15 2019 bp@suse.de
- cpufreq: AMD: Ignore the check for ProcFeedback in ST/CZ
  (fate#327735).
- commit 1efb484
* Sat Jun 15 2019 bp@suse.de
- ACPI: Add Hygon Dhyana support (fate#327735).
- commit 29482a8
* Sat Jun 15 2019 bp@suse.de
- x86/xen: Add Hygon Dhyana support to Xen (fate#327735).
- commit 9cfd6b0
* Sat Jun 15 2019 bp@suse.de
- x86/kvm: Add Hygon Dhyana support to KVM (fate#327735).
- commit d26ddbb
* Sat Jun 15 2019 bp@suse.de
- x86/mce: Add Hygon Dhyana support to the MCA infrastructure
  (fate#327735).
- commit e8b6320
* Sat Jun 15 2019 bp@suse.de
- x86/bugs: Add Hygon Dhyana to the respective mitigation
  machinery (fate#327735).
- Refresh
  patches.arch/x86-speculation-consolidate-cpu-whitelists.patch.
- Refresh
  patches.arch/x86-speculation-mds-add-basic-bug-infrastructure-for-mds.patch.
- commit 950ac78
* Sat Jun 15 2019 bp@suse.de
- x86/apic: Add Hygon Dhyana support (fate#327735).
- commit 67e2d3f
* Sat Jun 15 2019 bp@suse.de
- x86/pci, x86/amd_nb: Add Hygon Dhyana support to PCI and
  northbridge (fate#327735).
- commit 732e9eb
* Sat Jun 15 2019 bp@suse.de
- x86/amd_nb: Check vendor in AMD-only functions (fate#327735).
- x86/alternative: Init ideal_nops for Hygon Dhyana (fate#327735).
- commit 9641595
* Sat Jun 15 2019 bp@suse.de
- x86/events: Add Hygon Dhyana support to PMU infrastructure
  (fate#327735).
- commit e0edbf2
* Sat Jun 15 2019 bp@suse.de
- x86/smpboot: Do not use BSP INIT delay and MWAIT to idle on
  Dhyana (fate#327735).
- commit 0a372f4
* Sat Jun 15 2019 bp@suse.de
- x86/cpu/mtrr: Support TOP_MEM2 and get MTRR number
  (fate#327735).
- commit 317d610
* Fri Jun 14 2019 bp@suse.de
- x86/cpu: Get cache info and setup cache cpumap for Hygon Dhyana
  (fate#327735).
- commit d0d2f71
* Fri Jun 14 2019 tiwai@suse.de
- kABI workaround for the new pci_dev.skip_bus_pm field addition
  (bsc#1051510).
- PCI: PM: Avoid possible suspend-to-idle issue (bsc#1051510).
- commit d586254
* Fri Jun 14 2019 tiwai@suse.de
- Revert "ALSA: hda/realtek - Improve the headset mic for Acer
  Aspire laptops" (bsc#1051510).
- ASoC: cs42xx8: Add regcache mask dirty (bsc#1051510).
- ASoC: fsl_asrc: Fix the issue about unsupported rate
  (bsc#1051510).
- ALSA: oxfw: allow PCM capture for Stanton SCS.1m (bsc#1051510).
- ALSA: firewire-motu: fix destruction of data for isochronous
  resources (bsc#1051510).
- ALSA: hda/realtek - Update headset mode for ALC256
  (bsc#1051510).
- commit 4f42d54
* Fri Jun 14 2019 bp@suse.de
- x86/cpu: Create Hygon Dhyana architecture support file
  (fate#327735).
- commit 4a184d9
* Fri Jun 14 2019 tiwai@suse.de
- Update patch referecens for two sercurity fixes (CVE-2019-12819, bsc#1138291, CVE-2019-12818, bsc#1138293).
- commit 481b6f0
* Fri Jun 14 2019 nsaenzjulienne@suse.de
- HID: input: fix a4tech horizontal wheel custom usage
  (bsc#1137429).
- commit 3cf1881
* Fri Jun 14 2019 tiwai@suse.de
- drm/gma500/cdv: Check vbt config bits when detecting lvds panels
  (bsc#1051510).
- drm/radeon: prefer lower reference dividers (bsc#1051510).
- commit 44c7a53
* Thu Jun 13 2019 tiwai@suse.de
- spi: pxa2xx: Add support for Intel Comet Lake (jsc#SLE-5331).
- i2c: i801: Add support for Intel Comet Lake (jsc#SLE-5331).
- commit 2c93ce9
* Thu Jun 13 2019 aaptel@suse.com
- SMB3: Fix endian warning (bsc#1137884).
- commit db19091
* Thu Jun 13 2019 jack@suse.cz
- nvme-rdma: fix double freeing of async event data (bsc#1120423).
- commit 88632ab
* Thu Jun 13 2019 jack@suse.cz
- nvme-rdma: fix possible double free of controller async event
  buffer (bsc#1120423).
- commit e0009ed
* Thu Jun 13 2019 msuchanek@suse.de
- Build klp-symbols in kernel devel projects.
- commit ffd0ed9
* Thu Jun 13 2019 tiwai@suse.de
- Correct the patch reference tag for scsi fix (bsc#1136922 CVE-2019-12456)
- commit 84f1421
* Wed Jun 12 2019 lduncan@suse.com
- scsi: mpt3sas_ctl: fix double-fetch bug in _ctl_ioctl_main()
  (bsc#1136922 cve-2019-12456).
- commit 4628a5a
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: eof trim writeback mapping as soon as it is cached
  (bsc#1138019).
- commit 237bb05
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: remove XFS_IO_INVALID (bsc#1138017).
- commit ac8a63b
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: refactor the tail of xfs_writepage_map (bsc#1138016).
- commit a20daf3
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: remove xfs_start_page_writeback (bsc#1138015).
- commit d875624
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: move all writeback buffer_head manipulation into
  xfs_map_at_offset (bsc#1138014).
- commit cf774b7
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: don't look at buffer heads in xfs_add_to_ioend
  (bsc#1138013).
- commit ebca087
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: remove the imap_valid flag (bsc#1138012).
- commit 13de851
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: simplify xfs_map_blocks by using xfs_iext_lookup_extent
  directly (bsc#1138011).
- commit d6e36c3
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: remove xfs_reflink_find_cow_mapping (bsc#1138010).
- commit b578118
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: make xfs_writepage_map extent map centric (bsc#1138009).
- commit 0709c6a
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: rename the offset variable in xfs_writepage_map
  (bsc#1138008).
- commit 565882f
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: remove xfs_map_cow (bsc#1138007).
- commit fcfbf37
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: remove xfs_reflink_trim_irec_to_next_cow (bsc#1138006).
- commit 3e058c7
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: don't use XFS_BMAPI_IGSTATE in xfs_map_blocks
  (bsc#1138005).
- commit f64d5e7
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: don't clear imap_valid for a non-uptodate buffers
  (bsc#1138018).
- commit ff6d472
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: do not set the page uptodate in xfs_writepage_map
  (bsc#1138003).
- commit a5dfa25
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: xfs_reflink_convert_cow() memory allocation deadlock
  (bsc#1138002).
- commit c8a7c99
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: minor cleanup for xfs_get_blocks (bsc#1138000).
- commit e483ffc
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: don't use XFS_BMAPI_ENTRIRE in xfs_get_blocks
  (bsc#1137999).
- commit cf7f150
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: skip CoW writes past EOF when writeback races with truncate
  (bsc#1137998).
- commit 8d2bc73
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: fix s_maxbytes overflow problems (bsc#1137996).
- commit 62c74f8
* Wed Jun 12 2019 ailiopoulos@suse.com
- xfs: remove unused parameter from xfs_writepage_map
  (bsc#1137995).
- commit b3f5aef
* Wed Jun 12 2019 tiwai@suse.de
- Refresh patches.fixes/efi-x86-Add-missing-error-handling-to-old_memmap-1-1.patch
  Fix the missing __flush_tlb_all() call in !EFI_OLD_MEMMAP case.
- commit 90f7a62
* Wed Jun 12 2019 tiwai@suse.de
- efi/x86/Add missing error handling to old_memmap 1:1 mapping
  code (CVE-2019-12380,bsc#1136598).
- commit 692028b
* Tue Jun 11 2019 tiwai@suse.de
- rtc: don't reference bogus function pointer in kdoc
  (bsc#1051510).
- commit 1310bf8
* Tue Jun 11 2019 tiwai@suse.de
- rtc: 88pm860x: prevent use-after-free on device remove
  (bsc#1051510).
- commit 2c50489
* Tue Jun 11 2019 tiwai@suse.de
- rtlwifi: fix a potential NULL pointer dereference (bsc#1051510).
- thunderbolt: Fix to check for kmemdup failure (bsc#1051510).
- commit 7397c23
* Tue Jun 11 2019 tiwai@suse.de
- tty: serial: msm_serial: Fix XON/XOFF (bsc#1051510).
- usbip: usbip_host: fix stub_dev lock context imbalance
  regression (bsc#1051510).
- USB: rio500: fix memory leak in close after disconnect
  (bsc#1051510).
- USB: rio500: refuse more than one device at a time
  (bsc#1051510).
- usbip: usbip_host: fix BUG: sleeping function called from
  invalid context (bsc#1051510).
- USB: sisusbvga: fix oops in error path of sisusb_probe
  (bsc#1051510).
- USB: Add LPM quirk for Surface Dock GigE adapter (bsc#1051510).
- USB: Fix slab-out-of-bounds write in usb_get_bos_descriptor
  (bsc#1051510).
- usbnet: fix kernel crash after disconnect (bsc#1051510).
- tty/vt: fix write/write race in ioctl(KDSKBSENT) handler
  (bsc#1051510).
- tty: ipwireless: fix missing checks for ioremap (bsc#1051510).
- USB: core: Don't unbind interfaces following device reset
  failure (bsc#1051510).
- usb: core: Add PM runtime calls to usb_hcd_platform_shutdown
  (bsc#1051510).
- commit 7bab3ca
* Tue Jun 11 2019 tiwai@suse.de
- staging: vc04_services: prevent integer overflow in
  create_pagelist() (bsc#1051510).
- Staging: vc04_services: Fix a couple error codes (bsc#1051510).
- commit faf8391
* Tue Jun 11 2019 tiwai@suse.de
- vxlan: trivial indenting fix (bsc#1051510).
- vxlan: use __be32 type for the param vni in __vxlan_fdb_delete
  (bsc#1051510).
- commit e3d500e
* Tue Jun 11 2019 tiwai@suse.de
- staging: wlan-ng: fix adapter initialization failure
  (bsc#1051510).
- w1: fix the resume command API (bsc#1051510).
- commit 6503b43
* Tue Jun 11 2019 tiwai@suse.de
- fuse: fallocate: fix return with locked inode (bsc#1051510).
- xhci: Use %%zu for printing size_t type (bsc#1051510).
- xhci: Convert xhci_handshake() to use
  readl_poll_timeout_atomic() (bsc#1051510).
- xhci: update bounce buffer with correct sg num (bsc#1051510).
- commit 78f38a5
* Tue Jun 11 2019 tiwai@suse.de
- parport: Fix mem leak in parport_register_dev_model
  (bsc#1051510).
- commit 12b7c53
* Tue Jun 11 2019 tiwai@suse.de
- mmc_spi: add a status check for spi_sync_locked (bsc#1051510).
- commit 521d88d
* Tue Jun 11 2019 tiwai@suse.de
- mmc: sdhci-iproc: Set NO_HISPD bit to fix HS50 data hold time
  problem (bsc#1051510).
- mmc: sdhci-iproc: cygnus: Set NO_HISPD bit to fix HS50 data
  hold time problem (bsc#1051510).
- mmc: core: Verify SD bus width (bsc#1051510).
- mmc: sdhci-of-esdhc: add erratum A-009204 support (bsc#1051510).
- mmc: sdhci-of-esdhc: add erratum eSDHC5 support (bsc#1051510).
- commit e02a49f
* Tue Jun 11 2019 tiwai@suse.de
- media: smsusb: better handle optional alignment (bsc#1051510).
- media: usb: siano: Fix false-positive "uninitialized variable"
  warning (bsc#1051510).
- media: usb: siano: Fix general protection fault in smsusb
  (bsc#1051510).
- mfd: da9063: Fix OTP control register names to match datasheets
  for DA9063/63L (bsc#1051510).
- mfd: max77620: Fix swapped FPS_PERIOD_MAX_US values
  (bsc#1051510).
- media: coda: clear error return value before picture run
  (bsc#1051510).
- media: ov2659: make S_FMT succeed even if requested format
  doesn't match (bsc#1051510).
- media: au0828: stop video streaming only when last user stops
  (bsc#1051510).
- media: au0828: Fix NULL pointer dereference in
  au0828_analog_stream_enable() (bsc#1051510).
- media: m88ds3103: serialize reset messages in
  m88ds3103_set_frontend (bsc#1051510).
- media: go7007: avoid clang frame overflow warning with KASAN
  (bsc#1051510).
- media: saa7146: avoid high stack usage with clang (bsc#1051510).
- media: cpia2: Fix use-after-free in cpia2_exit (bsc#1051510).
- commit e681227
* Tue Jun 11 2019 tiwai@suse.de
- leds: avoid flush_work in atomic context (bsc#1051510).
- mac80211/cfg80211: update bss channel on channel switch
  (bsc#1051510).
- mac80211: Fix kernel panic due to use of txq after free
  (bsc#1051510).
- commit a885e4a
* Tue Jun 11 2019 tiwai@suse.de
- iwlwifi: pcie: don't crash on invalid RX interrupt
  (bsc#1051510).
- iwlwifi: mvm: check for length correctness in
  iwl_mvm_create_skb() (bsc#1051510).
- commit 96e363c
* Tue Jun 11 2019 tiwai@suse.de
- i2c: dev: fix potential memory leak in i2cdev_ioctl_rdwr
  (bsc#1051510).
- iio: ad_sigma_delta: Properly handle SPI bus locking vs CS
  assertion (bsc#1051510).
- iio: hmc5843: fix potential NULL pointer dereferences
  (bsc#1051510).
- iio: common: ssp_sensors: Initialize calculated_time in
  ssp_common_process_data (bsc#1051510).
- commit 422839a
* Tue Jun 11 2019 tiwai@suse.de
- hwmon: (pmbus/core) Treat parameters as paged if on multiple
  pages (bsc#1051510).
- hwmon: (core) add thermal sensors only if dev->of_node is
  present (bsc#1051510).
- gpio: fix gpio-adp5588 build errors (bsc#1051510).
- fuse: honor RLIMIT_FSIZE in fuse_file_fallocate (bsc#1051510).
- fuse: fix writepages on 32bit (bsc#1051510).
- gpio: Remove obsolete comment about gpiochip_free_hogs() usage
  (bsc#1051510).
- extcon: arizona: Disable mic detect if running when driver is
  removed (bsc#1051510).
- HID: logitech-hidpp: use RAP instead of FAP to get the protocol
  version (bsc#1051510).
- HID: logitech-hidpp: change low battery level threshold from
  31 to 30 percent (bsc#1051510).
- hwrng: omap - Set default quality (bsc#1051510).
- commit 7e80b06
* Tue Jun 11 2019 tiwai@suse.de
- drm/amdgpu: fix old fence check in amdgpu_fence_emit
  (bsc#1051510).
- drm/drv: Hold ref on parent device during drm_device lifetime
  (bsc#1051510).
- drm: Wake up next in drm_read() chain if we are forced to
  putback the event (bsc#1051510).
- commit e8a31f2
* Tue Jun 11 2019 tiwai@suse.de
- ALSA: hda/realtek - Set default power save node to 0
  (bsc#1051510).
- ASoC: fsl_sai: Update is_slave_mode with correct value
  (bsc#1051510).
- ASoC: eukrea-tlv320: fix a leaked reference by adding missing
  of_node_put (bsc#1051510).
- ASoC: fsl_utils: fix a leaked reference by adding missing
  of_node_put (bsc#1051510).
- ASoC: hdmi-codec: unlock the device on startup errors
  (bsc#1051510).
- brcmfmac: fix missing checks for kmemdup (bsc#1051510).
- brcmfmac: convert dev_init_lock mutex to completion
  (bsc#1051510).
- brcmfmac: fix Oops when bringing up interface during USB
  disconnect (bsc#1051510).
- brcmfmac: fix race during disconnect when USB completion is
  in progress (bsc#1051510).
- brcmfmac: fix WARNING during USB disconnect in case of unempty
  psq (bsc#1051510).
- batman-adv: allow updating DAT entry timeouts on incoming ARP
  Replies (bsc#1051510).
- chardev: add additional check for minor range overlap
  (bsc#1051510).
- ACPI / property: fix handling of data_nodes in
  acpi_get_next_subnode() (bsc#1051510).
- commit a683629
* Tue Jun 11 2019 fabian.baumanis@suse.com
- docs: Fix conf.py for Sphinx 2.0 (bsc#1135642).
- commit dd9aa10
* Tue Jun 11 2019 fabian.baumanis@suse.com
- Documentation: Correct the possible MDS sysfs values
  (bsc#1135642).
- commit e1b2b70
* Tue Jun 11 2019 fabian.baumanis@suse.com
- test_firmware: Use correct snprintf() limit (bsc#1135642).
- commit 0c24ec2
* Tue Jun 11 2019 jgross@suse.com
- xen/pciback: Don't disable PCI_COMMAND on PCI device reset
  (bsc#1065600).
- commit 53b7eb9
* Tue Jun 11 2019 mkubecek@suse.cz
- tcp: fix fack_count accounting on tcp_shift_skb_data()
  (CVE-2019-11477 bsc#1137586).
- commit 4a006b2
* Tue Jun 11 2019 tzimmermann@suse.de
- drm/i915/gvt: Fix cmd length of VEB_DI_IECP (bsc#1113722)
- commit 038e070
* Tue Jun 11 2019 tzimmermann@suse.de
- drm/i915/gvt: refine ggtt range validation (bsc#1113722)
- commit 44184d3
* Tue Jun 11 2019 tzimmermann@suse.de
- drm/nouveau/i2c: Disable i2c bus access after ->fini() (bsc#1113722)
- commit 943a224
* Tue Jun 11 2019 mkubecek@suse.cz
- add CVE references to bsc#1137586 patches
  patches.fixes/tcp-add-tcp_min_snd_mss-sysctl.patch (add CVE-2019-11479)
  patches.fixes/tcp-enforce-tcp_min_snd_mss-in-tcp_mtu_probing.patch (add CVE-2019-11479)
  patches.fixes/tcp-limit-payload-size-of-sacked-skbs.patch (add CVE-2019-11477)
  patches.fixes/tcp-tcp_fragment-should-apply-sane-memory-limits.patch (add CVE-2019-11478)
  patches.kabi/kabi-drop-LINUX_MIB_TCPWQUEUETOOBIG-snmp-counter.patch (add CVE-2019-11478)
  patches.kabi/kabi-move-sysctl_tcp_min_snd_mss-to-preserve-struct-.patch (add CVE-2019-11479)
- commit 2e2a3c9
* Tue Jun 11 2019 neilb@suse.com
- NFS add module option to limit NFSv4 minor version (jsc#PM-231).
- commit 3752b39
* Mon Jun 10 2019 msuchanek@suse.de
- KVM: PPC: Book3S: Protect memslots while validating user address
  (bsc#1061840).
- commit 487f82e
* Mon Jun 10 2019 msuchanek@suse.de
- powerpc/powernv/idle: Restore IAMR after idle (bsc#1065729).
- powerpc: Fix HMIs on big-endian with CONFIG_RELOCATABLE=y
  (bsc#1065729).
- powerpc/msi: Fix NULL pointer access in teardown code
  (bsc#1065729).
- powerpc/eeh: Fix race with driver un/bind (bsc#1065729).
- powerpc: Always initialize input array when calling
  epapr_hypercall() (bsc#1065729).
- commit 6105eae
* Mon Jun 10 2019 msuchanek@suse.de
- KVM: PPC: Book3S HV: XIVE: Do not clear IRQ data of passthrough
  interrupts (bsc#1061840).
- KVM: PPC: Book3S HV: Avoid lockdep debugging in TCE realmode
  handlers (bsc#1061840).
- KVM: PPC: Release all hardware TCE tables attached to a group
  (bsc#1061840).
- KVM: PPC: Remove redundand permission bits removal
  (bsc#1061840).
- KVM: PPC: Validate TCEs against preregistered memory page sizes
  (bsc#1061840).
- KVM: PPC: Validate all tces before updating tables
  (bsc#1061840).
- commit 7ab76b6
* Mon Jun 10 2019 msuchanek@suse.de
- blacklist.conf: build fix for config we don't use.
  e40542aff909 KVM: PPC: Book3S HV: Fix build failure without IOMMU
  support
- commit 1b8526b
* Mon Jun 10 2019 msuchanek@suse.de
- powerpc/process: Fix sparse address space warnings
  (bsc#1065729).
- commit 7faf413
* Mon Jun 10 2019 msuchanek@suse.de
- blacklist.conf: add fsl-specific nospec patches
  406d2b6ae342 powerpc/64: Make meltdown reporting Book3S 64 specific
  ebcd1bfc33c7 powerpc/fsl: Add barrier_nospec implementation for NXP
  PowerPC Book3E
- commit 106942e
* Mon Jun 10 2019 msuchanek@suse.de
- ibmvnic: Fix unchecked return codes of memory allocations
  (bsc#1137752).
- ibmvnic: Refresh device multicast list after reset
  (bsc#1137752).
- ibmvnic: Do not close unopened driver during reset
  (bsc#1137752).
- commit 5dd1a87
* Mon Jun 10 2019 msuchanek@suse.de
- ibmvnic: Add device identification to requested IRQs
  (bsc#1137739).
- ibmvnic: remove set but not used variable 'netdev'
  (bsc#1137739).
- net/ibmvnic: Remove tests of member address (bsc#1137739).
- treewide: Use DEVICE_ATTR_WO (bsc#1137739).
  - Refresh patches.arch/s390-smp-fix-cpu-hotplug-deadlock-with-cpu-rescan.
- commit b30515c
* Mon Jun 10 2019 jslaby@suse.cz
- ipv4: Define __ipv4_neigh_lookup_noref when CONFIG_INET is
  disabled (git-fixes).
- commit 11184ff
* Mon Jun 10 2019 jack@suse.cz
- patches.fixes/mm-Fix-modifying-of-page-protection-by-insert_pfn.patch:
  Fix buggy backport leading to MAP_SYNC failures (bsc#1137372)
- commit 38f4efc
* Mon Jun 10 2019 jslaby@suse.cz
- kernel/signal.c: trace_signal_deliver when signal_group_exit
  (git-fixes).
- tipc: fix hanging clients using poll with EPOLLOUT flag
  (git-fixes).
- neighbor: Call __ipv4_neigh_lookup_noref in neigh_xmit
  (git-fixes).
- commit 5fba04a
* Mon Jun 10 2019 msuchanek@suse.de
- powerpc/perf: Fix MMCRA corruption by bhrb_filter (bsc#1053043).
- commit 3717d57
* Mon Jun 10 2019 msuchanek@suse.de
- blacklist.conf: blacklist unsupported ppc platforms
  Specifically we don't support 32bit (except syscalls, signals, and
  ptrace which is used with 32bit processes on 64bit)
  don't suport embedded - fsl, pasemi, book3e, booke, 64e, 4xx, 500, 6xx,
  8xx, 8xxx, 5xxx
- commit 4e1e10c
* Mon Jun 10 2019 wqu@suse.com
- Refresh
  patches.suse/btrfs-reloc-also-queue-orphan-reloc-tree-for-cleanup-to-avoid-bug_on.patch.
- commit d9976dd
* Sun Jun  9 2019 mkubecek@suse.cz
- kabi: move sysctl_tcp_min_snd_mss to preserve struct net layout
  (bsc#1137586).
  Refresh
  patches.kabi/kabi-handle-addition-of-ip6addrlbl_table-into-struct.patch
  patches.kabi/kabi-handle-addition-of-uevent_sock-into-struct-net.patch
- tcp: enforce tcp_min_snd_mss in tcp_mtu_probing() (bsc#1137586).
- tcp: add tcp_min_snd_mss sysctl (bsc#1137586).
- kabi: drop LINUX_MIB_TCPWQUEUETOOBIG snmp counter (bsc#1137586).
- tcp: tcp_fragment() should apply sane memory limits
  (bsc#1137586).
- tcp: limit payload size of sacked skbs (bsc#1137586).
- commit 0a0be12
* Fri Jun  7 2019 hare@suse.de
- blk-mq: fix hang caused by freeze/unfreeze sequence
  (bsc#1128432).
- commit 58aac55
* Fri Jun  7 2019 mvedovati@suse.com
- rpm/post.sh: correct typo in err msg (bsc#1137625)
- commit 9fe85cc
* Thu Jun  6 2019 hare@suse.de
- nvme: skip nvme_update_disk_info() if the controller is not live
  (bsc#1128432).
- commit cf4fe48
* Thu Jun  6 2019 fabian.baumanis@suse.com
- of: fix clang -Wunsequenced for be32_to_cpu() (bsc#1135642).
- commit 09b7c1c
* Thu Jun  6 2019 mkubecek@suse.cz
- net: unbreak CONFIG_RETPOLINE=n builds (bsc#1124503).
- udp: use indirect call wrappers for GRO socket lookup
  (bsc#1124503).
- net: use indirect call wrappers at GRO transport layer
  (bsc#1124503).
- net: use indirect call wrappers at GRO network layer
  (bsc#1124503).
- indirect call wrappers: helpers to speed-up indirect calls of
  builtin (bsc#1124503).
- commit dbad7a1
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: NULL check before some freeing functions is
  not needed (bsc#1137444).
- scsi: qla2xxx: Split the __qla2x00_abort_all_cmds() function
  (bsc#1137444).
- scsi: qla2xxx: Introduce a switch/case statement in
  qlt_xmit_tm_rsp() (bsc#1137444).
- scsi: qla2xxx: use lower_32_bits and upper_32_bits instead of
  reinventing them (bsc#1137444).
- commit c0027ab
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: Remove two arguments from qlafx00_error_entry()
  (bsc#1137444).
- scsi: qla2xxx: Make sure that qlafx00_ioctl_iosb_entry()
  initializes 'res' (bsc#1137444).
- commit b79868f
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: Remove a set-but-not-used variable (bsc#1137444).
- Refresh
  patches.drivers/scsi-qla2xxx-Timeouts-occur-on-surprise-removal-of-Q.patch.
- commit ea8d0d3
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: Make qla2x00_sysfs_write_nvram() easier to
  analyze (bsc#1137444).
- scsi: qla2xxx: Declare local functions 'static' (bsc#1137444).
- scsi: qla2xxx: Improve several kernel-doc headers (bsc#1137444).
- scsi: qla2xxx: fully convert to the generic DMA API
  (bsc#1137444).
- commit c521810
* Thu Jun  6 2019 vbabka@suse.cz
- Refresh
  patches.fixes/mm-prevent-get_user_pages-from-overflowing-page-refcount.patch.
  (Add one more missed check on x86 and prevent spurious warning on s390).
- commit 1a7767e
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: remove the unused tcm_qla2xxx_cmd_wq
  (bsc#1118139).
- commit 6256c14
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: fx00 copypaste typo (bsc#1118139).
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-small-memory-leak-in-qla2x00_probe_.patch.
- commit 250a772
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: fix error message on <qla2400 (bsc#1118139).
- commit 0c3d9c8
* Thu Jun  6 2019 hare@suse.de
- Refresh
  patches.fixes/scsi-qla2xxx-fix-driver-unload-by-shutting-down-chip.patch.
- commit a102af6
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: Fix memory corruption during hba reset test
  (bsc#1118139).
- commit ae7be5f
* Thu Jun  6 2019 hare@suse.de
- scsi: qla2xxx: fix spelling mistake: "existant" -> "existent"
  (bsc#1118139).
- scsi: qla2xxx: Fix function argument descriptions (bsc#1118139).
- scsi: qla2xxx: Remove unused symbols (bsc#1118139).
- scsi: qla2xxx: Use %%p for printing pointers (bsc#1118139).
- commit 214e4fc
* Wed Jun  5 2019 fabian.baumanis@suse.com
- Documentation: Add MDS vulnerability documentation
  (bsc#1135642).
- commit 6935e28
* Wed Jun  5 2019 mhocko@suse.com
- blacklist.conf: blacklist ac5b2c18911f
- commit 4519279
* Wed Jun  5 2019 neilb@suse.com
- mount: copy the port field into the cloned nfs_server structure
  (bsc#1136990).
- commit 6c04f4e
* Tue Jun  4 2019 mbrugger@suse.com
- firmware: efi: factor out mem_reserve (bsc#1117158 bsc#1134671).
- commit d3b71b7
* Tue Jun  4 2019 mhocko@suse.com
- mm: thp: relax __GFP_THISNODE for MADV_HUGEPAGE mappings
  (bnc#1012382).
- commit ec75cec
* Tue Jun  4 2019 oneukum@suse.com
- mwifiex: Fix heap overflow in mwifiex_uap_parse_tail_ies()
  (bsc#1136935).
- commit 962016b
* Tue Jun  4 2019 oneukum@suse.com
- mwifiex: Abort at too short BSS descriptor element (bsc#1136424
  CVE-2019-3846).
- commit b07c2e2
* Tue Jun  4 2019 oneukum@suse.com
- mwifiex: Fix possible buffer overflows at parsing bss descriptor
- commit ace6d67
* Tue Jun  4 2019 vbabka@suse.cz
- Refresh
  patches.fixes/mm-prevent-get_user_pages-from-overflowing-page-refcount.patch.
- commit 398d995
* Tue Jun  4 2019 mbrugger@suse.com
- iommu/arm-smmu-v3: Don't disable SMMU in kdump kernel
  (bsc#1117158 bsc#1134671).
- commit a343fd2
* Tue Jun  4 2019 msuchanek@suse.de
- crypto: vmx - ghash: do nosimd fallback manually (bsc#1135661,
  bsc#1137162).
- crypto: vmx - return correct error code on failed setkey
  (bsc#1135661, bsc#1137162).
- commit 6ca8b7b
* Tue Jun  4 2019 mbrugger@suse.com
- arch: arm64: acpi: KABI ginore includes (bsc#1117158
  bsc#1134671).
- commit 3e244cb
* Tue Jun  4 2019 ptesarik@suse.cz
- Refresh
  patches.suse/btrfs-fix-wrong-ctime-and-mtime-of-a-directory-after.patch.
- commit c321464
* Tue Jun  4 2019 tzimmermann@suse.de
- drm/etnaviv: lock MMU while dumping core (bsc#1113722)
- commit d81ef7c
* Tue Jun  4 2019 tzimmermann@suse.de
- drm/i915/gvt: add 0x4dfc to gen9 save-restore list (bsc#1113722)
- commit 08bdb02
* Tue Jun  4 2019 tzimmermann@suse.de
- drm/i915/gvt: Tiled Resources mmios are in-context mmios for gen9+ (bsc#1113722)
- commit 8b8d7b3
* Tue Jun  4 2019 tzimmermann@suse.de
- drm/vmwgfx: NULL pointer dereference from vmw_cmd_dx_view_define() (bsc#1113722)
- commit 64e1c75
* Tue Jun  4 2019 tzimmermann@suse.de
- fbdev: fix WARNING in __alloc_pages_nodemask bug (bsc#1113722)
- commit 999019d
* Tue Jun  4 2019 tzimmermann@suse.de
- fbdev: fix divide error in fb_var_to_videomode (bsc#1113722)
- commit 88305ed
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: use 1024x768 by default on non-MIPS, fix garbled display'
- commit 6e93cf2
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: fix support for 1024x768-16 mode'
- commit 393898c
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: fix crashes and garbled display during DPMS modesetting'
- commit 2c1e780
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: fix crashes during framebuffer writes by correctly mapping VRAM'
- commit 58ac3c1
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: fix boot screen glitch when sm712fb replaces VGA'
- commit d73d11c
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: fix VRAM detection, don't set SR70/71/74/75'
- commit 4817d93
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: fix brightness control on reboot, don't set SR30'
- commit 35d7d4e
* Tue Jun  4 2019 tzimmermann@suse.de
- blacklist.conf: Append 'fbdev: sm712fb: fix white screen of death on reboot, don't set CR3B-CR3F'
- commit b3f3380
* Mon Jun  3 2019 fdmanana@suse.com
- Btrfs: fix race updating log root item during fsync
  (bsc#1137153).
- commit a494c93
* Mon Jun  3 2019 fdmanana@suse.com
- Btrfs: fix wrong ctime and mtime of a directory after log replay
  (bsc#1137152).
- commit 91e5499
* Mon Jun  3 2019 fdmanana@suse.com
- Btrfs: fix fsync not persisting changed attributes of a
  directory (bsc#1137151).
- commit e8f83fa
* Mon Jun  3 2019 mbrugger@suse.com
- arm64/x86: Update config files.
  Use CONFIG_ARCH_SUPPORTS_ACPI
- commit 1c432af
* Mon Jun  3 2019 jroedel@suse.de
- blacklist.conf: Add 43a0541e312f iommu/tegra-smmu: Fix invalid ASID bits on Tegra30/114
- commit a23cc59
* Mon Jun  3 2019 mbrugger@suse.com
- efi/arm: Revert "Defer persistent reservations until after
  paging_init()" (bsc#1117158).
- commit e96dc10
* Mon Jun  3 2019 mbrugger@suse.com
- arm64, mm, efi: Account for GICv3 LPI tables in static memblock
  reserve table (bsc#1117158).
- commit 42a592e
* Mon Jun  3 2019 mbrugger@suse.com
- efi: Reduce the amount of memblock reservations for persistent
  allocations (bsc#1117158).
- Refresh
  patches.suse/0002-MODSIGN-print-appropriate-status-message-when-gettin.patch.
- commit 3af452b
* Mon Jun  3 2019 mbrugger@suse.com
- efi: Permit multiple entries in persistent memreserve data
  structure (bsc#1117158).
- Refresh
  patches.suse/0002-MODSIGN-print-appropriate-status-message-when-gettin.patch.
- commit d569a2e
* Mon Jun  3 2019 mbrugger@suse.com
- efi: Prevent GICv3 WARN() by mapping the memreserve table
  before first use (bsc#1117158).
- commit e756c85
* Mon Jun  3 2019 mbrugger@suse.com
- efi: Permit calling efi_mem_reserve_persistent() from atomic
  context (bsc#1117158).
- commit bc55ab2
* Mon Jun  3 2019 mbrugger@suse.com
- efi/arm: Defer persistent reservations until after paging_init()
  (bsc#1117158).
- commit 31eda48
* Mon Jun  3 2019 mbrugger@suse.com
- efi: add API to reserve memory persistently across kexec reboot
  (bsc#1117158).
- commit 23b0f24
* Mon Jun  3 2019 mbrugger@suse.com
- efi/arm: libstub: add a root memreserve config table
  (bsc#1117158).
- commit 955743f
* Mon Jun  3 2019 mbrugger@suse.com
- efi: honour memory reservations passed via a linux specific
  config table (bsc#1117158).
- Refresh
  patches.suse/0002-MODSIGN-print-appropriate-status-message-when-gettin.patch.
- commit 30a4b0a
* Mon Jun  3 2019 hare@suse.de
- Refresh
  patches.suse/nvme-flush-scan_work-when-resetting-controller.patch.
- commit edf089e
* Mon Jun  3 2019 mbrugger@suse.com
- iommu/arm-smmu-v3: Abort all transactions if SMMU is enabled
  in kdump kernel (bsc#1117158).
- ACPI: fix menuconfig presentation of ACPI submenu (bsc#1117158).
- commit 51f7441
* Mon Jun  3 2019 mhocko@suse.com
- mm: hwpoison: fix thp split handing in
  soft_offline_in_use_page() (bsc#1130699, CVE-2019-10124).
- commit f0e18c6
* Mon Jun  3 2019 mbrugger@suse.com
- arm64: fix ACPI dependencies (bsc#1117158).
- arm64: acpi: fix alignment fault in accessing ACPI
  (bsc#1117158).
- efi/arm: map UEFI memory map even w/o runtime services enabled
  (bsc#1117158).
- efi/arm: preserve early mapping of UEFI memory map longer for
  BGRT (bsc#1117158).
- drivers: acpi: add dependency of EFI for arm64 (bsc#1117158).
- commit 50a260e
* Mon Jun  3 2019 hare@suse.de
- scsi: qedf: fixup bit operations (bsc#1135542).
- scsi: qedf: fixup locking in qedf_restart_rport() (bsc#1135542).
- scsi: qedf: missing kref_put in qedf_xmit() (bsc#1135542).
- commit aeecf02
* Mon Jun  3 2019 jslaby@suse.cz
- ipv4: ip_do_fragment: Preserve skb_iif during fragmentation
  (networking-stable-19_05_04).
- sctp: avoid running the sctp state machine recursively
  (networking-stable-19_05_04).
- net: dsa: bcm_sf2: fix buffer overflow doing set_rxnfc
  (networking-stable-19_05_04).
- bnxt_en: Improve multicast address setup logic
  (networking-stable-19_05_04).
- net: phy: marvell: Fix buffer overrun with stats counters
  (networking-stable-19_05_04).
- commit 3177994
* Mon Jun  3 2019 jslaby@suse.cz
- memcg: make it work on sparse non-0-node systems (bnc#1133616).
- memcg: make it work on sparse non-0-node systems kabi
  (bnc#1133616).
- commit a3ffa5a
* Fri May 31 2019 tiwai@suse.de
- mmc: block: Delete gendisk before cleaning up the request queue
  (bsc#1127616).
- commit 098f519
* Fri May 31 2019 jslaby@suse.cz
- signal: Restore the stop PTRACE_EVENT_EXIT (git-fixes).
- commit 6eedc81
* Fri May 31 2019 tiwai@suse.de
- rtc: da9063: set uie_unsupported when relevant (bsc#1051510).
- rtc: sh: Fix invalid alarm warning for non-enabled alarm
  (bsc#1051510).
- commit 8105b25
* Fri May 31 2019 tiwai@suse.de
- configfs: Fix use-after-free when accessing sd->s_dentry
  (bsc#1051510).
- commit 5a729aa
* Fri May 31 2019 tiwai@suse.de
- ALSA: hda/realtek - Improve the headset mic for Acer Aspire
  laptops (bsc#1051510).
- ARM: iop: don't use using 64-bit DMA masks (bsc#1051510).
- ARM: orion: don't use using 64-bit DMA masks (bsc#1051510).
- commit 1c0a657
* Fri May 31 2019 jslaby@suse.cz
- userfaultfd: use RCU to free the task struct when fork fails
  (git-fixes).
- switchtec: Fix unintended mask of MRPC event (git-fixes).
- PCI: Work around Pericom PCIe-to-PCI bridge Retrain Link erratum
  (git-fixes).
- kABI: protect struct pci_dev (kabi).
- PCI: Factor out pcie_retrain_link() function (git-fixes).
- kernel/sys.c: prctl: fix false positive in validate_prctl_map()
  (git-fixes).
- ptrace: take into account saved_sigmask in
  PTRACE{GET,SET}SIGMASK (git-fixes).
- commit 4b79357
* Fri May 31 2019 jslaby@suse.cz
- signal: Better detection of synchronous signals (git-fixes).
- signal: Always notice exiting tasks (git-fixes).
- commit d78bfdd
* Fri May 31 2019 jslaby@suse.cz
- PCI: endpoint: Use EPC's device in
  dma_alloc_coherent()/dma_free_coherent() (git-fixes).
- kABI: protect dma-mapping.h include (kabi).
- commit cdb335e
* Fri May 31 2019 jslaby@suse.cz
- blacklist.conf: add 2 ARCH_RENESAS commits and 1 unneeded
- commit 556e784
* Fri May 31 2019 jslaby@suse.cz
- net: dsa: mv88e6xxx: fix handling of upper half of
  STATS_TYPE_PORT (git-fixes).
- commit f9ecc4c
* Fri May 31 2019 jslaby@suse.cz
- net/rose: fix unbound loop in rose_loopback_timer()
  (networking-stable-19_04_30).
- net: rds: exchange of 8K and 1M pool
  (networking-stable-19_04_30).
- net: stmmac: move stmmac_check_ether_addr() to driver probe
  (networking-stable-19_04_30).
- net/mlx5e: ethtool, Remove unsupported SFP EEPROM high pages
  query (networking-stable-19_04_30).
- team: fix possible recursive locking when add slaves
  (networking-stable-19_04_30).
- stmmac: pci: Adjust IOT2000 matching
  (networking-stable-19_04_30).
- mlxsw: spectrum: Fix autoneg status in ethtool
  (networking-stable-19_04_30).
- ipv4: set the tcp_min_rtt_wlen range from 0 to one day
  (networking-stable-19_04_30).
- commit 96259b9
* Fri May 31 2019 wqu@suse.com
- btrfs: qgroup: Check bg while resuming relocation to  avoid
  NULL pointer dereference (bsc#1134806).
- commit f7220b7
* Fri May 31 2019 wqu@suse.com
- Refresh
  patches.suse/btrfs-reloc-also-queue-orphan-reloc-tree-for-cleanup-to-avoid-bug_on.patch.
- commit 375bd5a
* Fri May 31 2019 jslaby@suse.cz
- ipv4: add sanity checks in ipv4_link_failure() (git-fixes).
- commit 905af0e
* Thu May 30 2019 lyan@suse.com
- KVM: s390: kABI Workaround for 'kvm_vcpu_stat'
  Add halt_no_poll_steal to kvm_vcpu_stat. Hide it from the kABI checker.
  Related patch:
  KVM-s390-provide-kvm_arch_no_poll-function.patch
- commit 5991d45
* Thu May 30 2019 lyan@suse.com
- KVM: s390: enable CONFIG_HAVE_KVM_NO_POLL (bsc#1119222)
  We need to enable CONFIG_HAVE_KVM_NO_POLL for bsc#1119222
- commit df0fa87
* Thu May 30 2019 lyan@suse.com
- KVM: s390: change default halt poll time to 50us (bsc#1119222).
- KVM: s390: fix typo in parameter description (bsc#1119222).
- KVM: s390: provide kvm_arch_no_poll function (bsc#1119222).
- KVM: polling: add architecture backend to disable polling
  (bsc#1119222).
- s390/vtime: steal time exponential moving average (bsc#1119222).
- commit 705523a
* Thu May 30 2019 fdmanana@suse.com
- btrfs: don't double unlock on error in btrfs_punch_hole
  (bsc#1136881).
- commit e903367
* Thu May 30 2019 mbenes@suse.cz
- ftrace/x86_64: Emulate call function while updating in
  breakpoint handler (bsc#1099658).
- commit fae436c
* Thu May 30 2019 mbenes@suse.cz
- x86_64: Allow breakpoints to emulate call instructions
  (bsc#1099658).
- commit 5ac027b
* Thu May 30 2019 mbenes@suse.cz
- x86_64: Add gap to int3 to allow for call emulation
  (bsc#1099658).
- commit 7433070
* Thu May 30 2019 jslaby@suse.cz
- tcp: tcp_grow_window() needs to respect tcp_space()
  (networking-stable-19_04_19).
- net: atm: Fix potential Spectre v1 vulnerabilities
  (networking-stable-19_04_19).
- bonding: fix event handling for stacked bonds
  (networking-stable-19_04_19).
- ipv4: ensure rcu_read_lock() in ipv4_link_failure()
  (networking-stable-19_04_19).
- ipv4: recompile ip options in ipv4_link_failure
  (networking-stable-19_04_19).
- net: thunderx: don't allow jumbo frames with XDP
  (networking-stable-19_04_19).
- net: thunderx: raise XDP MTU to 1508
  (networking-stable-19_04_19).
- net: fou: do not use guehdr after iptunnel_pull_offloads in
  gue_udp_recv (networking-stable-19_04_19).
- tipc: missing entries in name table of publications
  (networking-stable-19_04_19).
- vhost: reject zero size iova range (networking-stable-19_04_19).
- commit 4c0bbc3
* Thu May 30 2019 jslaby@suse.cz
- x86/smpboot: Rename match_die() to match_pkg() (jsc#SLE-5454).
- commit abb6430
* Thu May 30 2019 jslaby@suse.cz
- perf/x86/intel/rapl: Cosmetic rename internal variables in
  response to multi-die/pkg support (jsc#SLE-5454).
- perf/x86/intel/uncore: Cosmetic renames in response to
  multi-die/pkg support (jsc#SLE-5454).
- hwmon/coretemp: Cosmetic: Rename internal variables to zones
  from packages (jsc#SLE-5454).
- thermal/x86_pkg_temp_thermal: Cosmetic: Rename internal
  variables to zones from packages (jsc#SLE-5454).
- perf/x86/intel/cstate: Support multi-die/package (jsc#SLE-5454).
- perf/x86/intel/rapl: Support multi-die/package (jsc#SLE-5454).
- perf/x86/intel/uncore: Support multi-die/package (jsc#SLE-5454).
- topology: Create core_cpus and die_cpus sysfs attributes
  (jsc#SLE-5454).
- topology: Create package_cpus sysfs attribute (jsc#SLE-5454).
- hwmon/coretemp: Support multi-die/package (jsc#SLE-5454).
- powercap/intel_rapl: Update RAPL domain name and debug messages
  (jsc#SLE-5454).
- thermal/x86_pkg_temp_thermal: Support multi-die/package
  (jsc#SLE-5454).
- powercap/intel_rapl: Support multi-die/package (jsc#SLE-5454).
- powercap/intel_rapl: Simplify rapl_find_package()
  (jsc#SLE-5454).
- x86/topology: Define topology_logical_die_id() (jsc#SLE-5454).
- kabi: x86/topology: Define topology_logical_die_id()
  (jsc#SLE-5454).
- Refresh
  patches.kabi/x86-topology-Add-CPUID.1F-multi-die-package-support.patch.
- x86/topology: Define topology_die_id() (jsc#SLE-5454).
- cpu/topology: Export die_id (jsc#SLE-5454).
- x86/topology: Create topology_max_die_per_package()
  (jsc#SLE-5454).
- x86/topology: Add CPUID.1F multi-die/package support
  (jsc#SLE-5454).
- kabi: x86/topology: Add CPUID.1F multi-die/package support
  (jsc#SLE-5454).
- commit 1bbf122
* Wed May 29 2019 lyan@suse.com
- KVM: s390: vsie: fix < 8k check for the itdba (bsc#1136206).
- KVM: s390: fix memory overwrites when not using SCA entries
  (bsc#1136206).
- KVM: s390: provide io interrupt kvm_stat (bsc#1136206).
- KVM: s390: use created_vcpus in more places (bsc#1136206).
- commit ac8acab
* Wed May 29 2019 nborisov@suse.com
- btrfs: reloc: Also queue orphan reloc tree for cleanup to avoid  BUG_ON() (bsc#1133612).
- commit a060248
* Wed May 29 2019 tiwai@suse.de
- Update cx2072x patches to follow the upstream development (bsc#1068546)
- commit 994eaf4
* Wed May 29 2019 mbenes@suse.cz
- livepatch: Remove duplicated code for early initialization
  (bsc#1071995).
- commit d7cb081
* Tue May 28 2019 mbenes@suse.cz
- livepatch: Remove custom kobject state handling (bsc#1071995).
- commit a4335b2
* Tue May 28 2019 mbenes@suse.cz
- livepatch: Convert error about unsupported reliable stacktrace
  into a warning (bsc#1071995).
- commit 72f483c
* Tue May 28 2019 jeyu@suse.de
- blacklist.conf: blacklist unneeded git-fix for kbuild
- commit 68fd002
* Tue May 28 2019 tiwai@suse.de
- drm/edid: Fix a missing-check bug in drm_load_edid_firmware()
  (CVE-2019-12382, bsc#1136586).
- commit 1e30a36
* Tue May 28 2019 ailiopoulos@suse.com
- xfs: serialize unaligned dio writes against all other dio writes
  (bsc#1134936).
- commit 74a4006
* Tue May 28 2019 mbenes@suse.cz
- tracing: Fix partial reading of trace event's id file
  (bsc#1136573).
- commit 09f1eb3
* Tue May 28 2019 mbenes@suse.cz
- blacklist.conf: 8ea58f1e8b11 ("objtool: Allow AR to be overridden with HOSTAR")
  Not needed. We can happily use just AR.
- commit 8993380
* Tue May 28 2019 mbenes@suse.cz
- objtool: Fix function fallthrough detection (bsc#1058115).
- commit 0746a05
* Tue May 28 2019 vbabka@suse.cz
- fs: prevent page refcount overflow in pipe_buf_get
  (CVE-2019-11487, bsc#1133190).
- fs: prevent page refcount overflow in pipe_buf_get - KABI fix
  (CVE-2019-11487, bsc#1133190, KABI).
- Refresh patches.suse/tracing-fix-buffer_ref-pipe-ops.patch.
- commit c6248ad
* Tue May 28 2019 fabian.baumanis@suse.com
- dt-bindings: rtc: sun6i-rtc: Fix register range in example
  (bsc#1120902).
- commit 927760c
* Tue May 28 2019 fabian.baumanis@suse.com
- dt-bindings: clock: r8a7796: Remove CSIREF clock (bsc#1120902).
- commit c971b53
* Tue May 28 2019 fabian.baumanis@suse.com
- dt-bindings: clock: r8a7795: Remove CSIREF clock (bsc#1120902).
- commit 3779405
* Tue May 28 2019 fabian.baumanis@suse.com
- dt-bindings: net: Add binding for the external clock for TI
  WiLink (bsc#1085535).
- commit a82e24e
* Mon May 27 2019 fdmanana@suse.com
- Btrfs: tree-checker: detect file extent items with overlapping
  ranges (bsc#1136478).
- commit 99c28e3
* Mon May 27 2019 fdmanana@suse.com
- Btrfs: fix race between ranged fsync and writeback of adjacent
  ranges (bsc#1136477).
- commit 78d735d
* Mon May 27 2019 jack@suse.cz
- blacklist.conf: Blacklist e5d01196c042
- commit f5f212c
* Mon May 27 2019 jack@suse.cz
- blacklist.conf: Blacklist e5d01196c042
- commit 8d4155b
* Mon May 27 2019 jack@suse.cz
- ext4: make sanity check in mballoc more strict (bsc#1136439).
- commit 6ac995b
* Mon May 27 2019 jack@suse.cz
- ext4: wait for outstanding dio during truncate in nojournal mode
  (bsc#1136438).
- commit 638f0df
* Mon May 27 2019 jack@suse.cz
- ext4: avoid panic during forced reboot due to aborted journal
  (bsc#1126356).
- commit 0e51a34
* Mon May 27 2019 jack@suse.cz
- fs/writeback.c: use rcu_barrier() to wait for inflight wb
  switches going into workqueue when umount (bsc#1136435).
- commit 9efa073
* Mon May 27 2019 jack@suse.cz
- ocfs2: fix ocfs2 read inode data panic in ocfs2_iget
  (bsc#1136434).
- commit c5999d1
* Mon May 27 2019 jack@suse.cz
- fs/sync.c: sync_file_range(2) may use WB_SYNC_ALL writeback
  (bsc#1136432).
- commit d0e9c49
* Mon May 27 2019 jack@suse.cz
- jbd2: check superblock mapped prior to committing (bsc#1136430).
- commit e8faf2c
* Mon May 27 2019 jack@suse.cz
- ext4: fix data corruption caused by overlapping unaligned and
  aligned IO (bsc#1136428).
- commit 1dc7363
* Mon May 27 2019 oneukum@suse.com
- blacklist.conf: not neeed for our kernel configs
- commit 57259c7
* Mon May 27 2019 oneukum@suse.com
- p54: drop device reference count if fails to enable device
  (bsc#1135642).
- commit 4fe5e78
* Mon May 27 2019 oneukum@suse.com
- keys: safe concurrent user->{session,uid}_keyring access
  (bsc#1135642).
- commit 208d509
* Mon May 27 2019 jgross@suse.com
- xenbus: drop useless LIST_HEAD in xenbus_write_watch() and
  xenbus_file_write() (bsc#1065600).
- commit 19f3981
* Mon May 27 2019 mwilck@suse.com
- RDMA/rxe: Consider skb reserve space based on netdev of GID
  (bsc#1082387, bsc#1103992, FATE#326009).
- commit 1002de7
* Mon May 27 2019 glin@suse.com
- kabi: implement map_lookup_elem_sys_only in another way
  (bsc#1083647).
- bpf, lru: avoid messing with eviction heuristics upon syscall
  lookup (bsc#1083647).
- bpf: add map_lookup_elem_sys_only for lookups from syscall side
  (bsc#1083647).
- commit f662f86
* Mon May 27 2019 wqu@suse.com
- Refresh
  patches.suse/0001-btrfs-extent-tree-Fix-a-bug-that-btrfs-is-unable-to-.patch.
- commit 3d0a3c7
* Sun May 26 2019 tiwai@suse.de
- Bluetooth: Check key sizes only when Secure Simple Pairing is
  enabled (bsc#1135556).
- commit 6cda879
* Fri May 24 2019 tiwai@suse.de
- drm/i915/gvt: do not let TRTTE and 0x4dfc write passthrough
  to hardware (bsc#1051510).
- commit 7358223
* Fri May 24 2019 tiwai@suse.de
- platform/x86: pmc_atom: Add several Beckhoff Automation boards
  to critclk_systems DMI table (bsc#1051510).
- platform/x86: pmc_atom: Add Lex 3I380D industrial PC to
  critclk_systems DMI table (bsc#1051510).
- drm/vmwgfx: integer underflow in vmw_cmd_dx_set_shader()
  leading to an invalid read (bsc#1051510).
- drm/vmwgfx: Don't send drm sysfs hotplug events on initial
  master set (bsc#1051510).
- commit 70d4924
* Fri May 24 2019 dkirjanov@suse.com
- netfilter: ebtables: CONFIG_COMPAT: reject trailing data after
  last rule (git-fixes).
- ipv6/flowlabel: wait rcu grace period before put_pid()
  (git-fixes).
- ipv6: invert flowlabel sharing check in process and user mode
  (git-fixes).
- netfilter: nf_tables: fix leaking object reference count
  (git-fixes).
- netfilter: ipset: do not call ipset_nest_end after
  nla_nest_cancel (git-fixes).
- ipvs: call ip_vs_dst_notifier earlier than ipv6_dev_notf
  (git-fixes).
- net: don't keep lonely packets forever in the gro hash
  (git-fixes).
- netfilter: nft_compat: do not dump private area (git-fixes).
- net/ipv4: defensive cipso option parsing (git-fixes).
- ip_gre: fix parsing gre header in ipgre_err (git-fixes).
- net: make skb_partial_csum_set() more robust against overflows
  (git-fixes).
- commit 86f6537
* Fri May 24 2019 tbogendoerfer@suse.de
- net: ena: fix return value of ena_com_config_llq_info()
  (bsc#1111696 bsc#1117561).
- bpf: Add missed newline in verifier verbose log (bsc#1056787).
- net: hns3: remove resetting check in hclgevf_reset_task_schedule
  (bsc#1104353 FATE#326415 bsc#1135056).
- bnxt_en: Free short FW command HWRM memory in error path in
  bnxt_init_one() (bsc#1050242 FATE#322914).
- RDMA/hns: Fix bug that caused srq creation to fail (bsc#1104427
  FATE#326416).
- net/sched: don't dereference a->goto_chain to read the chain
  index (bsc#1064802 bsc#1066129).
- net/mlx5e: IPoIB, Reset QP after channels are closed
  (bsc#1075020).
- net/mlx5e: Fix trailing semicolon (bsc#1075020).
- commit 1a64be3
* Thu May 23 2019 neilb@suse.com
- arm64: Export save_stack_trace_tsk() (jsc#SLE-4214).
- commit 47a499b
* Thu May 23 2019 ptesarik@suse.cz
- s390/qdio: clear intparm during shutdown (bsc#1134597
  LTC#177516).
- commit fbf32ad
* Thu May 23 2019 ptesarik@suse.cz
- kmsg: Update message catalog to latest IBM level (2019/03/08)
  (bsc#1128904 LTC#176078).
- commit d18ce40
* Thu May 23 2019 ptesarik@suse.cz
- Refresh
  patches.drm/drm-i915-Disable-LP3-watermarks-on-all-SNB-machines.patch.
- commit d7b63e6
* Thu May 23 2019 jthumshirn@suse.de
- nvme-rdma: fix possible free of a non-allocated async event
  buffer (bsc#1120423).
- commit 897ddf2
* Thu May 23 2019 vbabka@suse.cz
- mm/mincore.c: make mincore() more conservative (CVE-2019-5489,
  bsc#1120843).
- commit 1e17fa5
* Thu May 23 2019 tiwai@suse.de
- MD: fix invalid stored role for a disk (bsc#1051510).
- commit 44ef4a6
* Thu May 23 2019 tiwai@suse.de
- mac8390: Fix mmio access size probe (bsc#1051510).
- commit ae05479
* Thu May 23 2019 tiwai@suse.de
- l2tp: revert "l2tp: fix missing print session offset info"
  (bsc#1051510).
- l2tp: cleanup l2tp_tunnel_delete calls (bsc#1051510).
- commit 9da90d9
* Thu May 23 2019 tiwai@suse.de
- iw_cxgb4: only allow 1 flush on user qps (bsc#1051510).
- commit 917dc56
* Thu May 23 2019 tiwai@suse.de
- ipvs: Fix signed integer overflow when setsockopt timeout
  (bsc#1051510).
- ipvs: fix race between ip_vs_conn_new() and ip_vs_del_dest()
  (bsc#1051510).
- commit c0d0472
* Thu May 23 2019 tiwai@suse.de
- blacklist.conf: Add reverted entries for ipvlan
- commit e8535d6
* Thu May 23 2019 tiwai@suse.de
- ipvlan: use ETH_MAX_MTU as max mtu (bsc#1051510).
- ipvlan: Add the skb->mark as flow4's member to lookup route
  (bsc#1051510).
- ipvlan: fix ipv6 outbound device (bsc#1051510).
- commit 034e32f
* Thu May 23 2019 tiwai@suse.de
- ipconfig: Correctly initialise ic_nameservers (bsc#1051510).
- commit dfaa13c
* Thu May 23 2019 tiwai@suse.de
- debugfs: fix use-after-free on symlink traversal (bsc#1051510).
- commit 472b149
* Thu May 23 2019 tiwai@suse.de
- dccp: Fix memleak in __feat_register_sp (bsc#1051510).
- commit f3bfe00
* Thu May 23 2019 tiwai@suse.de
- crypto: vmx - CTR: always increment IV as quadword
  (bsc#1051510).
- commit 8dd0014
* Thu May 23 2019 tiwai@suse.de
- 9p locks: add mount option for lock retry interval
  (bsc#1051510).
- Refresh
  patches.fixes/9p-locks-fix-glock.client_id-leak-in-do_lock.patch.
- commit 70d83b3
* Thu May 23 2019 tiwai@suse.de
- blacklist.conf: blacklist entries for unsupported fsl hypervisor
- commit cd8abeb
* Wed May 22 2019 dkirjanov@suse.com
- xfrm: reset crypto_done when iterating over multiple input xfrms
  (git-fixes).
- xfrm: reset transport header back to network header after all
  input transforms ahave been applied (git-fixes).
- xfrm6: call kfree_skb when skb is toobig (git-fixes).
- xfrm: Validate address prefix lengths in the xfrm selector
  (git-fixes).
- netfilter: bridge: Don't sabotage nf_hook calls from an l3mdev
  (git-fixes).
- netfilter: nf_tables: release chain in flushing set (git-fixes).
- igmp: fix incorrect unsolicit report count when join group
  (git-fixes).
- ipv6: fix cleanup ordering for pingv6 registration (git-fixes).
- ipv6: fix cleanup ordering for ip6_mr failure (git-fixes).
- ip6_tunnel: collect_md xmit: Use ip_tunnel_key's provided src
  address (git-fixes).
- xfrm: fix 'passing zero to ERR_PTR()' warning (git-fixes).
- net/ipv6: propagate net.ipv6.conf.all.addr_gen_mode to devices
  (git-fixes).
- net/ipv6: reserve room for IFLA_INET6_ADDR_GEN_MODE (git-fixes).
- net/ipv6: don't reinitialize ndev->cnf.addr_gen_mode on new
  inet6_dev (git-fixes).
- net/ipv6: fix addrconf_sysctl_addr_gen_mode (git-fixes).
- packet: refine ring v3 block size test to hold one frame
  (git-fixes).
- net: socket: fix potential spectre v1 gadget in socketcall
  (git-fixes).
- xfrm: fix missing dst_release() after policy blocking lbcast
  and multicast (git-fixes).
- xfrm_user: prevent leaking 2 bytes of kernel memory (git-fixes).
- netfilter: nf_log: don't hold nf_log_mutex during user access
  (git-fixes).
- netfilter: nf_log: fix uninit read in nf_log_proc_dostring
  (git-fixes).
- commit 303186e
* Wed May 22 2019 aaptel@suse.com
- cifs: a smb2_validate_and_copy_iov failure does not mean the handle is invalid (bsc#1144333).
- commit 68f6ab0
* Wed May 22 2019 aaptel@suse.com
- SMB3: Allow persistent handle timeout to be configurable on mount (bsc#1144333).
- commit 627d619
* Wed May 22 2019 aaptel@suse.com
- smb3: Fix enumerating snapshots to Azure (bsc#1144333).
- commit 0a9c290
* Wed May 22 2019 aaptel@suse.com
- cifs: fix kref underflow in close_shroot() (bsc#1144333).
- commit 615abb2
* Wed May 22 2019 aaptel@suse.com
- fs/cifs: Simplify ib_post_(send|recv|srq_recv)() calls (bsc#1144333).
- commit 04b1ce0
* Wed May 22 2019 aaptel@suse.com
- cifs_lookup(): switch to d_splice_alias() (bsc#1144333).
- commit 36ccce5
* Wed May 22 2019 aaptel@suse.com
- cifs_lookup(): cifs_get_inode_...() never returns 0 with *inode left NULL (bsc#1144333).
- commit f01e8fd
* Wed May 22 2019 jack@suse.cz
- ext4: zero out the unused memory region in the extent tree block
  (bsc#1135281 CVE-2019-11833).
- commit 5827b89
* Wed May 22 2019 tiwai@suse.de
- ARM: imx6q: cpuidle: fix bug that CPU might not wake up at
  expected time (bsc#1051510).
- ARM: 8833/1: Ensure that NEON code always compiles with Clang
  (bsc#1051510).
- ARM: avoid Cortex-A9 livelock on tight dmb loops (bsc#1051510).
- ARM: 8840/1: use a raw_spinlock_t in unwind (bsc#1051510).
- ARM: 8839/1: kprobe: make patch_lock a raw_spinlock_t
  (bsc#1051510).
- ARM: s3c24xx: Fix boolean expressions in osiris_dvs_notify
  (bsc#1051510).
- ARM: 8824/1: fix a migrating irq bug when hotplug cpu
  (bsc#1051510).
- ARM: OMAP2+: fix lack of timer interrupts on CPU1 after hotplug
  (bsc#1051510).
- ARM: OMAP2+: Variable "reg" in function omap4_dsi_mux_pads()
  could be uninitialized (bsc#1051510).
- ARM: pxa: ssp: unneeded to free devm_ allocated data
  (bsc#1051510).
- ARM: samsung: Limit SAMSUNG_PM_CHECK config option to non-Exynos
  platforms (bsc#1051510).
- commit 8a4cc44
* Wed May 22 2019 msuchanek@suse.de
- Update config files.
  Debug kernel is not supported (bsc#1135492).
- commit 166e766
* Wed May 22 2019 aaptel@suse.com
- cifs: Fix to use kmem_cache_free() instead of kfree() (bsc#1144333).
- commit 3845c98
* Wed May 22 2019 fabian.baumanis@suse.com
- tools lib traceevent: Fix missing equality check for strcmp
  (bsc#1129770).
- commit 677ed0a
* Wed May 22 2019 fabian.baumanis@suse.com
- x86/speculation/mds: Fix documentation typo (bsc#1135642).
- commit 4e531e5
* Tue May 21 2019 aaptel@suse.com
- smb3: missing defines and structs for reparse point handling (bsc#1144333).
- commit 7fa072b
* Tue May 21 2019 aaptel@suse.com
- smb3: if server does not support posix do not allow posix mount option (bsc#1144333).
- commit 99d410c
* Tue May 21 2019 aaptel@suse.com
- cifs: smbd: Check for iov length on sending the last iov (bsc#1144333).
- commit c0232af
* Tue May 21 2019 fdmanana@suse.com
- Btrfs: improve performance on fsync of files with multiple
  hardlinks (bsc#1123454).
- commit 19a09ba
* Tue May 21 2019 fdmanana@suse.com
- Btrfs: send, flush dellaloc in order to avoid data loss
  (bsc#1133320).
- commit 9e6fc7e
* Tue May 21 2019 fdmanana@suse.com
- Btrfs: do not allow trimming when a fs is mounted with the
  nologreplay option (bsc#1135758).
- commit f1cd52b
* Tue May 21 2019 tiwai@suse.de
- blacklist.conf: add a CVE entry that isn't needed for SLE15-SP0
- commit 6366742
* Tue May 21 2019 tiwai@suse.de
- Update reference tag for MDS fixes, adding mising CVE-2019-11091
- commit b6b4ce8
* Tue May 21 2019 jslaby@suse.cz
- TTY: serial_core, add ->install (bnc#1129693).
- commit f4a2fd2
* Tue May 21 2019 tiwai@suse.de
- vsock/virtio: Initialize core virtio vsock before registering
  the driver (bsc#1051510).
- soc/fsl/qe: Fix an error code in qe_pin_request() (bsc#1051510).
- commit 71c20f2
* Tue May 21 2019 jslaby@suse.cz
- Refresh
  patches.drivers/serial-fix-race-between-flush_to_ldisc-and-tty_open.patch.
  Fix misapplied hunk. The second hunk should have been in
  uart_unthrottle.
- commit 2e69a77
* Mon May 20 2019 tiwai@suse.de
- Update reference tag for tun security fix (CVE-2018-7191, bsc#1135603)
- commit fe4b52d
* Mon May 20 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gvt: Add in context mmio 0x20D8 to gen9 mmio list'
- commit f377034
* Mon May 20 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/sun4i: rgb: Change the pixel clock validation check'
- commit bfb6b1e
* Sun May 19 2019 bp@suse.de
- Update config files.
- commit 32d89f9
* Sun May 19 2019 tiwai@suse.de
- blacklist.conf: Add a blacklist entry for HD-audio core that would break kABI
- commit 1d28cd1
* Sun May 19 2019 tiwai@suse.de
- ALSA: hda/realtek - Fix for Lenovo B50-70 inverted internal
  microphone bug (bsc#1051510).
- ALSA: hda/realtek - Corrected fixup for System76 Gazelle
  (gaze14) (bsc#1051510).
- ALSA: hda/realtek - Avoid superfluous COEF EAPD setups
  (bsc#1051510).
- ALSA: hda/realtek - Fixup headphone noise via runtime suspend
  (bsc#1051510).
- ALSA: hda - Use a macro for snd_array iteration loops
  (bsc#1051510).
- commit ed69d64
* Sun May 19 2019 bp@suse.de
- x86/mce: Don't disable MCA banks when offlining a CPU on AMD
  (fate#327735).
- commit 956d775
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: force summary counter recalc at next mount (bsc#1114427).
- commit 437f1ec
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: refactor unmount record write (bsc#1114427).
- commit fd58dbe
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: move error injection tags into their own file
  (bsc#1114427).
- commit 269d9c3
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: fix unused variable warning in xfs_buf_set_ref()
  (bsc#1114427).
- commit b0ec684
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: create inode pointer verifiers (bsc#1114427).
- commit 2fc02cb
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: buffer lru reference count error injection tag
  (bsc#1114427).
- commit 7c870d3
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: add log item pinning error injection tag (bsc#1114427).
- commit 50a1a91
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: replace log_badcrc_factor knob with error injection tag
  (bsc#1114427).
- commit 71829d5
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: convert drop_writes to use the errortag mechanism
  (bsc#1114427).
- commit 7756cd3
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: expose errortag knobs via sysfs (bsc#1114427).
- Refresh
  patches.fixes/xfs-remove-unneeded-parameter-from-XFS_TEST_ERROR.patch.
- commit 4c318be
* Sat May 18 2019 ailiopoulos@suse.com
- xfs: export _inobt_btrec_to_irec and _ialloc_cluster_alignment
  for scrub (bsc#1114427).
- commit 9a1c1d3
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number (bsc#1144333).
- commit 7464d29
* Fri May 17 2019 aaptel@suse.com
- SMB3: Fix SMB3.1.1 guest mounts to Samba (bsc#1051510, bsc#1144333).
- commit 4f51c39
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix slab-out-of-bounds when tracing SMB tcon (bsc#1144333).
- commit cbe5f9f
* Fri May 17 2019 aaptel@suse.com
- cifs: allow guest mounts to work for smb3.11 (bsc#1051510, bsc#1144333).
- commit dd5b721
* Fri May 17 2019 aaptel@suse.com
- fix incorrect error code mapping for OBJECTID_NOT_FOUND (bsc#1144333).
- commit 363dad3
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix an issue with re-sending rdata when transport returning -EAGAIN (bsc#1144333).
- commit f215a41
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix an issue with re-sending wdata when transport returning -EAGAIN (bsc#1144333).
- commit 58f5208
* Fri May 17 2019 aaptel@suse.com
- CIFS: fix POSIX lock leak and invalid ptr deref (bsc#1114542, bsc#1144333).
- commit 84b9ca5
* Fri May 17 2019 aaptel@suse.com
- SMB3: Allow SMB3 FSCTL queries to be sent to server from tools (bsc#1144333).
- commit 0fc8064
* Fri May 17 2019 aaptel@suse.com
- cifs: fix incorrect handling of smb2_set_sparse() return in smb3_simple_falloc (bsc#1144333).
- commit be9b2e4
* Fri May 17 2019 aaptel@suse.com
- smb2: fix typo in definition of a few error flags (bsc#1144333).
- commit 94d3a94
* Fri May 17 2019 aaptel@suse.com
- CIFS: make mknod() an smb_version_op (bsc#1144333).
- commit 37ba4d4
* Fri May 17 2019 aaptel@suse.com
- cifs: remove unused value pointed out by Coverity (bsc#1144333).
- commit c4f35af
* Fri May 17 2019 aaptel@suse.com
- SMB3: passthru query info doesn't check for SMB3 FSCTL passthru (bsc#1144333).
- commit 0c79e6b
* Fri May 17 2019 aaptel@suse.com
- smb3: add dynamic tracepoints for simple fallocate and zero range (bsc#1144333).
- commit 4b80521
* Fri May 17 2019 aaptel@suse.com
- cifs: fix smb3_zero_range so it can expand the file-size when required (bsc#1144333).
- commit 869e25e
* Fri May 17 2019 aaptel@suse.com
- cifs: add SMB2_ioctl_init/free helpers to be used with compounding (bsc#1144333).
- commit 2e0785f
* Fri May 17 2019 aaptel@suse.com
- smb3: Add dynamic trace points for various compounded smb3 ops (bsc#1144333).
- commit bfb0a61
* Fri May 17 2019 aaptel@suse.com
- cifs: cache FILE_ALL_INFO for the shared root handle (bsc#1144333).
- commit 24457c8
* Fri May 17 2019 aaptel@suse.com
- smb3: display volume serial number for shares in /proc/fs/cifs/DebugData (bsc#1144333).
- commit 69a9bf3
* Fri May 17 2019 aaptel@suse.com
- cifs: simplify how we handle credits in compound_send_recv() (bsc#1144333).
- commit 2c6e52b
* Fri May 17 2019 aaptel@suse.com
- smb3: add dynamic tracepoint for timeout waiting for credits (bsc#1144333).
- commit 0205de1
* Fri May 17 2019 aaptel@suse.com
- smb3: display security information in /proc/fs/cifs/DebugData more accurately (bsc#1144333).
- commit 45e7cec
* Fri May 17 2019 aaptel@suse.com
- cifs: add a timeout argument to wait_for_free_credits (bsc#1144333).
- commit 5c67c91
* Fri May 17 2019 aaptel@suse.com
- cifs: prevent starvation in wait_for_free_credits for multi-credit requests (bsc#1144333).
- commit 79213cb
* Fri May 17 2019 aaptel@suse.com
- cifs: wait_for_free_credits() make it possible to wait for >=1 credits (bsc#1144333).
- commit 19ec29e
* Fri May 17 2019 aaptel@suse.com
- cifs: pass flags down into wait_for_free_credits() (bsc#1144333).
- commit 4e5a6f9
* Fri May 17 2019 aaptel@suse.com
- cifs: change wait_for_free_request() to take flags as argument (bsc#1144333).
- commit 61d499e
* Fri May 17 2019 aaptel@suse.com
- fs: cifs: Kconfig: pedantic formatting (bsc#1144333).
- commit 236ac2b
* Fri May 17 2019 aaptel@suse.com
- smb3: request more credits on normal (non-large read/write) ops (bsc#1144333).
- commit e7ba074
* Fri May 17 2019 aaptel@suse.com
- CIFS: Mask off signals when sending SMB packets (bsc#1144333).
- commit 39b8127
* Fri May 17 2019 aaptel@suse.com
- CIFS: Return -EAGAIN instead of -ENOTSOCK (bsc#1144333).
- commit 7d43c63
* Fri May 17 2019 aaptel@suse.com
- CIFS: Only send SMB2_NEGOTIATE command on new TCP connections (bsc#1144333).
- commit 2216157
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix read after write for files with read caching (bsc#1051510, bsc#1144333).
- commit 5b17941
* Fri May 17 2019 aaptel@suse.com
- smb3: for kerberos mounts display the credential uid used (bsc#1144333).
- commit e768732
* Fri May 17 2019 aaptel@suse.com
- cifs: use correct format characters (bsc#1144333).
- commit 349330a
* Fri May 17 2019 aaptel@suse.com
- smb3: add dynamic trace point for query_info_enter/done (bsc#1144333).
- commit f313794
* Fri May 17 2019 aaptel@suse.com
- smb3: add dynamic trace point for smb3_cmd_enter (bsc#1144333).
- commit 868407f
* Fri May 17 2019 aaptel@suse.com
- smb3: improve dynamic tracing of open and posix mkdir (bsc#1144333).
- commit 9b6ec9e
* Fri May 17 2019 aaptel@suse.com
- smb3: add missing read completion trace point (bsc#1144333).
- commit f768d2f
* Fri May 17 2019 aaptel@suse.com
- smb3: Add tracepoints for read, write and query_dir enter (bsc#1144333).
- commit 57da492
* Fri May 17 2019 aaptel@suse.com
- smb3: add tracepoints for query dir (bsc#1144333).
- commit f27bdad
* Fri May 17 2019 aaptel@suse.com
- smb3: Update POSIX negotiate context with POSIX ctxt GUID (bsc#1144333).
- commit 1e6924b
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number (bsc#1144333).
- commit 6e02e6e
* Fri May 17 2019 aaptel@suse.com
- CIFS: Try to acquire credits at once for compound requests (bsc#1144333).
- commit d1ac7e2
* Fri May 17 2019 aaptel@suse.com
- CIFS: Return error code when getting file handle for writeback (bsc#1144333).
- commit e5eabf3
* Fri May 17 2019 aaptel@suse.com
- CIFS: Move open file handling to writepages (bsc#1144333).
- commit 88e44ed
* Fri May 17 2019 aaptel@suse.com
- CIFS: Move unlocking pages from wdata_send_pages() (bsc#1144333).
- commit f35bc80
* Fri May 17 2019 aaptel@suse.com
- CIFS: Find and reopen a file before get MTU credits in writepages (bsc#1144333).
- commit fc9ec19
* Fri May 17 2019 aaptel@suse.com
- CIFS: Reopen file before get SMB2 MTU credits for async IO (bsc#1144333).
- commit 5d647a5
* Fri May 17 2019 aaptel@suse.com
- CIFS: Remove custom credit adjustments for SMB2 async IO (bsc#1144333).
- commit 77a1406
* Fri May 17 2019 aaptel@suse.com
- CIFS: Adjust MTU credits before reopening a file (bsc#1144333).
- commit 78e9be0
* Fri May 17 2019 aaptel@suse.com
- CIFS: Check for reconnects before sending compound requests (bsc#1144333).
- commit 07d400d
* Fri May 17 2019 aaptel@suse.com
- CIFS: Check for reconnects before sending async requests (bsc#1144333).
- commit 378cdb1
* Fri May 17 2019 aaptel@suse.com
- CIFS: Respect reconnect in non-MTU credits calculations (bsc#1144333).
- commit eb47f27
* Fri May 17 2019 aaptel@suse.com
- CIFS: Respect reconnect in MTU credits calculations (bsc#1144333).
- commit 96ab551
* Fri May 17 2019 aaptel@suse.com
- CIFS: Set reconnect instance to one initially (bsc#1144333).
- commit 203835a
* Fri May 17 2019 aaptel@suse.com
- CIFS: Respect SMB2 hdr preamble size in read responses (bsc#1144333).
- commit 2202d63
* Fri May 17 2019 aaptel@suse.com
- CIFS: Count SMB3 credits for malformed pending responses (bsc#1144333).
- commit c414c2c
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not log credits when unmounting a share (bsc#1144333).
- commit 0b56f16
* Fri May 17 2019 aaptel@suse.com
- CIFS: Always reset read error to -EIO if no response (bsc#1144333).
- commit b50fd91
* Fri May 17 2019 aaptel@suse.com
- cifs: Accept validate negotiate if server return NT_STATUS_NOT_SUPPORTED (bsc#1144333).
- commit 76d6e1d
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not skip SMB2 message IDs on send failures (bsc#1144333).
- commit 1495978
* Fri May 17 2019 aaptel@suse.com
- smb3: request more credits on tree connect (bsc#1144333).
- commit 78f6cae
* Fri May 17 2019 aaptel@suse.com
- smb3: make default i/o size for smb3 mounts larger (bsc#1144333).
- commit d51d536
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not reset lease state to NONE on lease break (bsc#1051510, bsc#1144333).
- commit 2b009f3
* Fri May 17 2019 aaptel@suse.com
- smb3: fix bytes_read statistics (bsc#1144333).
- commit a25167c
* Fri May 17 2019 aaptel@suse.com
- cifs: return -ENODATA when deleting an xattr that does not exist (bsc#1144333).
- commit dfbb286
* Fri May 17 2019 aaptel@suse.com
- cifs: add credits from unmatched responses/messages (bsc#1144333).
- commit f7e3ff5
* Fri May 17 2019 aaptel@suse.com
- cifs: replace snprintf with scnprintf (bsc#1144333).
- commit b9e1b5e
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix NULL pointer dereference of devname (bnc#1129519).
- commit 3454751
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix leaking locked VFS cache pages in writeback retry (bsc#1144333).
- commit 8439227
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number (bsc#1144333).
- commit f226dd4
* Fri May 17 2019 aaptel@suse.com
- CIFS: fix use-after-free of the lease keys (bsc#1144333).
- commit d144209
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not consider -ENODATA as stat failure for reads (bsc#1144333).
- commit 865bfac
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not count -ENODATA as failure for query directory (bsc#1051510, bsc#1144333).
- commit e5bfe8c
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix trace command logging for SMB2 reads and writes (bsc#1144333).
- commit eb75aa6
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix possible oops and memory leaks in async IO (bsc#1144333).
- commit b2f69fa
* Fri May 17 2019 aaptel@suse.com
- cifs: limit amount of data we request for xattrs to CIFSMaxBufSize (bsc#1144333).
- commit 3978692
* Fri May 17 2019 aaptel@suse.com
- cifs: fix computation for MAX_SMB2_HDR_SIZE (bsc#1144333).
- commit f3a9346
* Fri May 17 2019 aaptel@suse.com
- cifs: print CIFSMaxBufSize as part of /proc/fs/cifs/DebugData (bsc#1144333).
- commit 8f07afe
* Fri May 17 2019 aaptel@suse.com
- smb3: add credits we receive from oplock/break PDUs (bsc#1144333).
- commit 87f92a0
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix mounts if the client is low on credits (bsc#1144333).
- commit 76a2d83
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not assume one credit for async responses (bsc#1144333).
- commit 6184794
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix credit calculations in compound mid callback (bsc#1144333).
- commit 12e2df3
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix credit calculation for encrypted reads with errors (bsc#1051510, bsc#1144333).
- commit 77d31e3
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix credits calculations for reads with errors (bsc#1051510, bsc#1144333).
- commit 3425dd4
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not reconnect TCP session in add_credits() (bsc#1051510, bsc#1144333).
- commit 43a8d95
* Fri May 17 2019 aaptel@suse.com
- smb3: Cleanup license mess (bsc#1144333).
- commit 96ab85f
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix possible hang during async MTU reads and writes (bsc#1051510, bsc#1144333).
- commit f42401b
* Fri May 17 2019 aaptel@suse.com
- cifs: fix memory leak of an allocated cifs_ntsd structure (bsc#1144333).
- commit 1b0facc
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number (bsc#1144333).
- commit b2ce5d5
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix error paths in writeback code (bsc#1144333).
- commit f308483
* Fri May 17 2019 aaptel@suse.com
- CIFS: Move credit processing to mid callbacks for SMB3 (bsc#1144333).
- commit f1f1223
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix credits calculation for cancelled requests (bsc#1144333).
- commit f982603
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix potential OOB access of lock element array (bsc#1051510, bsc#1144333).
- commit 30c45eb
* Fri May 17 2019 aaptel@suse.com
- cifs: Limit memory used by lock request calls to a page (bsc#1144333).
- commit 5aef325
* Fri May 17 2019 aaptel@suse.com
- cifs: move large array from stack to heap (bsc#1144333).
- commit 629e8fc
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not hide EINTR after sending network packets (bsc#1051510, bsc#1144333).
- commit 01f77d5
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix credit computation for compounded requests (bsc#1144333).
- commit b4a44d3
* Fri May 17 2019 aaptel@suse.com
- CIFS: Do not set credits to 1 if the server didn't grant anything (bsc#1144333).
- commit c6cfe86
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix adjustment of credits for MTU requests (bsc#1051510, bsc#1144333).
- commit 09b367d
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix a tiny potential memory leak (bsc#1144333).
- commit 8389de5
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix a debug message (bsc#1144333).
- commit d393ca3
* Fri May 17 2019 aaptel@suse.com
- smb3: add smb3.1.1 to default dialect list (bsc#1144333).
- commit 653d973
* Fri May 17 2019 aaptel@suse.com
- cifs: fix confusing warning message on reconnect (bsc#1144333).
- commit 1bc1769
* Fri May 17 2019 aaptel@suse.com
- smb3: fix large reads on encrypted connections (bsc#1144333).
- commit be94072
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number (bsc#1144333).
- commit b83644e
* Fri May 17 2019 aaptel@suse.com
- cifs: we can not use small padding iovs together with encryption (bsc#1144333).
- commit a647d0f
* Fri May 17 2019 aaptel@suse.com
- cifs: Minor Kconfig clarification (bsc#1144333).
- commit ea760b7
* Fri May 17 2019 aaptel@suse.com
- cifs: Always resolve hostname before reconnecting (bsc#1051510, bsc#1144333).
- commit ab372db
* Fri May 17 2019 aaptel@suse.com
- cifs: Add support for failover in cifs_reconnect_tcon() (bsc#1144333).
- commit d743568
* Fri May 17 2019 aaptel@suse.com
- cifs: Add support for failover in smb2_reconnect() (bsc#1144333).
- commit 9cc4cfe
* Fri May 17 2019 aaptel@suse.com
- cifs: Only free DFS target list if we actually got one (bsc#1144333).
- commit 75a4193
* Fri May 17 2019 aaptel@suse.com
- cifs: start DFS cache refresher in cifs_mount() (bsc#1144333).
- commit a6460ef
* Fri May 17 2019 aaptel@suse.com
- cifs: Use GFP_ATOMIC when a lock is held in cifs_mount() (bsc#1144333).
- commit a7084cb
* Fri May 17 2019 aaptel@suse.com
- cifs: Add support for failover in cifs_reconnect() (bsc#1144333).
- commit 97c72ce
* Fri May 17 2019 aaptel@suse.com
- cifs: Add support for failover in cifs_mount() (bsc#1144333).
- commit 30da61c
* Fri May 17 2019 aaptel@suse.com
- cifs: remove set but not used variable 'sep' (bsc#1144333).
- commit 22614a6
* Fri May 17 2019 aaptel@suse.com
- cifs: Make use of DFS cache to get new DFS referrals (bsc#1144333).
- commit 90cce04
* Fri May 17 2019 aaptel@suse.com
- cifs: check kzalloc return (bsc#1144333).
- commit 6d6439c
* Fri May 17 2019 aaptel@suse.com
- cifs: remove set but not used variable 'server' (bsc#1144333).
- commit 5666e23
* Fri May 17 2019 aaptel@suse.com
- cifs: Use kzfree() to free password (bsc#1144333).
- commit 9b5a04d
* Fri May 17 2019 aaptel@suse.com
- cifs: Add DFS cache routines (bsc#1144333).
- commit 30e70bb
* Fri May 17 2019 aaptel@suse.com
- cifs: Save TTL value when parsing DFS referrals (bsc#1144333).
- commit 60f8dc6
* Fri May 17 2019 aaptel@suse.com
- cifs: auto disable 'serverino' in dfs mounts (bsc#1144333).
- commit f2a0a09
* Fri May 17 2019 aaptel@suse.com
- cifs: Make devname param optional in cifs_compose_mount_options() (bsc#1144333).
- commit 3acacec
* Fri May 17 2019 aaptel@suse.com
- cifs: Skip any trailing backslashes from UNC (bsc#1144333).
- commit 9d380ad
* Fri May 17 2019 aaptel@suse.com
- cifs: Refactor out cifs_mount() (bsc#1144333).
- commit 2e16c94
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix error mapping for SMB2_LOCK command which caused OFD lock problem (bsc#1051510, bsc#1144333).
- commit ee13ef4
* Fri May 17 2019 aaptel@suse.com
- CIFS: return correct errors when pinning memory failed for direct I/O (bsc#1144333).
- commit a8d345c
* Fri May 17 2019 aaptel@suse.com
- CIFS: use the correct length when pinning memory for direct I/O for write (bsc#1144333).
- commit 055d1d5
* Fri May 17 2019 aaptel@suse.com
- cifs: check ntwrk_buf_start for NULL before dereferencing it (bsc#1144333).
- commit d7754fb
* Fri May 17 2019 aaptel@suse.com
- cifs: remove coverity warning in calc_lanman_hash (bsc#1144333).
- commit afaec00
* Fri May 17 2019 aaptel@suse.com
- cifs: remove set but not used variable 'smb_buf' (bsc#1144333).
- commit 875f95a
* Fri May 17 2019 aaptel@suse.com
- cifs: suppress some implicit-fallthrough warnings (bsc#1144333).
- commit 2c43cd3
* Fri May 17 2019 aaptel@suse.com
- cifs: change smb2_query_eas to use the compound query-info helper (bsc#1144333).
- commit 386a052
* Fri May 17 2019 aaptel@suse.com
- Add vers=3.0.2 as a valid option for SMBv3.0.2 (bsc#1144333).
- commit 0271862
* Fri May 17 2019 aaptel@suse.com
- cifs: create a helper function for compound query_info (bsc#1144333).
- commit c9a1bc7
* Fri May 17 2019 aaptel@suse.com
- cifs: address trivial coverity warning (bsc#1144333).
- commit 0b6758a
* Fri May 17 2019 aaptel@suse.com
- cifs: smb2 commands can not be negative, remove confusing check (bsc#1144333).
- commit b6b77e4
* Fri May 17 2019 aaptel@suse.com
- cifs: use a compound for setting an xattr (bsc#1144333).
- commit 5b12a67
* Fri May 17 2019 aaptel@suse.com
- cifs: clean up indentation, replace spaces with tab (bsc#1144333).
- commit d4b4c5b
* Fri May 17 2019 aaptel@suse.com
- smb3: Fix rmdir compounding regression to strict servers (bsc#1144333).
- commit 49563e4
* Fri May 17 2019 aaptel@suse.com
- CIFS: Avoid returning EBUSY to upper layer VFS (bsc#1144333).
- commit 4869979
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix separator when building path from dentry (bsc#1051510, bsc#1144333).
- commit 9d852da
* Fri May 17 2019 aaptel@suse.com
- cifs: In Kconfig CONFIG_CIFS_POSIX needs depends on legacy (insecure cifs) (bsc#1144333).
- commit b62ba51
* Fri May 17 2019 aaptel@suse.com
- cifs: fix signed/unsigned mismatch on aio_read patch (bsc#1144333).
- commit b3103c7
* Fri May 17 2019 aaptel@suse.com
- cifs: don't dereference smb_file_target before null check (bsc#1051510, bsc#1144333).
- commit f46e1bc
* Fri May 17 2019 aaptel@suse.com
- CIFS: Add direct I/O functions to file_operations (bsc#1144333).
- commit 21498fd
* Fri May 17 2019 aaptel@suse.com
- CIFS: Add support for direct I/O write (bsc#1144333).
- commit f09dbb1
* Fri May 17 2019 aaptel@suse.com
- CIFS: Add support for direct I/O read (bsc#1144333).
- commit d458a08
* Fri May 17 2019 aaptel@suse.com
- smb3: on kerberos mount if server doesn't specify auth type use krb5 (bsc#1051510, bsc#1144333).
- commit 0bca5b4
* Fri May 17 2019 aaptel@suse.com
- smb3: add trace point for tree connection (bsc#1144333).
- commit 7e01105
* Fri May 17 2019 aaptel@suse.com
- cifs: fix spelling mistake, EACCESS -> EACCES (bsc#1144333).
- commit 24acada
* Fri May 17 2019 aaptel@suse.com
- cifs: fix return value for cifs_listxattr (bsc#1051510, bsc#1144333).
- commit e712206
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number for cifs.ko to 2.14 (bsc#1144333).
- commit 3e4e82a
* Fri May 17 2019 aaptel@suse.com
- smb3: add debug for unexpected mid cancellation (bsc#1144333).
- commit 840c007
* Fri May 17 2019 aaptel@suse.com
- cifs: allow calling SMB2_xxx_free(NULL) (bsc#1144333).
- commit c73ac60
* Fri May 17 2019 aaptel@suse.com
- smb3 - clean up debug output displaying network interfaces (bsc#1144333).
- commit cd37173
* Fri May 17 2019 aaptel@suse.com
- smb3: show number of current open files in /proc/fs/cifs/Stats (bsc#1144333).
- commit 036c847
* Fri May 17 2019 aaptel@suse.com
- cifs: add support for ioctl on directories (bsc#1144333).
- commit 55a421b
* Fri May 17 2019 aaptel@suse.com
- cifs: fallback to older infolevels on findfirst queryinfo retry (bsc#1144333).
- commit 95d13f3
* Fri May 17 2019 aaptel@suse.com
- smb3: do not attempt cifs operation in smb3 query info error path (bsc#1051510, bsc#1144333).
- commit cc10f95
* Fri May 17 2019 aaptel@suse.com
- smb3: send backup intent on compounded query info (bsc#1144333).
- commit 31189b6
* Fri May 17 2019 aaptel@suse.com
- cifs: track writepages in vfs operation counters (bsc#1144333).
- commit d316ce5
* Fri May 17 2019 aaptel@suse.com
- smb2: fix uninitialized variable bug in smb2_ioctl_query_info (bsc#1144333).
- commit 631d8d6
* Fri May 17 2019 aaptel@suse.com
- cifs: add IOCTL for QUERY_INFO passthrough to userspace (bsc#1144333).
- commit e4908f1
* Fri May 17 2019 aaptel@suse.com
- cifs: minor clarification in comments (bsc#1144333).
- commit 32759bb
* Fri May 17 2019 aaptel@suse.com
- CIFS: Print message when attempting a mount (bsc#1144333).
- commit b43e6a9
* Fri May 17 2019 aaptel@suse.com
- CIFS: Adds information-level logging function (bsc#1144333).
- commit b88e3c1
* Fri May 17 2019 aaptel@suse.com
- cifs: OFD locks do not conflict with eachothers (bsc#1051510, bsc#1144333).
- commit b6fdf1b
* Fri May 17 2019 aaptel@suse.com
- CIFS: SMBD: Do not call ib_dereg_mr on invalidated memory registration (bsc#1144333).
- commit f4f9160
* Fri May 17 2019 aaptel@suse.com
- CIFS: pass page offsets on SMB1 read/write (bsc#1144333).
- commit 1a0e880
* Fri May 17 2019 aaptel@suse.com
- fs/cifs: fix uninitialised variable warnings (bsc#1144333).
- commit c1745e9
* Fri May 17 2019 aaptel@suse.com
- smb3: add tracepoint for sending lease break responses to server (bsc#1144333).
- commit 36cd9b7
* Fri May 17 2019 aaptel@suse.com
- cifs: do not return atime less than mtime (bsc#1144333).
- commit 143e27f
* Fri May 17 2019 aaptel@suse.com
- smb3: update default requested iosize to 4MB from 1MB for recent dialects (bsc#1144333).
- commit 5a9e797
* Fri May 17 2019 aaptel@suse.com
- smb3: Add debug message later in smb2/smb3 reconnect path (bsc#1144333).
- commit 2026c25
* Fri May 17 2019 aaptel@suse.com
- CIFS: make 'nodfs' mount opt a superblock flag (bsc#1051510, bsc#1144333).
- commit 6a0fc8f
* Fri May 17 2019 aaptel@suse.com
- smb3: track the instance of each session for debugging (bsc#1144333).
- commit a85af4a
* Fri May 17 2019 aaptel@suse.com
- smb3: minor missing defines relating to reparse points (bsc#1144333).
- commit a2bc0a9
* Fri May 17 2019 aaptel@suse.com
- smb3: add way to control slow response threshold for logging and stats (bsc#1144333).
- commit 08ac21a
* Fri May 17 2019 aaptel@suse.com
- cifs: minor updates to module description for cifs.ko (bsc#1144333).
- commit 85b442a
* Fri May 17 2019 aaptel@suse.com
- cifs: protect against server returning invalid file system block size (bsc#1144333).
- commit bdfadb0
* Fri May 17 2019 aaptel@suse.com
- smb3: allow stats which track session and share reconnects to be reset (bsc#1051510, bsc#1144333).
- commit 261fe49
* Fri May 17 2019 aaptel@suse.com
- SMB3: Backup intent flag missing from compounded ops (bsc#1144333).
- commit 92e6870
* Fri May 17 2019 aaptel@suse.com
- cifs: create a define for the max number of iov we need for a SMB2 set_info (bsc#1144333).
- commit e539455
* Fri May 17 2019 aaptel@suse.com
- cifs: change SMB2_OP_RENAME and SMB2_OP_HARDLINK to use compounding (bsc#1144333).
- commit d069f0a
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: sanity-check the unused space before trying to use it
  (bsc#1123663).
- commit d9d191e
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: refactor btree block header checking functions
  (bsc#1123663).
- commit 59af3d5
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: refactor btree pointer checks (bsc#1123663).
- commit a98bae6
* Fri May 17 2019 aaptel@suse.com
- cifs: remove the is_falloc argument to SMB2_set_eof (bsc#1144333).
- commit 0643e36
* Fri May 17 2019 aaptel@suse.com
- cifs: change SMB2_OP_SET_INFO to use compounding (bsc#1144333).
- commit d8d2551
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: create block pointer check functions (bsc#1123663).
- commit 69250e0
* Fri May 17 2019 aaptel@suse.com
- cifs: change SMB2_OP_SET_EOF to use compounding (bsc#1144333).
- commit 661207b
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: check _btree_check_block value (bsc#1123663).
- commit 678f7f4
* Fri May 17 2019 aaptel@suse.com
- cifs: make rmdir() use compounding (bsc#1144333).
- commit c27dee2
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: rename MAXPATHLEN to XFS_SYMLINK_MAXLEN (bsc#1123663).
- commit 2ba49d2
* Fri May 17 2019 aaptel@suse.com
- cifs: create helpers for SMB2_set_info_init/free() (bsc#1144333).
- commit 6a229a7
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: remove unneeded parameter from XFS_TEST_ERROR
  (bsc#1123663).
- Refresh
  patches.fixes/0038-xfs-split-xfs_bmap_shift_extents.patch.
- commit 468fad3
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: make errortag a per-mountpoint structure (bsc#1123663).
- commit 49ab9ae
* Fri May 17 2019 ailiopoulos@suse.com
- xfs: export various function for the online scrubber
  (bsc#1123663).
- commit 0f5a146
* Fri May 17 2019 aaptel@suse.com
- cifs: change unlink to use a compound (bsc#1144333).
- commit 7fb5bcc
* Fri May 17 2019 aaptel@suse.com
- cifs: change mkdir to use a compound (bsc#1144333).
- commit fd31c93
* Fri May 17 2019 aaptel@suse.com
- cifs: add a smb2_compound_op and change QUERY_INFO to use it (bsc#1144333).
- commit f6b452e
* Fri May 17 2019 aaptel@suse.com
- cifs: fix a credits leak for compund commands (bsc#1144333).
- commit 3a73eae
* Fri May 17 2019 aaptel@suse.com
- smb3: add tracepoint to catch cases where credit refund of failed op overlaps reconnect (bsc#1144333).
- commit 8a60cb1
* Fri May 17 2019 tiwai@suse.de
- power: supply: axp20x_usb_power: Fix typo in VBUS current
  limit macros (bsc#1051510).
- power: supply: axp288_charger: Fix unchecked return value
  (bsc#1051510).
- team: set slave to promisc if team is already in promisc mode
  (bsc#1051510).
- commit 960072f
* Fri May 17 2019 aaptel@suse.com
- cifs: remove set but not used variable 'cifs_sb' (bsc#1144333).
- commit b0206f8
* Fri May 17 2019 aaptel@suse.com
- cifs: Use kmemdup rather than duplicating its implementation in smb311_posix_mkdir() (bsc#1144333).
- commit 391676b
* Fri May 17 2019 aaptel@suse.com
- smb3: do not display confusing message on mount to Azure servers (bsc#1144333).
- commit d180654
* Fri May 17 2019 aaptel@suse.com
- smb3: fix lease break problem introduced by compounding (bsc#1144333).
- commit 029fcc0
* Fri May 17 2019 aaptel@suse.com
- cifs: only wake the thread for the very last PDU in a compound (bsc#1144333).
- commit 484a4a9
* Fri May 17 2019 aaptel@suse.com
- cifs: add a warning if we try to to dequeue a deleted mid (bsc#1144333).
- commit 05b4a01
* Fri May 17 2019 aaptel@suse.com
- smb2: fix missing files in root share directory listing (bsc#1112907, bsc#1144333).
- commit 3108c8c
* Fri May 17 2019 aaptel@suse.com
- cifs: read overflow in is_valid_oplock_break() (bsc#1144333).
- commit 04e56fc
* Fri May 17 2019 aaptel@suse.com
- cifs: integer overflow in in SMB2_ioctl() (bsc#1051510, bsc#1144333).
- commit e8f9960
* Fri May 17 2019 aaptel@suse.com
- CIFS: fix wrapping bugs in num_entries() (bsc#1051510, bsc#1144333).
- commit 49a1326
* Fri May 17 2019 aaptel@suse.com
- cifs: prevent integer overflow in nxt_dir_entry() (bsc#1051510, bsc#1144333).
- commit 9419e33
* Fri May 17 2019 aaptel@suse.com
- fs/cifs: require sha512 (bsc#1051510, bsc#1144333).
- commit 667714a
* Fri May 17 2019 tiwai@suse.de
- appletalk: Fix compile regression (bsc#1051510).
- appletalk: Fix use-after-free in atalk_proc_exit (bsc#1051510).
- commit f7c1154
* Fri May 17 2019 aaptel@suse.com
- fs/cifs: suppress a string overflow warning (bsc#1144333).
- commit 2052a84
* Fri May 17 2019 aaptel@suse.com
- cifs: connect to servername instead of IP for IPC$ share (bsc#1051510, bsc#1144333).
- commit 3eeaa88
* Fri May 17 2019 aaptel@suse.com
- smb3: check for and properly advertise directory lease support (bsc#1051510, bsc#1144333).
- commit ee6bae2
* Fri May 17 2019 tiwai@suse.de
- ACPI: button: reinitialize button state upon resume
  (bsc#1051510).
- drm/imx: don't skip DP channel disable for background plane
  (bsc#1051510).
- ACPI / utils: Drop reference in test for device presence
  (bsc#1051510).
- commit df10ac3
* Fri May 17 2019 aaptel@suse.com
- smb3: minor debugging clarifications in rfc1001 len processing (bsc#1144333).
- commit 101f78e
* Fri May 17 2019 aaptel@suse.com
- SMB3: Backup intent flag missing for directory opens with backupuid mounts (bsc#1051510, bsc#1144333).
- commit 8339bc2
* Fri May 17 2019 aaptel@suse.com
- fs/cifs: don't translate SFM_SLASH (U+F026) to backslash (bsc#1144333).
- commit 519a906
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number for cifs.ko to 2.12 (bsc#1144333).
- commit e4e5c10
* Fri May 17 2019 aaptel@suse.com
- cifs: check kmalloc before use (bsc#1051510, bsc#1144333).
- commit 623829b
* Fri May 17 2019 aaptel@suse.com
- cifs: check if SMB2 PDU size has been padded and suppress the warning (bsc#1144333).
- commit 8110eac
* Fri May 17 2019 aaptel@suse.com
- cifs: create a define for how many iovs we need for an SMB2_open() (bsc#1144333).
- commit e6177e7
* Fri May 17 2019 aaptel@suse.com
- smb3: create smb3 equivalent alias for cifs pseudo-xattrs (bsc#1144333).
- commit de22c0d
* Fri May 17 2019 aaptel@suse.com
- smb3: allow previous versions to be mounted with snapshot= mount parm (bsc#1144333).
- commit 529fe9d
* Fri May 17 2019 tiwai@suse.de
- Input: synaptics-rmi4 - fix possible double free (bsc#1051510).
- gpu: ipu-v3: dp: fix CSC handling (bsc#1051510).
- spi: ST ST95HF NFC: declare missing of table (bsc#1051510).
- spi: Micrel eth switch: declare missing of table (bsc#1051510).
- iio: adc: xilinx: fix potential use-after-free on remove
  (bsc#1051510).
- HID: input: add mapping for "Toggle Display" key (bsc#1051510).
- HID: input: add mapping for keyboard Brightness Up/Down/Toggle
  keys (bsc#1051510).
- HID: input: add mapping for Expose/Overview key (bsc#1051510).
- Input: elan_i2c - add hardware ID for multiple Lenovo laptops
  (bsc#1051510).
- mISDN: Check address length before reading address family
  (bsc#1051510).
- nl80211: Add NL80211_FLAG_CLEAR_SKB flag for other NL commands
  (bsc#1051510).
- mac80211: fix memory accounting with A-MSDU aggregation
  (bsc#1051510).
- mac80211: fix unaligned access in mesh table hash function
  (bsc#1051510).
- ACPICA: Namespace: remove address node from global list after
  method termination (bsc#1051510).
- drm/rockchip: fix for mailbox read validation (bsc#1051510).
- vt: always call notifier with the console lock held
  (bsc#1051510).
- drm/i915: Disable LP3 watermarks on all SNB machines
  (bsc#1051510).
- devres: Align data[] to ARCH_KMALLOC_MINALIGN (bsc#1051510).
- drm/i915: Downgrade Gen9 Plane WM latency error (bsc#1051510).
- ACPICA: AML interpreter: add region addresses in global list
  during initialization (bsc#1051510).
- leds: pwm: silently error out on EPROBE_DEFER (bsc#1051510).
- commit a9825cc
* Fri May 17 2019 aaptel@suse.com
- cifs: don't show domain= in mount output when domain is empty (bsc#1144333).
- commit b8f2d8d
* Fri May 17 2019 aaptel@suse.com
- cifs: add missing support for ACLs in SMB 3.11 (bsc#1051510, bsc#1144333).
- commit 595ccf9
* Fri May 17 2019 aaptel@suse.com
- smb3: enumerating snapshots was leaving part of the data off end (bsc#1051510, bsc#1144333).
- commit 0c7ae4c
* Fri May 17 2019 aaptel@suse.com
- cifs: update smb2_queryfs() to use compounding (bsc#1144333).
- commit 485f10e
* Fri May 17 2019 aaptel@suse.com
- cifs: update receive_encrypted_standard to handle compounded responses (bsc#1144333).
- commit 880f97e
* Fri May 17 2019 aaptel@suse.com
- cifs: create SMB2_open_init()/SMB2_open_free() helpers (bsc#1144333).
- commit 84bdf43
* Fri May 17 2019 aaptel@suse.com
- cifs: add SMB2_query_info_[init|free]() (bsc#1144333).
- commit 8c47233
* Fri May 17 2019 aaptel@suse.com
- cifs: add SMB2_close_init()/SMB2_close_free() (bsc#1144333).
- commit 1ca2fcd
* Fri May 17 2019 aaptel@suse.com
- smb3: display stats counters for number of slow commands (bsc#1144333).
- commit b08a4cc
* Fri May 17 2019 aaptel@suse.com
- CIFS: fix uninitialized ptr deref in smb2 signing (bsc#1144333).
- commit 6c7e58e
* Fri May 17 2019 aaptel@suse.com
- smb3: Do not send SMB3 SET_INFO if nothing changed (bsc#1051510, bsc#1144333).
- commit 5268023
* Fri May 17 2019 aaptel@suse.com
- smb3: fix minor debug output for CONFIG_CIFS_STATS (bsc#1144333).
- commit 7dc7709
* Fri May 17 2019 aaptel@suse.com
- smb3: add tracepoint for slow responses (bsc#1144333).
- commit 5d9dd2d
* Fri May 17 2019 aaptel@suse.com
- cifs: add compound_send_recv() (bsc#1144333).
- commit 8f8adfe
* Fri May 17 2019 aaptel@suse.com
- cifs: make smb_send_rqst take an array of requests (bsc#1144333).
- commit 0e34c1e
* Fri May 17 2019 aaptel@suse.com
- cifs: update init_sg, crypt_message to take an array of rqst (bsc#1144333).
- commit f4403e5
* Fri May 17 2019 aaptel@suse.com
- smb3: fix reset of bytes read and written stats (bsc#1112906, bsc#1144333).
- commit d6ac362
* Fri May 17 2019 aaptel@suse.com
- smb3: display bytes_read and bytes_written in smb3 stats (bsc#1144333).
- commit 4fb8374
* Fri May 17 2019 aaptel@suse.com
- cifs: simple stats should always be enabled (bsc#1144333).
- commit 58de6f9
* Fri May 17 2019 aaptel@suse.com
- cifs: use a refcount to protect open/closing the cached file handle (bsc#1144333).
- commit 6c4f09e
* Fri May 17 2019 aaptel@suse.com
- smb3: add reconnect tracepoints (bsc#1144333).
- commit af16afc
* Fri May 17 2019 aaptel@suse.com
- smb3: add tracepoint for session expired or deleted (bsc#1144333).
- commit 9b0e1bc
* Fri May 17 2019 aaptel@suse.com
- cifs: remove unused stats (bsc#1144333).
- commit 911bb06
* Fri May 17 2019 aaptel@suse.com
- smb3: don't request leases in symlink creation and query (bsc#1051510, bsc#1144333).
- commit 22074db
* Fri May 17 2019 aaptel@suse.com
- smb3: remove per-session operations from per-tree connection stats (bsc#1144333).
- commit cbbc544
* Fri May 17 2019 aaptel@suse.com
- SMB3: Number of requests sent should be displayed for SMB3 not just CIFS (bsc#1144333).
- commit af0a3a0
* Fri May 17 2019 aaptel@suse.com
- smb3: snapshot mounts are read-only and make sure info is displayable about the mount (bsc#1144333).
- commit e3301d9
* Fri May 17 2019 aaptel@suse.com
- smb3: remove noisy warning message on mount (bsc#1129664, bsc#1144333).
- commit e4e3a6f
* Fri May 17 2019 aaptel@suse.com
- smb3: simplify code by removing CONFIG_CIFS_SMB311 (bsc#1051510, bsc#1144333).
- commit 149aeb7
* Fri May 17 2019 aaptel@suse.com
- cifs: add missing debug entries for kconfig options (bsc#1051510, bsc#1144333).
- commit 0ced478
* Fri May 17 2019 aaptel@suse.com
- smb3: add support for statfs for smb3.1.1 posix extensions (bsc#1144333).
- commit 4c29597
* Fri May 17 2019 aaptel@suse.com
- smb3: fill in statfs fsid and correct namelen (bsc#1112905, bsc#1144333).
- commit 2adf99a
* Fri May 17 2019 aaptel@suse.com
- cifs: Make sure all data pages are signed correctly (bsc#1144333).
- commit ae1c766
* Fri May 17 2019 aaptel@suse.com
- CIFS: fix memory leak and remove dead code (bsc#1144333).
- commit bf039a7
* Fri May 17 2019 aaptel@suse.com
- Update config files. - cifs: allow disabling insecure dialects in the config (bsc#1144333).
- commit 81bf3fd
* Fri May 17 2019 bp@suse.de
- Move stuff git_sort chokes on, out of the way
- commit 5cfd89f
* Fri May 17 2019 aaptel@suse.com
- cifs: Silence uninitialized variable warning (bsc#1144333).
- commit de882a0
* Fri May 17 2019 tiwai@suse.de
- media: davinci/vpbe: array underflow in vpbe_enum_outputs()
  (bsc#1051510).
- media: omap_vout: potential buffer overflow in vidioc_dqbuf()
  (bsc#1051510).
- media: atmel: atmel-isc: fix INIT_WORK misplacement
  (bsc#1051510).
- configfs: fix possible use-after-free in configfs_register_group
  (bsc#1051510).
- thermal: cpu_cooling: Actually trace CPU load in
  thermal_power_cpu_get_power (bsc#1051510).
- drm/bridge: adv7511: Fix low refresh rate selection
  (bsc#1051510).
- drm/i915/fbc: disable framebuffer compression on GeminiLake
  (bsc#1051510).
- crypto: caam - fix caam_dump_sg that iterates through
  scatterlist (bsc#1051510).
- commit 5537bec
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix stack out-of-bounds in smb{2,3}_create_lease_buf() (bsc#1051510, bsc#1144333).
- commit c1c1d92
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix infinite loop when using hard mount option (bsc#1091171, bsc#1144333).
- commit 9efe8de
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix slab-out-of-bounds in send_set_info() on SMB2 ACE setting (bsc#1144333).
- commit 9a088fc
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix memory leak in smb2_set_ea() (bsc#1051510, bsc#1144333).
- commit 5fd3308
* Fri May 17 2019 aaptel@suse.com
- cifs: fix SMB1 breakage (bsc#1144333).
- commit adca1c0
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix validation of signed data in smb2 (bsc#1144333).
- commit d78f0b2
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix validation of signed data in smb3+ (bsc#1144333).
- commit 636b9ed
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix use after free of a mid_q_entry (bsc#1112903, bsc#1144333).
- commit d47c2fb
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix invalid check in __cifs_calc_signature() (bsc#1144333).
- commit 59bb8ba
* Fri May 17 2019 aaptel@suse.com
- cifs: Use correct packet length in SMB2_TRANSFORM header (bsc#1144333).
- commit 5fdece5
* Fri May 17 2019 aaptel@suse.com
- smb3: fix corrupt path in subdirs on smb311 with posix (bsc#1144333).
- commit b47d93b
* Fri May 17 2019 aaptel@suse.com
- smb3: do not display empty interface list (bsc#1144333).
- commit 2055cf7
* Fri May 17 2019 aaptel@suse.com
- smb3: Fix mode on mkdir on smb311 mounts (bsc#1144333).
- commit 90640a7
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix kernel oops when traceSMB is enabled (bsc#1144333).
- commit a87cd36
* Fri May 17 2019 aaptel@suse.com
- CIFS: dump every session iface info (bsc#1144333).
- commit 3820321
* Fri May 17 2019 aaptel@suse.com
- CIFS: parse and store info on iface queries (bsc#1144333).
- commit 883e2c6
* Fri May 17 2019 aaptel@suse.com
- CIFS: add iface info to struct cifs_ses (bsc#1144333).
- commit a89b0a1
* Fri May 17 2019 aaptel@suse.com
- CIFS: complete PDU definitions for interface queries (bsc#1144333).
- commit c7ea237
* Fri May 17 2019 aaptel@suse.com
- CIFS: move default port definitions to cifsglob.h (bsc#1144333).
- commit cfa8ece
* Fri May 17 2019 aaptel@suse.com
- cifs: Fix encryption/signing (bsc#1144333).
- commit 613d27c
* Fri May 17 2019 aaptel@suse.com
- cifs: update __smb_send_rqst() to take an array of requests (bsc#1144333).
- commit 83f1d85
* Fri May 17 2019 aaptel@suse.com
- cifs: remove smb2_send_recv() (bsc#1144333).
- commit 27db550
* Fri May 17 2019 aaptel@suse.com
- cifs: push rfc1002 generation down the stack (bsc#1144333).
- commit 8bd128f
* Fri May 17 2019 dkirjanov@suse.com
- rxrpc: Fix transport sockopts to get IPv4 errors on an IPv6
  socket (git-fixes).
- l2tp: fix missing refcount drop in pppol2tp_tunnel_ioctl()
  (git-fixes).
- packet: reset network header if packet shorter than ll reserved
  space (git-fixes).
- packet: fix reserve calculation (git-fixes).
- commit 7586350
* Fri May 17 2019 aaptel@suse.com
- smb3: increase initial number of credits requested to allow write (bsc#1144333).
- commit cbc385b
* Fri May 17 2019 aaptel@suse.com
- cifs: add lease tracking to the cached root fid (bsc#1144333).
- commit 4161268
* Fri May 17 2019 aaptel@suse.com
- smb3: note that smb3.11 posix extensions mount option is experimental (bsc#1144333).
- commit 243da7f
* Fri May 17 2019 aaptel@suse.com
- cifs: fix a buffer leak in smb2_query_symlink (bsc#1144333).
- commit d2d3c97
* Fri May 17 2019 aaptel@suse.com
- smb3: do not allow insecure cifs mounts when using smb3 (bsc#1144333).
- commit b77ecfc
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix NULL ptr deref (bsc#1144333).
- commit 75d9c3f
* Fri May 17 2019 aaptel@suse.com
- CIFS: fix encryption in SMB3.1.1 (bsc#1144333).
- commit 26e5e5e
* Fri May 17 2019 aaptel@suse.com
- CIFS: Pass page offset for encrypting (bsc#1144333).
- commit 51f05ed
* Fri May 17 2019 aaptel@suse.com
- CIFS: Pass page offset for calculating signature (bsc#1144333).
- commit 89b986f
* Fri May 17 2019 aaptel@suse.com
- CIFS: SMBD: Support page offset in memory registration (bsc#1144333).
- commit 0417817
* Fri May 17 2019 aaptel@suse.com
- CIFS: SMBD: Support page offset in RDMA recv (bsc#1144333).
- commit 55e7820
* Fri May 17 2019 aaptel@suse.com
- CIFS: SMBD: Support page offset in RDMA send (bsc#1144333).
- commit ca0de2e
* Fri May 17 2019 aaptel@suse.com
- CIFS: When sending data on socket, pass the correct page offset (bsc#1144333).
- commit 0eeceff
* Fri May 17 2019 aaptel@suse.com
- CIFS: Introduce helper function to get page offset and length in smb_rqst (bsc#1144333).
- commit f2d5055
* Fri May 17 2019 aaptel@suse.com
- CIFS: Calculate the correct request length based on page offset and tail size (bsc#1144333).
- commit 6f34b00
* Fri May 17 2019 aaptel@suse.com
- cifs: For SMB2 security informaion query, check for minimum sized security descriptor instead of sizeof FileAllInformation class (bsc#1051510, bsc#1144333).
- commit 37d522c
* Fri May 17 2019 aaptel@suse.com
- CIFS: Fix signing for SMB2/3 (bsc#1144333).
- commit 9293199
* Fri May 17 2019 aaptel@suse.com
- CIFS: Add support for direct pages in wdata (bsc#1144333).
- commit e36f228
* Fri May 17 2019 aaptel@suse.com
- CIFS: Use offset when reading pages (bsc#1144333).
- commit 8ea50a8
* Fri May 17 2019 aaptel@suse.com
- CIFS: Add support for direct pages in rdata (bsc#1144333).
- commit 41826e1
* Fri May 17 2019 aaptel@suse.com
- cifs: update multiplex loop to handle compounded responses (bsc#1144333).
- commit ac6c32f
* Fri May 17 2019 aaptel@suse.com
- cifs: remove header_preamble_size where it is always 0 (bsc#1144333).
- commit a6b93f4
* Fri May 17 2019 aaptel@suse.com
- cifs: remove struct smb2_hdr (bsc#1144333).
- commit a3f4540
* Fri May 17 2019 aaptel@suse.com
- CIFS: check for STATUS_USER_SESSION_DELETED (bsc#1112902, bsc#1144333).
- commit 1f55e1b
* Fri May 17 2019 aaptel@suse.com
- cifs: change smb2_get_data_area_len to take a smb2_sync_hdr as argument (bsc#1144333).
- commit d1b33f4
* Fri May 17 2019 aaptel@suse.com
- cifs: update smb2_calc_size to use smb2_sync_hdr instead of smb2_hdr (bsc#1144333).
- commit 0fbe7bf
* Fri May 17 2019 aaptel@suse.com
- cifs: remove struct smb2_oplock_break_rsp (bsc#1144333).
- commit 037a8e6
* Fri May 17 2019 aaptel@suse.com
- cifs: remove rfc1002 header from all SMB2 response structures (bsc#1144333).
- commit aee5ad9
* Fri May 17 2019 aaptel@suse.com
- smb3: on reconnect set PreviousSessionId field (bsc#1112899, bsc#1144333).
- commit 58ac08c
* Fri May 17 2019 aaptel@suse.com
- smb3: Add posix create context for smb3.11 posix mounts (bsc#1144333).
- commit 21ca206
* Fri May 17 2019 aaptel@suse.com
- smb3: add tracepoints for smb2/smb3 open (bsc#1144333).
- commit d87d42b
* Fri May 17 2019 aaptel@suse.com
- cifs: add debug output to show nocase mount option (bsc#1144333).
- commit 12df628
* Fri May 17 2019 aaptel@suse.com
- smb3: add define for id for posix create context and corresponding struct (bsc#1144333).
- commit 51ec5ca
* Fri May 17 2019 aaptel@suse.com
- cifs: update smb2_check_message to handle PDUs without a 4 byte length header (bsc#1144333).
- commit 485cf67
* Fri May 17 2019 aaptel@suse.com
- smb3: allow posix mount option to enable new SMB311 protocol extensions (bsc#1144333).
- commit d10ae9f
* Fri May 17 2019 aaptel@suse.com
- smb3: add support for posix negotiate context (bsc#1144333).
- commit 369dc05
* Fri May 17 2019 aaptel@suse.com
- cifs: allow disabling less secure legacy dialects (bsc#1144333).
- commit bcccc76
* Fri May 17 2019 aaptel@suse.com
- cifs: make minor clarifications to module params for cifs.ko (bsc#1144333).
- commit d450bfd
* Fri May 17 2019 aaptel@suse.com
- cifs: show the w bit for writeable /proc/fs/cifs/* files (bsc#1144333).
- commit 135d482
* Fri May 17 2019 aaptel@suse.com
- smb3: add module alias for smb3 to cifs.ko (bsc#1144333).
- commit 72710bc
* Fri May 17 2019 aaptel@suse.com
- cifs: return error on invalid value written to cifsFYI (bsc#1144333).
- commit 5841f4f
* Fri May 17 2019 aaptel@suse.com
- cifs: invalidate cache when we truncate a file (bsc#1051510, bsc#1144333).
- commit 0f7776d
* Fri May 17 2019 aaptel@suse.com
- smb3: print tree id in debugdata in proc to be able to help logging (bsc#1144333).
- commit 647a749
* Fri May 17 2019 aaptel@suse.com
- smb3: add additional ftrace entry points for entry/exit to cifs.ko (bsc#1144333).
- commit cb9802c
* Fri May 17 2019 aaptel@suse.com
- smb3: fix various xid leaks (bsc#1051510, bsc#1144333).
- commit c7dbd56
* Fri May 17 2019 aaptel@suse.com
- CIFS: Introduce offset for the 1st page in data transfer structures (bsc#1144333).
- commit 97133e1
* Fri May 17 2019 aaptel@suse.com
- smb3: Add ftrace tracepoints for improved SMB3 debugging (bsc#1144333).
- commit e89fde2
* Fri May 17 2019 dkirjanov@suse.com
- netfilter: x_tables: initialise match/target check parameter
  struct (git-fixes).
- commit ab0a962
* Fri May 17 2019 dkirjanov@suse.com
- netfilter: ebtables: reject non-bridge targets (git-fixes).
- commit a3d82d8
* Fri May 17 2019 dkirjanov@suse.com
- ipvs: fix check on xmit to non-local addresses (git-fixes).
- commit c2a2828
* Fri May 17 2019 jdelvare@suse.de
- Refresh
  patches.suse/sched-do-not-re-read-h_load_next-during-hierarchical-load-calculation.patch.
  Add upstream reference and move to sorted section.
- commit e41744b
* Fri May 17 2019 jslaby@suse.cz
- bnxt_en: Reset device on RX buffer errors
  (networking-stable-19_04_10).
- bnxt_en: Improve RX consumer index validity check
  (networking-stable-19_04_10).
- tcp: Ensure DCTCP reacts to losses (networking-stable-19_04_10).
- net/sched: act_sample: fix divide by zero in the traffic path
  (networking-stable-19_04_10).
- net-gro: Fix GRO flush when receiving a GSO packet
  (networking-stable-19_04_10).
- ip6_tunnel: Match to ARPHRD_TUNNEL6 for dev type
  (networking-stable-19_04_10).
- sctp: initialize _pad of sockaddr_in before copying to user
  memory (networking-stable-19_04_10).
- net/sched: fix ->get helper of the matchall cls
  (networking-stable-19_04_10).
- vrf: check accept_source_route on the original netdevice
  (networking-stable-19_04_10).
- kABI: protect ip_options_rcv_srr (kabi).
- net/mlx5e: Add a lock on tir list (networking-stable-19_04_10).
- kABI: protect struct mlx5_td (kabi).
- net/mlx5e: Fix error handling when refreshing TIRs
  (networking-stable-19_04_10).
- net/mlx5: Decrease default mr cache size
  (networking-stable-19_04_10).
- net: ethtool: not call vzalloc for zero sized memory request
  (networking-stable-19_04_10).
- commit cb65757
* Fri May 17 2019 aaptel@suse.com
- smb3: rename encryption_required to smb3_encryption_required (bsc#1144333).
- commit 2a0a3c2
* Fri May 17 2019 aaptel@suse.com
- cifs: update internal module version number for cifs.ko to 2.12 (bsc#1144333).
- commit 709609c
* Fri May 17 2019 aaptel@suse.com
- cifs: add a new SMB2_close_flags function (bsc#1144333).
- commit 52233b5
* Fri May 17 2019 aaptel@suse.com
- cifs: store the leaseKey in the fid on SMB2_open (bsc#1051510, bsc#1144333).
- commit afdf64d
* Fri May 17 2019 aaptel@suse.com
- cifs: fix build break when CONFIG_CIFS_DEBUG2 enabled (bsc#1144333).
- commit d25b49e
* Fri May 17 2019 aaptel@suse.com
- cifs: update calc_size to take a server argument (bsc#1144333).
- commit 2aee34a
* Fri May 17 2019 aaptel@suse.com
- cifs: add server argument to the dump_detail method (bsc#1144333).
- commit 4ed0919
* Fri May 17 2019 aaptel@suse.com
- smb3: fix redundant opens on root (bsc#1144333).
- commit 6773807
* Fri May 17 2019 aaptel@suse.com
- smb3: directory sync should not return an error (bsc#1051510, bsc#1144333).
- commit 9d0b0b3
* Fri May 17 2019 aaptel@suse.com
- cifs: smb2ops: Fix listxattr() when there are no EAs (bsc#1051510, bsc#1144333).
- commit 7c12818
* Fri May 17 2019 aaptel@suse.com
- cifs: smbd: Enable signing with smbdirect (bsc#1144333).
- commit 0fbaf77
* Fri May 17 2019 aaptel@suse.com
- cifs: Allocate validate negotiation request through kmalloc (bsc#1144333).
- commit 0ebd97f
* Fri May 17 2019 aaptel@suse.com
- cifs: smbd: depend on INFINIBAND_ADDR_TRANS (bsc#1144333).
- commit 8792c7c
* Fri May 17 2019 aaptel@suse.com
- cifs: smbd: Avoid allocating iov on the stack (bsc#1144333).
- commit fd39a05
* Fri May 17 2019 aaptel@suse.com
- cifs: smbd: Don't use RDMA read/write when signing is used (bsc#1144333).
- commit 36f2bb8
* Fri May 17 2019 aaptel@suse.com
- SMB311: Fix reconnect (bsc#1051510, bsc#1144333).
- commit d72a275
* Fri May 17 2019 aaptel@suse.com
- SMB3: Fix 3.11 encryption to Windows and handle encrypted smb3 tcon (bsc#1051510, bsc#1144333).
- commit 63da32b
* Fri May 17 2019 aaptel@suse.com
- CIFS: set *resp_buf_type to NO_BUFFER on error (bsc#1144333).
- commit 9b9a753
* Fri May 17 2019 aaptel@suse.com
- CIFS: fix typo in cifs_dbg (bsc#1144333).
- commit 1c55bf5
* Fri May 17 2019 aaptel@suse.com
- cifs: do not allow creating sockets except with SMB1 posix exensions (bsc#1102097, bsc#1144333).
- commit 2bffbe2
* Thu May 16 2019 aaptel@suse.com
- cifs: smbd: Dump SMB packet when configured (bsc#1144333).
- commit d88f8ba
* Thu May 16 2019 aaptel@suse.com
- cifs: smb2ops: Fix NULL check in smb2_query_symlink (bsc#1144333).
- commit b04299f
* Thu May 16 2019 aaptel@suse.com
- cifs: change validate_buf to validate_iov (bsc#1144333).
- commit 906bd59
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 hardcoded constants from cifs_discard_remaining_data() (bsc#1144333).
- commit 617a6f7
* Thu May 16 2019 aaptel@suse.com
- cifs: Change SMB2_open to return an iov for the error parameter (bsc#1144333).
- commit dcb9625
* Thu May 16 2019 aaptel@suse.com
- cifs: add resp_buf_size to the mid_q_entry structure (bsc#1144333).
- commit b08c29d
* Thu May 16 2019 aaptel@suse.com
- smb3.11: replace a 4 with server->vals->header_preamble_size (bsc#1144333).
- commit 23fc514
* Thu May 16 2019 aaptel@suse.com
- cifs: replace a 4 with server->vals->header_preamble_size (bsc#1144333).
- commit a2ae2c9
* Thu May 16 2019 aaptel@suse.com
- cifs: add pdu_size to the TCP_Server_Info structure (bsc#1144333).
- commit 1640413
* Thu May 16 2019 aaptel@suse.com
- SMB311: Improve checking of negotiate security contexts (bsc#1051510, bsc#1144333).
- commit 5803906
* Thu May 16 2019 aaptel@suse.com
- SMB3: Fix length checking of SMB3.11 negotiate request (bsc#1051510, bsc#1144333).
- commit 5ab66c0
* Thu May 16 2019 aaptel@suse.com
- CIFS: add ONCE flag for cifs_dbg type (bsc#1144333).
- commit b6c0c4c
* Thu May 16 2019 aaptel@suse.com
- cifs: Use ULL suffix for 64-bit constant (bsc#1051510, bsc#1144333).
- commit 5c4894b
* Thu May 16 2019 aaptel@suse.com
- SMB3: Log at least once if tree connect fails during reconnect (bsc#1144333).
- commit 05b0e92
* Thu May 16 2019 aaptel@suse.com
- cifs: smb2pdu: Fix potential NULL pointer dereference (bsc#1144333).
- commit 3e43540
* Thu May 16 2019 aaptel@suse.com
- cifs: Add minor debug message during negprot (bsc#1144333).
- commit 3b41e0d
* Thu May 16 2019 aaptel@suse.com
- smb3: Fix root directory when server returns inode number of zero (bsc#1051510, bsc#1144333).
- commit de0d034
* Thu May 16 2019 aaptel@suse.com
- cifs: fix sparse warning on previous patch in a few printks (bsc#1144333).
- commit 56ce311
* Thu May 16 2019 aaptel@suse.com
- cifs: add server->vals->header_preamble_size (bsc#1144333).
- commit f31a0d1
* Thu May 16 2019 aaptel@suse.com
- cifs: smbd: disconnect transport on RDMA errors (bsc#1144333).
- commit a08f5ab
* Thu May 16 2019 aaptel@suse.com
- cifs: smbd: avoid reconnect lockup (bsc#1144333).
- commit 0d4f8de
* Thu May 16 2019 aaptel@suse.com
- Don't log confusing message on reconnect by default (bsc#1129664, bsc#1144333).
- commit c62a1eb
* Thu May 16 2019 aaptel@suse.com
- Don't log expected error on DFS referral request (bsc#1051510, bsc#1144333).
- commit 2b0ffdc
* Thu May 16 2019 aaptel@suse.com
- fs: cifs: Replace _free_xid call in cifs_root_iget function (bsc#1144333).
- commit 3c774ad
* Thu May 16 2019 aaptel@suse.com
- SMB3.1.1 dialect is no longer experimental (bsc#1051510, bsc#1144333).
- commit 5a7f288
* Thu May 16 2019 aaptel@suse.com
- Tree connect for SMB3.1.1 must be signed for non-encrypted shares (bsc#1051510, bsc#1144333).
- commit bbb7b0e
* Thu May 16 2019 aaptel@suse.com
- fix smb3-encryption breakage when CONFIG_DEBUG_SG=y (bsc#1051510, bsc#1144333).
- commit ce4ef54
* Thu May 16 2019 aaptel@suse.com
- CIFS: fix sha512 check in cifs_crypto_secmech_release (bsc#1051510, bsc#1144333).
- commit d700426
* Thu May 16 2019 aaptel@suse.com
- CIFS: implement v3.11 preauth integrity (bsc#1051510, bsc#1144333).
- commit 282e69b
* Thu May 16 2019 aaptel@suse.com
- CIFS: add sha512 secmech (bsc#1051510, bsc#1144333).
- commit dd1b0dc
* Thu May 16 2019 aaptel@suse.com
- CIFS: refactor crypto shash/sdesc allocation&free (bsc#1051510, bsc#1144333).
- commit 7c8cd7a
* Thu May 16 2019 aaptel@suse.com
- cifs: fix memory leak in SMB2_open() (bsc#1112894, bsc#1144333).
- commit 9a11d87
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: fix spelling mistake: faield and legnth (bsc#1144333).
- commit 656fc0e
* Thu May 16 2019 aaptel@suse.com
- Add missing structs and defines from recent SMB3.1.1 documentation (bsc#1144333).
- commit 561ad80
* Thu May 16 2019 aaptel@suse.com
- address lock imbalance warnings in smbdirect.c (bsc#1144333).
- commit 764cd6d
* Thu May 16 2019 aaptel@suse.com
- cifs: silence compiler warnings showing up with gcc-8.0.0 (bsc#1090734, bsc#1144333).
- commit b26e318
* Thu May 16 2019 aaptel@suse.com
- Add some missing debug fields in server and tcon structs (bsc#1144333).
- commit b13c148
* Thu May 16 2019 aaptel@suse.com
- fs/cifs/cifsacl.c Fixes typo in a comment (bsc#1144333).
- commit 8a9435e
* Thu May 16 2019 aaptel@suse.com
- update internal version number for cifs.ko (bsc#1144333).
- commit 4d4e098
* Thu May 16 2019 aaptel@suse.com
- cifs: add .splice_write (bsc#1144333).
- commit 53f3d14
* Thu May 16 2019 aaptel@suse.com
- CIFS: document tcon/ses/server refcount dance (bsc#1144333).
- commit 541127a
* Thu May 16 2019 aaptel@suse.com
- move a few externs to smbdirect.h to eliminate warning (bsc#1144333).
- commit 054495e
* Thu May 16 2019 aaptel@suse.com
- CIFS: zero sensitive data when freeing (bsc#1087092, bsc#1144333).
- commit c3f174d
* Thu May 16 2019 aaptel@suse.com
- Cleanup some minor endian issues in smb3 rdma (bsc#1144333).
- commit 204ad24
* Thu May 16 2019 aaptel@suse.com
- CIFS: dump IPC tcon in debug proc file (bsc#1071306, bsc#1144333).
- commit 4801bbd
* Thu May 16 2019 aaptel@suse.com
- CIFS: use tcon_ipc instead of use_ipc parameter of SMB2_ioctl (bsc#1071306, bsc#1144333).
- commit 2029687
* Thu May 16 2019 aaptel@suse.com
- CIFS: make IPC a regular tcon (bsc#1071306, bsc#1144333).
- commit 8c62a07
* Thu May 16 2019 aaptel@suse.com
- cifs: remove redundant duplicated assignment of pointer 'node' (bsc#1144333).
- commit 8633c07
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: work around gcc -Wmaybe-uninitialized warning (bsc#1144333).
- commit 660ab15
* Thu May 16 2019 aaptel@suse.com
- cifs: Fix autonegotiate security settings mismatch (bsc#1087092, bsc#1144333).
- commit 79bbb54
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: _smbd_get_connection() can be static (bsc#1144333).
- commit 3dbcabb
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Disable signing on SMB direct transport (bsc#1144333).
- commit d36304b
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Add SMB Direct debug counters (bsc#1144333).
- commit e42b986
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Upper layer performs SMB read via RDMA write through memory registration (bsc#1144333).
- commit 479e730
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Read correct returned data length for RDMA write (SMB read) I/O (bsc#1144333).
- commit 49800bf
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Upper layer performs SMB write via RDMA read through memory registration (bsc#1144333).
- commit 451ce23
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Implement RDMA memory registration (bsc#1144333).
- commit 4bd37fc
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Upper layer sends data via RDMA send (bsc#1144333).
- commit 5a756b5
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Implement function to send data via RDMA send (bsc#1144333).
- commit bb8535a
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Upper layer receives data via RDMA receive (bsc#1144333).
- commit a05b399
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Implement function to receive data via RDMA receive (bsc#1144333).
- commit 0fa64fd
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Set SMB Direct maximum read or write size for I/O (bsc#1144333).
- commit bac6317
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Upper layer destroys SMB Direct session on shutdown or umount (bsc#1144333).
- commit 840e7c9
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Implement function to destroy a SMB Direct connection (bsc#1144333).
- commit 8acee94
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Upper layer reconnects to SMB Direct session (bsc#1144333).
- commit ca6bb73
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Implement function to reconnect to a SMB Direct transport (bsc#1144333).
- commit 7414215
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Upper layer connects to SMBDirect session (bsc#1144333).
- commit 58ec5a4
* Thu May 16 2019 aaptel@suse.com
- cifs: fix build errors for SMB_DIRECT (bsc#1144333).
- commit a13a689
* Thu May 16 2019 aaptel@suse.com
- cifs: Fix missing put_xid in cifs_file_strict_mmap (bsc#1087092, bsc#1144333).
- commit 5026bae
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: export protocol initial values (bsc#1144333).
- commit 2a890ed
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Implement function to create a SMB Direct connection (bsc#1144333).
- commit 66b6d3f
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Establish SMB Direct connection (bsc#1144333).
- commit f9633ed
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Add SMB Direct protocol initial values and constants (bsc#1144333).
- commit 3761db5
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Add rdma mount option (bsc#1144333).
- commit ddce205
* Thu May 16 2019 aaptel@suse.com
- Update config files. - CIFS: SMBD: Introduce kernel config option CONFIG_CIFS_SMB_DIRECT (bsc#1144333).
- commit ef3de16
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Add parameter rdata to smb2_new_read_req (bsc#1144333).
- commit 564812c
* Thu May 16 2019 aaptel@suse.com
- cifs: avoid a kmalloc in smb2_send_recv/SendReceive2 for the common case (bsc#1144333).
- commit ddfa27a
* Thu May 16 2019 aaptel@suse.com
- cifs: remove small_smb2_init (bsc#1144333).
- commit 42e787c
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_lease_ack (bsc#1144333).
- commit 9c703a7
* Thu May 16 2019 aaptel@suse.com
- cifs: remove unused variable from SMB2_read (bsc#1144333).
- commit a657e0f
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_oplock_break we get from server (bsc#1144333).
- commit 3b9f330
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_query_info_req (bsc#1144333).
- commit 419a2f6
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_query_directory_req (bsc#1144333).
- commit 31d741a
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_set_info_req (bsc#1144333).
- commit 8c059cb
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2 read/write requests (bsc#1144333).
- commit 9c3fb1c
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_lock_req (bsc#1144333).
- commit a519c85
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_flush_req (bsc#1144333).
- commit 7de26aa
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_create_req (bsc#1144333).
- commit 67e2e5a
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_sess_setup_req (bsc#1144333).
- commit 95aacf9
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_tree_connect_req (bsc#1144333).
- commit e0421bc
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_echo_req (bsc#1144333).
- commit ce0258d
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_ioctl_req (bsc#1144333).
- commit 4f10855
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_close_req (bsc#1144333).
- commit 1068bff
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_tree_disconnect_req (bsc#1144333).
- commit d3a1bc0
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_logoff_req (bsc#1144333).
- commit 3c2c6eb
* Thu May 16 2019 aaptel@suse.com
- cifs: remove rfc1002 header from smb2_negotiate_req (bsc#1144333).
- commit 7b194b5
* Thu May 16 2019 aaptel@suse.com
- cifs: Add smb2_send_recv (bsc#1144333).
- commit 135336f
* Thu May 16 2019 aaptel@suse.com
- fs/*/Kconfig: drop links to 404-compliant http://acl.bestbits.at (bsc#1144333).
- commit 9069308
* Thu May 16 2019 aaptel@suse.com
- CIFS: don't log STATUS_NOT_FOUND errors for DFS (bsc#1051510, bsc#1144333).
- commit 9260aad
* Thu May 16 2019 aaptel@suse.com
- cifs: fix NULL deref in SMB2_read (bsc#1085539, bsc#1144333).
- commit 74c4a72
* Thu May 16 2019 aaptel@suse.com
- cifs: check MaxPathNameComponentLength != 0 before using it (bsc#1085536, bsc#1144333).
- commit 7c39678
* Thu May 16 2019 aaptel@suse.com
- SMB3: Validate negotiate request must always be signed (bsc#1064597, bsc#1144333).
- commit 6a20e8b
* Thu May 16 2019 aaptel@suse.com
- SMB: fix validate negotiate info uninitialised memory use (bsc#1064597, bsc#1144333).
- commit 8350eb9
* Thu May 16 2019 aaptel@suse.com
- SMB: fix leak of validate negotiate info response buffer (bsc#1064597, bsc#1144333).
- commit 540580e
* Thu May 16 2019 aaptel@suse.com
- CIFS: Fix NULL pointer deref on SMB2_tcon() failure (bsc#1071009, bsc#1144333).
- commit 1d3a9de
* Thu May 16 2019 aaptel@suse.com
- CIFS: do not send invalid input buffer on QUERY_INFO requests (bsc#1144333).
- commit 6f46fd8
* Thu May 16 2019 aaptel@suse.com
- cifs: Select all required crypto modules (bsc#1085536, bsc#1144333).
- commit bd44e1c
* Thu May 16 2019 aaptel@suse.com
- CIFS: SMBD: Fix the definition for SMB2_CHANNEL_RDMA_V1_INVALIDATE (bsc#1144333).
- commit da19369
* Thu May 16 2019 aaptel@suse.com
- cifs: handle large EA requests more gracefully in smb2+ (bsc#1144333).
- commit 510e996
* Thu May 16 2019 aaptel@suse.com
- Fix encryption labels and lengths for SMB3.1.1 (bsc#1085536, bsc#1144333).
- commit 7fceff4
* Thu May 16 2019 aaptel@suse.com
- SMB3: Don't ignore O_SYNC/O_DSYNC and O_DIRECT flags (bsc#1085536, bsc#1144333).
- commit 4a9b75c
* Thu May 16 2019 aaptel@suse.com
- SMB3: handle new statx fields (bsc#1085536, bsc#1144333).
- commit bc2d9a1
* Thu May 16 2019 aaptel@suse.com
- SMB: Validate negotiate (to protect against downgrade) even if signing off (bsc#1085536, bsc#1144333).
- commit c098efa
* Thu May 16 2019 aaptel@suse.com
- cifs: release auth_key.response for reconnect (bsc#1085536, bsc#1144333).
- commit d8cd1cf
* Thu May 16 2019 aaptel@suse.com
- cifs: release cifs root_cred after exit_cifs (bsc#1085536, bsc#1144333).
- commit 5715b1a
* Thu May 16 2019 aaptel@suse.com
- CIFS: make arrays static const, reduces object code size (bsc#1144333).
- commit 023cf87
* Thu May 16 2019 aaptel@suse.com
- Update session and share information displayed for debugging SMB2/SMB3 (bsc#1144333).
- commit 61e32f7
* Thu May 16 2019 aaptel@suse.com
- cifs: show 'soft' in the mount options for hard mounts (bsc#1144333).
- commit e189fd2
* Thu May 16 2019 aaptel@suse.com
- SMB3: Warn user if trying to sign connection that authenticated as guest (bsc#1085536, bsc#1144333).
- commit b1d1dac
* Thu May 16 2019 aaptel@suse.com
- SMB3: Fix endian warning (bsc#1144333, bsc#1137884).
- commit 547afff
* Thu May 16 2019 aaptel@suse.com
- Fix SMB3.1.1 guest authentication to Samba (bsc#1085536, bsc#1144333).
- commit 61fb84c
* Thu May 16 2019 aaptel@suse.com
- Update version of cifs module (bsc#1144333).
- commit efad703
* Thu May 16 2019 aaptel@suse.com
- cifs: hide unused functions (bsc#1051510, bsc#1144333).
- commit d7281cb
* Thu May 16 2019 aaptel@suse.com
- SMB3: Add support for multidialect negotiate (SMB2.1 and later) (bsc#1051510, bsc#1144333).
- commit 3e420d7
* Thu May 16 2019 aaptel@suse.com
- cifs: check rsp for NULL before dereferencing in SMB2_open (bsc#1085536, bsc#1144333).
- commit 50c89fb
* Thu May 16 2019 aaptel@suse.com
- cifs: Check for timeout on Negotiate stage (bsc#1091171, bsc#1144333).
- commit 8c908c7
* Thu May 16 2019 aaptel@suse.com
- cifs: Add support for writing attributes on SMB2+ (bsc#1051510, bsc#1144333).
- commit bf83c0c
* Thu May 16 2019 aaptel@suse.com
- cifs: Add support for reading attributes on SMB2+ (bsc#1051510, bsc#1144333).
- commit a06eeb8
* Thu May 16 2019 aaptel@suse.com
- Fix warning messages when mounting to older servers (bsc#1144333).
- commit 093dfa2
* Thu May 16 2019 aaptel@suse.com
- Improve security, move default dialect to SMB3 from old CIFS (bsc#1051510, bsc#1144333).
- commit 1dbc35c
* Thu May 16 2019 aaptel@suse.com
- Remove ifdef since SMB3 (and later) now STRONGLY preferred (bsc#1051510, bsc#1144333).
- commit 03819a9
* Thu May 16 2019 aaptel@suse.com
- CIFS: Reconnect expired SMB sessions (bnc#1060662).
- commit a6b3714
* Thu May 16 2019 aaptel@suse.com
- Delete patches.kernel.org/4.12.4-101-CIFS-Reconnect-expired-SMB-sessions.patch.
- commit 6ca54d2
* Thu May 16 2019 dkirjanov@suse.com
- ipv6: mcast: fix unsolicited report interval after receiving querys (git-fixes).
- l2tp: filter out non-PPP sessions in pppol2tp_tunnel_ioctl() (git-fixes).
- l2tp: prevent pppol2tp_connect() from creating kernel sockets (git-fixes).
- l2tp: only accept PPP sessions in pppol2tp_connect() (git-fixes).
- netfilter: nf_tables: check msg_type before nft_trans_set(trans) (git-fixes).
- ip_tunnel: Fix name string concatenate in __ip_tunnel_create() (git-fixes).
- sctp: fix identification of new acks for SFR-CACC (git-fixes).
- xfrm6: avoid potential infinite loop in _decode_session6() (git-fixes).
- ipvs: fix buffer overflow with sync daemon and service (git-fixes).
- netfilter: ebtables: handle string from userspace with care (git-fixes).
- netfilter: nf_tables: fix NULL pointer dereference on nft_ct_helper_obj_dump() (git-fixes).
- net: Fix a bug in removing queues from XPS map (git-fixes).
- net: test tailroom before appending to linear skb (git-fixes).
- tcp: purge write queue in tcp_connect_init() (git-fixes).
- ipvs: fix stats update from local clients (git-fixes).
- packet: in packet_snd start writing at link layer allocation (git-fixes).
- rxrpc: Fix error reception on AF_INET6 sockets (git-fixes).
- netfilter: nf_tables: can't fail after linking rule into active rule list (git-fixes).
- ipvs: fix rtnl_lock lockups caused by start_sync_thread (git-fixes).
- inetpeer: fix uninit-value in inet_getpeer (git-fixes).
- net: fix uninit-value in __hw_addr_add_ex() (git-fixes).
- net: initialize skb->peeked when cloning (git-fixes).
- fix rtnh_ok() (git-fixes).
- netlink: fix uninit-value in netlink_sendmsg (git-fixes).
- commit a03d3d8
* Thu May 16 2019 aaptel@suse.com
- CIFS: Display SMB2 error codes in the hex format (bsc#1144333).
- commit db41c2a
* Thu May 16 2019 aaptel@suse.com
- cifs: Use smb 2 - 3 and cifsacl mount options setacl function (bsc#1051510, bsc#1144333).
- commit 0778119
* Thu May 16 2019 aaptel@suse.com
- cifs: prototype declaration and definition to set acl for smb 2 - 3 and cifsacl mount options (bsc#1051510, bsc#1144333).
- commit a71ef22
* Thu May 16 2019 aaptel@suse.com
- CIFS: fix circular locking dependency (bsc#1064701, bsc#1144333).
- commit 0594876
* Thu May 16 2019 aaptel@suse.com
- cifs: set oparms.create_options rather than or'ing in CREATE_OPEN_BACKUP_INTENT (bsc#1144333).
- commit a9243fa
* Thu May 16 2019 aaptel@suse.com
- cifs: Do not modify mid entry after submitting I/O in cifs_call_async (bsc#1051510, bsc#1144333).
- commit 3f97012
* Thu May 16 2019 aaptel@suse.com
- CIFS: add SFM mapping for 0x01-0x1F (bsc#1144333).
- commit 79a8706
* Thu May 16 2019 aaptel@suse.com
- cifs: hide unused functions (bsc#1051510, bsc#1144333).
- commit 33c52ee
* Thu May 16 2019 aaptel@suse.com
- cifs: Use smb 2 - 3 and cifsacl mount options getacl functions (bsc#1051510, bsc#1144333).
- commit 68ab5bd
* Thu May 16 2019 aaptel@suse.com
- cifs: prototype declaration and definition for smb 2 - 3 and cifsacl mount options (bsc#1051510, bsc#1144333).
- commit f2e25c6
* Thu May 16 2019 aaptel@suse.com
- Update config files. - CIFS: add CONFIG_CIFS_DEBUG_KEYS to dump encryption keys (bsc#1144333).
- commit 040aef8
* Thu May 16 2019 aaptel@suse.com
- cifs: set mapping error when page writeback fails in writepage or launder_pages (bsc#1144333).
- commit 73b6484
* Thu May 16 2019 jack@suse.cz
- mm/huge_memory: fix vmf_insert_pfn_{pmd, pud}() crash, handle
  unaligned addresses (bsc#1135330).
- commit 545b409
* Thu May 16 2019 jack@suse.cz
- blacklist.conf: Blacklist 7959cf3a7506, 988bec41318f, and 9ca2d7326444
- commit e060719
* Thu May 16 2019 jack@suse.cz
- ufs: fix braino in ufs_get_inode_gid() for solaris UFS flavour
  (bsc#1135323).
- blacklist.conf: Blacklist 0bf3d5c1604e, a5fdd713d256, and 71921ef85928
- commit 447e9de
* Thu May 16 2019 jack@suse.cz
- block: fix the return errno for direct IO (bsc#1135320).
- commit 7a5620b
* Thu May 16 2019 jack@suse.cz
- blacklist.conf: Blacklist b01531db6cec
- commit 584e057
* Thu May 16 2019 hare@suse.de
- nvme: flush scan_work when resetting controller (bsc#1131673).
- nvme: Do not remove namespaces during reset (bsc#1131673).
- commit 5170dea
* Thu May 16 2019 jack@suse.cz
- ext4: fix ext4_show_options for file systems w/o journal
  (bsc#1135316).
- commit 29b8927
* Thu May 16 2019 jack@suse.cz
- ext4: actually request zeroing of inode table after grow
  (bsc#1135315).
- commit a868c67
* Thu May 16 2019 jack@suse.cz
- ext4: fix use-after-free race with debug_want_extra_isize
  (bsc#1135314).
- commit 5eca021
* Thu May 16 2019 hare@suse.de
- block: Don't revalidate bdev of hidden gendisk (bsc#1120091).
- Refresh patches.kabi/kabi-fix-for-check_disk_size_change.patch.
- commit 8dce5a6
* Thu May 16 2019 jack@suse.cz
- block: fix use-after-free on gendisk (bsc#1135312).
- commit c63ecfb
* Thu May 16 2019 jack@suse.cz
- block: do not leak memory in bio_copy_user_iov() (bsc#1135309).
- commit 179d24e
* Thu May 16 2019 tiwai@suse.de
- Update patch reference for ipmi_ssif fix (bsc#1135120)
- commit b30d5bf
* Thu May 16 2019 tiwai@suse.de
- Update patch tag for i915 security fix (CVE-2019-11085, bsc#1135278).
- commit c9240fa
* Wed May 15 2019 aaptel@suse.com
- CIFS: keep FileInfo handle live during oplock break
  (bsc#1106284, bsc#1131565).
- commit 057abeb
* Wed May 15 2019 tiwai@suse.de
- backlight: lm3630a: Return 0 on success in update_status
  functions (bsc#1051510).
- PCI: Mark Atheros AR9462 to avoid bus reset (bsc#1051510).
- PCI: Mark AMD Stoney Radeon R7 GPU ATS as broken (bsc#1051510).
- commit ce79740
* Wed May 15 2019 tiwai@suse.de
- Move MDS patches into sorted section, too
  Also update/correct the patch tags
- commit c2d6df0
* Wed May 15 2019 tiwai@suse.de
- Move upstreamed nvme and powerpc patches to sorted section
- commit c1e9c04
* Wed May 15 2019 wqu@suse.com
- btrfs: qgroup: Don't scan leaf if we're modifying reloc  tree
  (bsc#1063638 bsc#1128052 bsc#1108838).
- commit 81e4693
* Wed May 15 2019 wqu@suse.com
- btrfs: extent-tree: Use btrfs_ref to refactor
  btrfs_free_extent() (bsc#1063638 bsc#1128052 bsc#1108838).
- commit ec353a9
* Wed May 15 2019 wqu@suse.com
- btrfs: extent-tree: Use btrfs_ref to refactor
  btrfs_inc_extent_ref() (bsc#1063638 bsc#1128052 bsc#1108838).
- Refresh
  patches.suse/0001-btrfs-extent-tree-Fix-a-bug-that-btrfs-is-unable-to-.patch.
- commit c0ee85b
* Wed May 15 2019 wqu@suse.com
- btrfs: extent-tree: Fix a bug that btrfs is unable to add
  pinned bytes (bsc#1063638 bsc#1128052 bsc#1108838).
- commit 37707c4
* Wed May 15 2019 wqu@suse.com
- btrfs: extent-tree: Use btrfs_ref to refactor
  add_pinned_bytes() (bsc#1063638 bsc#1128052 bsc#1108838).
- commit f19a7ab
* Wed May 15 2019 wqu@suse.com
- btrfs: delayed-ref: Use btrfs_ref to refactor
  btrfs_add_delayed_data_ref() (bsc#1063638 bsc#1128052
  bsc#1108838).
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit 5959973
* Wed May 15 2019 wqu@suse.com
- btrfs: delayed-ref: Use btrfs_ref to refactor
  btrfs_add_delayed_tree_ref() (bsc#1063638 bsc#1128052
  bsc#1108838).
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit eedfcc9
* Tue May 14 2019 tiwai@suse.de
- Revert "drm/sun4i: rgb: Change the pixel clock validation check (bnc#1113722)"
  The patch seems buggy, breaks the build for armv7hl/pae config.
- commit 7e3fe35
* Tue May 14 2019 msuchanek@suse.de
- net/ibmvnic: Update carrier state after link state change
  (bsc#1135100).
- commit 620e16c
* Tue May 14 2019 msuchanek@suse.de
- net/ibmvnic: Update MAC address settings after adapter reset
  (bsc#1134760).
- commit 9e9fbf7
* Tue May 14 2019 msuchanek@suse.de
- Refresh patches.fixes/nvme-multipath-avoid-crash-on-invalid-subsystem-cntl.patch.
  Fix commit id.
- commit 480e4e0
* Tue May 14 2019 fabian.baumanis@suse.com
- dt-bindings: net: Fix a typo in the phy-mode list for ethernet
  bindings (bsc#1129770).
- commit ce908a0
* Tue May 14 2019 tzimmermann@suse.de
- drm/ttm: Remove warning about inconsistent mapping information (bnc#1131488)
- commit 3b2528e
* Tue May 14 2019 wqu@suse.com
- btrfs: split delayed ref head initialization and addition
  (bsc#1134813).
- Refresh
  patches.fixes/0001-btrfs-qgroup-Move-reserved-data-accounting-from-btrf.patch.
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit a52dcc3
* Tue May 14 2019 hare@suse.de
- lpfc: validate command in lpfc_sli4_scmd_to_wqidx_distr()
  (bsc#1129138).
- commit c255cb4
* Tue May 14 2019 tiwai@suse.de
- phy: sun4i-usb: Make sure to disable PHY0 passby for peripheral
  mode (bsc#1051510).
- commit e14e420
* Tue May 14 2019 tiwai@suse.de
- vfio/mdev: Fix aborting mdev child device removal if one fails
  (bsc#1051510).
- vfio/mdev: Avoid release parent reference during error path
  (bsc#1051510).
- vfio/pci: use correct format characters (bsc#1051510).
- vsock/virtio: fix kernel panic from
  virtio_transport_reset_no_sock (bsc#1051510).
- vsock/virtio: reset connected sockets on device removal
  (bsc#1051510).
- vsock/virtio: fix kernel panic after device hot-unplug
  (bsc#1051510).
- vhost/vsock: fix reset orphans race with close timeout
  (bsc#1051510).
- commit df62ff0
* Tue May 14 2019 wqu@suse.com
- btrfs: Use init_delayed_ref_head in add_delayed_ref_head
  (bsc#1134813).
- Refresh
  patches.fixes/0001-btrfs-qgroup-Move-reserved-data-accounting-from-btrf.patch.
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit 07fe730
* Tue May 14 2019 wqu@suse.com
- btrfs: Introduce init_delayed_ref_head (bsc#1134813).
- Refresh
  patches.fixes/0001-btrfs-qgroup-Move-reserved-data-accounting-from-btrf.patch.
- commit 4ef0b81
* Tue May 14 2019 jroedel@suse.de
- iommu/vt-d: Make kernel parameter igfx_off work with vIOMMU
  (bsc#1135007).
- iommu/vt-d: Set intel_iommu_gfx_mapped correctly (bsc#1135008).
- iommu/vt-d: Don't request page request irq under
  dmar_global_lock (bsc#1135006).
- commit caca066
* Tue May 14 2019 wqu@suse.com
- btrfs: Open-code add_delayed_data_ref (bsc#1134813).
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit 3fb7e15
* Tue May 14 2019 tiwai@suse.de
- sc16is7xx: put err_spi and err_i2c into correct #ifdef
  (bsc#1051510).
- sc16is7xx: move label 'err_spi' to correct section
  (bsc#1051510).
- commit ef2d000
* Tue May 14 2019 mkubecek@suse.cz
- net: rds: force to destroy connection if t_sock is NULL in
  rds_tcp_kill_sock() (CVE-2019-11815 bsc#1134537).
- commit 1f4fdb2
* Tue May 14 2019 wqu@suse.com
- btrfs: Open-code add_delayed_tree_ref (bsc#1134813).
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit 2231136
* Tue May 14 2019 wqu@suse.com
- btrfs: Use init_delayed_ref_common in  add_delayed_data_ref
  (bsc#1134813).
- commit 50b6855
* Tue May 14 2019 wqu@suse.com
- btrfs: Use init_delayed_ref_common in  add_delayed_tree_ref
  (bsc#1134813).
- commit 3cf5280
* Tue May 14 2019 wqu@suse.com
- btrfs: Factor out common delayed refs init code (bsc#1134813).
- commit ce2a0bd
* Tue May 14 2019 wqu@suse.com
- btrfs: track refs in a rb_tree instead of a list (bsc#1134813).
- Refresh
  patches.suse/btrfs-Take-trans-lock-before-access-running-trans-in.patch.
- Refresh
  patches.suse/btrfs-fix-race-condition-between-delayed-refs-and-blockgroup-removal.patch.
- commit 1e5b754
* Tue May 14 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/opregion: rvda is relative from opregion base in opregion 2.1+'
- commit c35b08b
* Tue May 14 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/opregion: fix version check'
- commit 34cf39c
* Tue May 14 2019 tzimmermann@suse.de
- drm/meson: add size and alignment requirements for dumb buffers (bnc#1113722)
- commit 4a07be1
* Tue May 14 2019 tzimmermann@suse.de
- drm/i915/gvt: Fix incorrect mask of mmio 0x22028 in gen8/9 mmio list (bnc#1113722)
- commit 25e583c
* Tue May 14 2019 tzimmermann@suse.de
- drm/sun4i: rgb: Change the pixel clock validation check (bnc#1113722)
- commit 287e07e
* Mon May 13 2019 mwilck@suse.com
- Update config files: disable CONFIG_IDE on ppc64le
- commit 236e2cc
* Mon May 13 2019 tiwai@suse.de
- vfio_pci: Enable memory accesses before calling pci_map_rom
  (bsc#1051510).
- commit 40fa4f3
* Mon May 13 2019 tiwai@suse.de
- virtio-blk: limit number of hw queues by nr_cpu_ids
  (bsc#1051510).
- virtio: Honour 'may_reduce_num' in vring_create_virtqueue
  (bsc#1051510).
- virtio_pci: fix a NULL pointer reference in vp_del_vqs
  (bsc#1051510).
- commit e8aa979
* Mon May 13 2019 tiwai@suse.de
- sc16is7xx: missing unregister/delete driver on error in
  sc16is7xx_init() (bsc#1051510).
- spi: a3700: Clear DATA_OUT when performing a read (bsc#1051510).
- commit 8e9ab9a
* Mon May 13 2019 tiwai@suse.de
- pwm: meson: Use the spin-lock only to protect register
  modifications (bsc#1051510).
- pwm: meson: Don't disable PWM when setting duty repeatedly
  (bsc#1051510).
- pwm: meson: Consider 128 a valid pre-divider (bsc#1051510).
- pwm: tiehrpwm: Update shadow register for disabling PWMs
  (bsc#1051510).
- pwm: Fix deadlock warning when removing PWM device
  (bsc#1051510).
- commit eb64e0b
* Mon May 13 2019 tiwai@suse.de
- proc/sysctl: fix return error for proc_doulongvec_minmax()
  (bsc#1051510).
- proc/kcore: don't bounds check against address 0 (bsc#1051510).
- proc: revalidate kernel thread inodes to root:root
  (bsc#1051510).
- commit 65ec978
* Mon May 13 2019 tiwai@suse.de
- linux/kernel.h: Use parentheses around argument in
  u64_to_user_ptr() (bsc#1051510).
- commit ce6d021
* Mon May 13 2019 tiwai@suse.de
- omapfb: add missing of_node_put after of_device_is_available
  (bsc#1051510).
- commit d60e431
* Mon May 13 2019 tiwai@suse.de
- mtd: part: fix incorrect format specifier for an unsigned long
  long (bsc#1051510).
- mtd: nand: omap: Fix comment in platform data using wrong
  Kconfig symbol (bsc#1051510).
- mtd: docg3: fix a possible memory leak of mtd->name
  (bsc#1051510).
- mtd: docg3: Fix passing zero to 'PTR_ERR' warning in
  doc_probe_device (bsc#1051510).
- commit d8f4906
* Mon May 13 2019 tiwai@suse.de
- media: vivid: use vfree() instead of kfree() for dev->bitmap_cap
  (bsc#1051510).
- media: ov2659: fix unbalanced mutex_lock/unlock (bsc#1051510).
- media: wl128x: prevent two potential buffer overflows
  (bsc#1051510).
- media: tw5864: Fix possible NULL pointer dereference in
  tw5864_handle_frame (bsc#1051510).
- media: davinci-isif: avoid uninitialized variable use
  (bsc#1051510).
- media: serial_ir: Fix use-after-free in serial_ir_init_module
  (bsc#1051510).
- media: cx23885: check allocation return (bsc#1051510).
- media: wl128x: Fix an error code in fm_download_firmware()
  (bsc#1051510).
- media: cx18: update *pos correctly in cx18_read_pos()
  (bsc#1051510).
- media: ivtv: update *pos correctly in ivtv_read_pos()
  (bsc#1051510).
- commit a5d9aa0
* Mon May 13 2019 tiwai@suse.de
- kernel/sysctl.c: fix out-of-bounds access when setting file-max
  (bsc#1051510).
- kernel/sysctl.c: add missing range check in
  do_proc_dointvec_minmax_conv (bsc#1051510).
- commit 5ac58a3
* Mon May 13 2019 tiwai@suse.de
- drm/rockchip: shutdown drm subsystem on shutdown (bsc#1051510).
- drm/fb-helper: dpms_legacy(): Only set on connectors in use
  (bsc#1051510).
- drm/i915: Fix I915_EXEC_RING_MASK (bsc#1051510).
- drm/mediatek: fix possible object reference leak (bsc#1051510).
- commit 57b1ae5
* Mon May 13 2019 vbabka@suse.cz
- mm: prevent get_user_pages() from overflowing page refcount
  (CVE-2019-11487, bsc#1133190).
- mm: add 'try_get_page()' helper function (CVE-2019-11487,
  bsc#1133190).
- mm: make page ref count overflow check tighter and more explicit
  (CVE-2019-11487, bsc#1133190).
- commit 3ccf631
* Mon May 13 2019 tiwai@suse.de
- ASoC: Intel: avoid Oops if DMA setup fails (bsc#1051510).
- ASoC: fix valid stream condition (bsc#1051510).
- ASoC: tlv320aic32x4: Fix Common Pins (bsc#1051510).
- ASoC: cs4270: Set auto-increment bit for register writes
  (bsc#1051510).
- ASoC: wm_adsp: Add locking to wm_adsp2_bus_error (bsc#1051510).
- ASoC: samsung: odroid: Fix clock configuration for 44100 sample
  rate (bsc#1051510).
- ASoC: nau8810: fix the issue of widget with prefixed name
  (bsc#1051510).
- ASoC: nau8824: fix the issue of the widget with prefix name
  (bsc#1051510).
- ASoC:soc-pcm:fix a codec fixup issue in TDM case (bsc#1051510).
- ASoC: hdmi-codec: fix S/PDIF DAI (bsc#1051510).
- commit 1a2b4f8
* Mon May 13 2019 vbabka@suse.cz
- mm, gup: ensure real head page is ref-counted when using
  hugepages (CVE-2019-11487, bsc#1133190, prerequisity).
- Refresh patches.fixes/mm-fix-__gup_device_huge-vs-unmap.patch.
- commit 2aa1b48
* Mon May 13 2019 vbabka@suse.cz
- mm, gup: remove broken VM_BUG_ON_PAGE compound check for
  hugepages (CVE-2019-11487, bsc#1133190, prerequisity).
- commit a4548d7
* Mon May 13 2019 oneukum@suse.com
- mtd: spi-nor: intel-spi: Avoid crossing 4K address boundary
  on read/write (bsc#1129770).
- commit 79ff3e5
* Mon May 13 2019 oneukum@suse.com
- media: pvrusb2: Prevent a buffer overflow (bsc#1129770).
- commit 7a54ecd
* Mon May 13 2019 tiwai@suse.de
- Update patch tag for refecence (CVE-2019-11884, bsc#1134848).
- commit e12f3fe
* Mon May 13 2019 tiwai@suse.de
- Revert "tty: pty: Fix race condition between release_one_tty
  and pty_write" (bsc#1051510).
- usb-storage: Set virt_boundary_mask to avoid SG overflows
  (bsc#1051510).
- commit 875ce44
* Mon May 13 2019 tiwai@suse.de
- platform/x86: sony-laptop: Fix unintentional fall-through
  (bsc#1051510).
- platform/x86: alienware-wmi: printing the wrong error code
  (bsc#1051510).
- platform/x86: intel_punit_ipc: Revert "Fix resource ioremap
  warning" (bsc#1051510).
- platform/x86: intel_pmc_ipc: adding error handling
  (bsc#1051510).
- platform/x86: dell-rbtn: Add missing #include (bsc#1051510).
- clk: rockchip: Fix video codec clocks on rk3288 (bsc#1051510).
- clk: rockchip: fix wrong clock definitions for rk3328
  (bsc#1051510).
- dmaengine: tegra210-dma: free dma controller in remove()
  (bsc#1051510).
- dmaengine: axi-dmac: Don't check the number of frames for
  alignment (bsc#1051510).
- dwc2: gadget: Fix completed transfer size calculation in DDMA
  (bsc#1051510).
- ssb: Fix possible NULL pointer dereference in
  ssb_host_pcmcia_exit (bsc#1051510).
- Bluetooth: Align minimum encryption key size for LE and BR/EDR
  connections (bsc#1051510).
- Bluetooth: hidp: fix buffer overflow (bsc#1051510).
- intel_th: pci: Add Comet Lake support (bsc#1051510).
- commit e11b282
* Mon May 13 2019 mwilck@suse.com
- blacklist.conf: add drivers/ide
  We haven't been shipping IDE drivers since SLE12
- commit 8dce52a
* Mon May 13 2019 tiwai@suse.de
- ALSA: emu10k1: Drop superfluous id-uniquification behavior
  (bsc#1051510).
- commit c156a88
* Mon May 13 2019 tiwai@suse.de
- Re-export snd_cards for kABI compatibility (bsc#1051510).
- commit 78cf440
* Mon May 13 2019 tiwai@suse.de
- ALSA: core: Don't refer to snd_cards array directly
  (bsc#1051510).
- commit 1501d4d
* Mon May 13 2019 tiwai@suse.de
- kABI workaround for snd_seq_kernel_client_enqueue() API changes
  (bsc#1051510).
- commit 31233f8
* Mon May 13 2019 tiwai@suse.de
- ALSA: seq: Correct unlock sequence at
  snd_seq_client_ioctl_unlock() (bsc#1051510).
- ALSA: seq: Protect racy pool manipulation from OSS sequencer
  (bsc#1051510).
- ALSA: seq: Simplify snd_seq_kernel_client_enqueue() helper
  (bsc#1051510).
- commit 3b22932
* Mon May 13 2019 wqu@suse.com
- Update
  patches.fixes/0001-btrfs-reloc-Fix-NULL-pointer-dereference-due-to-expa.patch
  (bsc#1129497 bsc#1134651).
  Use upstream commit to make git-fixes happy.
- commit 95ca4df
* Mon May 13 2019 tiwai@suse.de
- ASoC: max98090: Fix restore of DAPM Muxes (bsc#1051510).
- ASoC: RT5677-SPI: Disable 16Bit SPI Transfers (bsc#1051510).
- ALSA: hdea/realtek - Headset fixup for System76 Gazelle (gaze14)
  (bsc#1051510).
- ALSA: hda/hdmi - Consider eld_valid when reporting jack event
  (bsc#1051510).
- ALSA: hda/hdmi - Read the pin sense from register when repolling
  (bsc#1051510).
- ASoC: fsl_esai: Fix missing break in switch statement
  (bsc#1051510).
- ALSA: hda - Register irq handler after the chip initialization
  (bsc#1051510).
- ALSA: usx2y: fix a double free bug (bsc#1051510).
- ALSA: usb-audio: Fix a memory leak bug (bsc#1051510).
- ALSA: hda/realtek - EAPD turn on later (bsc#1051510).
- ALSA: usb-audio: Handle the error from
  snd_usb_mixer_apply_create_quirk() (bsc#1051510).
- ALSA: seq: Cover unsubscribe_port() in list_mutex (bsc#1051510).
- Revert "ALSA: seq: Protect in-kernel ioctl calls with mutex"
  (bsc#1051510).
- ALSA: timer: Coding style fixes (bsc#1051510).
- ALSA: timer: Simplify error path in snd_timer_open()
  (bsc#1051510).
- ALSA: seq: Fix race of get-subscription call vs port-delete
  ioctls (bsc#1051510).
- ALSA: seq: Protect in-kernel ioctl calls with mutex
  (bsc#1051510).
- ALSA: seq: Remove superfluous irqsave flags (bsc#1051510).
- ALSA: seq: Align temporary re-locking with irqsave version
  (bsc#1051510).
- ALSA: timer: Revert active callback sync check at close
  (bsc#1051510).
- ALSA: timer: Make snd_timer_close() really kill pending actions
  (bsc#1051510).
- ALSA: timer: Check ack_list emptiness instead of bit flag
  (bsc#1051510).
- ALSA: timer: Make sure to clear pending ack list (bsc#1051510).
- ALSA: timer: Unify timer callback process code (bsc#1051510).
- commit 332dfdd
* Mon May 13 2019 wqu@suse.com
- btrfs: move all ref head cleanup to the helper function
  (bsc#1134813).
- btrfs: remove delayed_ref_node from ref_head (bsc#1134813).
- Refresh
  patches.fixes/0001-btrfs-qgroup-Move-reserved-data-accounting-from-btrf.patch.
- Refresh
  patches.suse/btrfs-Take-trans-lock-before-access-running-trans-in.patch.
- Refresh
  patches.suse/btrfs-fix-race-condition-between-delayed-refs-and-blockgroup-removal.patch.
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit 751bb6e
* Mon May 13 2019 wqu@suse.com
- btrfs: move ref_mod modification into the if (ref) logic
  (bsc#1134813).
- commit 43101f4
* Mon May 13 2019 wqu@suse.com
- btrfs: breakout empty head cleanup to a helper (bsc#1134813).
- commit 0b0f74c
* Mon May 13 2019 wqu@suse.com
- btrfs: move extent_op cleanup to a helper (bsc#1134813).
- commit accdac6
* Mon May 13 2019 wqu@suse.com
- btrfs: add a helper to return a head ref (bsc#1134813).
- commit 44c6263
* Mon May 13 2019 wqu@suse.com
- btrfs: extent-tree: Open-code process_func in  __btrfs_mod_ref
  (bsc#1063638 bsc#1128052 bsc#1108838).
- commit 2d4a201
* Mon May 13 2019 wqu@suse.com
- btrfs: delayed-ref: Introduce better documented delayed  ref
  structures (bsc#1063638 bsc#1128052 bsc#1108838).
- commit a50ff03
* Mon May 13 2019 wqu@suse.com
- selinux: use kernel linux/socket.h for genheaders and mdp
  (bsc#1134810).
- commit b1217e4
* Sun May 12 2019 ailiopoulos@suse.com
- xfs: prepare xfs_break_layouts() for another layout type
  (bsc#1106011).
- commit af8461c
* Sun May 12 2019 ailiopoulos@suse.com
- xfs: prepare xfs_break_layouts() to be called with
  XFS_MMAPLOCK_EXCL (bsc#1106011).
- commit 9fc7166
* Sun May 12 2019 ailiopoulos@suse.com
- xfs: remove xfs_zero_range (bsc#1106011).
- commit e210917
* Sun May 12 2019 ailiopoulos@suse.com
- xfs: kill meaningless variable 'zero' (bsc#1106011).
- commit 338018e
* Sun May 12 2019 ailiopoulos@suse.com
- xfs: detect and fix bad summary counts at mount (bsc#1114427).
- commit d041381
* Fri May 10 2019 jslaby@suse.cz
- thunderx: eliminate extra calls to put_page() for pages held
  for recycling (networking-stable-19_03_28).
- thunderx: enable page recycling for non-XDP case
  (networking-stable-19_03_28).
- genetlink: Fix a memory leak on error path
  (networking-stable-19_03_28).
- dccp: do not use ipv6 header for ipv4 flow
  (networking-stable-19_03_28).
- tcp: do not use ipv6 header for ipv4 flow
  (networking-stable-19_03_28).
- net: stmmac: fix memory corruption with large MTUs
  (networking-stable-19_03_28).
- sctp: get sctphdr by offset in sctp_compute_cksum
  (networking-stable-19_03_28).
- packets: Always register packet sk in the same order
  (networking-stable-19_03_28).
- vxlan: Don't call gro_cells_destroy() before device is
  unregistered (networking-stable-19_03_28).
- net: aquantia: fix rx checksum offload for UDP/TCP over IPv6
  (networking-stable-19_03_28).
- net: rose: fix a possible stack overflow
  (networking-stable-19_03_28).
- tun: add a missing rcu_read_unlock() in error path
  (networking-stable-19_03_28).
- tun: properly test for IFF_UP (networking-stable-19_03_28).
- commit dbe4469
* Thu May  9 2019 msuchanek@suse.de
- Refresh patches.arch/powerpc-pseries-Track-LMB-nid-instead-of-using-devic.patch.
- commit b8e67e0
* Thu May  9 2019 tiwai@suse.de
- scripts: override locale from environment when running
  recordmcount.pl (bsc#1134354).
- commit 4cacf9e
* Thu May  9 2019 hare@suse.de
- qla2xxx: always allocate qla_tgt_wq (bsc#1131451).
- commit e409e3d
* Thu May  9 2019 tiwai@suse.de
- Refresh patches.drivers/ALSA-hda-realtek-Add-quirk-for-Tuxedo-XC-1509.patch
  Upstreamed, move to sorted section.
- commit 61b3b1c
* Thu May  9 2019 hare@suse.de
- Delete
  patches.fixes/block_dev-fix-crash-on-chained-bios-with-O_DIRECT.patch.
- commit c9e1edf
* Thu May  9 2019 hare@suse.de
- Refresh
  patches.fixes/nvme-multipath-avoid-crash-on-invalid-subsystem-cntl.patch.
- commit c7eafa3
* Thu May  9 2019 msuchanek@suse.de
- Refresh sorted patches.
- Refresh patches.arch/cpu-speculation-add-mitigations-cmdline-option.patch.
- Refresh patches.arch/powerpc-speculation-support-mitigations-cmdline-option.patch.
- Refresh patches.arch/powerpc-tm-Avoid-machine-crash-on-rt_sigreturn.patch
- Refresh patches.arch/s390-speculation-support-mitigations-cmdline-option.patch.
- Refresh patches.arch/x86-mce-handle-varying-mca-bank-counts.patch.
- Refresh patches.arch/x86-speculation-support-mitigations-cmdline-option.patch.
- Refresh patches.drivers/ibmvnic-Report-actual-backing-device-speed-and-duple.patch.
- Refresh patches.fixes/md-batch-flush-requests.patch.
- commit 14d13e7
* Thu May  9 2019 tiwai@suse.de
- blacklist.conf: Remove incorrectly added blacklist entry for regulator
- commit dc57ffb
* Thu May  9 2019 tiwai@suse.de
- USB: core: Fix bug caused by duplicate interface PM usage
  counter (bsc#1051510).
- kABI workaround for removed usb_interface.pm_usage_cnt field
  (bsc#1051510).
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- commit 52f191f
* Thu May  9 2019 tiwai@suse.de
- tty: pty: Fix race condition between release_one_tty and
  pty_write (bsc#1051510).
- tty: vt.c: Fix TIOCL_BLANKSCREEN console blanking if
  blankinterval == 0 (bsc#1051510).
- usb: dwc3: Fix default lpm_nyet_threshold value (bsc#1051510).
- USB: serial: f81232: fix interrupt worker not stop
  (bsc#1051510).
- USB: serial: fix unthrottle races (bsc#1051510).
- USB: cdc-acm: fix unthrottle races (bsc#1051510).
- USB: w1 ds2490: Fix bug caused by improper use of altsetting
  array (bsc#1051510).
- USB: yurex: Fix protection fault after device removal
  (bsc#1051510).
- usb: usbip: fix isoc packet num validation in get_pipe
  (bsc#1051510).
- USB: core: Fix unterminated string returned by usb_string()
  (bsc#1051510).
- usb: gadget: net2272: Fix net2272_dequeue() (bsc#1051510).
- usb: gadget: net2280: Fix net2280_dequeue() (bsc#1051510).
- usb: gadget: net2280: Fix overrun of OUT messages (bsc#1051510).
- usb: u132-hcd: fix resource leak (bsc#1051510).
- usb: usb251xb: fix to avoid potential NULL pointer dereference
  (bsc#1051510).
- tty: increase the default flip buffer limit to 2*640K
  (bsc#1051510).
- commit 4aa2c5c
* Thu May  9 2019 tiwai@suse.de
- stm class: Fix channel free in stm output free path
  (bsc#1051510).
- commit 7dbf8ff
* Thu May  9 2019 tiwai@suse.de
- ipmi:ssif: compare block number correctly for multi-part return
  messages (bsc#1051510).
- rtlwifi: rtl8723ae: Fix missing break in switch statement
  (bsc#1051510).
- mwl8k: Fix rate_idx underflow (bsc#1051510).
- mwifiex: prevent an array overflow (bsc#1051510).
- mwifiex: Fix mem leak in mwifiex_tm_cmd (bsc#1051510).
- openvswitch: add seqadj extension when NAT is used
  (bsc#1051510).
- openvswitch: fix flow actions reallocation (bsc#1051510).
- HID: input: add mapping for Assistant key (bsc#1051510).
- stm class: Prevent division by zero (bsc#1051510).
- stm class: Fix an endless loop in channel allocation
  (bsc#1051510).
- Input: introduce KEY_ASSISTANT (bsc#1051510).
- commit 06048d9
* Thu May  9 2019 oneukum@suse.com
- UAS: fix alignment of scatter/gather segments (bsc#1129770).
- commit b23bdd3
* Thu May  9 2019 tiwai@suse.de
- brcm80211: potential NULL dereference in
  brcmf_cfg80211_vndr_cmds_dcmd_handler() (bsc#1051510).
- at76c50x-usb: Don't register led_trigger if usb_register_driver
  failed (bsc#1051510).
- b43: shut up clang -Wuninitialized variable warning
  (bsc#1051510).
- audit: fix a memleak caused by auditing load module
  (bsc#1051510).
- ASoC: stm32: fix sai driver name initialisation (bsc#1051510).
- HID: debug: fix race condition with between rdesc_show()
  and device removal (bsc#1051510).
- HID: logitech: check the return value of
  create_singlethread_workqueue (bsc#1051510).
- gpio: aspeed: fix a potential NULL pointer dereference
  (bsc#1051510).
- commit d26e26c
* Wed May  8 2019 bp@suse.de
- ghes, EDAC: Fix ghes_edac registration (bsc#1133176).
- commit 8ce891d
* Wed May  8 2019 lhenriques@suse.com
- ceph: fix ci->i_head_snapc leak (bsc#1122776).
- ceph: ensure d_name stability in ceph_dentry_hash()
  (bsc#1134461).
- ceph: only use d_name directly when parent is locked
  (bsc#1134460).
- ceph: fix use-after-free on symlink traversal (bsc#1134459).
- commit 3c28b50
* Wed May  8 2019 hare@suse.de
- qla2xxx: allow irqbalance control in non-MQ mode (bsc#1128979).
- commit a4c2dd4
* Wed May  8 2019 ghe@suse.com
- ocfs2: turn on OCFS2_FS_STATS setting(bsc#1134393)
  We need to turn on OCFS2_FS_STATS kernel configuration setting,
  to fix bsc#1134393.
- commit 45279fb
* Wed May  8 2019 tiwai@suse.de
- blacklist.conf: Add regulator entries that require the missing API
- commit 0145c38
* Wed May  8 2019 tiwai@suse.de
- spi: bcm2835aux: setup gpio-cs to output and correct level
  during setup (bsc#1051510).
- spi: bcm2835aux: warn in dmesg that native cs is not really
  supported (bsc#1051510).
- spi: bcm2835aux: fix driver to not allow 65535 (=-1) cs-gpios
  (bsc#1051510).
- spi: rspi: Fix sequencer reset during initialization
  (bsc#1051510).
- regulator: tps65086: Fix tps65086_ldoa1_ranges for selector 0xB
  (bsc#1051510).
- commit eef4b75
* Wed May  8 2019 tiwai@suse.de
- leds: avoid races with workqueue (bsc#1051510).
- ALSA: line6: Avoid polluting led_* namespace (bsc#1051510).
- intel_th: msu: Fix single mode with IOMMU (bsc#1051510).
- mmc: core: fix possible use after free of host (bsc#1051510).
- commit 013cf36
* Wed May  8 2019 wqu@suse.com
- btrfs: Don't panic when we can't find a root key (bsc#1112063).
- commit e5728d0
* Tue May  7 2019 colyli@suse.de
- bcache: use (REQ_META|REQ_PRIO) to indicate bio for metadata
  (bsc#1130972).
- bcache: fix input overflow to cache set sysfs file
  io_error_halflife (bsc#1130972).
- bcache: fix input overflow to cache set io_error_limit
  (bsc#1130972).
- bcache: fix input overflow to journal_delay_ms (bsc#1130972).
- bcache: fix input overflow to writeback_rate_minimum
  (bsc#1130972).
- bcache: fix potential div-zero error of
  writeback_rate_p_term_inverse (bsc#1130972).
- bcache: fix potential div-zero error of
  writeback_rate_i_term_inverse (bsc#1130972).
- bcache: fix input overflow to writeback_delay (bsc#1130972).
- bcache: use sysfs_strtoul_bool() to set bit-field variables
  (bsc#1130972).
- bcache: add sysfs_strtoul_bool() for setting bit-field variables
  (bsc#1130972).
- bcache: fix input overflow to sequential_cutoff (bsc#1130972).
- bcache: fix input integer overflow of congested threshold
  (bsc#1130972).
- bcache: improve sysfs_strtoul_clamp() (bsc#1130972).
- bcache: treat stale && dirty keys as bad keys (bsc#1130972).
- bcache: fix indentation issue, remove tabs on a hunk of code
  (bsc#1130972).
- bcache: export backing_dev_uuid via sysfs (bsc#1130972).
- bcache: export backing_dev_name via sysfs (bsc#1130972).
- bcache: not use hard coded memset size in
  bch_cache_accounting_clear() (bsc#1130972).
- bcache: never writeback a discard operation (bsc#1130972).
- bcache: print number of keys in trace_bcache_journal_write
  (bsc#1130972).
- bcache: set writeback_percent in a flexible range (bsc#1130972).
- bcache: make cutoff_writeback and cutoff_writeback_sync tunable
  (bsc#1130972).
- bcache: add MODULE_DESCRIPTION information (bsc#1130972).
- bcache: option to automatically run gc thread after writeback
  (bsc#1130972).
- bcache: introduce force_wake_up_gc() (bsc#1130972).
- bcache: cannot set writeback_running via sysfs if no writeback
  kthread created (bsc#1130972).
- bcache: do not mark writeback_running too early (bsc#1130972).
- bcache: update comment in sysfs.c (bsc#1130972).
- bcache: update comment for bch_data_insert (bsc#1130972).
- bcache: do not check if debug dentry is ERR or NULL explicitly
  on remove (bsc#1130972).
- bcache: add comment for cache_set->fill_iter (bsc#1130972).
- bcache: panic fix for making cache device (bsc#1130972).
- bcache: split combined if-condition code into separate ones
  (bsc#1130972).
- bcache: use MAX_CACHES_PER_SET instead of magic number 8 in
  __bch_bucket_alloc_set (bsc#1130972).
- bcache: replace hard coded number with BUCKET_GC_GEN_MAX
  (bsc#1130972).
- bcache: remove useless parameter of bch_debug_init()
  (bsc#1130972).
- bcache: remove unused bch_passthrough_cache (bsc#1130972).
- bcache: recal cached_dev_sectors on detach (bsc#1130972).
- bcache: Populate writeback_rate_minimum attribute (bsc#1130972).
- bcache: correct dirty data statistics (bsc#1130972).
- bcache: fix typo in code comments of
  closure_return_with_destructor() (bsc#1130972).
- bcache: fix ioctl in flash device (bsc#1130972).
- bcache: use REQ_PRIO to indicate bio for metadata (bsc#1130972).
- bcache: account size of buckets used in uuid write to
  ca->meta_sectors_written (bsc#1130972).
- bcache: add separate workqueue for journal_write to avoid
  deadlock (bsc#1130972).
- bcache: add the missing comments for smp_mb()/smp_wmb()
  (bsc#1130972).
- bcache: remove unnecessary space before ioctl function pointer
  arguments (bsc#1130972).
- bcache: add missing SPDX header (bsc#1130972).
- bcache: move open brace at end of function definitions to next
  line (bsc#1130972).
- bcache: add static const prefix to char * array declarations
  (bsc#1130972).
- bcache: fix code comments style (bsc#1130972).
- bcache: do not check NULL pointer before calling
  kmem_cache_destroy (bsc#1130972).
- bcache: prefer 'help' in Kconfig (bsc#1130972).
- commit 6f636cd
* Tue May  7 2019 colyli@suse.de
- bcache: use routines from lib/crc64.c for CRC64 calculation
  (bsc#1130972).
- lib: add crc64 calculation routines (bsc#1130972).
- lib: don't depend on linux headers being installed
  (bsc#1130972).
- Add config for lib/crc64
- Add lib/crc64 to supported.conf
- Refresh for above change,
  patches.suse/0238-bcache-style-fix-to-replace-unsigned-by-unsigned-int.patch.
- commit 1121803
* Tue May  7 2019 colyli@suse.de
- bcache: fix typo 'succesfully' to 'successfully' (bsc#1130972).
- bcache: replace '%%pF' by '%%pS' in seq_printf() (bsc#1130972).
- bcache: fix indent by replacing blank by tabs (bsc#1130972).
- bcache: replace printk() by pr_*() routines (bsc#1130972).
- bcache: replace Symbolic permissions by octal permission numbers
  (bsc#1130972).
- bcache: style fixes for lines over 80 characters (bsc#1130972).
- bcache: add identifier names to arguments of function
  definitions (bsc#1130972).
- bcache: style fix to add a blank line after declarations
  (bsc#1130972).
- bcache: style fix to replace 'unsigned' by 'unsigned int'
  (bsc#1130972).
- bcache: trivial - remove tailing backslash in macro BTREE_FLAG
  (bsc#1130972).
- bcache: add code comments for bset.c (bsc#1130972).
- bcache: fix mistaken comments in request.c (bsc#1130972).
- bcache: fix mistaken code comments in bcache.h (bsc#1130972).
- bcache: add a comment in super.c (bsc#1130972).
- bcache: stop using the deprecated get_seconds() (bsc#1130972).
- commit 18444d1
* Tue May  7 2019 tiwai@suse.de
- thermal/int340x_thermal: fix mode setting (bsc#1051510).
- thermal/int340x_thermal: Add additional UUIDs (bsc#1051510).
- commit 5147b07
* Tue May  7 2019 tiwai@suse.de
- soc/tegra: pmc: Drop locking from tegra_powergate_is_powered()
  (bsc#1051510).
- commit 262c86c
* Tue May  7 2019 tiwai@suse.de
- serial: ar933x_uart: Fix build failure with disabled console
  (bsc#1051510).
- serial: 8250_pxa: honor the port number from devicetree
  (bsc#1051510).
- commit 3179a44
* Tue May  7 2019 tiwai@suse.de
- serial: uartps: console_setup() can't be placed to init section
  (bsc#1051510).
- commit 64be059
* Tue May  7 2019 tiwai@suse.de
- staging: rtl8188eu: Fix potential NULL pointer dereference of
  kcalloc (bsc#1051510).
- commit 3c15a6e
* Tue May  7 2019 colyli@suse.de
- bcache: do not assign in if condition in bcache_init()
  (bsc#1130972).
- Refresh for above change,
  patches.suse/0232-bcache-do-not-check-return-value-of-debugfs_create_d.patch.
- commit 1e79131
* Tue May  7 2019 colyli@suse.de
- bcache: do not assign in if condition register_bcache()
  (bsc#1130972).
- bcache: don't clone bio in bch_data_verify (bsc#1130972).
- bcache: Replace bch_read_string_list() by __sysfs_match_string()
  (bsc#1130972).
- bcache: Move couple of functions to sysfs.c (bsc#1130972).
- bcache: Move couple of string arrays to sysfs.c (bsc#1130972).
- bcache: stop bcache device when backing device is offline
  (bsc#1130972).
- commit fcba1aa
* Tue May  7 2019 tiwai@suse.de
- rt2x00: do not increment sequence number while re-transmitting
  (bsc#1051510).
- commit 85007ed
* Tue May  7 2019 tiwai@suse.de
- qmi_wwan: add Olicard 600 (bsc#1051510).
- commit dc4a78d
* Tue May  7 2019 tiwai@suse.de
- platform/x86: pmc_atom: Drop __initconst on dmi table
  (bsc#1051510).
- commit 4df1f03
* Tue May  7 2019 tiwai@suse.de
- libata: fix using DMA buffers on stack (bsc#1051510).
- commit a1804f1
* Tue May  7 2019 tiwai@suse.de
- hwmon: (vt1211) Use request_muxed_region for Super-IO accesses
  (bsc#1051510).
- hwmon: (w83627hf) Use request_muxed_region for Super-IO accesses
  (bsc#1051510).
- hwmon: (smsc47m1) Use request_muxed_region for Super-IO accesses
  (bsc#1051510).
- hwmon: (smsc47b397) Use request_muxed_region for Super-IO
  accesses (bsc#1051510).
- hwmon: (pc87427) Use request_muxed_region for Super-IO accesses
  (bsc#1051510).
- hwmon: (f71805f) Use request_muxed_region for Super-IO accesses
  (bsc#1051510).
- commit eedae7d
* Tue May  7 2019 tiwai@suse.de
- crypto: sun4i-ss - Fix invalid calculation of hash end
  (bsc#1051510).
- crypto: ccm - fix incompatibility between "ccm" and "ccm_base"
  (bsc#1051510).
- crypto: gcm - fix incompatibility between "gcm" and "gcm_base"
  (bsc#1051510).
- crypto: arm/aes-neonbs - don't access already-freed walk.iv
  (bsc#1051510).
- crypto: ccp - Do not free psp_master when PLATFORM_INIT fails
  (bsc#1051510).
- crypto: chacha20poly1305 - set cra_name correctly (bsc#1051510).
- crypto: skcipher - don't WARN on unprocessed data after slow
  walk step (bsc#1051510).
- crypto: x86/crct10dif-pcl - fix use via crypto_shash_digest()
  (bsc#1051510).
- crypto: crct10dif-generic - fix use via crypto_shash_digest()
  (bsc#1051510).
- crypto: fips - Grammar s/options/option/, s/to/the/
  (bsc#1051510).
- crypto: vmx - fix copy-paste error in CTR mode (bsc#1051510).
- commit 300438f
* Tue May  7 2019 hare@suse.de
- scsi: qla2xxx: Fix panic in qla_dfs_tgt_counters_show
  (bsc#1132044).
- commit d578582
* Tue May  7 2019 lpechacek@suse.com
- supported.conf: Add openvswitch to kernel-default-base (bsc#1124839).
- commit 353f0eb
* Tue May  7 2019 dkirjanov@suse.com
- netfilter: nf_socket: Fix out of bounds access in
  nf_sk_lookup_slow_v{4,6} (git-fixes).
- netfilter: drop template ct when conntrack is skipped
  (git-fixes).
- netfilter: bridge: ebt_among: add more missing match size checks
  (git-fixes).
- netfilter: bridge: ebt_among: add missing match size checks
  (git-fixes).
- net: avoid skb_warn_bad_offload on IS_ERR (git-fixes).
- xfrm: Return error on unknown encap_type in init_state
  (git-fixes).
- xfrm: fix xfrm_do_migrate() with AEAD e.g(AES-GCM) (git-fixes).
- commit f21ff42
* Tue May  7 2019 dkirjanov@suse.com
- xfrm: Fix stack-out-of-bounds read on socket policy lookup
  (git-fixes).
- commit 5a31401
* Tue May  7 2019 jslaby@suse.cz
- tty: make R3964 line discipline fail (bnc#1133188 CVE-2019-11486).
- commit 75ae661
* Mon May  6 2019 dkirjanov@suse.com
- sctp: only update outstanding_bytes for transmitted queue when doing prsctp_prune (git-fixes).
- sctp: set frag_point in sctp_setsockopt_maxseg correctly` (git-fixes).
- net: dsa: legacy: don't unmask port bitmaps (git-fixes).
- commit 72e2f6f
* Mon May  6 2019 jroedel@suse.de
- blacklist.conf: Add 4a58038b9e42 Revert "svm: Fix AVIC incomplete IPI emulation"
  Reverted commit not in SLE15
- commit 027a60e
* Mon May  6 2019 jroedel@suse.de
- KVM: x86: svm: make sure NMI is injected after nmi_singlestep (bsc#1134205).
- commit 1efa1ca
* Mon May  6 2019 jroedel@suse.de
- KVM: x86: Always use 32-bit SMRAM save state for 32-bit kernels
  (bsc#1134203).
- KVM: x86: Don't clear EFER during SMM transitions for 32-bit
  vCPU (bsc#1134204).
- KVM: VMX: Zero out *all* general purpose registers after VM-Exit
  (bsc#1134202).
- KVM: Fix UAF in nested posted interrupt processing
  (bsc#1134199).
- KVM: nVMX: restore host state in nested_vmx_vmexit for VMFail
  (bsc#1134201).
- KVM: nVMX: Clear reserved bits of #DB exit qualification
  (bsc#1134200).
- commit 09e58c5
* Mon May  6 2019 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/i915/fbdev: Actually configure untiled displays"'
- commit 1a6d210
* Mon May  6 2019 wqu@suse.com
- btrfs: qgroup: Move reserved data accounting from
  btrfs_delayed_ref_head to btrfs_qgroup_extent_record
  (bsc#1134162).
- commit c46e00b
* Mon May  6 2019 wqu@suse.com
- btrfs: qgroup: Remove duplicated trace points for
  qgroup_rsv_add/release (bsc#1134160).
- commit 4a0e633
* Sat May  4 2019 tiwai@suse.de
- ALSA: hda/realtek - Apply the fixup for ASUS Q325UAR
  (bsc#1051510).
- ALSA: line6: use dynamic buffers (bsc#1051510).
- ALSA: hda/realtek - Fixed Dell AIO speaker noise (bsc#1051510).
- ALSA: hda/realtek - Add new Dell platform for headset mode
  (bsc#1051510).
- commit 818b345
* Fri May  3 2019 bp@suse.de
- blacklist.conf: 379d98ddf413 x86: vdso: Use $LD instead of $CC to link
- commit 513d103
* Fri May  3 2019 hare@suse.de
- nvme-multipath: avoid crash on invalid subsystem cntlid
  enumeration (bsc#1129273).
- commit e2a5094
* Fri May  3 2019 msuchanek@suse.de
- powerpc/mm: Fix page table dump to work on Radix (bsc#1055186,
  fate#323286, git-fixes).
- powerpc/mm/radix: Display if mappings are exec or not
  (bsc#1055186, fate#323286, git-fixes).
- powerpc/mm/radix: Prettify mapped memory range print out
  (bsc#1055186, fate#323286, git-fixes).
- Refresh patches.arch/powerpc-mm-radix-Split-linear-mapping-on-hot-unplug.patch
- commit 5451b1e
* Fri May  3 2019 hare@suse.de
- scsi: qla2xxx: Add new FC-NVMe enable BIT to enable FC-NVMe
  feature (bsc#1130579).
- commit 0222aa2
* Fri May  3 2019 jslaby@suse.cz
- packet: validate msg_namelen in send directly (git-fixes).
- commit f8a64bd
* Fri May  3 2019 neilb@suse.com
- NFS: Add missing encode / decode sequence_maxsz to v4.2
  operations (git-fixes).
- commit 3673108
* Fri May  3 2019 neilb@suse.com
- blacklist.conf: Add a not-a-bug commit id
- commit 83ebe4a
* Thu May  2 2019 yousaf.kaukab@suse.com
- ipmi: Fix I2C client removal in the SSIF driver (bsc#1108193).
- ipmi_ssif: Remove duplicate NULL check (bsc#1108193).
- i2c: Make i2c_unregister_device() NULL-aware (bsc#1108193).
- commit 99bec98
* Thu May  2 2019 dkirjanov@suse.com
- net: Fix untag for vlan packets without ethernet header
  (git-fixes).
- commit 99361c7
* Thu May  2 2019 bp@suse.de
- Update
  patches.arch/kvm-x86-report-stibp-on-get_supported_cpuid.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/locking-atomics-asm-generic-move-some-macros-from-linux-bitops-h-to-a-new-linux-bits-h-file.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update patches.arch/x86-cpu-sanitize-fam6_atom-naming.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-kvm-expose-x86_feature_md_clear-to-guests.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-kvm-vmx-add-mds-protection-when-l1d-flush-is-not-active.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update patches.arch/x86-msr-index-cleanup-bit-defines.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-consolidate-cpu-whitelists.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-basic-bug-infrastructure-for-mds.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update patches.arch/x86-speculation-mds-add-bug_msbds_only.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-mds-full-nosmt-cmdline-option.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-mds_clear_cpu_buffers.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-mitigation-control-for-mds.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-mitigation-mode-vmwerv.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-mitigations-support-for-mds.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-smt-warning-message.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-add-sysfs-reporting-for-mds.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-clear-cpu-buffers-on-exit-to-user.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-conditionally-clear-cpu-buffers-on-idle-entry.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-mds-print-smt-vulnerable-on-msbds-with-mitigations-off.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-move-arch_smt_update-call-to-after-mitigation-decisions.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- Update
  patches.arch/x86-speculation-simplify-the-cpu-bug-detection-logic.patch
  (bsc#1111331, CVE-2018-12126, CVE-2018-12127, CVE-2018-12130).
- commit 0d6b73d
* Thu May  2 2019 msuchanek@suse.de
- s390/dasd: fix panic for failed online processing (bsc#1132589).
- commit e24913c
* Thu May  2 2019 dkirjanov@suse.com
- tcp: fix TCP_REPAIR_QUEUE bound checking (git-fixes).
- rxrpc: Don't treat call aborts as conn aborts (git-fixes).
- rxrpc: Fix Tx ring annotation after initial Tx failure
  (git-fixes).
- xfrm: fix rcu_read_unlock usage in xfrm_local_error (git-fixes).
- net: Fix vlan untag for bridge and vlan_dev with reorder_hdr
  off (git-fixes).
- net: xfrm: use preempt-safe this_cpu_read() in
  ipcomp_alloc_tfms() (git-fixes).
- xfrm: Fix ESN sequence number handling for IPsec GSO packets
  (git-fixes).
- xfrm: do not call rcu_read_unlock when afinfo is NULL in
  xfrm_get_tos (git-fixes).
- ipvs: remove IPS_NAT_MASK check to fix passive FTP (git-fixes).
- netfilter: ipv6: fix use-after-free Write in
  nf_nat_ipv6_manip_pkt (git-fixes).
- netfilter: x_tables: avoid out-of-bounds reads in
  xt_request_find_{match|target} (git-fixes).
- netfilter: x_tables: fix int overflow in xt_alloc_table_info()
  (git-fixes).
- netfilter: ipset: Missing nfnl_lock()/nfnl_unlock() is added
  to ip_set_net_exit() (git-fixes).
- rds: tcp: atomically purge entries from rds_tcp_conn_list
  during netns delete (git-fixes).
- commit 2e1ed06
* Thu May  2 2019 hare@suse.de
- nvme-multipath: split bios with the ns_head bio_set before
  submitting (bsc#1103259, bsc#1131673).
- commit d40d160
* Thu May  2 2019 hare@suse.de
- scripts/git_sort/git_sort.py: update nvme repository to 5.2
- commit a7486ed
* Thu May  2 2019 tiwai@suse.de
- blacklist.conf: Add entries for ACPICA changes causing regression (bsc#1132943)
- commit 52de608
* Wed May  1 2019 dbueso@suse.de
- futex: Cure exit race (bsc#1050549).
- commit fd88aa5
* Wed May  1 2019 dbueso@suse.de
- blacklist.conf: Add small qrwlock change, breaks kabi
- commit c74e4c7
* Wed May  1 2019 dbueso@suse.de
- blacklist.conf: Add SCHED_DEBUG patch
- commit 05d077d
* Wed May  1 2019 rgoldwyn@suse.com
- kernfs: don't set dentry->d_fsdata (boo#1133115).
- commit 87703df
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: rename clone_verify_area to remap_verify_area (bsc#1133852,
  bsc#1132219).
- commit e7a6da0
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: skip zero-length dedupe requests (bsc#1133851,
  bsc#1132219).
- commit 3cb446d
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: avoid problematic remapping requests into partial EOF block
  (bsc#1133850, bsc#1132219).
- commit bf23f52
* Tue Apr 30 2019 jroedel@suse.de
- mm/vmalloc: fix size check for remap_vmalloc_range_partial() (bsc#1133825).
- commit aa4afbd
* Tue Apr 30 2019 tiwai@suse.de
- blacklist.conf: Add CVE entries to be ignored (CVE-2019-9003,CVE-2018-16880)
- commit c4eee01
* Tue Apr 30 2019 tiwai@suse.de
- mmc: sdhci: Handle auto-command errors (bsc#1051510).
- mmc: sdhci: Rename SDHCI_ACMD12_ERR and SDHCI_INT_ACMD12ERR
  (bsc#1051510).
- mmc: sdhci: Fix data command CRC error handling (bsc#1051510).
- commit 3b43b40
* Tue Apr 30 2019 tiwai@suse.de
- mac80211: do not call driver wake_tx_queue op during reconfig
  (bsc#1051510).
- commit 6c6b354
* Tue Apr 30 2019 tiwai@suse.de
- Input: synaptics-rmi4 - write config register values to the
  right offset (bsc#1051510).
- io: accel: kxcjk1013: restore the range after resume
  (bsc#1051510).
- commit 7de4d86
* Tue Apr 30 2019 tiwai@suse.de
- iio: dac: mcp4725: add missing powerdown bits in store eeprom
  (bsc#1051510).
- iio: adc: at91: disable adc channel interrupt in timeout case
  (bsc#1051510).
- iio: gyro: mpu3050: fix chip ID reading (bsc#1051510).
- iio: Fix scan mask selection (bsc#1051510).
- staging: iio: ad7192: Fix ad7193 channel address (bsc#1051510).
- iio/gyro/bmg160: Use millidegrees for temperature scale
  (bsc#1051510).
- commit 8dcd648
* Tue Apr 30 2019 tiwai@suse.de
- dmaengine: sh: rcar-dmac: With cyclic DMA residue 0 is valid
  (bsc#1051510).
- commit 23721ea
* Tue Apr 30 2019 tiwai@suse.de
- device_cgroup: fix RCU imbalance in error case (bsc#1051510).
- commit 496ae7a
* Tue Apr 30 2019 tiwai@suse.de
- crypto: crypto4xx - properly set IV after de- and encrypt
  (bsc#1051510).
- commit 923e152
* Tue Apr 30 2019 tiwai@suse.de
- staging: comedi: ni_usb6501: Fix possible double-free of
  - >usb_rx_buf (bsc#1051510).
- staging: comedi: ni_usb6501: Fix use of uninitialized mutex
  (bsc#1051510).
- staging: comedi: vmk80xx: Fix possible double-free of
  - >usb_rx_buf (bsc#1051510).
- staging: comedi: vmk80xx: Fix use of uninitialized semaphore
  (bsc#1051510).
- commit 6f218bd
* Tue Apr 30 2019 tiwai@suse.de
- clk: x86: Add system specific quirk to mark clocks as critical
  (bsc#1051510).
- commit 2550217
* Tue Apr 30 2019 tiwai@suse.de
- HID: i2c-hid: Ignore input report if there's no data present
  on Elan touchpanels (bsc#1133486).
- commit 186ac94
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: vfs_clone_file_prep_inodes should return EINVAL for a
  clone from beyond EOF (bsc#1133780, bsc#1132219).
- commit f8cdd64
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: dedupe should return EPERM if permission is not granted
  (bsc#1133779, bsc#1132219).
- commit ee49cef
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: allow dedupe of user owned read-only files (bsc#1133778,
  bsc#1132219).
- commit f928d34
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: swap names of {do,vfs}_clone_file_range() (bsc#1133774,
  bsc#1132219).
- commit 418217d
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: export vfs_dedupe_file_range_one() to modules (bsc#1133772,
  bsc#1132219).
- commit ee6046d
* Tue Apr 30 2019 ailiopoulos@suse.com
- vfs: dedupe: extract helper for a single dedup (bsc#1133769,
  bsc#1132219).
- commit 0adcab6
* Tue Apr 30 2019 msuchanek@suse.de
- Fix duplicate commit id.
- Refresh patches.suse/0021-btrfs-switch-args-for-comp_-_refs.patch.
- Refresh patches.suse/0022-btrfs-add-a-comp_refs-helper.patch.
- commit 557f7ab
* Tue Apr 30 2019 mbrugger@suse.com
- efi/arm: Revert deferred unmap of early memmap mapping (bsc#1117158).
- commit 11eff9a
* Tue Apr 30 2019 msuchanek@suse.de
- Fix sorting of series.conf
- Refresh patches.drivers/ibmvnic-Enable-GRO.patch.
- Refresh patches.drivers/ibmvnic-Fix-netdev-feature-clobbering-during-a-reset.patch.
- rename nvme patches to match SLE15-SP1
- commit 47068e2
* Tue Apr 30 2019 acho@suse.com
- Bluetooth: hci_uart: Check if socket buffer is ERR_PTR in
  h4_recv_buf() (bsc#1133731).
- commit 6020c13
* Tue Apr 30 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vc4: Fix compilation error reported by kbuild test bot'
- commit 8f2ead0
* Tue Apr 30 2019 tzimmermann@suse.de
- drm/sun4i: Unbind components before releasing DRM and memory (bsc#1113722)
- commit 8c0f712
* Mon Apr 29 2019 jeyu@suse.de
- blacklist.conf: blacklist some unneeded git-fixes for kbuild
- commit bc4e6d5
* Mon Apr 29 2019 msuchanek@suse.de
- powerpc/numa: document topology_updates_enabled, disable by
  default (bsc#1133584).
- powerpc/numa: improve control of topology updates (bsc#1133584).
- commit 418216f
* Mon Apr 29 2019 hare@suse.de
- blk-mq: Avoid that submitting a bio concurrently with device
  removal triggers a crash (bsc#1131673).
- commit ec6a00b
* Mon Apr 29 2019 mbenes@suse.cz
- blacklist.conf: d6097c9e4454 ("trace: Fix preempt_enable_no_resched() abuse")
  There is no difference on !PREEMPT kernel.
- commit 015cb02
* Mon Apr 29 2019 mbenes@suse.cz
- tracing: Fix a memory leak by early error exit in
  trace_pid_write() (bsc#1133702).
- commit b236635
* Mon Apr 29 2019 hare@suse.de
- block: Fix a race between request queue removal and the block
  cgroup controller (bsc#1131673).
- Refresh patches.fixes/blkcg-Introduce-blkg_root_lookup.patch.
- Refresh
  patches.fixes/block-Ensure-that-a-request-queue-is-dissociated-fro.patch.
- Refresh patches.fixes/block-Introduce-blk_exit_queue.patch.
- commit c699a18
* Mon Apr 29 2019 mbenes@suse.cz
- tracing: Fix buffer_ref pipe ops (bsc#1133698).
- commit da9fad9
* Mon Apr 29 2019 mbenes@suse.cz
- blacklist.conf: fabe38ab6b2b ("kprobes: Mark ftrace mcount handler functions nokprobe")
  Not needed.
- commit eaa083a
* Mon Apr 29 2019 ailiopoulos@suse.com
- xfs: hold xfs_buf locked between shortform->leaf conversion
  and the addition of an attribute (bsc#1133675).
- commit cab0145
* Mon Apr 29 2019 ailiopoulos@suse.com
- xfs: add the ability to join a held buffer to a defer_ops
  (bsc#1133674).
- commit 6b7ffad
* Mon Apr 29 2019 ailiopoulos@suse.com
- xfs: remove the ip argument to xfs_defer_finish (bsc#1133672).
- Refresh
  patches.fixes/0036-xfs-inline-xfs_shift_file_space-into-callers.patch.
- Refresh
  patches.fixes/0059-xfs-introduce-the-xfs_iext_cursor-abstraction.patch.
- commit ebe7eab
* Mon Apr 29 2019 ailiopoulos@suse.com
- xfs: rename xfs_defer_join to xfs_defer_ijoin (bsc#1133668).
- commit bcff405
* Mon Apr 29 2019 ailiopoulos@suse.com
- xfs: refactor xfs_trans_roll (bsc#1133667).
  Refresh
  patches.fixes/xfs-relog-dirty-buffers-during-swapext-bmbt-owner-ch.patch.
- commit 1ff0f5c
* Mon Apr 29 2019 tzimmermann@suse.de
- drm/vc4: Fix memory leak during gpu reset. (bsc#1113722)
- commit eddacb4
* Mon Apr 29 2019 tzimmermann@suse.de
- drm/sun4i: Fix component unbinding and component master deletion (bsc#1113722)
- commit 11c33d3
* Mon Apr 29 2019 tzimmermann@suse.de
- drm/sun4i: Set device driver data at bind time for use in unbind (bsc#1113722)
- commit ed9bd32
* Mon Apr 29 2019 tzimmermann@suse.de
- drm/sun4i: Add missing drm_atomic_helper_shutdown at driver unbind (bsc#1113722)
- commit ed4e572
* Mon Apr 29 2019 tzimmermann@suse.de
- drm: bridge: dw-hdmi: Fix overflow workaround for Rockchip SoCs (bsc#1113722)
- commit 408e420
* Sat Apr 27 2019 hare@suse.de
- nvme: make sure ns head inherits underlying device limits
  (bsc#1131673).
- blkcg: Make blkg_root_lookup() work for queues in bypass mode
  (bsc#1131673).
- commit bb15eb6
* Fri Apr 26 2019 msuchanek@suse.de
- Rename patches that exist in SLE15-SP1 to the same name.
- commit f242f0b
* Fri Apr 26 2019 ptesarik@suse.cz
- Fix kernel-vanilla by moving
  patches.kernel.org/0001-drm-udl-add-a-release-method-and-delay-modeset-teard.patch
  under patches.drm/.
- commit 059ed35
* Fri Apr 26 2019 hare@suse.de
- blk-mq: fallback to previous nr_hw_queues when updating fails
  (bsc#1131673).
- blk-mq: realloc hctx when hw queue is mapped to another node
  (bsc#1131673).
- blk-mq: change gfp flags to GFP_NOIO in blk_mq_realloc_hw_ctxs
  (bsc#1131673).
- blk-mq: adjust debugfs and sysfs register when updating
  nr_hw_queues (bsc#1131673).
- commit f88bc93
* Fri Apr 26 2019 hare@suse.de
- blk-mq: sync the update nr_hw_queues with
  blk_mq_queue_tag_busy_iter (bsc#1131673).
- blk-mq: init hctx sched after update ctx and hctx mapping
  (bsc#1131673).
- commit d935704
* Fri Apr 26 2019 hare@suse.de
- block: Ensure that a request queue is dissociated from the
  cgroup controller (bsc#1131673).
- block: Introduce blk_exit_queue() (bsc#1131673).
- blkcg: Introduce blkg_root_lookup() (bsc#1131673).
- commit a5dd3b2
* Fri Apr 26 2019 dkirjanov@suse.com
- netfilter: bridge: set skb transport_header before entering
  NF_INET_PRE_ROUTING (git-fixes).
- commit d426b2c
* Fri Apr 26 2019 dkirjanov@suse.com
- net: datagram: fix unbounded loop in __skb_try_recv_datagram()
  (git-fixes).
- commit 8a8a896
* Fri Apr 26 2019 dkirjanov@suse.com
- ipv6: Fix dangling pointer when ipv6 fragment (git-fixes).
- commit 167348a
* Fri Apr 26 2019 dkirjanov@suse.com
- ipv6: sit: reset ip header pointer in ipip6_rcv (git-fixes).
- commit 6cc7095
* Fri Apr 26 2019 dkirjanov@suse.com
- net: bridge: multicast: use rcu to access port list from
  br_multicast_start_querier (git-fixes).
- commit 077343d
* Fri Apr 26 2019 dkirjanov@suse.com
- net: bridge: fix per-port af_packet sockets (git-fixes).
- commit 85d5245
* Fri Apr 26 2019 ailiopoulos@suse.com
- xfs: fix reporting supported extra file attributes for statx()
  (bsc#1133529).
- commit f8af342
* Fri Apr 26 2019 jack@suse.cz
- patches.fixes/ext4-Avoid-panic-during-forced-reboot.patch: Update tags
- commit 2eb9dad
* Thu Apr 25 2019 dkirjanov@suse.com
- cxgb4: remove redundant assignment to vlan_cmd.dropnovlan_fm
  (bsc#1127371).
- commit 9878a01
* Thu Apr 25 2019 dkirjanov@suse.com
- cxgb4: specify IQTYPE in fw_iq_cmd (bsc#1127371).
- Refresh
  patches.fixes/0001-cxgb4-cxgb4vf-Add-support-for-SGE-doorbell-queue-tim.patch.
- commit fffff56
* Thu Apr 25 2019 dkirjanov@suse.com
- cxgb4: impose mandatory VLAN usage when non-zero TAG ID
  (bsc#1127371).
- commit 98b6e7b
* Thu Apr 25 2019 dkirjanov@suse.com
- cxgb4/cxgb4vf: Program hash region for {t4/t4vf}_change_mac()
  (bsc#1127371).
- commit 0080200
* Wed Apr 24 2019 dkirjanov@suse.com
- cxgb4: use new fw interface to get the VIN and smt index
  (bsc#1127371).
- Refresh
  patches.fixes/0001-cxgb4-cxgb4vf-Add-support-for-SGE-doorbell-queue-tim.patch.
- commit 5344b4b
* Wed Apr 24 2019 tiwai@suse.de
- Drop "PCI: designware-ep: Read-only registers need DBI_RO_WR_EN to"
  The patch doesn't work with SLE15 / Leap 15.0 code as the prerequisite
  helper functions are missing.  Drop it for now.
- commit 77b9d89
* Wed Apr 24 2019 ohering@suse.de
- Drivers: hv: vmbus: Offload the handling of channels to two
  workqueues (bsc#1130567).
- commit 2f3f8d7
* Wed Apr 24 2019 tiwai@suse.de
- iio: core: fix a possible circular locking dependency
  (bsc#1051510).
- iio: ad_sigma_delta: select channel when reading register
  (bsc#1051510).
- iio: cros_ec: Fix the maths for gyro scale calculation
  (bsc#1051510).
- Input: snvs_pwrkey - initialize necessary driver data before
  enabling IRQ (bsc#1051510).
- crypto: x86/poly1305 - fix overflow during partial reduction
  (bsc#1051510).
- PCI: Add function 1 DMA alias quirk for Marvell 9170 SATA
  controller (bsc#1051510).
- ASoC: fsl_esai: fix channel swap issue when stream starts
  (bsc#1051510).
- mmc: davinci: remove extraneous __init annotation (bsc#1051510).
- drm/nouveau/volt/gf117: fix speedo readout register
  (bsc#1051510).
- crypto: sha512/arm - fix crash bug in Thumb2 build
  (bsc#1051510).
- crypto: sha256/arm - fix crash bug in Thumb2 build
  (bsc#1051510).
- ASoC: topology: free created components in tplg load error
  (bsc#1051510).
- 9p: do not trust pdu content for stat item size (bsc#1051510).
- ACPI / SBS: Fix GPE storm on recent MacBookPro's (bsc#1051510).
- ath10k: avoid possible string overflow (bsc#1051510).
- PCI: designware-ep: Read-only registers need DBI_RO_WR_EN to
  be writable (bsc#1051510).
- commit 3abb7dd
* Wed Apr 24 2019 osalvador@suse.de
- acpi, nfit: Prefer _DSM over _LSR for namespace label reads
  (bsc#112128) (bsc#1132426).
- commit d87d52e
* Wed Apr 24 2019 jslaby@suse.cz
- bonding: fix PACKET_ORIGDEV regression (git-fixes).
- rds: fix refcount bug in rds_sock_addref (git-fixes).
- commit c43c4da
* Wed Apr 24 2019 jslaby@suse.cz
- blacklist.conf: add an ORC patch
- commit 8377b75
* Wed Apr 24 2019 jslaby@suse.cz
- Delete
  patches.suse/bridge-do-not-add-port-to-router-list-when-receives-.patch.
- Delete
  patches.suse/net-bridge-remove-ipv6-zero-address-check-in-mcast-q.patch.
  Both were reverted in upstream by 278e2148c075.
- commit 0e2431c
* Wed Apr 24 2019 jslaby@suse.cz
- blacklist.conf: preserve R3964 module
- commit aae746b
* Wed Apr 24 2019 dkirjanov@suse.com
- cxgb4: remove the unneeded locks (bsc#1127371).
- commit 8c41499
* Wed Apr 24 2019 dkirjanov@suse.com
- cxgb4: fix the error path of cxgb4_uld_register() (bsc#1127371).
- commit 47726a9
* Wed Apr 24 2019 ohering@suse.de
- Drivers: hv: vmbus: Reset the channel callback in
  vmbus_onoffer_rescind() (bsc#1130567).
- commit 0c6a64e
* Wed Apr 24 2019 glin@suse.com
- bpf: fix use after free in bpf_evict_inode (bsc#1083647).
- commit b930261
* Wed Apr 24 2019 neilb@suse.com
- NFS: Fix dentry revalidation on NFSv4 lookup (bsc#1132618).
- commit 89a6e08
* Tue Apr 23 2019 tiwai@suse.de
- drm/i915/gvt: Annotate iomem usage (bsc#1051510).
- commit 313092c
* Tue Apr 23 2019 jroedel@suse.de
- KVM: SVM: Workaround errata#1096 (insn_len maybe zero on SMAP
  violation) (bsc#1133149).
- KVM: Fix kABI for AMD SMAP Errata workaround (bsc#1133149).
- Refresh patches.kabi/fix-kvm-kabi.patch.
- Refresh
  patches.kabi/kABI-Hide-get_msr_feature-in-kvm_x86_ops.patch.
- Refresh
  patches.kabi/kvm-x86-kABI-fix-for-vm_alloc-vm_free-changes.patch.
- commit 03fe042
* Tue Apr 23 2019 tiwai@suse.de
- ALSA: hda/realtek - add two more pin configuration sets to
  quirk table (bsc#1051510).
- ALSA: core: Fix card races between register and disconnect
  (bsc#1051510).
- ALSA: info: Fix racy addition/deletion of nodes (bsc#1051510).
- ALSA: hda: Initialize power_state field properly (bsc#1051510).
- commit a758061
* Tue Apr 23 2019 fabian.baumanis@suse.com
- blacklist.conf:
  c7084edc3f6d67750f50d4183134c4fb5712a5c8 #build-system only
- commit 433694c
* Tue Apr 23 2019 dkirjanov@suse.com
- kabi/severities: add cxgb4 and cxgb4vf shared data to the whitelis (bsc#1127372)
- commit 06e5150
* Tue Apr 23 2019 dkirjanov@suse.com
- cxgb4: Add flag tc_flower_initialized (bsc#1127371).
- cxgb4: convert flower table to use rhashtable (bsc#1127371).
- commit aa6e062
* Tue Apr 23 2019 oneukum@suse.com
- PCI: pciehp: Convert to threaded IRQ (bsc#1133005).
- commit f0731dc
* Tue Apr 23 2019 oneukum@suse.com
- blacklist.conf: this breaks some kernel command lines
- commit cc177f9
* Tue Apr 23 2019 oneukum@suse.com
- PCI: pciehp: Ignore Link State Changes after powering off a slot
  (bsc#1133005).
- commit ef568c9
* Tue Apr 23 2019 mkoutny@suse.com
- fix cgroup_do_mount() handling of failure exits (bsc#1133095).
- commit fe5a2ff
* Tue Apr 23 2019 mkoutny@suse.com
- cgroup: fix parsing empty mount option string (bsc#1133094).
- commit 17de6c6
* Tue Apr 23 2019 mbrugger@suse.com
- efi/arm: Don't mark ACPI reclaim memory as MEMBLOCK_NOMAP (bsc#1117158 bsc#1115688 bsc#1120566).
- commit 8ab8717
* Tue Apr 23 2019 tzimmermann@suse.de
- drm/mediatek: Fix an error code in mtk_hdmi_dt_parse_pdata() (bsc#1113722)
- commit 63c727d
* Tue Apr 23 2019 tzimmermann@suse.de
- drm/udl: add a release method and delay modeset teardown (bsc#1085536)
- commit c54c0c4
* Tue Apr 23 2019 msuchanek@suse.de
- intel_idle: add support for Jacobsville (jsc#SLE-5394).
- commit 653c52e
* Tue Apr 23 2019 neilb@suse.com
- Fix kabi after "md: batch flush requests." (bsc#1119680).
- md: batch flush requests (bsc#1119680).
- commit db3b444
* Mon Apr 22 2019 dkirjanov@suse.com
- cxgb4: update supported DCB version (bsc#1127371).
- commit e9610db
* Mon Apr 22 2019 dkirjanov@suse.com
- netfilter: ip6t_MASQUERADE: add dependency on conntrack module
  (git-fixes).
- commit c067711
* Mon Apr 22 2019 dkirjanov@suse.com
- gre6: use log_ecn_error module parameter in ip6_tnl_rcv()
  (git-fixes).
- commit 45fd2cd
* Mon Apr 22 2019 dkirjanov@suse.com
- net: bridge: add vlan_tunnel to bridge port policies (git-fixes).
- commit 81c6555
* Mon Apr 22 2019 dkirjanov@suse.com
- rxrpc: Don't release call mutex on error pointer (git-fixes).
- commit b6257a8
* Mon Apr 22 2019 dkirjanov@suse.com
- blacklist.conf: bbbe211c295f ("net: rcu lock and preempt disable missing around generic xdp")
- commit 6d9e01f
* Sat Apr 20 2019 dkirjanov@suse.com
- RDMA/iw_cxgb4: Drop __GFP_NOFAIL (bsc#1127371).
- commit ab1de4b
* Sat Apr 20 2019 dkirjanov@suse.com
- rdma/cxgb4: fix some info leaks (bsc#1127371).
- commit 0460620
* Sat Apr 20 2019 dkirjanov@suse.com
- rdma/cxgb4: Remove a set-but-not-used variable (bsc#1127371).
- commit 64752bc
* Sat Apr 20 2019 dkirjanov@suse.com
- blacklist.conf: 23ff6ba8feec("RDMA/cxgb4: Restore the dropped
  uninitialized_var")
- commit 8ebcd6e
* Sat Apr 20 2019 dkirjanov@suse.com
- rdma/cxgb4: Add support for kernel mode SRQ's (bsc#1127371).
- commit 982fc38
* Fri Apr 19 2019 dkirjanov@suse.com
- rdma/cxgb4: Add support for 64Byte cqes (bsc#1127371).
- commit ed618c3
* Fri Apr 19 2019 dkirjanov@suse.com
- RDMA/cxgb4: Make c4iw_poll_cq_one() easier to analyze (bsc#1127371).
- commit 59e79c3
* Fri Apr 19 2019 dkirjanov@suse.com
- rdma/cxgb4: Add support for srq functions & structs (bsc#1127371).
- commit d29463d
* Thu Apr 18 2019 bp@suse.de
- x86/mce/AMD, EDAC/mce_amd: Enumerate Reserved SMCA bank type
  (bsc#1128415).
- Refresh
  patches.arch/x86-mce-amd-edac-mce_amd-add-new-error-descriptions-for-some-smca-bank-types.patch.
- Refresh
  patches.arch/x86-mce-amd-get-address-from-already-initialized-block.
- commit f372d3f
* Thu Apr 18 2019 dkirjanov@suse.com
- cxgb4/cxgb4vf: Fix mac_hlist initialization and free
  (bsc#1127374).
- commit 50c39df
* Thu Apr 18 2019 dkirjanov@suse.com
- cxgb4vf: Update port information in cxgb4vf_open()
  (bsc#1127374).
- commit 6c8b745
* Thu Apr 18 2019 dkirjanov@suse.com
- cxgb4vf: Few more link management changes (bsc#1127374).
- commit a3abbde
* Thu Apr 18 2019 dkirjanov@suse.com
- cxgb4vf: fix memleak in mac_hlist initialization (bsc#1127374).
- commit 136530a
* Thu Apr 18 2019 bp@suse.de
- s390/speculation: Support 'mitigations=' cmdline option
  (bsc#1112178).
- powerpc/speculation: Support 'mitigations=' cmdline option
  (bsc#1112178).
- x86/speculation: Support 'mitigations=' cmdline option
  (bsc#1112178).
- cpu/speculation: Add 'mitigations=' cmdline option
  (bsc#1112178).
- commit 3423234
* Thu Apr 18 2019 tiwai@suse.de
- Correct the wrongly assigned CVE# (CVE-2019-9503,bsc#1132828)
- commit dc2acc2
* Thu Apr 18 2019 tiwai@suse.de
- x86/PCI: Fixup RTIT_BAR of Intel Denverton Trace Hub (bsc#1120318).
  Delete the old patch with the upstream version, too
  patches.suse/PCI-Disable-broken-RTIT_BAR-of-Intel-TH.patch.
- commit 966a590
* Wed Apr 17 2019 palcantara@suse.de
- CIFS: fix POSIX lock leak and invalid ptr deref (bsc#1114542).
- commit ed4103e
* Wed Apr 17 2019 dkirjanov@suse.com
- iw_cxgb4: cq/qp mask depends on bar2 pages in a host page
  (bsc#1127371).
- commit c36e1b8
* Wed Apr 17 2019 dkirjanov@suse.com
- cxgb4: Export sge_host_page_size to ulds (bsc#1127371).
- Refresh patches.kabi/kabi-cxgb4-MU.patch.
- commit 6d1f2b8
* Wed Apr 17 2019 dkirjanov@suse.com
- cxgb4: collect number of free PSTRUCT page pointers
  (bsc#1127371).
- Refresh
  patches.fixes/0001-cxgb4-move-Tx-Rx-free-pages-collection-to-common-cod.patch.
- commit e76f63e
* Wed Apr 17 2019 dkirjanov@suse.com
- cxgb4: collect ASIC LA dumps from ULP TX (bsc#1127371).
- commit 0173335
* Wed Apr 17 2019 dkirjanov@suse.com
- cxgb4: Remove SGE_HOST_PAGE_SIZE dependency on page size
  (bsc#1127371).
- commit 5b5f3de
* Wed Apr 17 2019 tiwai@suse.de
- brcmfmac: assure SSID length from firmware is limited
  (CVE-2019-9500,bsc#1132681).
- commit beb6147
* Wed Apr 17 2019 dkirjanov@suse.com
- cxgb4: move Tx/Rx free pages collection to common code (bsc#1127371).
- commit d3b85a6
* Wed Apr 17 2019 jroedel@suse.de
- svm/avic: Fix invalidate logical APIC id entry (bsc#1132726).
- commit a0c00f8
* Tue Apr 16 2019 tiwai@suse.de
- brcmfmac: add subtype check for event handling in data path
  (CVE-2019-8564,bsc#1132673).
- commit dfd89cb
* Tue Apr 16 2019 dkirjanov@suse.com
- cxgb4: add support to display DCB info (bsc#1127371).
- commit 5b50c7b
* Tue Apr 16 2019 bp@suse.de
- blacklist.conf: bebd024e4815 ("x86/smp: Enforce CONFIG_HOTPLUG_CPU when SMP=y")
  SLE kernels already enable this.
- commit 577c0d1
* Tue Apr 16 2019 dkirjanov@suse.com
- cxgb4: Add new T6 PCI device ids 0x608a (bsc#1127371).
- commit 06d9ae2
* Tue Apr 16 2019 dkirjanov@suse.com
- cxgb4: Add new T5 PCI device ids 0x50af and 0x50b0 (bsc#1127371).
- commit 9210ec3
* Tue Apr 16 2019 dkirjanov@suse.com
- cxgb4: display number of rx and tx pages free (bsc#1127371).
- commit 436d16d
* Tue Apr 16 2019 dkirjanov@suse.com
- cxgb4: cxgb4: use FW_PORT_ACTION_L1_CFG32 for 32 bit capability (bsc#1127371).
- commit a42b78c
* Tue Apr 16 2019 dkirjanov@suse.com
- assume flash part size to be 4MB, if it can't be determined (bsc#1127371).
- commit 84ea04f
* Tue Apr 16 2019 jroedel@suse.de
- Refresh patches.arch/svm-fix-avic-dfr-and-ldr-handling.
  Fix compile warning introduced by this patch.
- commit 30fa6d4
* Tue Apr 16 2019 jgross@suse.com
- xen: Prevent buffer overflow in privcmd ioctl (bsc#1065600).
- commit c236911
* Tue Apr 16 2019 jroedel@suse.de
- blacklist.conf: Blacklist some KVM reverts not needed in SLE
- commit d786a86
* Tue Apr 16 2019 bp@suse.de
- KVM: x86: Emulate MSR_IA32_ARCH_CAPABILITIES on AMD hosts
  (bsc#1114279).
- commit 321dd9f
* Mon Apr 15 2019 bp@suse.de
- x86/mce/AMD: Pass the bank number to smca_get_bank_type()
  (bsc#1128415).
- commit 2a78c16
* Mon Apr 15 2019 jkosina@suse.cz
- x86/bugs: do not default to IBRS even on SKL (bsc#1068032
  CVE-2017-5753 bsc#1112824).
  Drop SUSE-specific IBRS-on-SKL implementation. Please refer to
  page 16 of [1]
  [1] https://software.intel.com/security-software-guidance/api-app/sites/default/files/Retpoline-A-Branch-Target-Injection-Mitigation.pdf
- commit 6ab40f5
* Mon Apr 15 2019 dkirjanov@suse.com
- cxgb4: Support ethtool private flags (bsc#1127371).
- commit dc8dc20
* Mon Apr 15 2019 jroedel@suse.de
- x86/kvm/hyper-v: avoid spurious pending stimer on vCPU init
  (bsc#1132572).
- KVM: x86/mmu: Do not cache MMIO accesses while memslots are
  in flux (bsc#1132571).
- KVM: x86/mmu: Detect MMIO generation wrap in any address space
  (bsc#1132570).
- commit eff2335
* Mon Apr 15 2019 jroedel@suse.de
- KVM: Call kvm_arch_memslots_updated() before updating memslots
  (bsc#1132563).
- KVM: nVMX: Ignore limit checks on VMX instructions using flat
  segments (bsc#1132564).
- commit f524d2f
* Mon Apr 15 2019 jroedel@suse.de
- KVM: nVMX: Apply addr size mask to effective address for VMX
  instructions (bsc#1132561).
- KVM: nVMX: Sign extend displacements of VMX instr's mem operands
  (bsc#1132562).
- commit 27486c3
* Mon Apr 15 2019 dkirjanov@suse.com
- cxgb4: collect hardware queue descriptors (bsc#1127371).
- commit 16f34c6
* Mon Apr 15 2019 jroedel@suse.de
- svm: Fix AVIC DFR and LDR handling (bsc#1132558).
- commit e81dbdd
* Mon Apr 15 2019 msuchanek@suse.de
- powerpc/powernv: Make opal log only readable by root
  (bsc#1065729).
- commit e1d68e1
* Mon Apr 15 2019 jroedel@suse.de
- KVM: VMX: Compare only a single byte for VMCS' "launched" in vCPU-run (bsc#1132555).
- commit 709aa15
* Mon Apr 15 2019 msuchanek@suse.de
- powerpc/64s: Fix logic when handling unknown CPU features
  (bsc#1055117).
- commit 9eac226
* Mon Apr 15 2019 tiwai@suse.de
- ALSA: hda - Add two more machines to the power_save_blacklist
  (bsc#1051510).
- ALSA: seq: Fix OOB-reads from strlcpy (bsc#1051510).
- commit 6ae1972
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: tracing: affected code is not in our kernel
- commit 9d2222a
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: tracing: affected code is not in our kernel
- commit 99bb62d
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: tracing: affected code is not in our kernel
- commit 8e8b386
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: tracing: cosmetic
- commit bba8a93
* Mon Apr 15 2019 pmladek@suse.com
- ring-buffer: Check if memory is available before allocation
  (bsc#1132531).
- commit 30fa12d
* Mon Apr 15 2019 pmladek@suse.com
- tracing/hrtimer: Fix tracing bugs by taking all clock bases
  and modes into account (bsc#1132527).
- commit 08a11e1
* Mon Apr 15 2019 jroedel@suse.de
- iommu/amd: Set exclusion range correctly (bsc#1130425).
- commit 0dd02d9
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: trace/xdp: compilation warning; we do not have
  the affected code
- commit 28d52fb
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: tracing: nothing serious
- commit fad463b
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: vsprintf: cosmetic
- commit 2fa0e86
* Mon Apr 15 2019 pmladek@suse.com
- blacklist.conf: printk: cosmetic; anyway, it fixes a commit
  that we do not have in SLE15
- commit 8801f18
* Sun Apr 14 2019 dkirjanov@suse.com
- Refresh patches.kabi/kabi-cxgb4-MU.patch.
- commit 3439f3f
* Sun Apr 14 2019 dkirjanov@suse.com
- cxgb4: Add capability to get/set SGE Doorbell Queue Timer Tick
  (bsc#1127371).
- commit 7cc943d
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: flush removing page cache in xfs_reflink_remap_prep
  (bsc#1132414, bsc#1132219).
- commit ab00137
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: clean up xfs_reflink_remap_blocks call site (bsc#1132413,
  bsc#1132219).
- commit 07a90bd
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: fix pagecache truncation prior to reflink (bsc#1132412,
  bsc#1132219).
- commit b82ce17
* Fri Apr 12 2019 ailiopoulos@suse.com
- vfs: exit early from zero length remap operations (bsc#1132411,
  bsc#1132219).
- commit 1006b3a
* Fri Apr 12 2019 bp@suse.de
- x86/MCE: Fix kABI for new AMD bank names (bsc#1128415).
- commit e9b2424
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: fix data corruption w/ unaligned reflink ranges
  (bsc#1132407, bsc#1132219).
- commit a452f04
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: fix data corruption w/ unaligned dedupe ranges
  (bsc#1132405, bsc#1132219).
- commit 16170da
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: update ctime and remove suid before cloning files
  (bsc#1132404, bsc#1132219).
- commit 9e067d2
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: zero posteof blocks when cloning above eof (bsc#1132403,
  bsc#1132219).
- commit e7442c0
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: refactor clonerange preparation into a separate helper
  (bsc#1132402, bsc#1132219).
- commit 7ca8ffb
* Fri Apr 12 2019 ailiopoulos@suse.com
- vfs: limit size of dedupe (bsc#1132397, bsc#1132219).
- commit 3488d92
* Fri Apr 12 2019 ailiopoulos@suse.com
- fs: avoid fdput() after failed fdget() in
  vfs_dedupe_file_range() (bsc#1132384, bsc#1132219).
- commit 71bd329
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: cap the length of deduplication requests (bsc#1132373,
  bsc#1132219).
- commit 190ac4b
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: only grab shared inode locks for source file during reflink
  (bsc#1132372, bsc#1132219).
- commit 3e9e506
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: allow xfs_lock_two_inodes to take different EXCL/SHARED
  modes (bsc#1132370, bsc#1132219).
- commit e1da3ac
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: reflink should break pnfs leases before sharing blocks
  (bsc#1132369, bsc#1132219).
- commit 808ec37
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: call xfs_qm_dqattach before performing reflink operations
  (bsc#1132368, bsc#1132219).
- commit 8d05605
* Fri Apr 12 2019 ailiopoulos@suse.com
- xfs: remove dest file's post-eof preallocations before
  reflinking (bsc#1132365, bsc#1132219).
- commit 4e87704
* Fri Apr 12 2019 dkirjanov@suse.com
- cxgb4: Added missing break in ndo_udp_tunnel_{add/del} (bsc#1127371).
- commit 3d3df4e
* Fri Apr 12 2019 dkirjanov@suse.com
- cxgb4: do not return DUPLEX_UNKNOWN when link is down (bsc#1127371).
- commit 85c678c
* Fri Apr 12 2019 dkirjanov@suse.com
- cxgb4: Add new T5 PCI device id 0x50ae (bsc#1127371).
- commit 899ca26
* Fri Apr 12 2019 dkirjanov@suse.com
- cxgb4/cxgb4vf: Link management changes (bsc#1127371).
- commit e37a35f
* Fri Apr 12 2019 jroedel@suse.de
- vfio/type1: Limit DMA mappings per container (CVE-2019-3882 bsc#1131427).
- commit ddc4716
* Fri Apr 12 2019 jslaby@suse.cz
- net/x25: reset state in x25_connect()
  (networking-stable-19_03_15).
- net: sit: fix UBSAN Undefined behaviour in check_6rd
  (networking-stable-19_03_15).
- net/x25: fix use-after-free in x25_device_event()
  (networking-stable-19_03_15).
- rxrpc: Fix client call queueing, waiting for channel
  (networking-stable-19_03_15).
- route: set the deleted fnhe fnhe_daddr to 0 in ip_del_fnhe to
  fix a race (networking-stable-19_03_15).
- net/hsr: fix possible crash in add_timer()
  (networking-stable-19_03_15).
- ravb: Decrease TxFIFO depth of Q3 and Q2 to one
  (networking-stable-19_03_15).
- net: hsr: fix memory leak in hsr_dev_finalize()
  (networking-stable-19_03_15).
- net/x25: fix a race in x25_bind() (networking-stable-19_03_15).
- net: Set rtm_table to RT_TABLE_COMPAT for ipv6 for tables >
  255 (networking-stable-19_03_15).
- ipvlan: disallow userns cap_net_admin to change global
  mode/flags (networking-stable-19_03_15).
- missing barriers in some of unix_sock ->addr and ->path accesses
  (networking-stable-19_03_15).
- commit 4256fc7
* Fri Apr 12 2019 jslaby@suse.cz
- net/packet: Set __GFP_NOWARN upon allocation in alloc_pg_vec
  (git-fixes).
- commit 9b93af5
* Fri Apr 12 2019 jslaby@suse.cz
- qmi_wwan: Add support for Quectel EG12/EM12
  (networking-stable-19_03_07).
- net: sit: fix memory leak in sit_init_net()
  (networking-stable-19_03_07).
- net: dsa: mv88e6xxx: Fix u64 statistics
  (networking-stable-19_03_07).
- xen-netback: don't populate the hash cache on XenBus disconnect
  (networking-stable-19_03_07).
- xen-netback: fix occasional leak of grant ref mappings under
  memory pressure (networking-stable-19_03_07).
- netlabel: fix out-of-bounds memory accesses
  (networking-stable-19_03_07).
- net: nfc: Fix NULL dereference on nfc_llcp_build_tlv fails
  (networking-stable-19_03_07).
- bnxt_en: Drop oversize TX packets to prevent errors
  (networking-stable-19_03_07).
- tipc: fix race condition causing hung sendto
  (networking-stable-19_03_07).
- hv_netvsc: Fix IP header checksum for coalesced packets
  (networking-stable-19_03_07).
- mpls: Return error for RTA_GATEWAY attribute
  (networking-stable-19_03_07).
- ipv6: Return error for RTA_VIA attribute
  (networking-stable-19_03_07).
- ipv4: Return error for RTA_VIA attribute
  (networking-stable-19_03_07).
- net: avoid use IPCB in cipso_v4_error
  (networking-stable-19_03_07).
- net: Add __icmp_send helper (networking-stable-19_03_07).
- kABI: restore icmp_send (kabi).
- tun: remove unnecessary memory barrier
  (networking-stable-19_03_07).
- net: socket: set sock->sk to NULL after calling
  proto_ops::release() (networking-stable-19_03_07).
- tun: fix blocking read (networking-stable-19_03_07).
- commit 8f4c9d1
* Thu Apr 11 2019 msuchanek@suse.de
- supported.conf: dw_mmc-bluefield is not needed in kernel-default-base
  (bsc#1131574).
- commit 3eb7cba
* Thu Apr 11 2019 msuchanek@suse.de
- ibmvnic: Fix netdev feature clobbering during a reset
  (bsc#1132227).
- ibmvnic: Enable GRO (bsc#1132227).
- commit 0d7a77f
* Thu Apr 11 2019 dbueso@suse.de
- futex: Ensure that futex address is aligned in
  handle_futex_death() (bsc#1050549).
- x86/tsc: Force inlining of cyc2ns bits (bsc#1052904).
- commit 15ce0ba
* Thu Apr 11 2019 dkirjanov@suse.com
- Refresh patches.kabi/kabi-cxgb4-MU.patch.
- commit e74784a
* Thu Apr 11 2019 msuchanek@suse.de
- Do not provide kernel-default from kernel-default-base (boo#1132154, bsc#1106751).
- commit 0e54e61
* Thu Apr 11 2019 msuchanek@suse.de
- rpm/kernel-subpackage-spec: only provide firmware actually present in
  subpackage.
- commit 839debd
* Thu Apr 11 2019 tiwai@suse.de
- crypto: pcbc - remove bogus memcpy()s with src == dest
  (bsc#1051510).
- commit 94f7856
* Thu Apr 11 2019 ailiopoulos@suse.com
- xfs: reflink find shared should take a transaction (bsc#1132226,
  bsc#1132219).
- Refresh
  patches.fixes/0009-xfs-rewrite-getbmap-using-the-xfs_iext_-helpers.patch.
- commit cd2c8d9
* Thu Apr 11 2019 jack@suse.cz
- patches.fixes/vfs-Avoid-softlockups-in-drop_pagecache_sb.patch: Update
  tags and push to sorted section
- commit ad7e442
* Thu Apr 11 2019 dkirjanov@suse.com
- cxgb4/cxgb4vf: Add support for SGE doorbell queue timer (bsc#1127371).
- commit 58a71eb
* Thu Apr 11 2019 tiwai@suse.de
- KEYS: user: Align the payload buffer (bsc#1051510).
- commit 40d3684
* Thu Apr 11 2019 tiwai@suse.de
- KEYS: always initialize keyring_index_key::desc_len
  (bsc#1051510).
- commit 5ee13c4
* Thu Apr 11 2019 tiwai@suse.de
- mmc: tmio_mmc_core: don't claim spurious interrupts
  (bsc#1051510).
- commit ecf4c22
* Thu Apr 11 2019 tiwai@suse.de
- NFC: nci: Add some bounds checking in nci_hci_cmd_received()
  (bsc#1051510).
- commit 6f0ec11
* Thu Apr 11 2019 tiwai@suse.de
- staging: vt6655: Remove vif check from vnt_interrupt
  (bsc#1051510).
- staging: vt6655: Fix interrupt race condition on device start up
  (bsc#1051510).
- commit 6182d56
* Thu Apr 11 2019 jslaby@suse.cz
- net: avoid false positives in untrusted gso validation
  (git-fixes).
- commit d106ebd
* Thu Apr 11 2019 jslaby@suse.cz
- sctp: call gso_reset_checksum when computing checksum in
  sctp_gso_segment (networking-stable-19_02_24).
- net_sched: fix two more memory leaks in cls_tcindex
  (networking-stable-19_02_24).
- net/packet: fix 4gb buffer limit due to overflow check
  (networking-stable-19_02_24).
- ipv6: propagate genlmsg_reply return code
  (networking-stable-19_02_24).
- sit: check if IPv6 enabled before calling
  ip6_err_gen_icmpv6_unreach() (networking-stable-19_02_24).
- net/mlx5e: Don't overwrite pedit action when multiple pedit used
  (networking-stable-19_02_24).
- commit 905de62
* Thu Apr 11 2019 jslaby@suse.cz
- kcm: switch order of device registration to fix a crash
  (bnc#1130527).
- commit 97a6921
* Thu Apr 11 2019 hare@suse.de
- nvme: fix the dangerous reference of namespaces list
  (bsc#1131673).
- Refresh
  patches.fixes/nvme-ensure-forward-progress-during-admin-passthru.patch.
- Refresh
  patches.fixes/nvme-flush-namespace-scanning-work-just-before-remov.patch.
- commit 723fb31
* Thu Apr 11 2019 jslaby@suse.cz
- net: Do not allocate page fragments that are not skb aligned
  (networking-stable-19_02_20).
- tcp: tcp_v4_err() should be more careful
  (networking-stable-19_02_20).
- net: Add header for usage of fls64()
  (networking-stable-19_02_20).
- net: validate untrusted gso packets without csum offload
  (networking-stable-19_02_20).
- net: Fix for_each_netdev_feature on Big endian
  (networking-stable-19_02_20).
- dsa: mv88e6xxx: Ensure all pending interrupts are handled
  prior to exit (networking-stable-19_02_20).
- net: fix IPv6 prefix route residue (networking-stable-19_02_20).
- vxlan: test dev->flags & IFF_UP before calling netif_rx()
  (networking-stable-19_02_20).
- commit a7a9e9f
* Thu Apr 11 2019 dbueso@suse.de
- futex: Handle early deadlock return correctly (bsc#1050549).
- commit 616063c
* Wed Apr 10 2019 dkirjanov@suse.com
- cxgb4: Add support for FW_ETH_TX_PKT_VM_WR (bsc#1127371).
- commit 3691bab
* Wed Apr 10 2019 dkirjanov@suse.com
- Update patches.kabi/kabi-cxgb4-MU.patch (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584 bsc#1127371).
- commit 7897fc2
* Wed Apr 10 2019 dkirjanov@suse.com
- cxgb4: Add support to read actual provisioned resources
  (bsc#1127371).
- commit 295f1ae
* Wed Apr 10 2019 msuchanek@suse.de
- kernel-subpackage-spec: Add dummy package to ensure subpackages are
  rebuilt with kernel update (bsc#1106751).
  In factory packages are not rebuilt automatically so a dependency is
  needed on the old kernel to get a rebuild with the new kernel. THe
  subpackage itself cannot depend on the kernel so add another empty
  pacakge that does depend on it.
- commit 6d14837
* Wed Apr 10 2019 msuchanek@suse.de
- supported.conf: Add vxlan to kernel-default-base (bsc#1132083).
- commit 6b4f077
* Wed Apr 10 2019 oneukum@suse.com
- iwiwifi: fix bad monitor buffer register addresses
  (bsc#1129770).
- commit a09c4f1
* Wed Apr 10 2019 oneukum@suse.com
- iwlwifi: fix send hcmd timeout recovery flow (bsc#1129770).
- commit 675aabf
* Wed Apr 10 2019 oneukum@suse.com
- mwifiex: don't advertise IBSS features without FW support
  (bsc#1129770).
- commit ad88ebe
* Wed Apr 10 2019 msuchanek@suse.de
- tpm: Fix the type of the return value in calc_tpm2_event_size()
  (bsc#1082555).
- commit 6313c7d
* Wed Apr 10 2019 tiwai@suse.de
- Bluetooth: btusb: request wake pin with NOAUTOEN (bsc#1051510).
- commit 8a90dff
* Wed Apr 10 2019 msuchanek@suse.de
- powerpc/powernv/cpuidle: Init all present cpus for deep states
  (bsc#1055121).
- commit ef0cd6d
* Tue Apr  9 2019 msuchanek@suse.de
- Refresh patches.arch/powerpc-64s-Simple-RFI-macro-conversions.patch.
- commit a429c56
* Tue Apr  9 2019 msuchanek@suse.de
- kbuild: strip whitespace in cmd_record_mcount findstring
  (bsc#1065729).
- powerpc: avoid -mno-sched-epilog on GCC 4.9 and newer
  (bsc#1065729).
- powerpc: consolidate -mno-sched-epilog into FTRACE flags
  (bsc#1065729).
- commit 051f1dc
* Tue Apr  9 2019 tiwai@suse.de
- Disable kgdboc failed by echo space to
  /sys/module/kgdboc/parameters/kgdboc (bsc#1051510).
- commit b2052bc
* Tue Apr  9 2019 hare@suse.de
- dm: disable DISCARD if the underlying storage no longer supports
  it (bsc#1114638).
- nvme: add proper discard setup for the multipath device
  (bsc#1114638).
- nvme: only reconfigure discard if necessary (bsc#1114638).
- commit da20e0a
* Tue Apr  9 2019 oneukum@suse.com
- crypto: caam - add missing put_device() call (bsc#1129770).
- commit 160936b
* Tue Apr  9 2019 osalvador@suse.de
- mm/page_isolation.c: fix a wrong flag in
  set_migratetype_isolate() (bsc#1131935).
- commit adffe77
* Tue Apr  9 2019 fabian.baumanis@suse.com
- blacklist.conf: Prerequisites would be too invasive
- commit 53a57ca
* Tue Apr  9 2019 nborisov@suse.com
- btrfs: Avoid possible qgroup_rsv_size overflow in
  btrfs_calculate_inode_block_rsv_size (git-fixes).
- btrfs: Fix bound checking in qgroup_trace_new_subtree_blocks
  (git-fixes).
- commit e57933e
* Tue Apr  9 2019 dkirjanov@suse.com
- cxgb4: Mask out interrupts that are not enabled (bsc#1127175).
- commit 3062605
* Tue Apr  9 2019 dkirjanov@suse.com
- cxgb4: add per rx-queue counter for packet errors (bsc#1127371).
- commit 1e45816
* Tue Apr  9 2019 osalvador@suse.de
- mm/debug.c: fix __dump_page when mapping->host is not set
  (bsc#1131934).
- commit 49f8973
* Tue Apr  9 2019 hare@suse.de
- block: kABI fixes for bio_rewind_iter() removal (bsc#1131673).
- block: remove bio_rewind_iter() (bsc#1131673).
- commit ed035ef
* Tue Apr  9 2019 neilb@suse.com
- NFSv4.1: Reinitialise sequence results before retransmitting
  a request (git-fixes).
- Refresh
  patches.kabi/NFSv4.1-Fix-up-replays-of-interrupted-requests.patch.
- commit c0890e9
* Tue Apr  9 2019 neilb@suse.com
- NFS: Fix a typo in nfs_init_timeout_values() (git-fixes).
- NFSv4/flexfiles: Fix invalid deref in FF_LAYOUT_DEVID_NODE()
  (git-fixes).
- NFS/pnfs: Bulk destroy of layouts needs to be safe w.r.t. umount
  (git-fixes).
- NFS: Fix a soft lockup in the delegation recovery code
  (git-fixes).
- fs/nfs: Fix nfs_parse_devname to not modify it's argument
  (git-fixes).
- NFS: Don't recoalesce on error in nfs_pageio_complete_mirror()
  (git-fixes).
- NFS: Fix an I/O request leakage in nfs_do_recoalesce
  (git-fixes).
- NFS: Fix I/O request leakages (git-fixes).
- sunrpc: fix 4 more call sites that were using stack memory
  with a scatterlist (git-fixes).
- nfsd4: catch some false session retries (git-fixes).
- nfsd4: fix cached replies to solo SEQUENCE compounds
  (git-fixes).
- commit f540a8d
* Tue Apr  9 2019 neilb@suse.com
- NFSv4.1 don't free interrupted slot on open (git-fixes).
- NFS: fix mount/umount race in nlmclnt (git-fixes).
- NFS: Don't use page_file_mapping after removing the page
  (git-fixes).
- commit 85579ed
* Tue Apr  9 2019 neilb@suse.com
- md: Fix failed allocation of md_register_thread (git-fixes).
- It's wrong to add len to sector_nr in raid10 reshape twice
  (git-fixes).
- md/raid1: don't clear bitmap bits on interrupted recovery
  (git-fixes).
- md/raid5: fix 'out of memory' during raid cache recovery
  (git-fixes).
- commit d04c4f2
* Mon Apr  8 2019 msuchanek@suse.de
- powerpc/mm/hash: Handle mmap_min_addr correctly in
  get_unmapped_area topdown search (bsc#1131900).
- powerpc/hugetlb: Handle mmap_min_addr correctly in
  get_unmapped_area callback (bsc#1131900).
- commit 01e3e7d
* Mon Apr  8 2019 msuchanek@suse.de
- powerpc/mm: Check secondary hash page table (bsc#1065729).
- commit 705707e
* Mon Apr  8 2019 msuchanek@suse.de
- powerpc/kvm: Save and restore host AMR/IAMR/UAMOR (bsc#1061840).
- powerpc/powernv/ioda: Fix locked_vm counting for memory used
  by IOMMU tables (bsc#1061840).
- powerpc/powernv: Don't reprogram SLW image on every KVM guest
  entry/exit (bsc#1061840).
- powerpc: Fix 32-bit KVM-PR lockup and host crash with MacOS
  guest (bsc#1061840).
- powerpc/powernv: Remove never used pnv_power9_force_smt4
  (bsc#1061840).
- powerpc/powernv/ioda: Allocate indirect TCE levels of cached
  userspace addresses on demand (bsc#1061840).
- KVM: PPC: Book3S HV: Fix race between kvm_unmap_hva_range and
  MMU mode switch (bsc#1061840).
- powerpc/powernv/ioda2: Remove redundant free of TCE pages
  (bsc#1061840).
- commit 793f82e
* Mon Apr  8 2019 msuchanek@suse.de
- powerpc/perf: Remove l2 bus events from HW cache event array
  (bsc#1053043).
- powerpc/perf: Fix unit_sel/cache_sel checks (bsc#1053043).
- commit 9d44872
* Mon Apr  8 2019 msuchanek@suse.de
- blacklist
  0bbea75c476b powerpc/traps: fix recoverability of machine check handling on book3s/32
  179ab1cbf883 powerpc/64: Add CONFIG_PPC_BARRIER_NOSPEC
- commit cd08784
* Mon Apr  8 2019 tiwai@suse.de
- wlcore: Fix memory leak in case wl12xx_fetch_firmware failure
  (bsc#1051510).
- commit 6809a3d
* Mon Apr  8 2019 tiwai@suse.de
- wil6210: check null pointer in _wil_cfg80211_merge_extra_ies
  (bsc#1051510).
- commit 6b4747c
* Mon Apr  8 2019 tiwai@suse.de
- usb: chipidea: Grab the (legacy) USB PHY by phandle first
  (bsc#1051510).
- usb: f_fs: Avoid crash due to out-of-scope stack ptr access
  (bsc#1051510).
- commit 0b2fd5e
* Mon Apr  8 2019 tiwai@suse.de
- sysctl: handle overflow for file-max (bsc#1051510).
- commit a956e89
* Mon Apr  8 2019 tiwai@suse.de
- SoC: imx-sgtl5000: add missing put_device() (bsc#1051510).
- soc: qcom: gsbi: Fix error handling in gsbi_probe()
  (bsc#1051510).
- soc/tegra: fuse: Fix illegal free of IO base address
  (bsc#1051510).
- commit dc51183
* Mon Apr  8 2019 tiwai@suse.de
- staging: rtl8712: uninitialized memory in read_bbreg_hdl()
  (bsc#1051510).
- commit 155de9a
* Mon Apr  8 2019 tiwai@suse.de
- phy: sun4i-usb: Support set_mode to USB_HOST for non-OTG PHYs
  (bsc#1051510).
- commit cb64f79
* Mon Apr  8 2019 tiwai@suse.de
- mt7601u: bump supported EEPROM version (bsc#1051510).
- commit 208ba38
* Mon Apr  8 2019 tiwai@suse.de
- media: sh_veu: Correct return type for mem2mem buffer helpers
  (bsc#1051510).
- media: s5p-jpeg: Correct return type for mem2mem buffer helpers
  (bsc#1051510).
- media: s5p-g2d: Correct return type for mem2mem buffer helpers
  (bsc#1051510).
- media: mx2_emmaprp: Correct return type for mem2mem buffer
  helpers (bsc#1051510).
- media: mtk-jpeg: Correct return type for mem2mem buffer helpers
  (bsc#1051510).
- media: mt9m111: set initial frame size other than 0x0
  (bsc#1051510).
- commit 90a0ddb
* Mon Apr  8 2019 tiwai@suse.de
- iio: adc: fix warning in Qualcomm PM8xxx HK/XOADC driver
  (bsc#1051510).
- commit 6caf79b
* Mon Apr  8 2019 tiwai@suse.de
- hwrng: virtio - Avoid repeated init of completion (bsc#1051510).
- commit bf42009
* Mon Apr  8 2019 tiwai@suse.de
- HID: intel-ish-hid: avoid binding wrong ishtp_cl_device
  (bsc#1051510).
- HID: intel-ish: ipc: handle PIMR before ish_wakeup also clear
  PISR busy_clear bit (bsc#1051510).
- commit ae1bdb3
* Mon Apr  8 2019 msuchanek@suse.de
- blacklist.conf: blacklist ppc/32bit and ppc/embedded commits
  b45ba4a51cde powerpc/lib: fix book3s/32 boot failure due to code patching
  9580b71b5a78 powerpc/32: Clear on-stack exception marker upon exception return
  039daac55269 powerpc/fsl: Fixed warning: orphan section `__btb_flush_fixup'
  76a5eaa38b15 powerpc/fsl: Add infrastructure to fixup branch predictor flush
  1cbf8990d79f powerpc/fsl: Add macro to flush the branch predictor
  f633a8ad636e powerpc/fsl: Add nospectre_v2 command line argument
  10c5e83afd4a powerpc/fsl: Flush the branch predictor at each kernel entry (64bit)
  7fef436295bf powerpc/fsl: Flush the branch predictor at each kernel entry (32 bit)
  3bc8ea8603ae powerpc/fsl: Enable runtime patching if nospectre_v2 boot arg is used
  dfa88658fb05 powerpc/fsl: Update Spectre v2 reporting
  36da5ff0bea2 powerpc/83xx: Also save/restore SPRG4-7 during suspend
  6d183ca8baec powerpc/wii: properly disable use of BATs when requested.
- commit b0dd199
* Mon Apr  8 2019 tiwai@suse.de
- gpio: of: Fix of_gpiochip_add() error path (bsc#1051510).
- gpio: adnp: Fix testing wrong value in adnp_gpio_direction_input
  (bsc#1051510).
- gpio: gpio-omap: fix level interrupt idling (bsc#1051510).
- commit 4bb2e39
* Mon Apr  8 2019 msuchanek@suse.de
- powerpc/mm: Add missing tracepoint for tlbie (bsc#1055117,
  git-fixes).
- powerpc64/ftrace: Include ftrace.h needed for enable/disable
  calls (bsc#1088804, git-fixes).
- commit c88ea21
* Mon Apr  8 2019 tiwai@suse.de
- fm10k: Fix a potential NULL pointer dereference (bsc#1051510).
- commit bbe540e
* Mon Apr  8 2019 tiwai@suse.de
- fbdev: fbmem: fix memory access if logo is bigger than the
  screen (bsc#1051510).
- commit d825899
* Mon Apr  8 2019 tiwai@suse.de
- e1000e: Fix -Wformat-truncation warnings (bsc#1051510).
- e1000e: fix cyclic resets at link up with active tx
  (bsc#1051510).
- commit 4f78665
* Mon Apr  8 2019 tiwai@suse.de
- drm/i915/gvt: do not deliver a workload if its creation fails
  (bsc#1051510).
- drm: Auto-set allow_fb_modifiers when given modifiers at plane
  init (bsc#1051510).
- drm/nouveau: Stop using drm_crtc_force_disable (bsc#1051510).
- drm/dp/mst: Configure no_stop_bit correctly for remote i2c xfers
  (bsc#1051510).
- commit 1e63ac0
* Mon Apr  8 2019 tiwai@suse.de
- dmaengine: tegra: avoid overflow of byte tracking (bsc#1051510).
- dmaengine: imx-dma: fix warning comparison of distinct pointer
  types (bsc#1051510).
- dmaengine: qcom_hidma: assign channel cookie correctly
  (bsc#1051510).
- commit 503f9a0
* Mon Apr  8 2019 tiwai@suse.de
- cpupowerutils: bench - Fix cpu online check (bsc#1051510).
- commit a829aa9
* Mon Apr  8 2019 tiwai@suse.de
- clk: rockchip: fix frac settings of GPLL clock for rk3328
  (bsc#1051510).
- clk: fractional-divider: check parent rate only if flag is set
  (bsc#1051510).
- commit 142df98
* Mon Apr  8 2019 tiwai@suse.de
- cdrom: Fix race condition in cdrom_sysctl_register
  (bsc#1051510).
- commit a569b56
* Mon Apr  8 2019 tiwai@suse.de
- batman-adv: Reduce tt_global hash refcnt only for removed entry
  (bsc#1051510).
- batman-adv: Reduce tt_local hash refcnt only for removed entry
  (bsc#1051510).
- batman-adv: Reduce claim hash refcnt only for removed entry
  (bsc#1051510).
- commit 6d5f647
* Mon Apr  8 2019 tiwai@suse.de
- ASoC: fsl-asoc-card: fix object reference leaks in
  fsl_asoc_card_probe (bsc#1051510).
- commit 0c80b58
* Mon Apr  8 2019 tiwai@suse.de
- ALSA: PCM: check if ops are defined before suspending PCM
  (bsc#1051510).
- commit 3af8a26
* Mon Apr  8 2019 oneukum@suse.com
- RAS/CEC: Check the correct variable in the debugfs error
  handling (bsc#1085535).
- commit b4b7dc8
* Mon Apr  8 2019 oneukum@suse.com
- blacklist.conf: cleanup that breaks kABI (removing exported macros)
- commit 0f9dd9c
* Mon Apr  8 2019 oneukum@suse.com
- lightnvm: if LUNs are already allocated fix return
  (bsc#1085535).
- commit 7a5f19f
* Mon Apr  8 2019 jack@suse.cz
- ext4: cleanup bh release code in ext4_ind_remove_space()
  (bsc#1131851).
- commit 0f68dfb
* Mon Apr  8 2019 fdmanana@suse.com
- Btrfs: fix assertion failure on fsync with NO_HOLES enabled
  (bsc#1131848).
- commit 344ee60
* Mon Apr  8 2019 fdmanana@suse.com
- btrfs: remove WARN_ON in log_dir_items (bsc#1131847).
- commit 3905aef
* Mon Apr  8 2019 fdmanana@suse.com
- Btrfs: fix incorrect file size after shrinking truncate and
  fsync (bsc#1130195).
- commit 16559ac
* Mon Apr  8 2019 tzimmermann@suse.de
- drm/i915/gvt: do not let pin count of shadow mm go negative (bsc#1113722)
- commit adbe28f
* Mon Apr  8 2019 tzimmermann@suse.de
- drm/i915/gvt: Add in context mmio 0x20D8 to gen9 mmio list (bsc#1113722)
- commit b9f4942
* Mon Apr  8 2019 tzimmermann@suse.de
- drm/rockchip: vop: reset scale mode when win is disabled (bsc#1113722)
- commit 766b520
* Mon Apr  8 2019 oneukum@suse.com
- USB: serial: cp210x: fix GPIO in autosuspend (bsc#1120902).
- commit c2fe95d
* Mon Apr  8 2019 jthumshirn@suse.de
- blacklist.conf: 47b16820c490 ("xsysace: Fix error handling in ace_setup")
  Xilinx SystemACE is unsupported.
- commit 5aa9dd7
* Mon Apr  8 2019 jthumshirn@suse.de
- blacklist.conf: 02db99548d36 ("nvmet: fix building bvec from sg list") is
  only needed with file-backed namespace, so only backport it to SLE15-SP1.
- commit 14a4b83
* Mon Apr  8 2019 oneukum@suse.com
- blacklist.conf: unsupported Atom version
- commit 19dc7a1
* Mon Apr  8 2019 osalvador@suse.de
- s390/pkey: move pckmo subfunction available checks away from
  module init (bsc#1128544).
- commit bf44580
* Mon Apr  8 2019 jack@suse.cz
- patches.fixes/mm-huge_memory.c-fix-modifying-of-page-protection-by-insert_pfn_pmd.patch:
  Update tags
- commit 6abd3db
* Fri Apr  5 2019 msuchanek@suse.de
- ibmvnic: Fix completion structure initialization (bsc#1131659).
- commit 64ed59b
* Thu Apr  4 2019 msuchanek@suse.de
- Linux v5.0-rc7: bcm2835 MMC issues (bsc#1070872).
- commit add15c8
* Thu Apr  4 2019 jeffm@suse.com
- scsi: libsas: allocate sense buffer for bsg queue (bsc#1131467).
  This patch obsoletes the following patches and they have been removed:
- patches.fixes/bsg-Do-not-copy-sense-if-no-response-buffer-is-alloc.patch.
- patches.suse/mpt3sas-check-sense-buffer-before-copying-sense-data.patch.
- commit a55f096
* Thu Apr  4 2019 msuchanek@suse.de
- powerpc/vdso64: Fix CLOCK_MONOTONIC inconsistencies across Y2038
  (bsc#1131587).
- commit 5da8af1
* Thu Apr  4 2019 msuchanek@suse.de
- powerpc/vdso32: fix CLOCK_MONOTONIC on PPC64 (bsc#1131587).
- commit ceb6b90
* Thu Apr  4 2019 jeyu@suse.de
- blacklist.conf: blacklist some unneeded git-fixes for kbuild
- commit abe6c5a
* Thu Apr  4 2019 neilb@suse.com
- sunrpc/cache: handle missing listeners better (bsc#1126221).
- commit 222e680
* Wed Apr  3 2019 tiwai@suse.de
- ALSA: hda/realtek - Add quirk for Tuxedo XC 1509 (bsc#1131442).
- commit 8e330f3
* Wed Apr  3 2019 msuchanek@suse.de
- Fix struct page kABI after adding atomic for ppc (bsc#1131326,
  bsc#1108937).
- commit be14dd3
* Wed Apr  3 2019 dkirjanov@suse.com
- net_sched: acquire RTNL in tc_action_net_exit() (git-fixes).
- commit 8f2ce8d
* Wed Apr  3 2019 msuchanek@suse.de
- powerpc/64s: Fix page table fragment refcount race vs
  speculative references (bsc#1131326, bsc#1108937).
- commit 5305157
* Wed Apr  3 2019 dkirjanov@suse.com
- netlink: fix nla_put_{u8,u16,u32} for KASAN (git-fixes).
- commit 923fbed
* Wed Apr  3 2019 dkirjanov@suse.com
- ip6_tunnel: fix ip6 tunnel lookup in collect_md mode
  (git-fixes).
- commit 5540e41
* Wed Apr  3 2019 dkirjanov@suse.com
- net/hsr: Check skb_put_padto() return value (git-fixes).
- commit eaaa0aa
* Wed Apr  3 2019 mbenes@suse.cz
- blacklist.conf: 0c671812f152 ("objtool: Move objtool_file struct off the stack")
  Optimization only.
- commit 95167b9
* Wed Apr  3 2019 tiwai@suse.de
- drm/i915/gvt: Fix MI_FLUSH_DW parsing with correct index check
  (bsc#1051510).
- drm/meson: Uninstall IRQ handler (bsc#1051510).
- drm/meson: Fix invalid pointer in meson_drv_unbind()
  (bsc#1051510).
- commit ca8e7de
* Wed Apr  3 2019 tiwai@suse.de
- ALSA: hda/realtek - Add support headset mode for DELL WYSE AIO
  (bsc#1051510).
- ALSA: hda/realtek - Add support headset mode for New DELL WYSE
  NB (bsc#1051510).
- Refresh
  patches.drivers/ALSA-hda-realtek-Enable-ASUS-X441MB-and-X705FD-heads.patch.
- Refresh
  patches.drivers/ALSA-hda-realtek-Enable-headset-MIC-of-Acer-AIO-with.patch.
- commit a592cc5
* Wed Apr  3 2019 tiwai@suse.de
- leds: pca9532: fix a potential NULL pointer dereference
  (bsc#1051510).
- serial: sh-sci: Fix setting SCSCR_TIE while transferring data
  (bsc#1051510).
- tty: atmel_serial: fix a potential NULL pointer dereference
  (bsc#1051510).
- serial: max310x: Fix to avoid potential NULL pointer dereference
  (bsc#1051510).
- USB: serial: option: add Olicard 600 (bsc#1051510).
- USB: serial: cp210x: add new device id (bsc#1051510).
- USB: serial: ftdi_sio: add additional NovaTech products
  (bsc#1051510).
- USB: serial: option: add support for Quectel EM12 (bsc#1051510).
- usb: mtu3: fix EXTCON dependency (bsc#1051510).
- xhci: Don't let USB3 ports stuck in polling state prevent
  suspend (bsc#1051510).
- xhci: Fix port resume done detection for SS ports with LPM
  enabled (bsc#1051510).
- usb: host: xhci-rcar: Add XHCI_TRUST_TX_LENGTH quirk
  (bsc#1051510).
- mISDN: hfcpci: Test both vendor & device ID for Digium HFC4S
  (bsc#1051510).
- Bluetooth: Check L2CAP option sizes returned from
  l2cap_get_conf_opt (bsc#1051510).
- video: fbdev: Set pixclock = 0 in goldfishfb (bsc#1051510).
- commit 178f505
* Wed Apr  3 2019 jack@suse.cz
- Move merged patch to sorted section.
- commit f8a5a36
* Wed Apr  3 2019 jack@suse.cz
- mm/huge_memory.c: fix modifying of page protection by
  insert_pfn_pmd() (bsc#1126740).
- commit f2d3c27
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Fix read after write for files with read caching
  (bsc#1051510).
- commit 3e38596
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Do not reset lease state to NONE on lease break
  (bsc#1051510).
- commit fa36ef9
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Do not count -ENODATA as failure for query directory
  (bsc#1051510).
- commit 6e009d6
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Fix credit calculation for encrypted reads with errors
  (bsc#1051510).
- commit a3abad5
* Tue Apr  2 2019 fdmanana@suse.com
- btrfs: save drop_progress if we drop refs at all (bsc#1131336).
- commit 4b84d75
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Fix credits calculations for reads with errors
  (bsc#1051510).
- commit dea8577
* Tue Apr  2 2019 fdmanana@suse.com
- btrfs: check for refs on snapshot delete resume (bsc#1131335).
- commit aaca681
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Do not reconnect TCP session in add_credits()
  (bsc#1051510).
- commit 270290e
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Fix possible hang during async MTU reads and writes
  (bsc#1051510).
- commit 3617549
* Tue Apr  2 2019 palcantara@suse.de
- cifs: Fix potential OOB access of lock element array
  (bsc#1051510).
- commit 10b82f5
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Do not hide EINTR after sending network packets
  (bsc#1051510).
- commit 2e205b5
* Tue Apr  2 2019 palcantara@suse.de
- CIFS: Fix adjustment of credits for MTU requests (bsc#1051510).
- commit 877d080
* Tue Apr  2 2019 palcantara@suse.de
- cifs: don't dereference smb_file_target before null check
  (bsc#1051510).
- commit 4ceb2b6
* Tue Apr  2 2019 jeyu@suse.de
- kbuild: modversions: Fix relative CRC byte order interpretation
  (bsc#1131290).
- commit fbd5ed2
* Mon Apr  1 2019 jack@suse.cz
- ext4: fix EXT4_IOC_SWAP_BOOT (bsc#1131180).
- commit 6300d9f
* Mon Apr  1 2019 jack@suse.cz
- ext4: update quota information while swapping boot loader inode
  (bsc#1131179).
- commit 698c374
* Mon Apr  1 2019 jack@suse.cz
- ext4: cleanup pagecache before swap i_data (bsc#1131178).
- commit 6cc247a
* Mon Apr  1 2019 jack@suse.cz
- ext4: fix check of inode in swap_inode_boot_loader
  (bsc#1131177).
- commit e7db433
* Mon Apr  1 2019 jack@suse.cz
- patches.fixes/mm-Fix-modifying-of-page-protection-by-insert_pfn.patch:
  Update tags.
- commit b903146
* Mon Apr  1 2019 jack@suse.cz
- ext4: add missing brelse() in add_new_gdb_meta_bg()
  (bsc#1131176).
- commit dfe0576
* Mon Apr  1 2019 jack@suse.cz
- udf: Fix crash on IO error during truncate (bsc#1131175).
- commit c18f321
* Mon Apr  1 2019 jack@suse.cz
- ext2: Fix underflow in ext2_max_size() (bsc#1131174).
- commit 84e6e73
* Mon Apr  1 2019 jack@suse.cz
- ext4: brelse all indirect buffer in ext4_ind_remove_space()
  (bsc#1131173).
- commit 9721810
* Mon Apr  1 2019 jack@suse.cz
- ext4: fix data corruption caused by unaligned direct AIO
  (bsc#1131172).
- commit feb5c5f
* Mon Apr  1 2019 jack@suse.cz
- ext4: fix NULL pointer dereference while journal is aborted
  (bsc#1131171).
- commit 92c9de9
* Mon Apr  1 2019 jack@suse.cz
- ext4: add mask of ext4 flags to swap (bsc#1131170).
- commit 99206bf
* Mon Apr  1 2019 jack@suse.cz
- ocfs2: fix inode bh swapping mixup in ocfs2_reflink_inodes_lock
  (bsc#1131169).
- commit 4a73aec
* Mon Apr  1 2019 jack@suse.cz
- jbd2: fix compile warning when using JBUFFER_TRACE
  (bsc#1131168).
- commit c3e6bb8
* Mon Apr  1 2019 jack@suse.cz
- jbd2: clear dirty flag when revoking a buffer from an older
  transaction (bsc#1131167).
- commit a421763
* Mon Apr  1 2019 tiwai@suse.de
- Revert drm/i915 patches that caused regressions (bsc#1131062)
  Deleted:
  patches.drm/0001-drm-i915-Use-the-correct-crtc-when-sanitizing-plane-.patch
  patches.drm/0001-drm-i915-fbdev-Actually-configure-untiled-displays.patch
  blacklist.conf: added two entries above
- commit 0e4b019
* Mon Apr  1 2019 msuchanek@suse.de
- powerpc/security: Fix spectre_v2 reporting (bsc#1131107).
- powerpc/fsl: Fix spectre_v2 mitigations reporting (bsc#1131107).
- powerpc/powernv: Query firmware for count cache flush settings
  (bsc#1131107).
- powerpc/pseries: Query hypervisor for count cache flush settings
  (bsc#1131107).
- powerpc/64s: Add support for software count cache flush
  (bsc#1131107).
- powerpc/64s: Add new security feature flags for count cache
  flush (bsc#1131107).
- powerpc/asm: Add a patch_site macro & helpers for patching
  instructions (bsc#1131107).
- powerpc/64: Call setup_barrier_nospec() from setup_arch()
  (bsc#1131107).
- powerpc/64: Make stf barrier PPC_BOOK3S_64 specific
  (bsc#1131107).
- powerpc/64: Disable the speculation barrier from the command
  line (bsc#1131107).
- commit e6638b6
* Mon Apr  1 2019 oneukum@suse.com
- usb: common: Consider only available nodes for dr_mode
  (bsc#1129770).
- commit 1ee54b2
* Mon Apr  1 2019 oneukum@suse.com
- usb: cdc-acm: fix race during wakeup blocking TX traffic
  (bsc#1129770).
- commit 6b4c74d
* Mon Apr  1 2019 oneukum@suse.com
- USB: gadget: f_hid: fix deadlock in f_hidg_write()
  (bsc#1129770).
- commit 231f4ae
* Mon Apr  1 2019 oneukum@suse.com
- USB: serial: option: set driver_info for SIM5218 and compatibles
  (bsc#1129770).
- commit 83ea3de
* Mon Apr  1 2019 oneukum@suse.com
- USB: serial: mos7720: fix mos_parport refcount imbalance on
  error path (bsc#1129770).
- commit 875c985
* Mon Apr  1 2019 msuchanek@suse.de
- Refresh patches.arch/pseries-energy-Use-OF-accessor-function-to-read-ibm-.patch
- Refresh patches.drivers/ibmvscsi-Fix-empty-event-pool-access-during-host-rem.patch.
- Refresh patches.drivers/ibmvscsi-Protect-ibmvscsi_head-from-concurrent-modif.patch.
- commit fdf19d9
* Mon Apr  1 2019 jroedel@suse.de
- iommu/amd: Reserve exclusion range in iova-domain (bsc#1130425).
- iommu: Don't print warning when IOMMU driver only supports
  unmanaged domains (bsc#1130130).
- commit 0d6792b
* Mon Apr  1 2019 msuchanek@suse.de
- x86/cpu: Add Atom Tremont (Jacobsville) (FATE#327454).
- commit 3c49c7d
* Mon Apr  1 2019 msuchanek@suse.de
- powerpc/pseries/mce: Fix misleading print for TLB mutlihit
  (bsc#1094244, git-fixes).
- commit f2a2099
* Mon Apr  1 2019 msuchanek@suse.de
- powercap: intel_rapl: add support for Jacobsville (FATE#327454).
- commit e9c57f5
* Mon Apr  1 2019 msuchanek@suse.de
- thermal/intel_powerclamp: fix truncated kthread name
  (FATE#326597).
- commit 8eb43dd
* Mon Apr  1 2019 neilb@suse.com
- nfsd: fix memory corruption caused by readdir (bsc#1127445).
- commit d7221f2
* Sun Mar 31 2019 bp@suse.de
- x86/mce: Improve error message when kernel cannot recover, p2
  (bsc#1114279).
- blacklist.conf:
- x86/CPU/AMD: Set the CPB bit unconditionally on F17h
  (bsc#1114279).
- x86/uaccess: Don't leak the AC flag into __put_user() value
  evaluation (bsc#1114279).
- commit 8d74308
* Sat Mar 30 2019 tiwai@suse.de
- Delete a USB patch that has been reverted in upstream
- Delete
  patches.drivers/USB-core-only-clean-up-what-we-allocated.patch.
- blacklist.conf: updated
- commit ce8dfae
* Sat Mar 30 2019 tiwai@suse.de
- ALSA: pcm: Don't suspend stream in unrecoverable PCM state
  (bsc#1051510).
- ALSA: pcm: Fix possible OOB access in PCM oss plugins
  (bsc#1051510).
- ALSA: hda/realtek: Enable headset mic of ASUS P5440FF with
  ALC256 (bsc#1051510).
- ALSA: hda/realtek: Enable ASUS X441MB and X705FD headset MIC
  with ALC256 (bsc#1051510).
- ALSA: hda/realtek - Add support for Acer Aspire E5-523G/ES1-432
  headset mic (bsc#1051510).
- ALSA: hda/realtek: Enable headset MIC of Acer Aspire Z24-890
  with ALC286 (bsc#1051510).
- ALSA: seq: oss: Fix Spectre v1 vulnerability (bsc#1051510).
- ALSA: rawmidi: Fix potential Spectre v1 vulnerability
  (bsc#1051510).
- commit 69f1f87
* Fri Mar 29 2019 ohering@suse.de
- hv: reduce storvsc_ringbuffer_size from 1M to 128K to simplify
  booting with 1k vcpus (fate#323887).
- commit 3adae84
* Fri Mar 29 2019 tiwai@suse.de
- PCI: designware-ep: dw_pcie_ep_set_msi() should only set MMC
  bits (bsc#1051510).
- Refresh
  patches.drivers/PCI-designware-ep-Fix-get_msi-to-check-MSI_EN-bit.
- commit 4500d8d
* Fri Mar 29 2019 tiwai@suse.de
- rhashtable: Still do rehash when we get EEXIST (bsc#1051510).
- commit c19465e
* Fri Mar 29 2019 tiwai@suse.de
- soc: fsl: qbman: avoid race in clearing QMan interrupt
  (bsc#1051510).
- serial: imx: Update cached mctrl value when changing RTS
  (bsc#1051510).
- commit d010558
* Fri Mar 29 2019 tiwai@suse.de
- tpm: Fix some name collisions with drivers/char/tpm.h
  (bsc#1051510).
- tpm/tpm_crb: Avoid unaligned reads in crb_recv() (bsc#1051510).
- tpm_tis_spi: Pass the SPI IRQ down to the driver (bsc#1051510).
- commit 6cd0a4a
* Fri Mar 29 2019 tiwai@suse.de
- uio: Reduce return paths from uio_write() (bsc#1051510).
- USB: core: only clean up what we allocated (bsc#1051510).
- commit ab0f288
* Fri Mar 29 2019 tbogendoerfer@suse.de
- net: ena: update driver version from 2.0.2 to 2.0.3 (bsc#1129276
  bsc#1125342).
- commit 369fffc
* Fri Mar 29 2019 tiwai@suse.de
- ALSA: hda/realtek: Enable headset MIC of Acer AIO with ALC286
  (bsc#1051510).
- ALSA: hda - Enforces runtime_resume after S3 and S4 for each
  codec (bsc#1051510).
- ALSA: hda - Record the current power state before suspend/resume
  calls (bsc#1051510).
- commit de6e070
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: kABI
- commit ae0ea58
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: cleanup
- commit ef4abe8
* Thu Mar 28 2019 oneukum@suse.com
- media: vb2: don't call __vb2_queue_cancel if vb2_start_streaming
  failed (bsc#1119086).
- commit fbc0f52
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: unsupported architecture
- commit 1b8dc44
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: our kernel configs build
- commit 47fd8e3
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: just a cleanup
- commit e8b7243
* Thu Mar 28 2019 oneukum@suse.com
- media: rc: mce_kbd decoder: fix stuck keys (bsc#1100132).
- commit 9e1c047
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: drops support for old hardware
- commit ebbb144
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit a09f690
* Thu Mar 28 2019 oneukum@suse.com
- blacklist.conf: breaks kABI
- commit 3726cc3
* Thu Mar 28 2019 oneukum@suse.com
- Input: uinput - fix undefined behavior in
  uinput_validate_absinfo() (bsc#1120902).
- commit c89d255
* Thu Mar 28 2019 glin@suse.com
- bpf: do not restore dst_reg when cur_state is freed (bsc#1068032
  CVE-2017-5753 bsc#1124055 CVE-2019-7308).
- commit 9276bbc
* Thu Mar 28 2019 jslaby@suse.cz
- memremap: fix softlockup reports at teardown (bnc#1130154).
- commit 6db61c3
* Wed Mar 27 2019 lduncan@suse.com
- scsi: libiscsi: fix possible NULL pointer dereference in case
  of TMF (bsc#1127378).
- commit 54a0fde
* Wed Mar 27 2019 tiwai@suse.de
- qmi_wwan: apply SET_DTR quirk to Sierra WP7607 (bsc#1051510).
- qmi_wwan: Fix qmap header retrieval in qmimux_rx_fixup
  (bsc#1051510).
- commit 42461a9
* Wed Mar 27 2019 tiwai@suse.de
- power: supply: charger-manager: Fix incorrect return value
  (bsc#1051510).
- commit c557f72
* Wed Mar 27 2019 tiwai@suse.de
- libertas_tf: don't set URB_ZERO_PACKET on IN USB transfer
  (bsc#1051510).
- commit 8f82e45
* Wed Mar 27 2019 tiwai@suse.de
- iscsi_ibft: Fix missing break in switch statement (bsc#1051510).
- irqchip/mmp: Only touch the PJ4 IRQ & FIQ bits on enable/disable
  (bsc#1051510).
- kbuild: fix false positive warning/error about missing libelf
  (bsc#1051510).
- kasan: fix shadow_size calculation error in kasan_module_alloc
  (bsc#1051510).
- commit e0d199f
* Wed Mar 27 2019 tiwai@suse.de
- irqchip/gic-v3-its: Avoid parsing _indirect_ twice for Device
  table (bsc#1051510).
- commit 3d1d012
* Wed Mar 27 2019 tiwai@suse.de
- Input: cap11xx - switch to using set_brightness_blocking()
  (bsc#1051510).
- commit 2da52af
* Wed Mar 27 2019 tiwai@suse.de
- media: v4l2-ctrls.c/uvc: zero v4l2_event (bsc#1051510).
- Bluetooth: hci_ldisc: Postpone HCI_UART_PROTO_READY bit set
  in hci_uart_set_proto() (bsc#1051510).
- Bluetooth: hci_ldisc: Initialize hci_dev before open()
  (bsc#1051510).
- Bluetooth: Fix decrementing reference count twice in releasing
  socket (bsc#1051510).
- pwm-backlight: Enable/disable the PWM before/after LCD enable
  toggle (bsc#1051510).
- rtc: Fix overflow when converting time64_t to rtc_time
  (bsc#1051510).
- commit f283d41
* Tue Mar 26 2019 fdmanana@suse.com
- Btrfs: fix deadlock between clone/dedupe and rename
  (bsc#1130518).
- commit cf4e851
* Tue Mar 26 2019 oneukum@suse.com
- Refresh
  patches.drivers/0001-iwlwifi-nvm-get-num-of-hw-addresses-from-firmware.patch.
- commit 6a5dbcd
* Mon Mar 25 2019 ggherdovich@suse.cz
- ACPI: acpi_pad: Do not launch acpi_pad threads on idle cpus
  (bsc#1113399).
- commit e7efd4e
* Mon Mar 25 2019 lhenriques@suse.com
- libceph: wait for latest osdmap in ceph_monc_blacklist_add() (bsc#1130427).
- commit 175d167
* Mon Mar 25 2019 tiwai@suse.de
- rtc: pm8xxx: fix unintended sign extension (bsc#1051510).
- rtc: 88pm80x: fix unintended sign extension (bsc#1051510).
- rtc: 88pm860x: fix unintended sign extension (bsc#1051510).
- rtc: ds1672: fix unintended sign extension (bsc#1051510).
- rtc: cmos: ignore bogus century byte (bsc#1051510).
- commit cef4199
* Mon Mar 25 2019 tiwai@suse.de
- serial: 8250_of: assume reg-shift of 2 for mrvl,mmp-uart
  (bsc#1051510).
- serial: fsl_lpuart: fix maximum acceptable baud rate with
  over-sampling (bsc#1051510).
- commit d6bf923
* Mon Mar 25 2019 tiwai@suse.de
- thermal: bcm2835: Fix crash in bcm2835_thermal_debugfs
  (bsc#1051510).
- auxdisplay: hd44780: Fix memory leak on ->remove()
  (bsc#1051510).
- mmc: pxamci: fix enum type confusion (bsc#1051510).
- drm/i915: Relax mmap VMA check (bsc#1051510).
- cpufreq: pxa2xx: remove incorrect __init annotation
  (bsc#1051510).
- PM / wakeup: Rework wakeup source timer cancellation
  (bsc#1051510).
- clk: ingenic: Fix doc of ingenic_cgu_div_info (bsc#1051510).
- clk: ingenic: Fix round_rate misbehaving with non-integer
  dividers (bsc#1051510).
- clk: clk-twl6040: Fix imprecise external abort for pdmclk
  (bsc#1051510).
- i2c: tegra: fix maximum transfer size (bsc#1051510).
- cpcap-charger: generate events for userspace (bsc#1051510).
- usb: phy: twl6030-usb: fix possible use-after-free on remove
  (bsc#1051510).
- device property: Fix the length used in PROPERTY_ENTRY_STRING()
  (bsc#1051510).
- cpufreq: tegra124: add missing of_node_put() (bsc#1051510).
- clocksource/drivers/exynos_mct: Clear timer interrupt when
  shutdown (bsc#1051510).
- clocksource/drivers/exynos_mct: Move one-shot check from tick
  clear to ISR (bsc#1051510).
- spi: pxa2xx: Setup maximum supported DMA transfer length
  (bsc#1051510).
- spi: ti-qspi: Fix mmap read when more than one CS in use
  (bsc#1051510).
- spi/topcliff_pch: Fix potential NULL dereference on allocation
  error (bsc#1051510).
- regulator: s2mpa01: Fix step values for some LDOs (bsc#1051510).
- regulator: max77620: Initialize values for DT properties
  (bsc#1051510).
- mac80211_hwsim: propagate genlmsg_reply return code
  (bsc#1051510).
- clk: sunxi-ng: v3s: Fix TCON reset de-assert bit (bsc#1051510).
- Input: st-keyscan - fix potential zalloc NULL dereference
  (bsc#1051510).
- Input: matrix_keypad - use flush_delayed_work() (bsc#1051510).
- auxdisplay: ht16k33: fix potential user-after-free on module
  unload (bsc#1051510).
- drm/imx: imx-ldb: add missing of_node_puts (bsc#1051510).
- drm/imx: ignore plane updates on disabled crtcs (bsc#1051510).
- mac80211: Fix Tx aggregation session tear down with ITXQs
  (bsc#1051510).
- usb: phy: fix link errors (bsc#1051510).
- usb: gadget: Potential NULL dereference on allocation error
  (bsc#1051510).
- usb: dwc3: gadget: Fix the uninitialized link_state when udc
  starts (bsc#1051510).
- usb: dwc3: gadget: synchronize_irq dwc irq in suspend
  (bsc#1051510).
- clk: vc5: Abort clock configuration without upstream clock
  (bsc#1051510).
- commit 6cb451f
* Mon Mar 25 2019 jack@suse.cz
- Move ext4 fix to sorted section.
- commit bc353a8
* Mon Mar 25 2019 jack@suse.cz
- ext4: Avoid panic during forced reboot (bsc#1126356).
- commit 395e2df
* Mon Mar 25 2019 palcantara@suse.de
- SMB3: Fix SMB3.1.1 guest mounts to Samba (bsc#1051510).
- commit 42fc847
* Mon Mar 25 2019 palcantara@suse.de
- cifs: allow guest mounts to work for smb3.11 (bsc#1051510).
- commit b9f1747
* Mon Mar 25 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Add back kernel-binary-base subpackage
  (jsc#SLE-3853).
- commit 54b6646
* Mon Mar 25 2019 dkirjanov@suse.com
- net/ncsi: Stop monitor if channel times out or is inactive
  (git-fixes).
- commit 51f02cc
* Mon Mar 25 2019 dkirjanov@suse.com
- net/ncsi: Fix AEN HNCDSC packet length (git-fixes).
- commit 131fc0a
* Mon Mar 25 2019 dkirjanov@suse.com
- rtnetlink: check DO_SETLINK_NOTIFY correctly in do_setlink
  (git-fixes).
- commit 67433ca
* Mon Mar 25 2019 dkirjanov@suse.com
- rtnetlink: bring NETDEV_CHANGEUPPER event process back in
  rtnetlink_event (git-fixes).
- commit 40c26cb
* Mon Mar 25 2019 dkirjanov@suse.com
- rtnetlink: bring NETDEV_POST_TYPE_CHANGE event process back
  in rtnetlink_event (git-fixes).
- commit 84885e6
* Mon Mar 25 2019 dkirjanov@suse.com
- rtnetlink: bring NETDEV_CHANGE_TX_QUEUE_LEN event process back
  in rtnetlink_event (git-fixes).
- commit 285df6b
* Mon Mar 25 2019 dkirjanov@suse.com
- Revert "ipv4: keep skb->dst around in presence of IP options"
  (git-fixes).
- commit 533ed1e
* Mon Mar 25 2019 dkirjanov@suse.com
- ip6: fix PMTU discovery when using /127 subnets (git-fixes).
- commit 8b09618
* Mon Mar 25 2019 dkirjanov@suse.com
- netfilter: check for seqadj ext existence before adding it in
  nf_nat_setup_info (git-fixes).
- commit 1475b19
* Mon Mar 25 2019 jroedel@suse.de
- iommu/vt-d: Check capability before disabling protected memory
  (bsc#1130338).
- iommu/amd: fix sg->dma_address for sg->offset bigger than
  PAGE_SIZE (bsc#1130337).
- svm: Fix improper check when deactivate AVIC (bsc#1130335).
- iommu/amd: Fix NULL dereference bug in match_hid_uid
  (bsc#1130336).
- commit 59d980d
* Sat Mar 23 2019 dkirjanov@suse.com
- ip6mr: Do not call __IP6_INC_STATS() from preemptible context (git-fixes).
- commit a0e7de3
* Fri Mar 22 2019 tiwai@suse.de
- ALSA: opl3: fix mismatch between snd_opl3_drum_switch definition
  and declaration (bsc#1051510).
- ALSA: hda - add Lenovo IdeaCentre B550 to the
  power_save_blacklist (bsc#1051510).
- ALSA: firewire-motu: use 'version' field of unit directory to
  identify model (bsc#1051510).
- ALSA: sb8: add a check for request_region (bsc#1051510).
- ALSA: echoaudio: add a check for ioremap_nocache (bsc#1051510).
- ALSA: firewire-motu: add support for Motu Traveler
  (bsc#1051510).
- ALSA: firewire-motu: add a flag for AES/EBU on XLR interface
  (bsc#1051510).
- ALSA: firewire: add const qualifier to identifiers for read-only
  symbols (bsc#1051510).
- ALSA: firewire-motu: add support for MOTU Audio Express
  (bsc#1051510).
- ALSA: firewire-motu: add specification flag for position of
  flag for MIDI messages (bsc#1051510).
- commit 44777c3
* Fri Mar 22 2019 msuchanek@suse.de
- Do not provide kernel-default-srchash from kernel-default-base.
- commit d6c71ce
* Fri Mar 22 2019 dkirjanov@suse.com
- net-sysfs: Fix mem leak in netdev_register_kobject (git-fixes).
- commit ab6d34b
* Fri Mar 22 2019 dkirjanov@suse.com
- ipv4/route: fail early when inet dev is missing (git-fixes).
- commit 2ab8395
* Fri Mar 22 2019 hare@suse.de
- nvme: schedule requeue whenever a LIVE state is entered
  (bsc#1123105).
- commit 8d25e58
* Fri Mar 22 2019 tiwai@suse.de
- Move the upstreamed drm vmwgfx patch into sorted section
  Also move to patches.drm subdirectory
- commit 31818d7
* Fri Mar 22 2019 tiwai@suse.de
- drm/i915/bios: assume eDP is present on port A when there is
  no VBT (bsc#1051510).
- drm/nouveau/debugfs: Fix check of pm_runtime_get_sync failure
  (bsc#1051510).
- commit 8e7b9bc
* Thu Mar 21 2019 oneukum@suse.com
- USB: serial: option: add Telit ME910 ECM composition
  (bsc#1129770).
- commit 1dcab61
* Thu Mar 21 2019 oneukum@suse.com
- USB: serial: ftdi_sio: add ID for Hjelmslund Electronics USB485
  (bsc#1129770).
- USB: serial: cp210x: add ID for Ingenico 3070 (bsc#1129770).
- commit 98bf3ee
* Thu Mar 21 2019 oneukum@suse.com
- iwlwifi: mvm: fix firmware statistics usage (bsc#1129770).
- commit 23e27f9
* Thu Mar 21 2019 tiwai@suse.de
- Enable CONFIG_RDMA_RXE=m also for ppc64le (bsc#1107665,FATE#327552)
- commit 01b35ce
* Thu Mar 21 2019 dkirjanov@suse.com
- gro_cells: make sure device is up in gro_cells_receive()
  (git-fixes).
- commit 07d85fc
* Thu Mar 21 2019 tiwai@suse.de
- Fix a wrongly applied patch for mlxsw
  Refresh
  patches.fixes/0001-mlxsw-__mlxsw_sp_port_headroom_set-Fix-a-use-of-loca.patch.
- commit 464fcba
* Thu Mar 21 2019 dkirjanov@suse.com
- l2tp: fix infoleak in l2tp_ip6_recvmsg() (git-fixes).
- commit 868559e
* Thu Mar 21 2019 dkirjanov@suse.com
- tcp: handle inet_csk_reqsk_queue_add() failures (git-fixes).
- commit 4e8b58b
* Thu Mar 21 2019 jack@suse.cz
- blacklist.conf: Blacklist c9e716eb9b34 and 231fe82b5609
- commit 2748115
* Thu Mar 21 2019 dkirjanov@suse.com
- net: stmmac: fix broken dma_interrupt handling for multi-queues
  (git-fixes).
- commit fb85ef5
* Thu Mar 21 2019 dkirjanov@suse.com
- net: stmmac: Use mutex instead of spinlock (git-fixes).
- commit 09b11af
* Thu Mar 21 2019 msuchanek@suse.de
- scsi: ibmvscsi: Fix empty event pool access during host removal
  (bsc#1119019).
- scsi: ibmvscsi: Protect ibmvscsi_head from concurrent
  modificaiton (bsc#1119019).
- commit cc2e069
* Wed Mar 20 2019 msuchanek@suse.de
- ibmvscsi: Protect ibmvscsi_head from concurrent modificaiton
  (bsc#1119019).
- commit ab6b8c2
* Wed Mar 20 2019 jack@suse.cz
- patches.fixes/ext4-Fix-crash-during-online-resizing.patch: Update tags
- commit ab2b2e4
* Wed Mar 20 2019 jack@suse.cz
- blacklist.conf: Blacklist fanotify cleanup and intrusive loop device
  rework
- commit 888b615
* Wed Mar 20 2019 dkirjanov@suse.com
- net/mlx5: fix uaccess beyond "count" in debugfs read/write handlers (git-fixes).
- commit 2a80c1f
* Wed Mar 20 2019 msuchanek@suse.de
- ibmvnic: Report actual backing device speed and duplex values
  (bsc#1129923).
- commit 4347029
* Wed Mar 20 2019 palcantara@suse.de
- smb3: remove noisy warning message on mount (bsc#1129664).
- commit a1f6570
* Wed Mar 20 2019 msuchanek@suse.de
- rpm/kernel-subpackage-build: handle arm kernel zImage.
- commit 81a63c3
* Wed Mar 20 2019 dkirjanov@suse.com
- net: thunderx: fix NULL pointer dereference in nic_remove (git-fixes).
- commit f02276a
* Wed Mar 20 2019 dkirjanov@suse.com
- mlxsw: __mlxsw_sp_port_headroom_set(): Fix a use of local variable (git-fixes).
- commit 69b065b
* Wed Mar 20 2019 hare@suse.de
- block_dev: fix crash on chained bios with O_DIRECT
  (bsc#1128094).
- Delete
  patches.fixes/bio-Introduce-BIO_ALLOCED-flag-and-check-it-in-bio_f.patch.
- commit 512ce8f
* Wed Mar 20 2019 dkirjanov@suse.com
- net: stmmac: handle endianness in dwmac4_get_timestamp (git-fixes).
- commit 5cdea6c
* Wed Mar 20 2019 jack@suse.cz
- Delete
  patches.fixes/block-loop-Use-global-lock-for-ioctl-operation.patch: It
  makes existing deadlocks much more probable (bsc#1129739).
- Delete patches.kabi/loop-lo_ctl_mutex-kabi-fixup.patch.
- commit 604f34a
* Wed Mar 20 2019 hare@suse.de
- scsi: mptsas: Fixup device hotplug for VMWare ESXi
  (bsc#1129046).
- commit a34b660
* Wed Mar 20 2019 dkirjanov@suse.com
- net: stmmac: Fix a race in EEE enable callback (git-fixes).
- commit ef5602d
* Wed Mar 20 2019 hare@suse.de
- ch: fixup refcounting imbalance for SCSI devices (bsc#1124235).
- ch: add missing mutex_lock()/mutex_unlock() in ch_release()
  (bsc#1124235).
- commit e1a0bf9
* Wed Mar 20 2019 fdmanana@suse.com
- Btrfs: fix fsync after succession of renames and unlink/rmdir
  (bsc#1126488).
- commit 773794e
* Wed Mar 20 2019 fdmanana@suse.com
- Btrfs: fix fsync after succession of renames of different files
  (bsc#1126481).
- commit e1d9100
* Wed Mar 20 2019 fdmanana@suse.com
- btrfs: simplify IS_ERR/PTR_ERR checks (bsc#1126481).
- commit db613f3
* Wed Mar 20 2019 hare@suse.de
- nvme-pci: fix out of bounds access in nvme_cqe_pending
  (bsc#1127595).
- commit 278fbe1
* Wed Mar 20 2019 hare@suse.de
- Delete
  patches.fixes/block_dev-fix-crash-on-chained-bios-with-O_DIRECT.patch.
- commit 54fa6df
* Wed Mar 20 2019 tiwai@suse.de
- rpm/kernel-source.changes.old: Really drop old changelogs (bsc#1098995)
- commit c98a840
* Wed Mar 20 2019 hare@suse.de
- bio: Introduce BIO_ALLOCED flag and check it in bio_free
  (bsc#1128094).
- commit bc841e1
* Wed Mar 20 2019 hare@suse.de
- block_dev: fix crash on chained bios with O_DIRECT
  (bsc#1128094).
- commit 3bf2ca7
* Wed Mar 20 2019 ailiopoulos@suse.com
- xfs: fix contiguous dquot chunk iteration livelock
  (bsc#1070995).
- Refresh
  patches.fixes/0059-xfs-introduce-the-xfs_iext_cursor-abstraction.patch.
- commit 227ca72
* Wed Mar 20 2019 ailiopoulos@suse.com
- xfs: rewrite xfs_dq_get_next_id using xfs_iext_lookup_extent
  (bsc#1070995).
- Refresh
  patches.fixes/0059-xfs-introduce-the-xfs_iext_cursor-abstraction.patch.
- commit 76eca08
* Wed Mar 20 2019 ailiopoulos@suse.com
- xfs: Switch to iomap for SEEK_HOLE / SEEK_DATA (bsc#1070995).
- Refresh
  patches.suse/mm-pagevec-remove-cold-parameter-for-pagevecs.patch.
- commit 9de815a
* Wed Mar 20 2019 ailiopoulos@suse.com
- vfs: in iomap seek_{hole,data}, return -ENXIO for negative
  offsets (bsc#1070995).
- commit b78c862
* Wed Mar 20 2019 ailiopoulos@suse.com
- vfs: Add iomap_seek_hole and iomap_seek_data helpers
  (bsc#1070995).
- commit 125ebab
* Wed Mar 20 2019 ailiopoulos@suse.com
- vfs: Add page_cache_seek_hole_data helper (bsc#1070995).
- commit 05d2885
* Wed Mar 20 2019 palcantara@suse.de
- Don't log confusing message on reconnect by default
  (bsc#1129664).
- commit 385bd76
* Tue Mar 19 2019 mgorman@suse.de
- sched: Do not re-read h_load_next during hierarchical load
  calculation (bnc#1120909).
- commit 50744d4
* Tue Mar 19 2019 tbogendoerfer@suse.de
- RDMA/vmw_pvrdma: Support upto 64-bit PFNs (bsc#1127285).
- VMCI: Support upto 64-bit PPNs (bsc#1127286).
- commit 7ae051b
* Tue Mar 19 2019 tbogendoerfer@suse.de
- IB/hfi1: Close race condition on user context disable and close
  (bsc#1060463 FATE#323043).
- IB/core: Fix potential memory leak while creating MAD agents
  (bsc#1046306 FATE#322942).
- IB/core: Unregister notifier before freeing MAD security
  (bsc#1046306 FATE#322942).
- IB/core: Destroy QP if XRC QP fails (bsc#1046306 FATE#322942).
- bnxt_en: Wait longer for the firmware message response to
  complete (bsc#1086282 FATE#324873).
- bnxt_en: Fix typo in firmware message timeout logic (bsc#1086282
  FATE#324873).
- net: ena: fix race between link up and device initalization
  (bsc#1083548).
- net: Don't default Cavium PTP driver to 'y' (bsc#1110096).
- net/mlx5e: RX, Fix wrong early return in receive queue poll
  (bsc#1046305 FATE#322943).
- bpf/verifier: fix verifier instability (bsc#1056787).
- IB/mlx5: Unmap DMA addr from HCA before IOMMU (bsc#1046305
  FATE#322943).
- commit 125f009
* Tue Mar 19 2019 dkirjanov@suse.com
- net/mlx5e: IPoIB, Fix RX checksum statistics update (git-fixes).
- commit 71cdac7
* Tue Mar 19 2019 dkirjanov@suse.com
- nfp: bpf: fix ALU32 high bits clearance bug (git-fixes).
- commit 367fb07
* Tue Mar 19 2019 fdmanana@suse.com
- Btrfs: fix corruption reading shared and compressed extents
  after hole punching (bsc#1126476).
- commit 1d61d84
* Tue Mar 19 2019 dkirjanov@suse.com
- net: aquantia: fixed instack structure overflow (git-fixes).
- commit c892ebe
* Tue Mar 19 2019 dkirjanov@suse.com
- net: dsa: mv88e6xxx: handle unknown duplex modes gracefully in mv88e6xxx_port_set_duplex (git-fixes).
- commit ba7b5b5
* Tue Mar 19 2019 dkirjanov@suse.com
- vxlan: Fix GRO cells race condition between receive and link delete (git-fixes).
- commit c54aad9
* Tue Mar 19 2019 dkirjanov@suse.com
- vxlan: test dev->flags & IFF_UP before calling gro_cells_receive() (git-fixes).
- commit 551356a
* Tue Mar 19 2019 tiwai@suse.de
- 9p/net: fix memory leak in p9_client_create (bsc#1051510).
- 9p: use inode->i_lock to protect i_size_write() under 32-bit
  (bsc#1051510).
- commit d372807
* Mon Mar 18 2019 rgoldwyn@suse.com
- splice: don't merge into linked buffers (git-fixes).
- blacklist.conf: upstream 35f12f0f5c3b fix already present
- fs/devpts: always delete dcache dentry-s in dput() (git-fixes).
- fs/dcache: Fix incorrect nr_dentry_unused accounting in
  shrink_dcache_sb() (git-fixes).
- proc/sysctl: don't return ENOMEM on lookup when a table is
  unregistering (git-fixes).
- commit 5249441
* Mon Mar 18 2019 mbenes@suse.cz
- tracing: Use strncpy instead of memcpy for string keys in hist
  triggers (bsc#1129625).
- commit e69f9ce
* Mon Mar 18 2019 mbenes@suse.cz
- tracing: Do not free iter->trace in fail path of
  tracing_open_pipe() (bsc#1129581).
- commit a28b9f0
* Mon Mar 18 2019 dkirjanov@suse.com
- net/mlx4_core: Fix reset flow when in command polling mode
  (git-fixes).
- commit 4d63fec
* Mon Mar 18 2019 dkirjanov@suse.com
- net/mlx4_core: Fix locking in SRIOV mode when switching between
  events and polling (git-fixes).
- commit 95405a1
* Mon Mar 18 2019 dkirjanov@suse.com
- net/mlx4_core: Fix qp mtt size calculation (git-fixes).
- commit 7ce612a
* Mon Mar 18 2019 dkirjanov@suse.com
- pptp: dst_release sk_dst_cache in pptp_sock_destruct
  (git-fixes).
- commit 1643380
* Mon Mar 18 2019 hare@suse.de
- nvme: flush namespace scanning work just before removing
  namespaces (bsc#1108101).
- commit c470403
* Mon Mar 18 2019 ohering@suse.de
- add mainline tags for two hyperv iommu patches
- commit aaca951
* Mon Mar 18 2019 jthumshirn@suse.de
- libnvdimm/pmem: Honor force_raw for legacy pmem regions
  (bsc#1129551).
- commit aa5d398
* Mon Mar 18 2019 jthumshirn@suse.de
- nfit: acpi_nfit_ctl(): Check out_obj->type in the right place
  (bsc#1129547).
- commit 6d08305
* Mon Mar 18 2019 jthumshirn@suse.de
- libnvdimm/label: Clear 'updating' flag after label-set update
  (bsc#1129543).
- commit 9178f22
* Mon Mar 18 2019 jthumshirn@suse.de
- blacklist.conf: Blacklist '5bc373ff2540 nvmet: fix indentation'
- commit e0af3a9
* Mon Mar 18 2019 tiwai@suse.de
- Move upstreamed patches into sorted section
  Along with the update of patch tags
- commit 78a41b7
* Mon Mar 18 2019 msuchanek@suse.de
- Trim build dependencies of sample subpackage spec file (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit 2eae420
* Mon Mar 18 2019 tzimmermann@suse.de
- drm/etnaviv: potential NULL dereference (bsc#1113722)
- commit 15c0a6e
* Mon Mar 18 2019 tzimmermann@suse.de
- drm/etnaviv: NULL vs IS_ERR() buf in etnaviv_core_dump() (bsc#1113722)
- commit 34ac361
* Mon Mar 18 2019 tzimmermann@suse.de
- fbdev: chipsfb: remove set but not used variable 'size' (bsc#1113722)
- commit 2f00fb2
* Mon Mar 18 2019 ohering@suse.de
- scsi: storvsc: Fix a race in sub-channel creation that can
  cause panic (fate#323887).
- commit 3c327bf
* Mon Mar 18 2019 jslaby@suse.cz
- cifs: Fix NULL pointer dereference of devname (bnc#1129519).
- commit c18b394
* Mon Mar 18 2019 wqu@suse.com
- btrfs: reloc: Fix NULL pointer dereference due to expanded
  reloc_root lifespan (bsc#1129497).
- commit 8078fe0
* Sat Mar 16 2019 dkirjanov@suse.com
- net/mlx5: Use multi threaded workqueue for page fault handling
  (git-fixes).
- commit 3211369
* Sat Mar 16 2019 dkirjanov@suse.com
- net/mlx5: Return success for PAGE_FAULT_RESUME in internal
  error state (git-fixes).
- commit 4f2b6f9
* Sat Mar 16 2019 dkirjanov@suse.com
- net/mlx5: Release resource on error flow (git-fixes).
- commit 82036aa
* Fri Mar 15 2019 msuchanek@suse.de
- Revert "Revert "Drop multiversion(kernel) from the KMP template (fate#323189)""
  This feature was requested for SLE15 but aws reverted in packaging and
  master.
- commit bb2780b
* Fri Mar 15 2019 msuchanek@suse.de
- Revert "KMPs: obsolete older KMPs of the same flavour (bsc#1127155, bsc#1109137)."
  This reverts commit 821419f311f3edd58124e551664a2362b62671d6.
- commit e9ac6b7
* Fri Mar 15 2019 msuchanek@suse.de
- Revert "KMPs: provide and conflict a kernel version specific KMP name"
  This reverts commit 5568093d5dbacaeb60b6e0f7f4bbe384b586b82a.
- commit 244e5c5
* Fri Mar 15 2019 ailiopoulos@suse.com
- xfs: remove filestream item xfs_inode reference (bsc#1127961).
- commit 77ac5bf
* Fri Mar 15 2019 tiwai@suse.de
- misc: hpilo: Do not claim unsupported hardware (bsc#1129330).
- misc: hpilo: Exclude unsupported device via blacklist
  (bsc#1129330).
- commit 839f28f
* Fri Mar 15 2019 jroedel@suse.de
- blacklist.conf: Add 826c1362e79a x86/kvm/nVMX: don't skip emulated instruction twice when vmptr address is not backed
- commit 0dd4c85
* Fri Mar 15 2019 tiwai@suse.de
- applicom: Fix potential Spectre v1 vulnerabilities
  (bsc#1051510).
- commit 1a09022
* Fri Mar 15 2019 tiwai@suse.de
- apparmor: Fix aa_label_build() error handling for failed merges
  (bsc#1051510).
- commit 0bdab75
* Fri Mar 15 2019 tiwai@suse.de
- clk: uniphier: Fix update register for CPU-gear (bsc#1051510).
- clk: sunxi-ng: sun8i-a23: Enable PLL-MIPI LDOs when ungating it
  (bsc#1051510).
- clk: dove: fix refcount leak in dove_clk_init() (bsc#1051510).
- clk: mv98dx3236: fix refcount leak in mv98dx3236_clk_init()
  (bsc#1051510).
- clk: armada-xp: fix refcount leak in axp_clk_init()
  (bsc#1051510).
- clk: kirkwood: fix refcount leak in kirkwood_clk_init()
  (bsc#1051510).
- clk: armada-370: fix refcount leak in a370_clk_init()
  (bsc#1051510).
- clk: vf610: fix refcount leak in vf610_clocks_init()
  (bsc#1051510).
- clk: imx7d: fix refcount leak in imx7d_clocks_init()
  (bsc#1051510).
- clk: imx6sx: fix refcount leak in imx6sx_clocks_init()
  (bsc#1051510).
- clk: imx6q: fix refcount leak in imx6q_clocks_init()
  (bsc#1051510).
- clk: samsung: exynos4: fix refcount leak in exynos4_get_xom()
  (bsc#1051510).
- clk: socfpga: fix refcount leak (bsc#1051510).
- clk: qoriq: fix refcount leak in clockgen_init() (bsc#1051510).
- clk: highbank: fix refcount leak in hb_clk_init() (bsc#1051510).
- clk: sunxi: A31: Fix wrong AHB gate number (bsc#1051510).
- commit b702993
* Fri Mar 15 2019 tiwai@suse.de
- clocksource/drivers/exynos_mct: Fix error path in timer
  resources initialization (bsc#1051510).
- clocksource/drivers/sun5i: Fail gracefully when clock rate is
  unavailable (bsc#1051510).
- commit 08bd77d
* Fri Mar 15 2019 tiwai@suse.de
- dmaengine: mv_xor: Use correct device for DMA API (bsc#1051510).
- dmaengine: sa11x0: drop useless LIST_HEAD (bsc#1051510).
- dmaengine: pl330: drop useless LIST_HEAD (bsc#1051510).
- dmaengine: st_fdma: drop useless LIST_HEAD (bsc#1051510).
- dmaengine: dw: drop useless LIST_HEAD (bsc#1051510).
- dmaengine: at_hdmac: drop useless LIST_HEAD (bsc#1051510).
- commit 79d5aed
* Fri Mar 15 2019 tiwai@suse.de
- driver core: Do not resume suppliers under
  device_links_write_lock() (bsc#1051510).
- commit 78f7e3b
* Fri Mar 15 2019 tiwai@suse.de
- enic: fix build warning without CONFIG_CPUMASK_OFFSTACK
  (bsc#1051510).
- commit fa4faec
* Fri Mar 15 2019 tiwai@suse.de
- geneve: correctly handle ipv6.disable module parameter
  (bsc#1051510).
- commit 91b6670
* Fri Mar 15 2019 tiwai@suse.de
- blacklist.conf: Add a superfluous entry of stable 4.14.y fix
- commit a9ad895
* Fri Mar 15 2019 jroedel@suse.de
- blacklist.conf: Add 24c41220659e x86/mm: Remove unused variable 'old_pte'
- commit 7fdcaa7
* Fri Mar 15 2019 tiwai@suse.de
- sky2: Disable MSI on Dell Inspiron 1545 and Gateway P-79
  (bsc#1051510).
- staging: rtl8723bs: Fix build error with Clang when inlining
  is disabled (bsc#1051510).
- commit ad62660
* Fri Mar 15 2019 tiwai@suse.de
- ACPI / device_sysfs: Avoid OF modalias creation for removed
  device (bsc#1051510).
- nfit/ars: Attempt short-ARS even in the no_init_ars case
  (bsc#1051510).
- nfit/ars: Attempt a short-ARS whenever the ARS state is idle
  at boot (bsc#1051510).
- acpi/nfit: Fix bus command validation (bsc#1051510).
- commit 3bd51ff
* Fri Mar 15 2019 jroedel@suse.de
- blacklist.conf: Add 0192e6535ebe x86/kprobes: Prohibit probing on optprobe template code
- commit cb9bc08
* Fri Mar 15 2019 hare@suse.de
- Refresh
  patches.fixes/nvme-fc-reject-reconnect-if-io-queue-count-is-reduce.patch.
- commit 509db55
* Fri Mar 15 2019 jroedel@suse.de
- Moved patches.fixes/x86-add-tsx-force-abort-cpuid-msr.patch
  to patches.arch/ and added upstream tags (bsc#1129363)
  patches.arch/x86-add-tsx-force-abort-cpuid-msr
- commit 2eb12ff
* Fri Mar 15 2019 jroedel@suse.de
- x86/pkeys: Properly copy pkey state at fork() (bsc#1129366).
- commit 2303e79
* Fri Mar 15 2019 wqu@suse.com
- btrfs: quota: Set rescan progress to (u64)-1 if we hit last
  leaf (bsc#1129327).
- commit de93501
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Cleanup old subtree swap code (bsc#1063638).
- commit 2cb2dcd
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Use delayed subtree rescan for balance
  (bsc#1063638).
- Refresh
  patches.suse/btrfs-suspend-qgroups-during-relocation-recovery.patch.
- commit e6256d6
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Introduce per-root swapped blocks  infrastructure
  (bsc#1063638).
- Refresh
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch.
- Refresh
  patches.suse/btrfs-suspend-qgroups-during-relocation-recovery.patch.
- commit 1212568
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Refactor btrfs_qgroup_trace_subtree_swap
  (bsc#1063638).
- commit 0b42e54
* Fri Mar 15 2019 wqu@suse.com
- btrfs: relocation: Delay reloc tree deletion after
  merge_reloc_roots (bsc#1063638).
- Refresh
  patches.suse/btrfs-suspend-qgroups-during-relocation-recovery.patch.
- commit 9fc8971
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Only trace data extents in leaves if we're
  relocating data block group (bsc#1063638).
- commit fafa3dd
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Don't trace subtree if we're dropping  reloc tree
  (bsc#1063638).
- commit 0b77be1
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Use generation-aware subtree swap to mark  dirty
  extents (bsc#1063638).
- commit 2b6dfe4
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Introduce function to find all new tree  blocks
  of reloc tree (bsc#1063638).
- commit 8a2e471
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Introduce function to trace two swaped  extents
  (bsc#1063638).
- commit 9332c5f
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Introduce trace event to analyse the  number
  of dirty extents accounted (bsc#1063638 dependency).
- commit 97025cc
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Finish rescan when hit the last leaf of  extent
  tree (bsc#1129327).
- commit 4f78aaa
* Fri Mar 15 2019 wqu@suse.com
- btrfs: qgroup: Search commit root for rescan to avoid  missing
  extent (bsc#1129326).
- Refresh
  patches.suse/btrfs-qgroups-fix-rescan-worker-running-races.patch.
- commit a587ad7
* Fri Mar 15 2019 msuchanek@suse.de
- Remove the previous subpackage infrastructure.
  This partially reverts commit 9b3ca32c11854156b2f950ff5e26131377d8445e
  ("Add kernel-subpackage-build.spec (FATE#326579).")
- commit a5ee24e
* Fri Mar 15 2019 msuchanek@suse.de
- Add sample kernel-default-base spec file (FATE#326579, jsc#SLE-4117,
  jsc#SLE-3853, bsc#1128910).
- commit 35c4a52
* Thu Mar 14 2019 tonyj@suse.de
- perf/x86/intel: Fix memory corruption (bsc#1121805).
- commit 0589774
* Thu Mar 14 2019 msuchanek@suse.de
- Install extra rpm scripts for kernel subpackaging (FATE#326579,
  jsc#SLE-4117, jsc#SLE-3853, bsc#1128910).
- commit ad7c227
* Thu Mar 14 2019 tiwai@suse.de
- blacklist.conf: Add an entry for non-existing dtsi
- commit fb9f4cf
* Thu Mar 14 2019 tiwai@suse.de
- pinctrl: sh-pfc: sh73a0: Fix fsic_spdif pin groups
  (bsc#1051510).
- pinctrl: sh-pfc: r8a7792: Fix vin1_data18_b pin group
  (bsc#1051510).
- pinctrl: sh-pfc: r8a7791: Fix scifb2_data_c pin group
  (bsc#1051510).
- pinctrl: sh-pfc: emev2: Add missing pinmux functions
  (bsc#1051510).
- pinctrl: sh-pfc: r8a7778: Fix HSPI pin numbers and names
  (bsc#1051510).
- platform/x86: Fix unmet dependency warning for SAMSUNG_Q10
  (bsc#1051510).
- commit 0688e3b
* Thu Mar 14 2019 tiwai@suse.de
- regulator: act8865: Fix act8600_sudcdc_voltage_ranges setting
  (bsc#1051510).
- regulator: wm831x-dcdc: Fix list of wm831x_dcdc_ilim from mA
  to uA (bsc#1051510).
- regulator: pv88090: Fix array out-of-bounds access
  (bsc#1051510).
- regulator: pv88080: Fix array out-of-bounds access
  (bsc#1051510).
- regulator: pv88060: Fix array out-of-bounds access
  (bsc#1051510).
- regulator: s2mps11: Fix steps for buck7, buck8 and LDO35
  (bsc#1051510).
- commit 23f9c9d
* Thu Mar 14 2019 tiwai@suse.de
- thermal: mediatek: fix register index error (bsc#1051510).
- commit f6dc5d0
* Thu Mar 14 2019 jroedel@suse.de
- KVM: x86: Fix single-step debugging (bsc#1129295).
- KVM: x86: Use jmp to invoke kvm_spurious_fault() from .fixup
  (bsc#1129296).
- kvm: nVMX: NMI-window and interrupt-window exiting should wake
  L2 from HLT (bsc#1129292).
- kvm: vmx: Set IA32_TSC_AUX for legacy mode guests (bsc#1129294).
- KVM: nVMX: Free the VMREAD/VMWRITE bitmaps if alloc_kvm_area()
  fails (bsc#1129291).
- kvm: nVMX: Set VM instruction error for VMPTRLD of unbacked page
  (bsc#1129293).
- commit e498c1c
* Thu Mar 14 2019 tiwai@suse.de
- tipc: fix RDM/DGRAM connect() regression (bsc#1051510).
- tipc: fix uninit-value in tipc_nl_compat_doit (bsc#1051510).
- tipc: fix uninit-value in tipc_nl_compat_name_table_dump
  (bsc#1051510).
- tipc: fix uninit-value in tipc_nl_compat_link_set (bsc#1051510).
- tipc: fix uninit-value in tipc_nl_compat_bearer_enable
  (bsc#1051510).
- tipc: fix uninit-value in tipc_nl_compat_link_reset_stats
  (bsc#1051510).
- tipc: eliminate KMSAN uninit-value in strcmp complaint
  (bsc#1051510).
- tipc: fix bug in function tipc_nl_node_dump_monitor
  (bsc#1051510).
- tipc: fix infinite loop when dumping link monitor summary
  (bsc#1051510).
- tipc: error path leak fixes in tipc_enable_bearer()
  (bsc#1051510).
- tipc: fix a race condition of releasing subscriber object
  (bsc#1051510).
- commit 090cbab
* Thu Mar 14 2019 jroedel@suse.de
- kvm: mmu: Fix race in emulated page table writes (bsc#1129284).
- svm: Add mutex_lock to protect apic_access_page_done on AMD
  systems (bsc#1129285).
- commit fdca877
* Thu Mar 14 2019 ohering@suse.de
- Adjust a commit id in a nvme patch to make our scripts happy
- commit 68e211e
* Thu Mar 14 2019 jroedel@suse.de
- PCI: qcom: Don't deassert reset GPIO during probe (bsc#1129281).
- commit a89893e
* Thu Mar 14 2019 jroedel@suse.de
- blacklist.conf: Add 02917e9f8676 mm, hmm: mark hmm_devmem_{add, add_resource} EXPORT_SYMBOL_GPL
- commit 4dfc4eb
* Thu Mar 14 2019 tiwai@suse.de
- blacklist.conf: Add already cherry-picked i915 patch
- commit 804dba5
* Thu Mar 14 2019 tiwai@suse.de
- ASoC: fsl_esai: fix register setting issue in RIGHT_J mode
  (bsc#1051510).
- commit 7d885f5
* Thu Mar 14 2019 oneukum@suse.com
- iwlwifi: pcie: fix TX while flushing (bsc#1120902).
- commit 9ece06a
* Thu Mar 14 2019 oneukum@suse.com
- rt2800: enable TX_PIN_CFG_RFRX_EN only for MT7620 (bsc#1120902).
- commit 33aec8d
* Thu Mar 14 2019 dkirjanov@suse.com
- net: phy: Micrel KSZ8061: link failure after cable connect
  (git-fixes).
- commit 88019b0
* Thu Mar 14 2019 jroedel@suse.de
- iommu/io-pgtable-arm-v7s: Only kmemleak_ignore L2 tables (bsc#1129205).
- commit 8629bf3
* Thu Mar 14 2019 jroedel@suse.de
- iommu: Document iommu_ops.is_attach_deferred() (bsc#1129182).
- iommu/vt-d: Fix NULL pointer reference in intel_svm_bind_mm()
  (bsc#1129184).
- iommu/vt-d: Check identity map for hot-added devices
  (bsc#1129183).
- iommu/dmar: Fix buffer overflow during PCI bus notification
  (bsc#1129181).
- commit 76ef4a9
* Thu Mar 14 2019 tiwai@suse.de
- Update patch tag for media security fix (CVE-2019-2024, bsc#1129179).
- commit fc8a3a2
* Thu Mar 14 2019 tiwai@suse.de
- Move upstreamed libnvdimm patch into sorted section
- commit 4437f27
* Thu Mar 14 2019 tiwai@suse.de
- intel_th: gth: Fix an off-by-one in output unassigning
  (bsc#1051510).
- mmc: spi: Fix card detection during probe (bsc#1051510).
- commit 9b464a7
* Thu Mar 14 2019 tiwai@suse.de
- media: uvcvideo: Avoid NULL pointer dereference at the end of
  streaming (bsc#1051510).
- media: uvcvideo: Fix 'type' check leading to overflow
  (bsc#1051510).
- media: s5k4ecgx: delete a bogus error message (bsc#1051510).
- media: v4l2: i2c: ov7670: Fix PLL bypass register values
  (bsc#1051510).
- media: dt-bindings: media: i2c: Fix i2c address for OV5645
  camera sensor (bsc#1051510).
- media: s5p-jpeg: Correct step and max values for
  V4L2_CID_JPEG_RESTART_INTERVAL (bsc#1051510).
- media: s5p-jpeg: Check for fmt_ver_flag when doing fmt
  enumeration (bsc#1051510).
- media: s5p-mfc: fix incorrect bus assignment in virtual child
  device (bsc#1051510).
- intel_th: Don't reference unassigned outputs (bsc#1051510).
- commit 388e4b3
* Thu Mar 14 2019 tiwai@suse.de
- Input: wacom_serial4 - add support for Wacom ArtPad II tablet
  (bsc#1051510).
- Input: elan_i2c - add id for touchpad found in Lenovo s21e-20
  (bsc#1051510).
- iio: adc: exynos-adc: Fix NULL pointer exception on unbind
  (bsc#1051510).
- staging: iio: adt7316: fix the dac write calculation
  (bsc#1051510).
- staging: iio: adt7316: fix the dac read calculation
  (bsc#1051510).
- staging: iio: adt7316: allow adt751x to use internal vref for
  all dacs (bsc#1051510).
- staging: iio: adt7316: fix register and bit definitions
  (bsc#1051510).
- i2c: omap: Use noirq system sleep pm ops to idle device for
  suspend (bsc#1051510).
- commit 0eb8a90
* Thu Mar 14 2019 tiwai@suse.de
- staging: comedi: ni_660x: fix missing break in switch statement
  (bsc#1051510).
- ASoC: qcom: Fix of-node refcount unbalance in
  apq8016_sbc_parse_of() (bsc#1051510).
- ASoC: msm8916-wcd-analog: add missing license information
  (bsc#1051510).
- ASoC: imx-sgtl5000: put of nodes if finding codec fails
  (bsc#1051510).
- ASoC: imx-audmux: change snprintf to scnprintf for possible
  overflow (bsc#1051510).
- ASoC: dapm: change snprintf to scnprintf for possible overflow
  (bsc#1051510).
- ASoC: Intel: Haswell/Broadwell: fix setting for .dynamic field
  (bsc#1051510).
- commit 6cb3dd6
* Thu Mar 14 2019 tiwai@suse.de
- drm: disable uncached DMA optimization for ARM and arm64
  (bsc#1051510).
- drm: Reorder set_property_atomic to avoid returning with an
  active ww_ctx (bsc#1051510).
- drm: Block fb changes for async plane updates (bsc#1051510).
- drm/sun4i: tcon: Prepare and enable TCON channel 0 clock at init
  (bsc#1051510).
- drm/msm: Unblock writer if reader closes file (bsc#1051510).
- commit 41c06b3
* Thu Mar 14 2019 tiwai@suse.de
- crypto: brcm - Fix some set-but-not-used warning (bsc#1051510).
- commit a9bf978
* Thu Mar 14 2019 tiwai@suse.de
- doc: rcu: Suspicious RCU usage is a warning (bsc#1051510).
- commit 3d3bebc
* Thu Mar 14 2019 jack@suse.cz
- mm: Fix warning in insert_pfn() (bsc#1126740).
- commit 128af59
* Thu Mar 14 2019 jack@suse.cz
- fs/dax: deposit pagetable even when installing zero page
  (bsc#1126740).
- commit 9d52431
* Thu Mar 14 2019 jslaby@suse.cz
- sctp: add a ceiling to optlen in some sockopts (bnc#1129163).
- commit ee5e978
* Thu Mar 14 2019 jack@suse.cz
- mm: Fix modifying of page protection by insert_pfn()
  (bsc#1126740).
- commit f17bd5d
* Wed Mar 13 2019 lduncan@suse.com
- scsi: csiostor: remove flush_scheduled_work() (bsc#1127363).
- commit 742d709
* Wed Mar 13 2019 bp@suse.de
- x86/speculation/mds: Add mitigation mode VMWERV (bsc#1111331).
- commit cee8cea
* Wed Mar 13 2019 bp@suse.de
- x86/speculation/mds: Add sysfs reporting for MDS (bsc#1111331).
- commit 0c734a7
* Wed Mar 13 2019 bp@suse.de
- x86/speculation/mds: Add mitigation control for MDS
  (bsc#1111331).
- commit 029ee41
* Wed Mar 13 2019 bp@suse.de
- x86/speculation/mds: Conditionally clear CPU buffers on idle
  entry (bsc#1111331).
- Refresh
  patches.suse/0003-x86-idle-Control-Indirect-Branch-Speculation-in-idle.patch.
- commit a1eb696
* Wed Mar 13 2019 bp@suse.de
- x86/kvm/vmx: Add MDS protection when L1D Flush is not active
  (bsc#1111331).
- commit 52e4b2a
* Wed Mar 13 2019 tiwai@suse.de
- PCI: endpoint: functions: Use memcpy_fromio()/memcpy_toio()
  (bsc#1051510).
- PCI/PME: Fix hotplug/sysfs remove deadlock in pcie_pme_remove()
  (bsc#1051510).
- serial: uartps: Fix stuck ISR if RX disabled with non-empty FIFO
  (bsc#1051510).
- serial: 8250_pci: Have ACCES cards that use the four
  port Pericom PI7C9X7954 chip use the pci_pericom_setup()
  (bsc#1051510).
- serial: 8250_pci: Fix number of ports for ACCES serial cards
  (bsc#1051510).
- tty: ipwireless: Fix potential NULL pointer dereference
  (bsc#1051510).
- staging: wilc1000: fix to set correct value for 'vif_num'
  (bsc#1051510).
- parport_pc: fix find_superio io compare code, should use equal
  test (bsc#1051510).
- team: Free BPF filter when unregistering netdev (bsc#1051510).
- commit 5d4a544
* Wed Mar 13 2019 tiwai@suse.de
- mmc: omap: fix the maximum timeout setting (bsc#1051510).
- mmc: sdhci-brcmstb: handle mmc_of_parse() errors during probe
  (bsc#1051510).
- mmc: sdhci-esdhc-imx: fix HS400 timing issue (bsc#1051510).
- commit fab7e26
* Wed Mar 13 2019 tiwai@suse.de
- mac80211: Add attribute aligned(2) to struct 'action'
  (bsc#1051510).
- mac80211: don't initiate TDLS connection if station is not
  associated to AP (bsc#1051510).
- mac80211: fix miscounting of ttl-dropped frames (bsc#1051510).
- commit 1409e1d
* Wed Mar 13 2019 tiwai@suse.de
- lib/div64.c: off by one in shift (bsc#1051510).
- commit cb47f8d
* Wed Mar 13 2019 tiwai@suse.de
- iwlwifi: pcie: fix emergency path (bsc#1051510).
- iwlwifi: mvm: fix RSS config command (bsc#1051510).
- iwlwifi: mvm: fix A-MPDU reference assignment (bsc#1051510).
- iwlwifi: mvm: avoid possible access out of array (bsc#1051510).
- leds: lp55xx: fix null deref on firmware load failure
  (bsc#1051510).
- commit a9a6f4b
* Wed Mar 13 2019 tiwai@suse.de
- cw1200: drop useless LIST_HEAD (bsc#1051510).
- cw1200: fix missing unlock on error in cw1200_hw_scan()
  (bsc#1051510).
- commit a8e63bf
* Wed Mar 13 2019 tiwai@suse.de
- crypto: crypto4xx - add missing of_node_put after
  of_device_is_available (bsc#1051510).
- crypto: cavium/zip - fix collision with generic cra_driver_name
  (bsc#1051510).
- crypto: ahash - fix another early termination in hash walk
  (bsc#1051510).
- crypto: caam - fixed handling of sg list (bsc#1051510).
- commit 454f584
* Wed Mar 13 2019 tiwai@suse.de
- crypto: arm/crct10dif - revert to C code for short inputs
  (bsc#1051510).
- crypto: arm64/aes-ccm - fix logical bug in AAD MAC handling
  (bsc#1051510).
- crypto: testmgr - skip crc32c context test for ahash algorithms
  (bsc#1051510).
- crypto: crypto4xx - Fix wrong
  ppc4xx_trng_probe()/ppc4xx_trng_remove() arguments
  (bsc#1051510).
- crypto: tgr192 - fix unaligned memory access (bsc#1051510).
- crypto: hash - set CRYPTO_TFM_NEED_KEY if ->setkey() fails
  (bsc#1051510).
- commit 6b741b1
* Wed Mar 13 2019 tiwai@suse.de
- cfg80211: extend range deviation for DMG (bsc#1051510).
- commit 13599e1
* Wed Mar 13 2019 msuchanek@suse.de
- pseries/energy: Use OF accessor function to read ibm,drc-indexes
  (bsc#1129080).
- commit 7394cd0
* Wed Mar 13 2019 tiwai@suse.de
- cdc-wdm: pass return value of recover_from_urb_loss
  (bsc#1051510).
- commit b516984
* Wed Mar 13 2019 tiwai@suse.de
- Move upstreamed ALSA and BT patches into sorted section
- commit 781d43e
* Wed Mar 13 2019 tiwai@suse.de
- kABI workaround for bt_accept_enqueue() change (bsc#1051510).
- commit 43ab1ea
* Wed Mar 13 2019 tiwai@suse.de
- Bluetooth: Fix locking in bt_accept_enqueue() for BH context
  (bsc#1051510).
- commit 51c4ae3
* Wed Mar 13 2019 tiwai@suse.de
- atm: he: fix sign-extension overflow on large shift
  (bsc#1051510).
- commit 5f6e8f4
* Wed Mar 13 2019 tiwai@suse.de
- ALSA: firewire-motu: fix construction of PCM frame for capture
  direction (bsc#1051510).
- ALSA: bebob: use more identical mod_alias for Saffire Pro 10
  I/O against Liquid Saffire 56 (bsc#1051510).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX362FA with
  ALC294 (bsc#1051510).
- ACPI / video: Extend chassis-type detection with a "Lunch Box"
  check (bsc#1051510).
- ACPI / video: Refactor and fix dmi_is_desktop() (bsc#1051510).
- ath9k: Avoid OF no-EEPROM quirks without qca,no-eeprom
  (bsc#1051510).
- ALSA: compress: prevent potential divide by zero bugs
  (bsc#1051510).
- commit d37d7e2
* Wed Mar 13 2019 fabian.baumanis@suse.com
- USB: Consolidate LPM checks to avoid enabling LPM twice
  (bsc#1120902).
- commit fcbbc9b
* Wed Mar 13 2019 fabian.baumanis@suse.com
- USB: Add new USB LPM helpers (bsc#1120902).
- commit e26fa0f
* Wed Mar 13 2019 bp@suse.de
- x86/speculation/mds: Clear CPU buffers on exit to user
  (bsc#1111331).
- commit f4c43e2
* Wed Mar 13 2019 jgross@suse.com
- Refresh
  patches.fixes/0001-xen-remove-pre-xen3-fallback-handlers.patch:
  use original upstream commit and add kabi patch.
- commit 936395d
* Wed Mar 13 2019 mkubecek@suse.cz
- geneve, vxlan: Don't set exceptions if skb->len < mtu
  (bsc#1123456).
- commit 38a43d6
* Wed Mar 13 2019 mkubecek@suse.cz
- geneve, vxlan: Don't check skb_dst() twice (bsc#1123456).
- commit 41534ed
* Wed Mar 13 2019 mkubecek@suse.cz
- ip6_tunnel: use the right value for ipv4 min mtu check in
  ip6_tnl_xmit (bsc#1123456).
- commit 126bfd9
* Wed Mar 13 2019 bp@suse.de
- x86/speculation/mds: Add mds_clear_cpu_buffers() (bsc#1111331).
- commit a810f6d
* Wed Mar 13 2019 mkubecek@suse.cz
- geneve: cleanup hard coded value for Ethernet header length
  (bsc#1123456).
- commit 9a70ea2
* Wed Mar 13 2019 mkubecek@suse.cz
- net: don't call update_pmtu unconditionally (bsc#1123456).
- Refresh
  patches.fixes/vti6-fix-PMTU-caching-and-reporting-on-xmit.patch
  patches.fixes/vti6-remove-skb-ignore_df-check-from-vti6_xmit.patch
- commit 593c444
* Wed Mar 13 2019 mkubecek@suse.cz
- ip6_tunnel: get the min mtu properly in ip6_tnl_xmit
  (bsc#1123456).
- commit f90f47d
* Wed Mar 13 2019 mkubecek@suse.cz
- vxlan: update skb dst pmtu on tx path (bsc#1123456).
- commit a42a5a4
* Wed Mar 13 2019 bp@suse.de
- x86/kvm: Expose X86_FEATURE_MD_CLEAR to guests (bsc#1111331).
- commit 2d3910e
* Wed Mar 13 2019 bp@suse.de
- x86/speculation/mds: Add BUG_MSBDS_ONLY (bsc#1111331).
- commit 6afac67
* Wed Mar 13 2019 jgross@suse.com
- xen/manage: don't complain about an empty value in control/sysrq
  node (bsc#1065600).
- commit d8327b8
* Tue Mar 12 2019 msuchanek@suse.de
- copy_mount_string: Limit string length to PATH_MAX (bsc#1082943).
- Delete patches.fixes/get_fs_type-Validate-fs-type-string-argument.patch.
  Refresh to upstream patch.
- commit 8717894
* Tue Mar 12 2019 jgross@suse.com
- xen: fix dom0 boot on huge systems (bsc#1127836).
- commit d4d49f5
* Tue Mar 12 2019 bp@suse.de
- x86/speculation/mds: Add basic bug infrastructure for MDS
  (bsc#1111331).
- commit ca135db
* Tue Mar 12 2019 jgross@suse.com
- xen: remove pre-xen3 fallback handlers (bsc#1065600).
- commit c8c4f0a
* Tue Mar 12 2019 jgross@suse.com
- xen, cpu_hotplug: Prevent an out of bounds access (bsc#1065600).
- commit 60b6d9d
* Tue Mar 12 2019 bp@suse.de
- x86/speculation: Consolidate CPU whitelists (bsc#1111331).
- commit 1d2d993
* Tue Mar 12 2019 mwilck@suse.com
- Refresh
  patches.suse/scsi-do-not-print-reservation-conflict-for-TEST-UNIT.patch
  (bsc#1119843)
- commit 2c06a05
* Tue Mar 12 2019 bp@suse.de
- x86/msr-index: Cleanup bit defines (bsc#1111331).
- commit 93e3cf8
* Tue Mar 12 2019 hare@suse.de
- nvme-fc: reject reconnect if io queue count is reduced to zero
  (bsc#1128351).
- commit a512dae
* Tue Mar 12 2019 hare@suse.de
- scripts/git_sort/git_sort.py: Update nvme git repository to 5.1
- commit cff4e76
* Tue Mar 12 2019 nsaenzjulienne@suse.de
- Input: raspberrypi-ts - select CONFIG_INPUT_POLLDEV (git-fixes).
- commit dfac1c8
* Tue Mar 12 2019 jthumshirn@suse.de
- block: don't use bio->bi_vcnt to figure out segment number
  (bsc#1128895).
- commit bfd835c
* Tue Mar 12 2019 bp@suse.de
- locking/atomics, asm-generic: Move some macros from
  <linux/bitops.h> to a new <linux/bits.h> file (bsc#1111331).
- commit 8bb1a8a
* Tue Mar 12 2019 mwilck@suse.com
- block: check_events: don't bother with events if unsupported (bsc#1110946, bsc#1119843).
- commit 0e16418
* Tue Mar 12 2019 mwilck@suse.com
- Revert "block: unexport DISK_EVENT_MEDIA_CHANGE for legacy/fringe drivers" (bsc#1110946, bsc#1119843).
- commit 63d99c8
* Tue Mar 12 2019 mwilck@suse.com
- block: disk_events: introduce event flags (bsc#1110946, bsc#1119843).
- commit 0b56ce7
* Tue Mar 12 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Don't try to use the hardware frame counter with i965gm TV output'
- commit 91bbd55
* Tue Mar 12 2019 glin@suse.com
- bpf: fix replace_map_fd_with_map_ptr's ldimm64 second imm field
  (bsc#1083647).
- commit 50ceb6a
* Tue Mar 12 2019 tonyj@suse.de
- perf/x86/intel: Implement support for TSX Force Abort
  (bsc#1121805).
- x86: Add TSX Force Abort CPUID/MSR (bsc#1121805).
- perf/x86/intel: Generalize dynamic constraint creation
  (bsc#1121805).
- perf/x86/intel: Make cpuc allocations consistent (bsc#1121805).
- perf/x86/intel: Delay memory deallocation until
  x86_pmu_dead_cpu() (bsc#1121805).
- perf/x86/intel: Don't enable freeze-on-smi for PerfMon V1
  (bsc#1121805).
- perf/x86: Add sysfs entry to freeze counters on SMI
  (bsc#1121805).
- commit 9317981
* Mon Mar 11 2019 bp@suse.de
- x86/speculation: Simplify the CPU bug detection logic
  (bsc#1111331).
- Refresh patches.arch/x86-bugs-add-amd-s-variant-of-ssb_no.patch.
- Refresh
  patches.arch/x86-speculation-support-enhanced-ibrs-on-future-cpus.patch.
- commit d82e4ef
* Mon Mar 11 2019 tzimmermann@suse.de
- drm/radeon/evergreen_cs: fix missing break in switch statement (bsc#1113722)
- commit 1cee3e3
* Mon Mar 11 2019 tzimmermann@suse.de
- drm/nouveau: Don't WARN_ON VCPI allocation failures (bsc#1113722)
- commit 82dc918
* Mon Mar 11 2019 tzimmermann@suse.de
- drm/nouveau/pmu: don't print reply values if exec is false (bsc#1113722)
- commit 8e01362
* Mon Mar 11 2019 tzimmermann@suse.de
- drm/nouveau/bios/ramcfg: fix missing parentheses when calculating RON (bsc#1113722)
- commit d1c8971
* Mon Mar 11 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Prevent a race during I915_GEM_MMAP ioctl with WC set'
- commit f1ee607
* Mon Mar 11 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Block fbdev HPD processing during suspend'
- commit 473e675
* Mon Mar 11 2019 jslaby@suse.cz
- hpet: Fix missing '=' character in the __setup() code of
  hpet_mmap_enable (git-fixes).
- commit 8cc8dbe
* Mon Mar 11 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/of: Fix kerneldoc'
- commit c41090b
* Mon Mar 11 2019 tzimmermann@suse.de
- drm/shmob: Fix return value check in shmob_drm_probe (bsc#1113722)
- commit c59e8a3
* Mon Mar 11 2019 tzimmermann@suse.de
- drm: Fix error handling in drm_legacy_addctx (bsc#1113722)
- commit 7646b89
* Mon Mar 11 2019 mbenes@suse.cz
- Refresh patches.suse/livepatch-add-atomic-replace.patch.
- Refresh
  patches.suse/livepatch-atomic-replace-and-cumulative-patches-documentation.patch.
- Refresh
  patches.suse/livepatch-change-unsigned-long-old_addr-void-old_func-in-struct-klp_func.patch.
- Refresh
  patches.suse/livepatch-consolidate-klp_free-functions.patch.
- Refresh
  patches.suse/livepatch-core-return-eopnotsupp-instead-of-enosys.patch.
- Refresh
  patches.suse/livepatch-don-t-block-the-removal-of-patches-loaded-after-a-forced-transition.patch.
- Refresh
  patches.suse/livepatch-introduce-klp_for_each_patch-macro.patch.
- Refresh
  patches.suse/livepatch-module-coming-and-going-callbacks-can-proceed-with-all-listed-patches.patch.
- Refresh
  patches.suse/livepatch-proper-error-handling-in-the-shadow-variables-selftest.patch.
- Refresh
  patches.suse/livepatch-remove-nop-structures-when-unused.patch.
- Refresh
  patches.suse/livepatch-remove-ordering-stacking-of-the-livepatches.patch.
- Refresh
  patches.suse/livepatch-remove-signal-sysfs-attribute.patch.
- Refresh
  patches.suse/livepatch-return-enomem-on-ptr_id-allocation-failure.patch.
- Refresh
  patches.suse/livepatch-send-a-fake-signal-periodically.patch.
- Refresh
  patches.suse/livepatch-shuffle-klp_enable_patch-klp_disable_patch-code.patch.
- Refresh
  patches.suse/livepatch-simplify-api-by-removing-registration-step.patch.
- Refresh
  patches.suse/livepatch-use-lists-to-manage-patches-objects-and-functions.patch.
- Refresh
  patches.suse/selftests-livepatch-add-dynamic_debug-config-dependency.patch.
- Refresh patches.suse/selftests-livepatch-introduce-tests.patch.
  Move upstream livepatch patches to the sorted section.
- commit 8ba9e19
* Mon Mar 11 2019 mbenes@suse.cz
- Refresh
  patches.arch/powerpc-pseries-Perform-full-re-add-of-CPU-for-topol.patch.
- Refresh
  patches.arch/powerpc-pseries-export-timebase-register-sample-in-l.patch.
- Refresh
  patches.fixes/0001-media-usb-pwc-Don-t-use-coherent-DMA-buffers-for-ISO.patch.
- Refresh
  patches.fixes/exec-Fix-mem-leak-in-kernel_read_file.patch.
- Refresh
  patches.fixes/scsi-core-reset-host-byte-in-DID_NEXUS_FAILURE-case.patch.
- Refresh
  patches.suse/powerpc-64s-clear-on-stack-exception-marker-upon-exception-return.patch.
- Refresh
  patches.suse/powerpc-livepatch-relax-reliable-stack-tracer-checks-for-first-frame.patch.
- Refresh
  patches.suse/powerpc-livepatch-small-cleanups-in-save_stack_trace_tsk_reliable.patch.
  Move upstreamed patches to the sorted section.
- commit 90d0c8c
* Mon Mar 11 2019 jroedel@suse.de
- kABI: Preserve kABI for dma_max_mapping_size() (bsc#1120008).
- virtio-blk: Consider virtio_max_dma_size() for maximum segment
  size (bsc#1120008).
- virtio: Introduce virtio_max_dma_size() (bsc#1120008).
- dma: Introduce dma_max_mapping_size() (bsc#1120008).
- swiotlb: Add is_swiotlb_active() function (bsc#1120008).
- swiotlb: Introduce swiotlb_max_mapping_size() (bsc#1120008).
- commit 5f5f865
* Mon Mar 11 2019 tzimmermann@suse.de
- backlight: pwm_bl: Use gpiod_get_value_cansleep() to get initial (bsc#1113722)
- commit df86ff8
* Fri Mar  8 2019 lduncan@suse.com
- scsi: libiscsi: Fix race between iscsi_xmit_task and
  iscsi_complete_task (bsc#1122192).
- commit a839a94
* Fri Mar  8 2019 dkirjanov@suse.com
- s390/qeth: conclude all event processing before offlining a card
  (LTC#175901, bsc#1127567).
- commit 670183e
* Fri Mar  8 2019 jthumshirn@suse.de
- btrfs: ensure that a DUP or RAID1 block group has exactly two
  stripes (bsc#1128451).
- commit 2cd1e7f
* Thu Mar  7 2019 bp@suse.de
- x86/kaslr: Fix incorrect i8254 outb() parameters (bsc#1114279).
- Refresh
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
- commit fc169b3
* Thu Mar  7 2019 hare@suse.de
- scsi: qla2xxx: Update driver version to 10.00.00.12-k (bsc#1094555).
- scsi: qla2xxx: Fix for FC-NVMe discovery for NPIV port (bsc#1094555).
- scsi: qla2xxx: Fix NPIV handling for FC-NVMe (bsc#1094555).
- scsi: qla2xxx: Enable FC-NVME on NPIV ports (bsc#1094555).
- scsi: qla2xxx: Initialize port speed to avoid setting lower speed (bsc#1094555).
- scsi: qla2xxx: Fix a typo in MODULE_PARM_DESC (bsc#1094555).
- scsi: qla2xxx: Modify fall-through annotations (bsc#1094555).
- scsi: qla2xxx: Simplify conditional check (bsc#1094555).
- scsi: qla2xxx: Remove unnecessary self assignment (bsc#1094555).
- commit ba2f97d
* Thu Mar  7 2019 jslaby@suse.cz
- net: netem: fix skb length BUG_ON in __skb_to_sgvec (git-fixes).
- commit ad202d7
* Thu Mar  7 2019 alnovak@suse.cz
- scsi: sym53c8xx: fix NULL pointer dereference panic in
  sym_int_sir() (bsc#1125315).
- commit 39c1bd9
* Thu Mar  7 2019 dkirjanov@suse.com
- s390/qeth: cancel close_dev work before removing a card
  (LTC#175898, bsc#1127561).
- commit e74805a
* Thu Mar  7 2019 jslaby@suse.cz
- netfilter: nf_tables: check the result of dereferencing
  base_chain->stats (git-fixes).
- commit a4e03cb
* Thu Mar  7 2019 lduncan@suse.com
- scsi: virtio_scsi: fix pi_bytes{out,in} on 4 KiB block size
  devices (bsc#1114585).
- block: move bio_integrity_{intervals,bytes} into blkdev.h
  (bsc#1114585).
- commit a620aaf
* Thu Mar  7 2019 lduncan@suse.com
- Remove blacklist of virtio patch so we can install it
  (bsc#1114585)
- commit c3293e9
* Wed Mar  6 2019 msuchanek@suse.de
- Revert "Drop multiversion(kernel) from the KMP template (fate#323189)"
  (bsc#1109137).
  This reverts commit 71504d805c1340f68715ad41958e5ef35da2c351.
- commit adade9f
* Wed Mar  6 2019 mhocko@suse.com
- mm: enforce min addr even if capable() in expand_downwards()
  (bsc#1128166, CVE-2019-9213).
- commit 998cff7
* Wed Mar  6 2019 mbenes@suse.cz
- powerpc/livepatch: small cleanups in
  save_stack_trace_tsk_reliable() (bsc#1071995 fate#323487).
- commit 38b76ee
* Wed Mar  6 2019 mbenes@suse.cz
- powerpc/livepatch: relax reliable stack tracer checks for
  first-frame (bsc#1071995 fate#323487).
- commit 618ef9f
* Wed Mar  6 2019 mbenes@suse.cz
- powerpc/64s: Clear on-stack exception marker upon exception
  return (bsc#1071995 fate#323487).
- commit ba10b93
* Wed Mar  6 2019 mbenes@suse.cz
- livepatch: Remove signal sysfs attribute (bsc#1071995
  fate#323487).
- commit c5e5181
* Wed Mar  6 2019 mbenes@suse.cz
- livepatch: Send a fake signal periodically (bsc#1071995
  fate#323487).
- commit 7088101
* Wed Mar  6 2019 mbenes@suse.cz
- livepatch: Module coming and going callbacks can proceed with
  all listed patches (bsc#1071995 fate#323487).
- commit 79db698
* Wed Mar  6 2019 mbenes@suse.cz
- livepatch: Proper error handling in the shadow variables
  selftest (bsc#1071995 fate#323487).
- commit 0eaa537
* Wed Mar  6 2019 mbenes@suse.cz
- livepatch: return -ENOMEM on ptr_id() allocation failure
  (bsc#1071995 fate#323487).
- commit 0f271e8
* Wed Mar  6 2019 mbenes@suse.cz
- livepatch: Introduce klp_for_each_patch macro (bsc#1071995
  fate#323487).
- commit da18829
* Wed Mar  6 2019 mbenes@suse.cz
- livepatch: core: Return EOPNOTSUPP instead of ENOSYS
  (bsc#1071995 fate#323487).
- commit 9ec6c45
* Wed Mar  6 2019 mbenes@suse.cz
- selftests/livepatch: add DYNAMIC_DEBUG config dependency
  (bsc#1071995 fate#323487).
- commit 2d37e66
* Tue Mar  5 2019 bp@suse.de
- blacklist.conf: 53bb565fc543 x86/PCI: Fix Broadcom CNB20LE unintended sign extension (redux)
- commit 38334db
* Tue Mar  5 2019 bp@suse.de
- blacklist.conf: 65bba0423ecf kbuild: fix UML build error with CONFIG_GCC_PLUGINS
- commit a2369f4
* Tue Mar  5 2019 bp@suse.de
- blacklist.conf: 29434801e7e9 x86/vdso: Remove a stale/misleading comment from the linker script
- commit 622c158
* Tue Mar  5 2019 bp@suse.de
- x86/vdso: Remove obsolete "fake section table" reservation
  (bsc#1114279).
- commit 23f423f
* Tue Mar  5 2019 aaptel@suse.com
- Update config files.
  Remove conditional support for SMB2 and SMB3:
- They were already enabled and are now always enabled.
- There are no more #ifdef checking these macros.
- They dont show up in fs/cifs/Kconfig
- They have been removed upstream
- It makes backporting easier, otherwise backported patches need to
  modified to add #ifdef
  Keep them as =y in vanilla config (which still requires it)
- commit 5cf8695
* Tue Mar  5 2019 mbenes@suse.cz
- Enable livepatch test drivers in lib/
  Livepatch kselftests need those.
- Update config files.
- supported.conf
- commit b5e1a19
* Tue Mar  5 2019 mbenes@suse.cz
- selftests/livepatch: introduce tests (bsc#1071995 fate#323487).
- commit 248f360
* Tue Mar  5 2019 mbenes@suse.cz
- Update config files.
- commit 83afceb
* Tue Mar  5 2019 mbenes@suse.cz
- livepatch: Define a macro for new API identification
  (bsc#1071995 fate#323487).
- commit c2e2280
* Tue Mar  5 2019 bp@suse.de
- x86/mtrr: Don't copy uninitialized gentry fields back to
  userspace (bsc#1114279).
- commit 135fda8
* Tue Mar  5 2019 bp@suse.de
- blacklist.conf: dbe733642e01 x86/Kconfig: Select SCHED_SMT if SMP enabled
- commit 117d5dd
* Tue Mar  5 2019 dkirjanov@suse.com
- s390/qeth: fix use-after-free in error path (bsc#1127534).
- commit 6ea74cd
* Tue Mar  5 2019 bp@suse.de
- blacklist.conf: b247be3fe89b locking/qspinlock/x86: Increase _Q_PENDING_LOOPS upper bound
  Not needed urgently in SLE15.
- commit f26ee44
* Tue Mar  5 2019 bp@suse.de
- x86/a.out: Clear the dump structure initially (bsc#1114279).
- commit 6c90b4f
* Tue Mar  5 2019 mbenes@suse.cz
- livepatch: Change unsigned long old_addr -> void *old_func in
  struct klp_func (bsc#1071995 fate#323487).
- livepatch: Consolidate klp_free functions (bsc#1071995
  fate#323487).
- livepatch: Don't block the removal of patches loaded after a
  forced transition (bsc#1071995 fate#323487).
- livepatch: Remove ordering (stacking) of the livepatches
  (bsc#1071995 fate#323487).
- livepatch: Shuffle klp_enable_patch()/klp_disable_patch() code
  (bsc#1071995 fate#323487).
- livepatch: Simplify API by removing registration step
  (bsc#1071995 fate#323487).
- Refresh patches.suse/livepatch-add-atomic-replace.patch.
- Refresh
  patches.suse/livepatch-atomic-replace-and-cumulative-patches-documentation.patch.
- Refresh
  patches.suse/livepatch-mark-the-kernel-unsupported-when-disabling.patch.
- Refresh
  patches.suse/livepatch-remove-nop-structures-when-unused.patch.
- Refresh
  patches.suse/livepatch-send-a-fake-signal-periodically.patch.
- Refresh
  patches.suse/livepatch-use-lists-to-manage-patches-objects-and-functions.patch.
- Delete
  patches.suse/livepatch-add-an-extra-flag-to-distinguish-registered-patches.patch.
- Delete
  patches.suse/livepatch-allow-to-replace-even-disabled-patches.patch.
- Delete
  patches.suse/livepatch-free-only-structures-with-initialized-kobject.patch.
- Delete
  patches.suse/livepatch-remove-replaced-patches-from-the-stack.patch.
  Atomic replace. Update to a final version.
- commit 2a26746
* Tue Mar  5 2019 glin@suse.com
- bpf: drop refcount if bpf_map_new_fd() fails in map_create()
  (bsc#1083647).
- bpf: decrease usercnt if bpf_map_new_fd() fails in
  bpf_map_get_fd_by_id() (bsc#1083647).
- commit 97bcd77
* Mon Mar  4 2019 msuchanek@suse.de
- powerpc/pseries: export timebase register sample in lparcfg
  (bsc#1127750).
- commit 6023475
* Mon Mar  4 2019 jlee@suse.com
- x86/efi: Allocate e820 buffer before calling
  efi_exit_boot_service (bsc#1127307).
- commit 35133e1
* Mon Mar  4 2019 msuchanek@suse.de
- libnvdimm: Fix altmap reservation size calculation
  (bsc#1127682).
- commit c006172
* Mon Mar  4 2019 osalvador@suse.de
- mm,memory_hotplug: fix scan_movable_pages() for gigantic
  hugepages (bsc#1127731).
- commit 8454bd2
* Mon Mar  4 2019 ohering@suse.de
- pci-hyperv: increase HV_VP_SET_BANK_COUNT_MAX to handle 1792
  vcpus (fate#327171, bsc#1122822).
- hv: v4.12 API for hyperv-iommu (fate#327171, bsc#1122822).
- HYPERV/IOMMU: Add Hyper-V stub IOMMU driver (fate#327171,
  bsc#1122822).
- x86/Hyper-V: Set x2apic destination mode to physical when
  x2apic is available (fate#327171, bsc#1122822).
- x86/apic: Provide apic_ack_irq() (fate#327171, bsc#1122822).
- commit 56ec609
* Mon Mar  4 2019 glin@suse.com
- bpf: fix sanitation rewrite in case of non-pointers
  (bsc#1083647).
- commit 7770a6f
* Mon Mar  4 2019 tzimmermann@suse.de
- drm/vmwgfx: Don't double-free the mode stored in par->set_mode (bsc#1103429)
- commit 99c4074
* Sat Mar  2 2019 fdmanana@suse.com
- btrfs: fix use-after-free of cmp workspace pages (bsc#1127603).
- commit 7753ef9
* Sat Mar  2 2019 fdmanana@suse.com
- btrfs: fix invalid-free in btrfs_extent_same (bsc#1127498).
- Btrfs: fix clone vs chattr NODATASUM race (bsc#1127497).
- btrfs: use kvzalloc for EXTENT_SAME temporary data
  (bsc#1127496).
- Btrfs: reuse cmp workspace in EXTENT_SAME ioctl (bsc#1127495).
- Btrfs: dedupe_file_range ioctl: remove 16MiB restriction
  (bsc#1127494).
- commit 8bb669e
* Sat Mar  2 2019 fdmanana@suse.com
- Btrfs: split btrfs_extent_same (bsc#1127493).
- Refresh
  patches.suse/btrfs-fix-data-corruption-when-deduplicating-between.patch.
- commit 67ac488
* Fri Mar  1 2019 lduncan@suse.com
- scsi: mpt3sas: switch to generic DMA API (bsc#1117108).
- scsi: mpt3sas: Remove unnecessary parentheses and simplify
  null checks (bsc#1117108).
- scsi: mpt3sas: Use dma_pool_zalloc (bsc#1117108).
- scsi: mpt3sas: Remove unused macro MPT3SAS_FMT (bsc#1117108).
- scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT without
  logging levels (bsc#1117108).
- scsi: mpt3sas: Remove KERN_WARNING from panic uses
  (bsc#1117108).
- scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT and
  reply_q_name to %%s: (bsc#1117108).
- scsi: mpt3sas: Convert mlsleading uses of pr_<level> with
  MPT3SAS_FMT (bsc#1117108).
- commit e3f05da
* Fri Mar  1 2019 lduncan@suse.com
- scsi: mpt3sas: Convert uses of pr_<level> with MPT3SAS_FMT to
  ioc_<level> (bsc#1117108).
- Refresh
  patches.suse/mpt3sas-check-sense-buffer-before-copying-sense-data.patch.
- commit 9574b94
* Fri Mar  1 2019 palcantara@suse.de
- cifs: Always resolve hostname before reconnecting (bsc#1051510).
- commit c95017f
* Fri Mar  1 2019 tiwai@suse.de
- ACPI: NUMA: Use correct type for printing addresses on i386-PAE
  (bsc#1051510).
- clocksource/drivers/integrator-ap: Add missing of_node_put()
  (bsc#1051510).
- cpufreq: conservative: Take limits changes into account properly
  (bsc#1051510).
- cpufreq: governor: Avoid accessing invalid governor_data
  (bsc#1051510).
- commit b5192ba
* Fri Mar  1 2019 tiwai@suse.de
- x86/boot/e820: Introduce the bootloader provided
  e820_table_firmware[] table (bsc#1127154).
- x86/boot/e820: Rename the e820_table_firmware to
  e820_table_kexec (bsc#1127154).
- x86/boot/e820: Avoid overwriting e820_table_firmware
  (bsc#1127154).
- commit 2e41e89
* Fri Mar  1 2019 jslaby@suse.cz
- rxrpc: bad unlock balance in rxrpc_recvmsg
  (networking-stable-19_02_10).
- net: dsa: slave: Don't propagate flag changes on down slave
  interfaces (networking-stable-19_02_10).
- net: dp83640: expire old TX-skb (networking-stable-19_02_10).
- net: systemport: Fix WoL with password after deep sleep
  (networking-stable-19_02_10).
- commit c07383b
* Fri Mar  1 2019 lduncan@suse.com
- scsi: mpt3sas: Add ioc_<level> logging macros (bsc#1117108).
- scsi: mpt3sas: Improve kernel-doc headers (bsc#1117108).
- scsi: mpt3sas: Split _base_reset_handler(),
  mpt3sas_scsih_reset_handler() and mpt3sas_ctl_reset_handler()
  (bsc#1117108).
- scsi: mpt3sas: Fix a race condition in
  mpt3sas_base_hard_reset_handler() (bsc#1117108).
- scsi: mpt3sas: Introduce struct mpt3sas_nvme_cmd (bsc#1117108).
- scsi: mpt3sas: Annotate switch/case fall-through (bsc#1117108).
- scsi: mpt3sas: Remove set-but-not-used variables (bsc#1117108).
- scsi: mpt3sas: Fix indentation (bsc#1117108).
- scsi: mpt3sas: Swap I/O memory read value back to cpu endianness
  (bsc#1117108).
- commit 4ec4b4f
* Thu Feb 28 2019 hare@suse.de
- bsg: Do not copy sense if no response buffer is allocated
  (bsc#1106811,bsc#1126555).
- Delete
  patches.fixes/bsg-allocate-sense-buffer-if-requested.patch.
- commit 9c493cb
* Thu Feb 28 2019 hare@suse.de
- nvme-multipath: drop optimization for static ANA group IDs
  (bsc#1113939).
- commit 1bbf15f
* Thu Feb 28 2019 jslaby@suse.cz
- l2tp: copy 4 more bytes to linear part if necessary
  (networking-stable-19_02_01).
- ipvlan, l3mdev: fix broken l3s mode wrt local routes
  (networking-stable-19_02_01).
- l2tp: fix reading optional fields of L2TPv3
  (networking-stable-19_02_01).
- virtio_net: Don't call free_old_xmit_skbs for xdp_frames
  (networking-stable-19_02_01).
- ucc_geth: Reset BQL queue when stopping device
  (networking-stable-19_02_01).
- net: set default network namespace in init_dummy_netdev()
  (networking-stable-19_02_01).
- net/mlx5e: Allow MAC invalidation while spoofchk is ON
  (networking-stable-19_02_01).
- net/rose: fix NULL ax25_cb kernel panic
  (networking-stable-19_02_01).
- net/mlx4_core: Add masking for a few queries on HCA caps
  (networking-stable-19_02_01).
- sctp: improve the events for sctp stream adding
  (networking-stable-19_02_01).
- sctp: improve the events for sctp stream reset
  (networking-stable-19_02_01).
- ipv6: Consider sk_bound_dev_if when binding a socket to an
  address (networking-stable-19_02_01).
- commit 7665cf7
* Wed Feb 27 2019 tiwai@suse.de
- blacklist.conf: Remove the duplicated and already-backported entries
- commit de43900
* Wed Feb 27 2019 tiwai@suse.de
- vhost: correctly check the return value of translate_desc()
  in log_used() (bsc#1051510).
- net: bcmgenet: remove HFB_CTRL access (bsc#1051510).
- commit 932bcf7
* Wed Feb 27 2019 jslaby@suse.cz
- kABI: protect vhost_log_write (kabi).
- commit 8090acf
* Wed Feb 27 2019 tiwai@suse.de
- net: bcmgenet: abort suspend on error (bsc#1051510).
- net: bcmgenet: code movement (bsc#1051510).
- commit ca48ef4
* Wed Feb 27 2019 yousaf.kaukab@suse.com
- kabi: cpufreq: keep min_sampling_rate in struct dbs_data
  (bsc#1127042).
- cpufreq: governor: Ensure sufficiently large sampling intervals
  (bsc#1127042).
- cpufreq: Cap the default transition delay value to 10 ms
  (bsc#1127042).
- cpufreq: Use transition_delay_us for legacy governors as well
  (bsc#1127042).
- cpufreq: governor: Drop min_sampling_rate (bsc#1127042).
- commit 28dc41c
* Wed Feb 27 2019 tiwai@suse.de
- mfd: mc13xxx: Fix a missing check of a register-read failure
  (bsc#1051510).
- mfd: tps65218: Use devm_regmap_add_irq_chip and clean up error
  path in probe() (bsc#1051510).
- mfd: wm5110: Add missing ASRC rate register (bsc#1051510).
- mfd: qcom_rpm: write fw_version to CTRL_REG (bsc#1051510).
- mfd: mt6397: Do not call irq_domain_remove if PMIC unsupported
  (bsc#1051510).
- mfd: db8500-prcmu: Fix some section annotations (bsc#1051510).
- mfd: twl-core: Fix section annotations on {,un}protect_pm_master
  (bsc#1051510).
- mfd: ti_am335x_tscadc: Use PLATFORM_DEVID_AUTO while registering
  mfd cells (bsc#1051510).
- pinctrl: max77620: Use define directive for
  max77620_pinconf_param values (bsc#1051510).
- phy: tegra: remove redundant self assignment of 'map'
  (bsc#1051510).
- commit 20f57da
* Wed Feb 27 2019 tiwai@suse.de
- mac80211: Free mpath object when rhashtable insertion fails
  (bsc#1051510).
- commit 1b53757
* Wed Feb 27 2019 tiwai@suse.de
- leds: lp5523: fix a missing check of return value of lp55xx_read
  (bsc#1051510).
- commit 9a76479
* Wed Feb 27 2019 tiwai@suse.de
- isdn: avm: Fix string plus integer warning from Clang
  (bsc#1051510).
- isdn: i4l: isdn_tty: Fix some concurrency double-free bugs
  (bsc#1051510).
- commit 5628a6c
* Wed Feb 27 2019 tiwai@suse.de
- hwmon: (tmp421) Correct the misspelling of the tmp442 compatible
  attribute in OF device ID table (bsc#1051510).
- commit 6420cdc
* Wed Feb 27 2019 tiwai@suse.de
- drm/meson: add missing of_node_put (bsc#1051510).
- commit d9d0985
* Wed Feb 27 2019 lyan@suse.com
- kvm: x86: Add AMD's EX_CFG to the list of ignored MSRs
  (bsc#1127082).
- commit e389988
* Tue Feb 26 2019 ailiopoulos@suse.com
- iomap: warn on zero-length mappings (bsc#1127062).
- commit 8971b0d
* Tue Feb 26 2019 dbueso@suse.de
- sched/wake_q: Reduce reference counting for special users
  (bsc#1050549).
- locking/rwsem: Fix (possible) missed wakeup (bsc#1050549).
- futex: Fix (possible) missed wakeup (bsc#1050549).
- sched/wake_q: Fix wakeup ordering for wake_q (bsc#1050549).
- sched/wake_q: Document wake_q_add() (bsc#1050549).
- commit 5e0bd2e
* Tue Feb 26 2019 tiwai@suse.de
- blacklist.conf: ignore Smack; we don't enable it
- commit 243e8f2
* Tue Feb 26 2019 tiwai@suse.de
- ntb_transport: Fix bug with max_mw_size parameter (bsc#1051510).
- commit 7687c1e
* Tue Feb 26 2019 tiwai@suse.de
- fuse: decrement NR_WRITEBACK_TEMP on the right page
  (bsc#1051510).
- fuse: call pipe_buf_release() under pipe lock (bsc#1051510).
- fuse: handle zero sized retrieve correctly (bsc#1051510).
- fuse: continue to send FUSE_RELEASEDIR when FUSE_OPEN returns
  ENOSYS (bsc#1051510).
- configfs: fix registered group removal (bsc#1051510).
- commit 1204575
* Tue Feb 26 2019 tiwai@suse.de
- mdio_bus: Fix use-after-free on device_register fails
  (bsc#1051510).
- sky2: Increase D3 delay again (bsc#1051510).
- mailbox: bcm-flexrm-mailbox: Fix FlexRM ring flush timeout issue
  (bsc#1051510).
- vsock: cope with memory allocation failure at socket creation
  time (bsc#1051510).
- mISDN: fix a race in dev_expire_timer() (bsc#1051510).
- enic: fix checksum validation for IPv6 (bsc#1051510).
- ax25: fix possible use-after-free (bsc#1051510).
- iser: set sector for ambiguous mr status errors (bsc#1051510).
- llc: do not use sk_eat_skb() (bsc#1051510).
- veth: set peer GSO values (bsc#1051510).
- vhost/vsock: fix uninitialized vhost_vsock->guest_cid
  (bsc#1051510).
- macvlan: Only deliver one copy of the frame to the macvlan
  interface (bsc#1051510).
- rocker: fix rocker_tlv_put_* functions for KASAN (bsc#1051510).
- sch_multiq: fix double free on init failure (bsc#1051510).
- commit 8d4ab3f
* Tue Feb 26 2019 oneukum@suse.com
- usb: musb: dsps: fix runtime pm for peripheral mode
  (bsc#1120902).
- commit 30a0f7d
* Tue Feb 26 2019 oneukum@suse.com
- blacklist.conf: just a cleanup removing defines
- commit f9a324f
* Tue Feb 26 2019 ailiopoulos@suse.com
- iomap: fix integer truncation issues in the zeroing and dirtying
  helpers (bsc#1125947).
- commit 839e087
* Tue Feb 26 2019 mgorman@suse.de
- mmap: relax file size limit for regular files (git fixes
  (mm/mmap)).
- commit b834536
* Tue Feb 26 2019 ohering@suse.de
- blacklist.conf: hide e04e7a7bbd4b
  It claims to fix 8195b139 instead of 7bf7bb37
- commit e5cfb61
* Tue Feb 26 2019 jack@suse.cz
- blacklist.conf: Blacklist ad211f3e94b3
- commit 0ebbe38
* Tue Feb 26 2019 jroedel@suse.de
- x86/platform/UV: Use efi_runtime_lock to serialise BIOS calls (bsc#1125614).
- commit 4240ccc
* Tue Feb 26 2019 ohering@suse.de
- blacklist.conf: a2aeea1cc14f is a merge commit
  It should not have been reported in the first place.
- commit dfc4190
* Mon Feb 25 2019 tiwai@suse.de
- blacklist.conf: Add a cherry-picked i915 entry
- commit 739b97f
* Mon Feb 25 2019 lyan@suse.com
- arm/arm64: KVM: Rename function
  kvm_arch_dev_ioctl_check_extension() (bsc#1126393).
- arm64: fault: avoid send SIGBUS two times (bsc#1126393).
- commit 5a09ef2
* Mon Feb 25 2019 jthumshirn@suse.de
- blacklist.conf: Blacklist 5cbab6303b47 ("nvmet-rdma: fix null dereference
  under heavy load") it's not applicable to SLE15
- commit 9f6d20d
* Mon Feb 25 2019 jthumshirn@suse.de
- blacklist.conf: ad1f824948e4 ("nvmet-rdma: Add unlikely for response
  allocated check") this shouldn't be a stable patch.
- commit 17ea6e8
* Mon Feb 25 2019 jthumshirn@suse.de
- nvme-loop: fix kernel oops in case of unhandled command
  (bsc#1126807).
- Refresh
  patches.drivers/nvme-loop-add-support-for-multiple-ports.patch.
- commit 0b338a9
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: fix deadlock when allocating tree block during leaf/node
  split (bsc#1126806).
- commit 67cd18a
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: fix deadlock when using free space tree due to block
  group creation (bsc#1126804).
- commit 1a60bde
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: send, fix race with transaction commits that create
  snapshots (bsc#1126802).
- commit 46fbd46
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: remove unnecessary level check in balance_level
  (bsc#1126802).
- commit 0139cfb
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: do not unnecessarily pass write_lock_level when
  processing leaf (bsc#1126802).
- commit 9293032
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: remove unused check of skip_locking (bsc#1126802).
- commit cfe15be
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: remove always true check in unlock_up (bsc#1126802).
- commit 070f0a1
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: grab write lock directly if write_lock_level is the
  max level (bsc#1126802).
- commit 98586f6
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: move get root out of btrfs_search_slot to a helper
  (bsc#1126802).
- commit 50d98f2
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: use more straightforward extent_buffer_uptodate check
  (bsc#1126802).
- commit 0f77b1f
* Mon Feb 25 2019 fdmanana@suse.com
- Btrfs: remove superfluous free_extent_buffer in
  read_block_for_search (bsc#1126802).
- commit b119805
* Mon Feb 25 2019 fdmanana@suse.com
- btrfs: fix reading stale metadata blocks after degraded raid1
  mounts (bsc#1126803).
- commit 5f7150d
* Mon Feb 25 2019 fdmanana@suse.com
- btrfs: Improve btrfs_search_slot description (bsc#1126802).
- commit f94b397
* Mon Feb 25 2019 mbenes@suse.cz
- kallsyms: Handle too long symbols in kallsyms.c (bsc#1126805).
- commit 0b0d3a6
* Mon Feb 25 2019 lhenriques@suse.com
- ceph: avoid repeatedly adding inode to mdsc->snap_flush_list
  (bsc#1126790).
- libceph: handle an empty authorize reply (bsc#1126789).
- commit 0d8a28b
* Mon Feb 25 2019 ohering@suse.de
- Drivers: hv: vmbus: preserve hv_ringbuffer_get_debuginfo kABI
  (bsc#1126389, bsc#1126579).
- commit c8c3824
* Mon Feb 25 2019 ohering@suse.de
- Drivers: hv: vmbus: Check for ring when getting debug info
  (bsc#1126389, bsc#1126579).
- Drivers: hv: vmbus: Return -EINVAL for the sys files for
  unopened channels (bsc#1126389, bsc#1126579).
- commit 90d107d
* Mon Feb 25 2019 glin@suse.com
- bpf, lpm: fix lookup bug in map_delete_elem (bsc#1083647).
- commit 6349ff2
* Mon Feb 25 2019 tzimmermann@suse.de
- drm/i915/fbdev: Actually configure untiled displays (bsc#1113722)
- commit 54b783a
* Sun Feb 24 2019 rgoldwyn@suse.com
- exec: Fix mem leak in kernel_read_file (bsc#1126209,CVE-2019-8980).
- commit 10aa86a
* Sun Feb 24 2019 rgoldwyn@suse.com
- scripts/git_sort/git_sort.py: add vfs "fixes" branch
- commit de81e9c
* Fri Feb 22 2019 jdelvare@suse.de
- Revert "sd: disable logical block provisioning if 'lbpme' is not set"
  This reverts commit e365f138cb9c9c48b710864a9f37a91b4b93381d.
  Patch not accepted upstream.
- commit 99b4d65
* Fri Feb 22 2019 tiwai@suse.de
- Revert the previous merge of drm fixes
  The branch was merged mistakenly and breaks the build.  Revert it.
- commit d2630bf
* Fri Feb 22 2019 tiwai@suse.de
- drm/nouveau: Don't spew kernel WARNING for each timeout
  (bsc#1126480).
- commit ea9c0cd
* Fri Feb 22 2019 mbenes@suse.cz
- tracing/uprobes: Fix output for multiple string arguments
  (bsc#1126495).
- commit c0729fb
* Fri Feb 22 2019 mgorman@suse.de
- mm: use swp_offset as key in shmem_replace_page() (git fixes
  (mm/shmem)).
- commit 44fe062
* Fri Feb 22 2019 mgorman@suse.de
- mm: do not drop unused pages when userfaultd is running (git
  fixes (mm/userfaultfd)).
- commit d1c0def
* Fri Feb 22 2019 mgorman@suse.de
- mm/ksm.c: ignore STABLE_FLAG of rmap_item->address in
  rmap_walk_ksm() (git fixes (mm/ksm)).
- commit 7367793
* Fri Feb 22 2019 mgorman@suse.de
- mmap: introduce sane default mmap limits (git fixes (mm/mmap)).
- commit 229f07a
* Fri Feb 22 2019 mgorman@suse.de
- mm/hmm: hmm_pfns_bad() was accessing wrong struct (git fixes
  (mm/hmm)).
- commit 7993690
* Fri Feb 22 2019 mgorman@suse.de
- blacklist.conf: Underlying problem reverted in bnc#1107078
- commit 2a64250
* Fri Feb 22 2019 jslaby@suse.cz
- net: Fix usage of pskb_trim_rcsum (networking-stable-19_01_26).
- net: phy: mdio_bus: add missing device_del() in
  mdiobus_register() error handling (networking-stable-19_01_26).
- net: bridge: Fix ethernet header pointer before check skb
  forwardable (networking-stable-19_01_26).
- vhost: log dirty page correctly (networking-stable-19_01_26).
- net_sched: refetch skb protocol for each filter
  (networking-stable-19_01_26).
- net: phy: marvell: Errata for mv88e6390 internal PHYs
  (networking-stable-19_01_26).
- net/sched: act_tunnel_key: fix memory leak in case of action
  replace (networking-stable-19_01_26).
- net: ipv4: Fix memory leak in network namespace dismantle
  (networking-stable-19_01_26).
- commit 071e596
* Fri Feb 22 2019 mgorman@suse.de
- blacklist.conf: Alpha is not supported
- commit 62df577
* Fri Feb 22 2019 mgorman@suse.de
- blacklist.conf: Alternative SLE-specific fix merged due to KABI hazards
- commit e3c740e
* Fri Feb 22 2019 mgorman@suse.de
- blacklist.conf: z3fold does not have per-cpu buddies support backported
- commit 39b8b7b
* Fri Feb 22 2019 mgorman@suse.de
- blacklist.conf: z3fold does not have compaction support backported
- commit c8cb5a7
* Fri Feb 22 2019 tiwai@suse.de
- Refresh patches.kabi/hid-debug-kfifo-kabi-workaround.patch.
  We don't need to move the struct fields but only wrap the header includes
  for this kABI workaround.
- commit cf5c4fd
* Fri Feb 22 2019 tiwai@suse.de
- kABI workaround for hid_debug_list kfifo changes (CVE-2019-3819,
  bsc#1123161).
- commit 88e274d
* Fri Feb 22 2019 tiwai@suse.de
- HID: debug: fix the ring buffer implementation (CVE-2019-3819,
  bsc#1123161).
- commit eaf5ad5
* Fri Feb 22 2019 tiwai@suse.de
- zswap: re-check zswap_is_full() after do zswap_shrink()
  (bsc#1051510).
- commit 2bf887e
* Fri Feb 22 2019 tiwai@suse.de
- ixgbe: check return value of napi_complete_done() (bsc#1051510).
- commit ac9d827
* Fri Feb 22 2019 tiwai@suse.de
- ixgbe: recognize 1000BaseLX SFP modules as 1Gbps (bsc#1051510).
- commit 4e2f25f
* Fri Feb 22 2019 tiwai@suse.de
- ixgbe: Be more careful when modifying MAC filters (bsc#1051510).
- commit b3e308a
* Fri Feb 22 2019 tiwai@suse.de
- igb: Fix an issue that PME is not enabled during runtime suspend
  (bsc#1051510).
- commit 07fde74
* Fri Feb 22 2019 tiwai@suse.de
- blacklist.conf: Add entries for exec shebang fix that was reverted later
- commit 2fa3749
* Fri Feb 22 2019 tiwai@suse.de
- dlm: Don't swamp the CPU with callbacks queued during recovery
  (bsc#1051510).
- commit d9bdbb4
* Fri Feb 22 2019 tiwai@suse.de
- debugfs: fix debugfs_rename parameter checking (bsc#1051510).
- commit ed6ebcd
* Fri Feb 22 2019 tiwai@suse.de
- dccp: fool proof ccid_hc_[rt]x_parse_options() (bsc#1051510).
- commit 514a7da
* Fri Feb 22 2019 tiwai@suse.de
- cpuidle: big.LITTLE: fix refcount leak (bsc#1051510).
- commit 1230850
* Fri Feb 22 2019 tiwai@suse.de
- ASoC: atom: fix a missing check of snd_pcm_lib_malloc_pages
  (bsc#1051510).
- commit bff73e0
* Fri Feb 22 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Use the correct crtc when sanitizing plane mapping'
- commit 1c57643
* Fri Feb 22 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/vgem: Fix vgem_init to get drm device available.'
- commit 54b3fa7
* Fri Feb 22 2019 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm/exynos/decon5433: implement frame counter"'
- commit 35ad752
* Fri Feb 22 2019 mbenes@suse.cz
- blacklist.conf: ea6eb5e7d15e ("tracing: uprobes: Fix typo in pr_fmt string")
  Just a cosmetic fixup.
- commit cb0a95a
* Fri Feb 22 2019 mkubecek@suse.cz
- net: crypto set sk to NULL when af_alg_release (CVE-2019-8912
  bsc#1125907).
- commit 9863801
* Fri Feb 22 2019 jslaby@suse.cz
- net: dsa: mv88x6xxx: mv88e6390 errata
  (networking-stable-19_01_22).
- mlxsw: spectrum: Disable lag port TX before removing it
  (networking-stable-19_01_22).
- ipv6: Take rcu_read_lock in __inet6_bind for mapped addresses
  (networking-stable-19_01_22).
- ipv6: Consider sk_bound_dev_if when binding a socket to a v4
  mapped address (networking-stable-19_01_22).
- qmi_wwan: add MTU default to qmap network interface
  (networking-stable-19_01_22).
- r8169: Add support for new Realtek Ethernet
  (networking-stable-19_01_22).
- r8169: use PCI_VDEVICE macro (networking-stable-19_01_22).
- PCI: add USR vendor id and use it in r8169 and w6692 driver
  (networking-stable-19_01_22).
- commit 91b1483
* Fri Feb 22 2019 tzimmermann@suse.de
- drm/i915/gvt: free VFIO region space in vgpu detach (bsc#1113722)
- commit 432dc8e
* Fri Feb 22 2019 tzimmermann@suse.de
- drm/i915: Flush GPU relocs harder for gen3 (bsc#1113722)
- commit 3f0e87c
* Fri Feb 22 2019 tzimmermann@suse.de
- drm/i915: Use the correct crtc when sanitizing plane mapping (bsc#1113722)
- commit a3cb597
* Fri Feb 22 2019 jslaby@suse.cz
- tcp: change txhash on SYN-data timeout
  (networking-stable-19_01_20).
- ipv6: fix kernel-infoleak in ipv6_local_error()
  (networking-stable-19_01_20).
- net: bridge: fix a bug on using a neighbour cache entry without
  checking its state (networking-stable-19_01_20).
- commit 1347dc9
* Thu Feb 21 2019 tiwai@suse.de
- gdrom: fix a memory leak bug (bsc#1051510).
- commit 00f6c39
* Thu Feb 21 2019 tiwai@suse.de
- blacklist.conf: Add already cherry-picked entry
- commit bc63eef
* Thu Feb 21 2019 tiwai@suse.de
- niu: fix missing checks of niu_pci_eeprom_read (bsc#1051510).
- commit 541bae9
* Thu Feb 21 2019 tiwai@suse.de
- skge: potential memory corruption in skge_get_regs()
  (bsc#1051510).
- commit 342f29f
* Thu Feb 21 2019 tiwai@suse.de
- tty: serial: samsung: Properly set flags in autoCTS mode
  (bsc#1051510).
- ucma: fix a use-after-free in ucma_resolve_ip() (bsc#1051510).
- commit 546029c
* Thu Feb 21 2019 tiwai@suse.de
- net: bcmgenet: return correct value 'ret' from
  bcmgenet_power_down (bsc#1051510).
- net: bcmgenet: fix OF child-node lookup (bsc#1051510).
- commit 7f18e9c
* Thu Feb 21 2019 tiwai@suse.de
- ata: ahci: mvebu: remove stale comment (bsc#1051510).
- commit 81701e5
* Thu Feb 21 2019 tiwai@suse.de
- altera-stapl: check for a null key before strcasecmp'ing it
  (bsc#1051510).
- net: aquantia: driver should correctly declare vlan_features
  bits (bsc#1051510).
- net: aquantia: Fix hardware DMA stream overload on large MRRS
  (bsc#1051510).
- aquantia: Setup max_mtu in ndev to enable jumbo frames
  (bsc#1051510).
- commit 295fd9e
* Thu Feb 21 2019 tiwai@suse.de
- mtd: spi-nor: Fix Cadence QSPI page fault kernel panic
  (bsc#1051510).
- mtd: docg3: don't set conflicting BCH_CONST_PARAMS option
  (bsc#1051510).
- mtd: spi-nor: fsl-quadspi: fix read error for flash size larger
  than 16MB (bsc#1051510).
- mtd/maps: fix solutionengine.c printk format warnings
  (bsc#1051510).
- mtdchar: fix overflows in adjustment of `count` (bsc#1051510).
- mtd: cfi_cmdset_0002: Avoid walking all chips when unlocking
  (bsc#1051510).
- mtd: cfi_cmdset_0002: Fix unlocking requests crossing a chip
  boudary (bsc#1051510).
- mtd: cfi_cmdset_0002: fix SEGV unlocking multiple chips
  (bsc#1051510).
- mtd: cfi_cmdset_0002: Use right chip in do_ppb_xxlock()
  (bsc#1051510).
- commit 1a98f26
* Thu Feb 21 2019 tiwai@suse.de
- mtd: cfi_cmdset_0002: Change write buffer to check correct value
  (bsc#1051510).
- mtd: spi-nor: cadence-quadspi: Fix page fault kernel panic
  (bsc#1051510).
- mtd: nand: atmel: Fix get_sectorsize() function (bsc#1051510).
- mtd: nand: fsl_ifc: Fix nand waitfunc return value
  (bsc#1051510).
- mtdchar: fix usage of mtd_ooblayout_ecc() (bsc#1051510).
- mtd: nand: vf610: set correct ooblayout (bsc#1051510).
- mtd: nand: sunxi: Fix ECC strength choice (bsc#1051510).
- mtd: nand: Fix nand_do_read_oob() return value (bsc#1051510).
- commit 07f7d0f
* Thu Feb 21 2019 tiwai@suse.de
- mtd: mtd_oobtest: Handle bitflips during reads (bsc#1051510).
- mtd: nand: brcmnand: Disable prefetch by default (bsc#1051510).
- mtd: nand: qcom: Add a NULL check for devm_kasprintf()
  (bsc#1051510).
- mtd: nand: ifc: update bufnum mask for ver >= 2.0.0
  (bsc#1051510).
- mtd: nand: denali_pci: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bsc#1051510).
- mtd: nand: fix interpretation of NAND_CMD_NONE in
  nand_command[_lp]() (bsc#1051510).
- mtd: nand: pxa3xx: Fix READOOB implementation (bsc#1051510).
- mtd: nand: brcmnand: Zero bitflip is not an error (bsc#1051510).
- mtd: nand: gpmi: Fix failure when a erased page has a bitflip
  at BBM (bsc#1051510).
- mtd: nand: Fix writing mtdoops to nand flash (bsc#1051510).
- mtd: nand: mtk: fix infinite ECC decode IRQ issue (bsc#1051510).
- mtd: nand: omap2: Fix subpage write (bsc#1051510).
- commit 5bfd438
* Thu Feb 21 2019 tiwai@suse.de
- mtd: spi-nor: stm32-quadspi: Fix uninitialized error return code
  (bsc#1051510).
- mtd: nand: atmel: fix buffer overflow in atmel_pmecc_user
  (bsc#1051510).
- mtd: nand: atmel: fix of_irq_get() error check (bsc#1051510).
- mtd: nandsim: remove debugfs entries in error path
  (bsc#1051510).
- mtd: nand: sunxi: fix potential divide-by-zero error
  (bsc#1051510).
- commit b6ab04b
* Thu Feb 21 2019 tiwai@suse.de
- ARM: 8808/1: kexec:offline panic_smp_self_stop CPU
  (bsc#1051510).
- ARM: pxa: avoid section mismatch warning (bsc#1051510).
- ARM: OMAP2+: hwmod: Fix some section annotations (bsc#1051510).
- commit 40e113a
* Thu Feb 21 2019 tiwai@suse.de
- blacklist.conf: Add superfluous stable 4.14 entry for loop
- commit d72e848
* Thu Feb 21 2019 nsaenzjulienne@suse.de
- Revert "xhci: Reset Renesas uPD72020x USB controller for 32-bit DMA issue" (bsc#1120854).
- blacklist.conf: Remove patch as it turned out to be needed
- commit 139f00f
* Thu Feb 21 2019 tiwai@suse.de
- pinctrl: meson: meson8b: fix the sdxc_a data 1..3 pins
  (bsc#1051510).
- pinctrl: msm: fix gpio-hog related boot issues (bsc#1051510).
- commit b0097cc
* Thu Feb 21 2019 tiwai@suse.de
- keys: Timestamp new keys (bsc#1051510).
- KEYS: allow reaching the keys quotas exactly (bsc#1051510).
- commit b64eb75
* Thu Feb 21 2019 tiwai@suse.de
- Input: elan_i2c - add ACPI ID for touchpad in Lenovo V330-15ISK
  (bsc#1051510).
- Revert "Input: elan_i2c - add ACPI ID for touchpad in ASUS
  Aspire F5-573G" (bsc#1051510).
- Input: elantech - enable 3rd button support on Fujitsu CELSIUS
  H780 (bsc#1051510).
- Input: bma150 - register input device after setting private data
  (bsc#1051510).
- commit 7b85020
* Thu Feb 21 2019 tiwai@suse.de
- drm/nouveau/falcon: avoid touching registers if engine is off
  (bsc#1051510).
- drm/bridge: tc358767: fix output H/V syncs (bsc#1051510).
- drm/bridge: tc358767: reject modes which require too much BW
  (bsc#1051510).
- drm/bridge: tc358767: fix initial DP0/1_SRCCTRL value
  (bsc#1051510).
- drm/bridge: tc358767: fix single lane configuration
  (bsc#1051510).
- drm/bridge: tc358767: add defines for DP1_SRCCTRL & PHY_2LANE
  (bsc#1051510).
- commit 5e71d60
* Thu Feb 21 2019 tiwai@suse.de
- assoc_array: Fix shortcut creation (bsc#1051510).
- commit de84871
* Thu Feb 21 2019 tiwai@suse.de
- ALSA: hda/realtek: Disable PC beep in passthrough on alc285
  (bsc#1051510).
- ALSA: hda/realtek - Headset microphone and internal speaker
  support for System76 oryp5 (bsc#1051510).
- ALSA: hda/realtek - Headset microphone support for System76
  darp5 (bsc#1051510).
- commit b333acf
* Wed Feb 20 2019 tiwai@suse.de
- ALSA: hda/realtek - Reduce click noise on Dell Precision 5820
  headphone (bsc#1126131).
- commit 5cc7bcc
* Wed Feb 20 2019 tiwai@suse.de
- mv88e6060: disable hardware level MAC learning (bsc#1051510).
- commit cf30fae
* Wed Feb 20 2019 tiwai@suse.de
- netrom: switch to sock timer API (bsc#1051510).
- commit aadd38f
* Wed Feb 20 2019 tiwai@suse.de
- blacklist.conf: Add a duplicated commit for of unittest
- commit bd2d3e6
* Wed Feb 20 2019 tiwai@suse.de
- of, numa: Validate some distance map rules (bsc#1051510).
- of: unittest: Disable interrupt node tests for old world MAC
  systems (bsc#1051510).
- commit 3b4a4c9
* Wed Feb 20 2019 tiwai@suse.de
- openvswitch: Avoid OOB read when parsing flow nlattrs
  (bsc#1051510).
- Revert "openvswitch: Fix template leak in error
  cases." (bsc#1051510).
- openvswitch: Remove padding from packet before L3+ conntrack
  processing (bsc#1051510).
- openvswitch: fix the incorrect flow action alloc size
  (bsc#1051510).
- commit 8967b23
* Wed Feb 20 2019 tiwai@suse.de
- phy: sun4i-usb: add support for missing USB PHY index
  (bsc#1051510).
- phy: renesas: rcar-gen3-usb2: fix vbus_ctrl for role sysfs
  (bsc#1051510).
- phy: allwinner: sun4i-usb: poll vbus changes on A23/A33 when
  driving VBUS (bsc#1051510).
- phy: rockchip-emmc: retry calpad busy trimming (bsc#1051510).
- phy: qcom-qmp: Fix phy pipe clock gating (bsc#1051510).
- phy: work around 'phys' references to usb-nop-xceiv devices
  (bsc#1051510).
- phy: qcom-qmp: Fix failure path in phy_init functions
  (bsc#1051510).
- commit 81c9fa1
* Wed Feb 20 2019 tiwai@suse.de
- mac80211: Restore vif beacon interval if start ap fails
  (bsc#1051510).
- mac80211: ensure that mgmt tx skbs have tailroom for encryption
  (bsc#1051510).
- commit f2a7fe0
* Wed Feb 20 2019 glin@suse.com
- Update
  patches.fixes/bpf-fix-check_map_access-smin_value-test-when-pointe.patch
  (bsc#1068032 CVE-2017-5753 bsc#1124055 CVE-2019-7308).
- Update
  patches.fixes/bpf-move-prev_-insn_idx-into-verifier-env.patch
  (bsc#1068032 CVE-2017-5753 bsc#1124055 CVE-2019-7308).
- Update
  patches.fixes/bpf-prevent-out-of-bounds-speculation-on-pointer-ari.patch
  (bsc#1068032 CVE-2017-5753 bsc#1124055 CVE-2019-7308).
- Update
  patches.fixes/bpf-restrict-map-value-pointer-arithmetic-for-unpriv.patch
  (bsc#1068032 CVE-2017-5753 bsc#1124055 CVE-2019-7308).
- Update
  patches.fixes/bpf-restrict-stack-pointer-arithmetic-for-unprivileg.patch
  (bsc#1068032 CVE-2017-5753 bsc#1124055 CVE-2019-7308).
- Update
  patches.fixes/bpf-restrict-unknown-scalars-of-mixed-signed-bounds-.patch
  (bsc#1068032 CVE-2017-5753 bsc#1124055 CVE-2019-7308).
- commit e503a7e
* Wed Feb 20 2019 glin@suse.com
- bpf: enable access to ax register also from verifier rewrite
  (bsc#1124055 CVE-2019-7308).
- bpf: move tmp variable into ax register in interpreter
  (bsc#1124055 CVE-2019-7308).
- commit 489cb8c
* Tue Feb 19 2019 jthumshirn@suse.de
- Update patches.fixes/acpi-nfit-Block-function-zero-DSMs.patch
  (bsc#1051510, bsc#1121789).
- Update
  patches.fixes/acpi-nfit-Fix-command-supported-detection.patch
  (bsc#1051510, bsc#1121789).
  Add more detailed bugzilla reference.
- commit 880f651
* Tue Feb 19 2019 hare@suse.de
- nvme: kABI fix for scan_lock (bsc#1123882).
- nvme: lock NS list changes while handling command effects
  (bsc#1123882).
- commit f4e8b61
* Tue Feb 19 2019 mbenes@suse.cz
- rpm/klp-symbols: Remove the second column in Symbols.list
  Symbols.list file contains also a symbol type next to its name.
  klp-convert cannot handle it well and it is superfluous anyway.
- commit 6bfd2cc
* Mon Feb 18 2019 mwilck@suse.com
- scsi: core: reset host byte in DID_NEXUS_FAILURE case
  (bsc#1122764).
- commit d0b7126
* Mon Feb 18 2019 lhenriques@suse.com
- libceph: avoid KEEPALIVE_PENDING races in ceph_con_keepalive()
  (bsc#1125800).
- ceph: clear inode pointer when snap realm gets dropped by its
  inode (bsc#1125799).
- rbd: don't return 0 on unmap if RBD_DEV_FLAG_REMOVING is set
  (bsc#1125797).
- commit b76b5e2
* Mon Feb 18 2019 msuchanek@suse.de
- powerpc/pseries: Perform full re-add of CPU for topology update
  post-migration (bsc#1125728, FATE#325308).
- commit 62299b4
* Mon Feb 18 2019 msuchanek@suse.de
- Remove patches rejected upstream (FATE#325308).
- Delete patches.arch/hotplug-cpu-Add-operation-queuing-function.patch.
- Delete patches.arch/hotplug-cpu-Conditionally-acquire-release-DRC-index.patch.
- Delete patches.arch/hotplug-cpu-Provide-CPU-readd-operation.patch.
- Delete patches.arch/hotplug-pmt-Update-topology-after-PMT.patch.
- Delete patches.arch/mobility-numa-Ensure-numa-update-does-not-overlap.patch.
- commit 3516587
* Mon Feb 18 2019 jthumshirn@suse.de
- lightnvm: fail fast on passthrough commands (bsc#1125780).
- commit 8af708e
* Mon Feb 18 2019 jthumshirn@suse.de
- Refresh
  patches.drivers/nvme_fc-fix-ctrl-create-failures-racing-with-workq-i.patch.
  Fixup Git-commit field.
- commit f97fe78
* Mon Feb 18 2019 hare@suse.de
- scsi: lpfc: Update lpfc version to 12.0.0.10 (bsc#1121317).
- scsi: lpfc: Add log messages to aid in debugging fc4type
  discovery issues (bsc#1121317).
- scsi: lpfc: Fix discovery failure when PLOGI is defered
  (bsc#1121317).
- scsi: lpfc: update fault value on successful trunk events
  (bsc#1121317).
- scsi: lpfc: Correct MDS loopback diagnostics support
  (bsc#1121317).
- scsi: lpfc: Fix link state reporting for trunking when adapter
  is offline (bsc#1121317).
- scsi: lpfc: do not set queue->page_count to 0 if
  pc_sli4_params.wqpcnt is invalid (bsc#1121317).
- scsi: lpfc: remove an unnecessary NULL check (bsc#1121317).
- commit a159aec
* Mon Feb 18 2019 jgross@suse.com
- x86/xen: dont add memory above max allowed allocation
  (bsc#1117645).
- x86: respect memory size limiting via mem= parameter
  (bsc#1117645).
- commit 6a9d615
* Mon Feb 18 2019 mgorman@suse.de
- mm, oom: fix use-after-free in oom_kill_process (git fixes
  (mm/oom)).
- commit 352decd
* Mon Feb 18 2019 mgorman@suse.de
- rcu: Make need_resched() respond to urgent RCU-QS needs (git
  fixes (kernel/rcu)).
- commit 9f61d67
* Mon Feb 18 2019 tiwai@suse.de
- ARM: tango: Improve ARCH_MULTIPLATFORM compatibility
  (bsc#1051510).
- ARM: iop32x/n2100: fix PCI IRQ mapping (bsc#1051510).
- commit 1324ce6
* Mon Feb 18 2019 tiwai@suse.de
- team: avoid complex list operations in team_nl_cmd_options_set()
  (bsc#1051510).
- commit db17c10
* Mon Feb 18 2019 tiwai@suse.de
- floppy: check_events callback should not return a negative
  number (bsc#1051510).
- commit 08d5ae8
* Mon Feb 18 2019 tiwai@suse.de
- batman-adv: fix uninit-value in batadv_interface_tx()
  (bsc#1051510).
- commit 98f136b
* Mon Feb 18 2019 tiwai@suse.de
- i2c: bcm2835: Clear current buffer pointers and counts after
  a transfer (bsc#1051510).
- i2c: cadence: Fix the hold bit setting (bsc#1051510).
- commit a28b18c
* Mon Feb 18 2019 mgorman@suse.de
- blacklist.conf: Fixes build of a userspace test tool
- commit 4cf3fc4
* Mon Feb 18 2019 mgorman@suse.de
- blacklist.conf: Cosmetic fix only
- commit 7cbedec
* Mon Feb 18 2019 mgorman@suse.de
- blacklist.conf: Fixes comments only
- commit 687339e
* Mon Feb 18 2019 mgorman@suse.de
- rcu: Fix up pending cbs check in rcu_prepare_for_idle (git fixes
  (kernel/rcu)).
- commit c71433c
* Mon Feb 18 2019 mgorman@suse.de
- blacklist.conf: Fixes an unused debugging option
- commit 6fe9af6
* Mon Feb 18 2019 mgorman@suse.de
- blacklist.conf: Fixes an unused debugging option
- commit 0a05a83
* Mon Feb 18 2019 tzimmermann@suse.de
- drm/i915/opregion: rvda is relative from opregion base in opregion (bsc#1113722)
- commit 6326f1f
* Mon Feb 18 2019 tzimmermann@suse.de
- drm/i915/opregion: fix version check (bsc#1113722)
- commit 948a27b
* Mon Feb 18 2019 tzimmermann@suse.de
- drm/i915: Prevent a race during I915_GEM_MMAP ioctl with WC set (bsc#1113722)
- commit d9414a1
* Mon Feb 18 2019 tzimmermann@suse.de
- drm/i915: Block fbdev HPD processing during suspend (bsc#1113722)
- commit 9bc1950
* Mon Feb 18 2019 tzimmermann@suse.de
- gpu: ipu-v3: Fix CSI offsets for imx53 (bsc#1113722)
- commit 700eb34
* Mon Feb 18 2019 tzimmermann@suse.de
- gpu: ipu-v3: Fix i.MX51 CSI control registers offset (bsc#1113722)
- commit aa477ef
* Mon Feb 18 2019 hare@suse.de
- blk-mq: fix a hung issue when fsync (bsc#1125252).
- commit 2d80d27
* Fri Feb 15 2019 glin@suse.com
- bpf: Fix syscall's stackmap lookup potential deadlock
  (bsc#1083647).
- bpf: fix lockdep false positive in percpu_freelist
  (bsc#1083647).
- commit d98e12d
* Fri Feb 15 2019 tiwai@suse.de
- drm/modes: Prevent division by zero htotal (bsc#1051510).
- commit 8a07ee2
* Thu Feb 14 2019 jdelvare@suse.de
- sd: disable logical block provisioning if 'lbpme' is not set
  (bsc#1086095 bsc#1078355).
- commit e365f13
* Thu Feb 14 2019 mkubecek@suse.cz
- blacklist.conf: add 9b3fa47d4a76
  Commit 9b3fa47d4a76 ("kobject: fix suppressing modalias in uevents
  delivered over netlink") is marked as fix for commit 4a336a23d619
  ("kobject: copy env blob in one go") but it fixes code added by commit
  6878e7de6af7 ("driver core: suppress sending MODALIAS in UNBIND uevents")
  which wasn't backported to SLE15.
- commit 226cfdd
* Thu Feb 14 2019 mkubecek@suse.cz
- netns: restrict uevents (bsc#1122982).
- commit 93bf53c
* Thu Feb 14 2019 mkubecek@suse.cz
- uevent: add alloc_uevent_skb() helper (bsc#1122982).
- commit d7be40a
* Thu Feb 14 2019 mkubecek@suse.cz
- kabi: handle addition of uevent_sock into struct net
  (bsc#1122982).
- commit fba27e2
* Thu Feb 14 2019 mkubecek@suse.cz
- net: add uevent socket member (bsc#1122982).
- commit 0d1872e
* Thu Feb 14 2019 mkubecek@suse.cz
- kabi: restore ip_tunnel_delete_net() (bsc#1122982).
- commit 3f50317
* Thu Feb 14 2019 mkubecek@suse.cz
- ipv4: speedup ipv6 tunnels dismantle (bsc#1122982).
- commit 37e2cde
* Thu Feb 14 2019 mkubecek@suse.cz
- ipv6: speedup ipv6 tunnels dismantle (bsc#1122982).
  Refresh patches.suse/ip6_vti-fix-a-null-pointer-deference-when-destroy-vt.patch
- commit e5f835f
* Thu Feb 14 2019 mkubecek@suse.cz
- tcp: batch tcp_net_metrics_exit (bsc#1122982).
- commit 07f6645
* Thu Feb 14 2019 mkubecek@suse.cz
- kabi: handle addition of ip6addrlbl_table into struct netns_ipv6
  (bsc#1122982).
- commit 7e7aa51
* Thu Feb 14 2019 mkubecek@suse.cz
- ipv6: addrlabel: per netns list (bsc#1122982).
- commit a20a6ca
* Thu Feb 14 2019 mkubecek@suse.cz
- kobject: factorize skb setup in kobject_uevent_net_broadcast()
  (bsc#1122982).
- commit 981380d
* Thu Feb 14 2019 mkubecek@suse.cz
- kobject: copy env blob in one go (bsc#1122982).
- commit 4131d33
* Thu Feb 14 2019 mkubecek@suse.cz
- kobject: add kobject_uevent_net_broadcast() (bsc#1122982).
- commit 79f04e3
* Thu Feb 14 2019 tiwai@suse.de
- ptp: Fix pass zero to ERR_PTR() in ptp_clock_register
  (bsc#1051510).
- ptp: check gettime64 return code in PTP_SYS_OFFSET ioctl
  (bsc#1051510).
- commit da8955a
* Thu Feb 14 2019 tiwai@suse.de
- pinctrl: meson: meson8b: fix the GPIO function for the GPIOAO
  pins (bsc#1051510).
- pinctrl: meson: meson8: fix the GPIO function for the GPIOAO
  pins (bsc#1051510).
- pinctrl: sunxi: a64: Rename function ts0 to ts (bsc#1051510).
- pinctrl: sunxi: a64: Rename function csi0 to csi (bsc#1051510).
- pinctrl: sx150x: handle failure case of devm_kstrdup
  (bsc#1051510).
- pinctrl: sunxi: a83t: Fix IRQ offset typo for PH11
  (bsc#1051510).
- pinctrl: meson: fix pull enable register calculation
  (bsc#1051510).
- commit 425b535
* Thu Feb 14 2019 tiwai@suse.de
- hwmon: (lm80) Fix missing unlock on error in set_fan_div()
  (bsc#1051510).
- kgdboc: Fix warning with module build (bsc#1051510).
- commit 9dd5b77
* Thu Feb 14 2019 tiwai@suse.de
- kprobes: Return error if we fail to reuse kprobe instead of
  BUG_ON() (bsc#1051510).
- commit a34e8dd
* Thu Feb 14 2019 tiwai@suse.de
- kgdboc: fix KASAN global-out-of-bounds bug in
  param_set_kgdboc_var() (bsc#1051510).
- kgdboc: Fix restrict error (bsc#1051510).
- commit 81f4204
* Thu Feb 14 2019 tiwai@suse.de
- kconfig: fix memory leak when EOF is encountered in quotation
  (bsc#1051510).
- kconfig: fix file name and line number of
  warn_ignored_character() (bsc#1051510).
- kconfig: fix the rule of mainmenu_stmt symbol (bsc#1051510).
- kconfig: fix line numbers for if-entries in menu tree
  (bsc#1051510).
- commit 48b9214
* Thu Feb 14 2019 tiwai@suse.de
- hwmon: (lm80) fix a missing check of bus read in lm80 probe
  (bsc#1051510).
- hwmon: (lm80) fix a missing check of the status of SMBus read
  (bsc#1051510).
- commit 673c6f7
* Thu Feb 14 2019 tiwai@suse.de
- hvc_opal: don't set tb_ticks_per_usec in udbg_init_opal_common()
  (bsc#1051510).
- commit 692e504
* Thu Feb 14 2019 tiwai@suse.de
- gianfar: Fix Rx byte accounting for ndev stats (bsc#1051510).
- gianfar: prevent integer wrapping in the rx handler
  (bsc#1051510).
- gianfar: fix a flooded alignment reports because of padding
  issue (bsc#1051510).
- commit 8dceab1
* Thu Feb 14 2019 tiwai@suse.de
- genwqe: Fix size check (bsc#1051510).
- commit 1222038
* Thu Feb 14 2019 tiwai@suse.de
- esp6: fix memleak on error path in esp6_input (bsc#1051510).
- esp: Fix skb tailroom calculation (bsc#1051510).
- esp: Fix locking on page fragment allocation (bsc#1051510).
- esp: Fix memleaks on error paths (bsc#1051510).
- ipsec: check return value of skb_to_sgvec always (bsc#1051510).
- commit 5e4fe86
* Thu Feb 14 2019 tiwai@suse.de
- earlycon: Remove hardcoded port->uartclk initialization in
  of_setup_earlycon (bsc#1051510).
- earlycon: Initialize port->uartclk based on clock-frequency
  property (bsc#1051510).
- commit 3501ab2
* Thu Feb 14 2019 tiwai@suse.de
- dmaengine: stm32-dma: fix incomplete configuration in cyclic
  mode (bsc#1051510).
- commit 320fcc4
* Thu Feb 14 2019 tiwai@suse.de
- cw1200: Fix concurrency use-after-free bugs in cw1200_hw_scan()
  (bsc#1051510).
- commit c2f6cd4
* Thu Feb 14 2019 wqu@suse.com
- btrfs: qgroup: Make qgroup async transaction commit more
  aggressive (bsc#1113042).
- commit 6571468
* Wed Feb 13 2019 tiwai@suse.de
- ALSA: hda - Add quirk for HP EliteBook 840 G5 (bsc#1051510).
- commit 02839ac
* Wed Feb 13 2019 ailiopoulos@suse.com
- xfs: add option to mount with barrier=0 or barrier=1
  (bsc#1088133).
- commit 041eec2
* Wed Feb 13 2019 tiwai@suse.de
- sata_rcar: fix deferred probing (bsc#1051510).
- sc16is7xx: Fix for multi-channel stall (bsc#1051510).
- commit 8335cf8
* Wed Feb 13 2019 tiwai@suse.de
- selinux: always allow mounting submounts (bsc#1051510).
- commit 2719b51
* Wed Feb 13 2019 tiwai@suse.de
- switchtec: Fix SWITCHTEC_IOCTL_EVENT_IDX_ALL flags overwrite
  (bsc#1051510).
- switchtec: Remove immediate status check after submitting MRPC
  command (bsc#1051510).
- commit bf525d0
* Wed Feb 13 2019 tiwai@suse.de
- timekeeping: Use proper seqcount initializer (bsc#1051510).
- commit f7ac05e
* Wed Feb 13 2019 tiwai@suse.de
- tpm: fix kdoc for tpm2_flush_context_cmd() (bsc#1051510).
- commit cc49795
* Wed Feb 13 2019 tiwai@suse.de
- tpm: tpm_try_transmit() refactor error flow (bsc#1051510).
- commit cd1784e
* Wed Feb 13 2019 tiwai@suse.de
- tpm: tpm_i2c_nuvoton: use correct command duration for TPM 2.x
  (bsc#1051510).
- commit cdee356
* Wed Feb 13 2019 tiwai@suse.de
- tpm: suppress transmit cmd error logs when TPM 1.2 is
  disabled/deactivated (bsc#1051510).
- Refresh patches.suse/tpm-Downgrade-error-level.
- commit 8e7a0f3
* Wed Feb 13 2019 tiwai@suse.de
- tpm/tpm_i2c_infineon: switch to i2c_lock_bus(...,
  I2C_LOCK_SEGMENT) (bsc#1051510).
- tpm: Return the actual size when receiving an unsupported
  command (bsc#1051510).
- commit dbd494e
* Wed Feb 13 2019 tiwai@suse.de
- tpm: return a TPM_RC_COMMAND_CODE response if command is not
  implemented (bsc#1051510).
- Refresh patches.drivers/tpm-add-retry-logic.patch.
- Refresh
  patches.drivers/tpm-cmd_ready-command-can-be-issued-only-after-grant.patch.
- Refresh
  patches.drivers/tpm-fix-intermittent-failure-with-self-tests.patch.
- Refresh
  patches.drivers/tpm-separate-cmd_ready-go_idle-from-runtime_pm.patch.
- commit 60c8417
* Wed Feb 13 2019 tiwai@suse.de
- usb: phy: am335x: fix race condition in _probe (bsc#1051510).
- usb: gadget: udc: net2272: Fix bitwise and boolean operations
  (bsc#1051510).
- usb: dwc3: gadget: Handle 0 xfer length for OUT EP
  (bsc#1051510).
- usb: gadget: musb: fix short isoc packets with inventra dma
  (bsc#1051510).
- USB: serial: pl2303: add new PID to support PL2303TB
  (bsc#1051510).
- USB: serial: simple: add Motorola Tetra TPG2200 device id
  (bsc#1051510).
- usb: musb: dsps: fix otg state machine (bsc#1051510).
- usb: dwc3: gadget: Disable CSP for stream OUT ep (bsc#1051510).
- usb: mtu3: fix the issue about SetFeature(U1/U2_Enable)
  (bsc#1051510).
- usb: dwc3: Correct the logic for checking TRB full in
  __dwc3_prepare_one_trb() (bsc#1051510).
- usb: hub: delay hub autosuspend if USB3 port is still link
  training (bsc#1051510).
- commit fc7d38b
* Wed Feb 13 2019 tiwai@suse.de
- usbnet: smsc95xx: fix rx packet alignment (bsc#1051510).
- commit c9b4f88
* Wed Feb 13 2019 tiwai@suse.de
- vxge: ensure data0 is initialized in when fetching firmware
  version information (bsc#1051510).
- commit 693db95
* Wed Feb 13 2019 tiwai@suse.de
- w90p910_ether: remove incorrect __init annotation (bsc#1051510).
- commit 709dd80
* Wed Feb 13 2019 tiwai@suse.de
- watchdog: docs: kernel-api: don't reference removed functions
  (bsc#1051510).
- commit 02aef73
* Wed Feb 13 2019 tiwai@suse.de
- Yama: Check for pid death before checking ancestry
  (bsc#1051510).
- yam: fix a missing-check bug (bsc#1051510).
- commit 8358606
* Wed Feb 13 2019 palcantara@suse.de
- SMB3: Fix 3.11 encryption to Windows and handle encrypted smb3
  tcon (bsc#1051510).
- Refresh patches.fixes/0001-CIFS-make-IPC-a-regular-tcon.patch.
- commit 3928810
* Wed Feb 13 2019 tiwai@suse.de
- blacklist.conf: Remove duplicated and already applied entries
- commit 9717602
* Wed Feb 13 2019 palcantara@suse.de
- SMB3: Enable encryption for SMB3.1.1 (bsc#1051510).
- commit adc9cc4
* Wed Feb 13 2019 jack@suse.cz
- loop: Reintroduce lo_ctl_mutex removed by commit 310ca162d
  (bsc#1124974).
- commit c020130
* Wed Feb 13 2019 tiwai@suse.de
- dmaengine: imx-dma: fix wrong callback invoke (bsc#1051510).
- serial: fix race between flush_to_ldisc and tty_open
  (bsc#1051510).
- drm/i915/gvt: release shadow batch buffer and wa_ctx before
  destroy one workload (bsc#1051510).
- video: clps711x-fb: release disp device node in probe()
  (bsc#1051510).
- i2c-axxia: check for error conditions first (bsc#1051510).
- i2c: sh_mobile: add support for r8a77990 (R-Car E3)
  (bsc#1051510).
- HID: lenovo: Add checks to fix of_led_classdev_register
  (bsc#1051510).
- Thermal: do not clear passive state during system sleep
  (bsc#1051510).
- thermal: generic-adc: Fix adc to temp interpolation
  (bsc#1051510).
- thermal: hwmon: inline helpers when CONFIG_THERMAL_HWMON is
  not set (bsc#1051510).
- isdn: hisax: hfc_pci: Fix a possible concurrency use-after-free
  bug in HFCPCI_l1hw() (bsc#1051510).
- pinctrl: sh-pfc: sh7734: Fix shifted values in IPSR10
  (bsc#1051510).
- pinctrl: sh-pfc: sh7734: Remove bogus IPSR10 value
  (bsc#1051510).
- pinctrl: sh-pfc: sh7269: Add missing PCIOR0 field (bsc#1051510).
- pinctrl: sh-pfc: sh7264: Fix PFCR3 and PFCR0 register
  configuration (bsc#1051510).
- pinctrl: sh-pfc: sh7734: Add missing IPSR11 field (bsc#1051510).
- pinctrl: sh-pfc: r8a7794: Remove bogus IPSR9 field
  (bsc#1051510).
- pinctrl: sh-pfc: sh73a0: Add missing TO pin to tpu4_to3 group
  (bsc#1051510).
- pinctrl: sh-pfc: r8a7791: Remove bogus marks from vin1_b_data18
  group (bsc#1051510).
- pinctrl: sh-pfc: r8a7791: Remove bogus ctrl marks from
  qspi_data4_b group (bsc#1051510).
- pinctrl: sh-pfc: r8a7740: Add missing LCD0 marks to
  lcd0_data24_1 group (bsc#1051510).
- pinctrl: sh-pfc: r8a7740: Add missing REF125CK pin to
  gether_gmii group (bsc#1051510).
- soc/tegra: Don't leak device tree node reference (bsc#1051510).
- soc: bcm: brcmstb: Don't leak device tree node reference
  (bsc#1051510).
- seq_buf: Make seq_buf_puts() null-terminate the buffer
  (bsc#1051510).
- iio: accel: kxcjk1013: Add KIOX010A ACPI Hardware-ID
  (bsc#1051510).
- staging: iio: ad7780: update voltage on read (bsc#1051510).
- staging:iio:ad2s90: Make probe handle spi_setup failure
  (bsc#1051510).
- staging: iio: adc: ad7280a: handle error from __ad7280_read32()
  (bsc#1051510).
- serial: fsl_lpuart: clear parity enable bit when disable parity
  (bsc#1051510).
- mmc: sdhci-xenon: Fix timeout checks (bsc#1051510).
- mmc: sdhci-of-esdhc: Fix timeout checks (bsc#1051510).
- memstick: Prevent memstick host from getting runtime suspended
  during card detection (bsc#1051510).
- mmc: bcm2835: Recover from MMC_SEND_EXT_CSD (bsc#1051510).
- crypto: ux500 - Use proper enum in hash_set_dma_transfer
  (bsc#1051510).
- crypto: ux500 - Use proper enum in cryp_set_dma_transfer
  (bsc#1051510).
- pcrypt: use format specifier in kobject_add (bsc#1051510).
- crypto: aes_ti - disable interrupts while accessing S-box
  (bsc#1051510).
- mac80211: fix radiotap vendor presence bitmap handling
  (bsc#1051510).
- firmware/efi: Add NULL pointer checks in efivars API functions
  (bsc#1051510).
- media: DaVinci-VPBE: fix error handling in vpbe_initialize()
  (bsc#1051510).
- media: adv*/tc358743/ths8200: fill in min
  width/height/pixelclock (bsc#1051510).
- media: mtk-vcodec: Release device nodes in
  mtk_vcodec_init_enc_pm() (bsc#1051510).
- drm: Clear state->acquire_ctx before leaving
  drm_atomic_helper_commit_duplicated_state() (bsc#1051510).
- gpu: ipu-v3: image-convert: Prevent race between run and
  unprepare (bsc#1051510).
- drm/rockchip: fix for mailbox read size (bsc#1051510).
- drm/bufs: Fix Spectre v1 vulnerability (bsc#1051510).
- staging: speakup: Replace strncpy with memcpy (bsc#1051510).
- pktcdvd: Fix possible Spectre-v1 for pkt_devs (bsc#1051510).
- thermal/drivers/hisi: Fix configuration register setting
  (bsc#1051510).
- thermal/drivers/hisi: Encapsulate register writes into helpers
  (bsc#1051510).
- mmc: Kconfig: Enable CONFIG_MMC_SDHCI_IO_ACCESSORS
  (bsc#1051510).
- commit 1c7e39d
* Wed Feb 13 2019 tiwai@suse.de
- kABI workaroudn for ath9k ath_node.ackto type change
  (bsc#1051510).
- commit d8369e0
* Wed Feb 13 2019 tiwai@suse.de
- ASoC: rsnd: fixup rsnd_ssi_master_clk_start() user count check
  (bsc#1051510).
- ALSA: usb-audio: Fix implicit fb endpoint setup by quirk
  (bsc#1051510).
- Bluetooth: Fix unnecessary error message for HCI request
  completion (bsc#1051510).
- ath9k: dynack: make ewma estimation faster (bsc#1051510).
- ath9k: dynack: check da->enabled first in sampling routines
  (bsc#1051510).
- ath9k: dynack: use authentication messages for 'late' ack
  (bsc#1051510).
- clk: imx6sl: ensure MMDC CH0 handshake is bypassed
  (bsc#1051510).
- clk: sunxi-ng: a33: Set CLK_SET_RATE_PARENT for all audio
  module clocks (bsc#1051510).
- ACPI/APEI: Clear GHES block_status before panic() (bsc#1051510).
- ASoC: fsl: Fix SND_SOC_EUKREA_TLV320 build error on i.MX8M
  (bsc#1051510).
- commit 068148f
* Wed Feb 13 2019 hare@suse.de
- Revert "scsi: qla2xxx: Fix NVMe Target discovery" (bsc#1125252).
- Delete
  patches.fixes/qla2xxx-Fixup-dual-protocol-FCP-connections.patch.
- commit d4e105c
* Wed Feb 13 2019 hare@suse.de
- blacklist.conf: add two patches which are fixed with SLE-specific patches
- commit 5a1d4e0
* Wed Feb 13 2019 hare@suse.de
- SCSI: fix queue cleanup race before queue initialization is done
  (bsc#1125252).
- scsi: lpfc: fix remoteport access (bsc#1125252).
- block: don't warn when doing fsync on read-only devices
  (bsc#1125252).
- s390/mm: fix addressing exception after suspend/resume
  (bsc#1125252).
- commit b2f7320
* Wed Feb 13 2019 hare@suse.de
- Partially revert "block: fail op_is_write() requests to
  (bsc#1125252).
- Refresh
  patches.fixes/block-don-t-warn-for-flush-on-read-only-device.patch.
- commit 2be11de
* Tue Feb 12 2019 palcantara@suse.de
- Refresh
  patches.fixes/SMB3-Add-support-for-multidialect-negotiate-SMB2.1-a.patch.
- commit 00c54bd
* Tue Feb 12 2019 palcantara@suse.de
- Tree connect for SMB3.1.1 must be signed for non-encrypted
  shares (bsc#1051510).
- commit 646759f
* Tue Feb 12 2019 palcantara@suse.de
- SMB311: Improve checking of negotiate security contexts
  (bsc#1051510).
- Refresh
  patches.fixes/smb3-simplify-code-by-removing-CONFIG_CIFS_SMB311.patch.
- commit 88a899d
* Tue Feb 12 2019 tiwai@suse.de
- Refresh series.conf for upstreamed patches
- commit 7080712
* Tue Feb 12 2019 palcantara@suse.de
- cifs: invalidate cache when we truncate a file (bsc#1051510).
- commit ac6d95b
* Tue Feb 12 2019 palcantara@suse.de
- cifs: connect to servername instead of IP for IPC$ share
  (bsc#1051510).
- commit 9ef1878
* Tue Feb 12 2019 palcantara@suse.de
- cifs: OFD locks do not conflict with eachothers (bsc#1051510).
- commit 60dc3ca
* Tue Feb 12 2019 ptesarik@suse.cz
- s390/smp: Fix calling smp_call_ipl_cpu() from ipl CPU
  (git-fixes).
- commit c4aa3bc
* Tue Feb 12 2019 ptesarik@suse.cz
- s390/smp: fix CPU hotplug deadlock with CPU rescan (git-fixes).
- commit 676a5c7
* Tue Feb 12 2019 ptesarik@suse.cz
- s390/mm: always force a load of the primary ASCE on context
  switch (git-fixes).
- commit 7dd5b69
* Tue Feb 12 2019 tiwai@suse.de
- sysfs: Disable lockdep for driver bind/unbind files
  (bsc#1051510).
- commit e3d560e
* Tue Feb 12 2019 tiwai@suse.de
- uprobes: Fix handle_swbp() vs. unregister() + register()
  race once more (bsc#1051510).
- commit e646146
* Tue Feb 12 2019 tiwai@suse.de
- irqchip/gic-v3-its: Fix ITT_entry_size accessor (bsc#1051510).
- commit 9762d21
* Tue Feb 12 2019 tiwai@suse.de
- irqchip/gic-v3-its: Align PCI Multi-MSI allocation on their size
  (bsc#1051510).
- irqchip/gic-v3-its: Don't bind LPI to unavailable NUMA node
  (bsc#1051510).
- commit aee5454
* Tue Feb 12 2019 tiwai@suse.de
- iio: chemical: atlas-ph-sensor: correct IIO_TEMP values to
  millicelsius (bsc#1051510).
- commit d30d8e7
* Tue Feb 12 2019 tiwai@suse.de
- ieee802154: ca8210: fix possible u8 overflow in ca8210_rx_done
  (bsc#1051510).
- commit d0cf762
* Tue Feb 12 2019 ptesarik@suse.cz
- s390/early: improve machine detection (git-fixes).
- commit a88d3d3
* Tue Feb 12 2019 tiwai@suse.de
- drm/atomic-helper: Complete fake_commit->flip_done potentially
  earlier (bsc#1051510).
- drm/i915: Redefine some Whiskey Lake SKUs (bsc#1051510).
- Revert "drm/rockchip: Allow driver to be shutdown on
  reboot/kexec" (bsc#1051510).
- drm/ast: Fix connector leak during driver unload (bsc#1051510).
- drm/msm: Fix error return checking (bsc#1051510).
- drm/msm: Grab a vblank reference when waiting for commit_done
  (bsc#1051510).
- drm/amdgpu: Add delay after enable RLC ucode (bsc#1051510).
- drm/ast: fixed reading monitor EDID not stable issue
  (bsc#1051510).
- commit e8eb419
* Tue Feb 12 2019 ptesarik@suse.cz
- virtio/s390: fix race in ccw_io_helper() (git-fixes).
- commit e56a72c
* Tue Feb 12 2019 ptesarik@suse.cz
- virtio/s390: avoid race on vcdev->config (git-fixes).
- commit 8787487
* Tue Feb 12 2019 tiwai@suse.de
- dmaengine: dmatest: Abort test in case of mapping error
  (bsc#1051510).
- dmaengine: bcm2835: Fix abort of transactions (bsc#1051510).
- dmaengine: bcm2835: Fix interrupt race on RT (bsc#1051510).
- dmaengine: at_xdmac: Fix wrongfull report of a channel as in
  use (bsc#1051510).
- batman-adv: Force mac header to start of data on xmit
  (bsc#1051510).
- batman-adv: Avoid WARN on net_device without parent in netns
  (bsc#1051510).
- commit 21abf3f
* Tue Feb 12 2019 ptesarik@suse.cz
- s390/cpum_cf: Reject request for sampling in event
  initialization (git-fixes).
- commit 43dc798
* Tue Feb 12 2019 ptesarik@suse.cz
- s390/qeth: invoke softirqs after napi_schedule() (git-fixes).
- s390/sthyi: Fix machine name validity indication (git-fixes).
- commit a8250d7
* Tue Feb 12 2019 ptesarik@suse.cz
- s390/cio: Fix how vfio-ccw checks pinned pages (git-fixes).
- commit 020f0c8
* Tue Feb 12 2019 ptesarik@suse.cz
- vfio: ccw: fix cleanup if cp_prefetch fails (git-fixes).
- commit f3cd170
* Tue Feb 12 2019 ptesarik@suse.cz
- vfio: ccw: process ssch with interrupts disabled (git-fixes).
- commit 504edfe
* Tue Feb 12 2019 ptesarik@suse.cz
- Update
  patches.arch/s390-sles15-zcrypt-fix-specification-exception.patch
  (LTC#174936, bsc#1123060, bsc#1123061).
- commit 1a2036b
* Tue Feb 12 2019 jthumshirn@suse.de
- blacklist.conf: blacklist 2623c7a5f27995
- commit f805abd
* Tue Feb 12 2019 jthumshirn@suse.de
- Delete
  patches.fixes/libata-ensure-host-is-free-d-on-error-exit-paths.patch.
  Not needed anymore as
  'patches.fixes/libata-add-refcounting-to-ata_host.patch' is gone (bsc#1125109).
- commit a0cb8f9
* Tue Feb 12 2019 jthumshirn@suse.de
- Refresh
  patches.fixes/libata-ensure-host-is-free-d-on-error-exit-paths.patch.
- Delete patches.fixes/libata-add-refcounting-to-ata_host.patch.
- Delete patches.kabi/kabi-protect-struct-ata_host.patch.
  The fix in 'patches.fixes/libata-add-refcounting-to-ata_host.patch.'
  introduced a kref in the middle of 'struct ata_host' which the KABI patch
  'patches.kabi/kabi-protect-struct-ata_host.patch' then moved to the end of
  the structure in order to preserve the KABI for out of tree modules. But
  this move to the end of the structure shadowed the dynamically allocated
  'ports' array at the end of 'struct ata_host' and lead to kernel crashes
  (bsc#1125109).
- commit 2d3b23e
* Tue Feb 12 2019 jack@suse.cz
- ext4: force inode writes when nfsd calls commit_metadata()
  (bsc#1125125).
- commit 31a2a0d
* Tue Feb 12 2019 mgorman@suse.de
- mm,vmscan: Make unregister_shrinker() no-op if
  register_shrinker() failed (git fixes (mm/vmscan)).
- commit 811e3e5
* Tue Feb 12 2019 mgorman@suse.de
- blacklist.conf: Microblaze not supported
- commit 4927691
* Tue Feb 12 2019 mgorman@suse.de
- blacklist.conf: KASAN not supported
- commit 2dc5c41
* Tue Feb 12 2019 mgorman@suse.de
- blacklist.conf: KASAN not supported
- commit b14c3e4
* Tue Feb 12 2019 mgorman@suse.de
- blacklist.conf: Preparation patch for other fixes
- commit ad1598c
* Tue Feb 12 2019 mgorman@suse.de
- mm: madvise(MADV_DODUMP): allow hugetlbfs pages (git fixes
  (mm/madvise)).
- commit ced6763
* Tue Feb 12 2019 mgorman@suse.de
- mm: hwpoison: use do_send_sig_info() instead of force_sig()
  (git fixes (mm/hwpoison)).
- commit df0f1cd
* Tue Feb 12 2019 mgorman@suse.de
- mm: migrate: don't rely on __PageMovable() of newpage after
  unlocking it (git fixes (mm/migrate)).
- commit c2ba9d9
* Tue Feb 12 2019 neilb@suse.com
- blacklist.conf: add commit with too many dependencies
- commit 228c48e
* Mon Feb 11 2019 lduncan@suse.com
- scsi: qedi: Add ep_state for login completion on un-reachable
  targets (bsc#1113712).
- commit 4d4bb59
* Mon Feb 11 2019 bp@suse.de
- x86/bugs: Add AMD's variant of SSB_NO (bsc#1114279).
- x86/bugs: Update when to check for the LS_CFG SSBD mitigation
  (bsc#1114279).
- x86/MCE: Initialize mce.bank in the case of a fatal error in
  mce_no_way_out() (bsc#1114279).
- x86/microcode/amd: Don't falsely trick the late loading
  mechanism (bsc#1114279).
- x86/speculation: Remove redundant arch_smt_update() invocation
  (bsc#1114279).
- Refresh
  patches.arch/x86-bugs-add-amd-s-spec_ctrl-msr-usage.patch.
- commit eff8f26
* Mon Feb 11 2019 jack@suse.cz
- blacklist.conf: Blacklist 4ea899ead278
- commit 6976585
* Mon Feb 11 2019 jthumshirn@suse.de
- acpi/nfit: Fix user-initiated ARS to be "ARS-long" rather than
  "ARS-short" (bsc#1124969).
- commit 3578008
* Mon Feb 11 2019 jthumshirn@suse.de
- scsi: qla2xxx: Timeouts occur on surprise removal of QLogic
  adapter (bsc#1124985).
- commit bb23d9d
* Mon Feb 11 2019 jack@suse.cz
- gfs2: Revert "Fix loop in gfs2_rbm_find" (bsc#1120601).
- commit 3792514
* Mon Feb 11 2019 jack@suse.cz
- blockdev: Fix livelocks on loop device (bsc#1124984).
- commit 857b548
* Mon Feb 11 2019 jack@suse.cz
- nbd: Use set_blocksize() to set device blocksize (bsc#1124984).
- blacklist.conf: Blacklist 967d1dc144b5 and 0a42e99b58a2
- commit 7439299
* Mon Feb 11 2019 jack@suse.cz
- ext4: track writeback errors using the generic tracking
  infrastructure (bsc#1124982).
- commit 036c27d
* Mon Feb 11 2019 jack@suse.cz
- ext4: avoid kernel warning when writing the superblock to a
  dead device (bsc#1124981).
- commit f92b2d6
* Mon Feb 11 2019 jack@suse.cz
- ext4: fix a potential fiemap/page fault deadlock w/ inline_data
  (bsc#1124980).
- commit 424532a
* Mon Feb 11 2019 jack@suse.cz
- ext4: make sure enough credits are reserved for dioread_nolock
  writes (bsc#1124979).
- commit 99a4d9d
* Mon Feb 11 2019 jack@suse.cz
- ext4: check for shutdown and r/o file system in
  ext4_write_inode() (bsc#1124978).
- commit dc5a120
* Mon Feb 11 2019 jack@suse.cz
- ext4: include terminating u32 in size of xattr entries when
  expanding inodes (bsc#1124976).
- commit c3a7a13
* Mon Feb 11 2019 jack@suse.cz
- loop: drop caches if offset or block_size are changed
  (bsc#1124975).
- commit df3c676
* Mon Feb 11 2019 jack@suse.cz
- block/loop: Use global lock for ioctl() operation (bsc#1124974).
- commit 8f611d6
* Mon Feb 11 2019 jack@suse.cz
- blacklist.conf: Blacklist b1ab5fa309e6
- commit b03a941
* Mon Feb 11 2019 jthumshirn@suse.de
- acpi, nfit: Fix Address Range Scrub completion tracking
  (bsc#1124969).
- Refresh
  patches.fixes/acpi-nfit-fix-ars-overflow-continuation.patch.
- Refresh patches.kabi/kabi-protect-struct-acpi_nfit_desc.patch.
- commit a36799d
* Mon Feb 11 2019 glin@suse.com
- Refresh
  patches.kabi/bpf-move-prev_-insn_idx-into-verifier-env.patch.
  Correct the patch to avoid breaking nfp.
- commit 328bd94
* Mon Feb 11 2019 glin@suse.com
- Refresh
  patches.kabi/bpf-fix-partial-copy-of-map_ptr-when-dst-is-scalar.patch.
  Add more details to the description of the patch.
- commit 6b541d7
* Mon Feb 11 2019 tzimmermann@suse.de
- drm/vmwgfx: Fix setting of dma masks (bsc#1120902)
- commit 0d96fca
* Mon Feb 11 2019 tzimmermann@suse.de
- drm/vmwgfx: Return error code from vmw_execbuf_copy_fence_user (bsc#1120902)
- commit d2f7791
* Mon Feb 11 2019 acho@suse.com
- Update
  patches.fixes/Bluetooth-Verify-that-l2cap_get_conf_opt-provides-la.patch
  (bsc#1120758 CVE-2019-3459 CVE-2019-3460).
- commit 31956dc
* Fri Feb  8 2019 tiwai@suse.de
- platform/x86: asus-nb-wmi: Drop mapping of 0x33 and 0x34 scan
  codes (bsc#1051510).
- platform/x86: asus-nb-wmi: Map 0x35 to KEY_SCREENLOCK
  (bsc#1051510).
- commit 3a743df
* Fri Feb  8 2019 ptesarik@suse.cz
- s390/zcrypt: fix specification exception on z196 during ap probe
  (LTC#174936, bsc#1123061).
- scripts/git_sort/git_sort.py: Add s390/linux.git fixes.
- commit d41c9f0
* Fri Feb  8 2019 tiwai@suse.de
- mmc: bcm2835: Fix DMA channel leak on probe error (bsc#1051510).
- mmc: dw_mmc-bluefield: : Fix the license information
  (bsc#1051510).
- mmc: sdhci-iproc: handle mmc_of_parse() errors during probe
  (bsc#1051510).
- mmc: atmel-mci: do not assume idle after atmci_request_end
  (bsc#1051510).
- commit 379914e
* Fri Feb  8 2019 tiwai@suse.de
- gpio: pcf857x: Fix interrupts on multiple instances
  (bsc#1051510).
- mfd: tps6586x: Handle interrupts on suspend (bsc#1051510).
- mfd: ab8500-core: Return zero in get_register_interruptible()
  (bsc#1051510).
- dmaengine: xilinx_dma: Remove __aligned attribute on
  zynqmp_dma_desc_ll (bsc#1051510).
- misc: vexpress: Off by one in vexpress_syscfg_exec()
  (bsc#1051510).
- driver core: Move async_synchronize_full call (bsc#1051510).
- clk: imx6q: reset exclusive gates on init (bsc#1051510).
- clk: rockchip: fix typo in rk3188 spdif_frac parent
  (bsc#1051510).
- clk: sunxi-ng: h3/h5: Fix CSI_MCLK parent (bsc#1051510).
- clk: sunxi-ng: enable so-said LDOs for A64 SoC's pll-mipi clock
  (bsc#1051510).
- dmaengine: dw: Fix FIFO size for Intel Merrifield (bsc#1051510).
- misc: mic/scif: fix copy-paste error in
  scif_create_remote_lookup (bsc#1051510).
- misc: atmel-ssc: Fix section annotation on
  atmel_ssc_get_driver_data (bsc#1051510).
- drivers/misc/sgi-gru: fix Spectre v1 vulnerability
  (bsc#1051510).
- misc: hmc6352: fix potential Spectre v1 (bsc#1051510).
- drivers: core: Remove glue dirs from sysfs earlier
  (bsc#1051510).
- misc: mic: SCIF Fix scif_get_new_port() error handling
  (bsc#1051510).
- misc: ti-st: Fix memory leak in the error path of probe()
  (bsc#1051510).
- misc: sram: enable clock before registering regions
  (bsc#1051510).
- misc: sram: fix resource leaks in probe error path
  (bsc#1051510).
- commit 7c91b33
* Fri Feb  8 2019 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Build livepatch support in SUSE release
  projects (bsc#1124167).
- commit 7519080
* Fri Feb  8 2019 jroedel@suse.de
- KVM: nVMX: unconditionally cancel preemption timer in
  free_nested (CVE-2019-7221) (CVE-2019-7221 bsc#1124732).
- KVM: x86: work around leak of uninitialized stack contents
  (CVE-2019-7222) (CVE-2019-7222 bsc#1124735).
- kvm: fix kvm_ioctl_create_device() reference counting
  (CVE-2019-6974) (CVE-2019-6974 bsc#1124728).
- commit 2b60717
* Thu Feb  7 2019 lyan@suse.com
- KVM: PPC: Book3S PR: Set hflag to indicate that POWER9 supports
  1T segments (bsc#1124589).
- commit 369f0f8
* Thu Feb  7 2019 palcantara@suse.de
- cifs: Fix separator when building path from dentry
  (bsc#1051510).
- commit e3522a0
* Thu Feb  7 2019 jthumshirn@suse.de
- Refresh patches.kabi/kabi-protect-struct-ata_host.patch.
- commit b3a0a59
* Thu Feb  7 2019 tiwai@suse.de
- ARM: cns3xxx: Use actual size reads for PCIe (bsc#1051510).
- ARM: cns3xxx: Fix writing to wrong PCI config registers after
  alignment (bsc#1051510).
- arm/arm64: KVM: vgic: Force VM halt when changing the active
  state of GICv3 PPIs/SGIs (bsc#1051510).
- ARM: imx: update the cpu power up timing setting on i.mx6sx
  (bsc#1051510).
- ARM: mmp/mmp2: fix cpu_is_mmp2() on mmp2-dt (bsc#1051510).
- ARM: 8815/1: V7M: align v7m_dma_inv_range() with v7 counterpart
  (bsc#1051510).
- ARM: 8814/1: mm: improve/fix ARM v7_dma_inv_range() unaligned
  address handling (bsc#1051510).
- ARM: OMAP1: ams-delta: Fix possible use of uninitialized field
  (bsc#1051510).
- ARM: OMAP2+: prm44xx: Fix section annotation on
  omap44xx_prm_enable_io_wakeup (bsc#1051510).
- ARM: 8802/1: Call syscall_trace_exit even when system call
  skipped (bsc#1051510).
- commit 7b1aa7a
* Thu Feb  7 2019 tiwai@suse.de
- ALSA: usb-audio: Add support for new T+A USB DAC (bsc#1051510).
- ALSA: hda/realtek - Use a common helper for hp pin reference
  (bsc#1051510).
- ALSA: hda/realtek - Fix lose hp_pins for disable auto mute
  (bsc#1051510).
- commit 76b3b48
* Thu Feb  7 2019 tiwai@suse.de
- Move the upstreamed HD-audio fix into sorted section
- commit accb944
* Thu Feb  7 2019 tiwai@suse.de
- ALSA: hda/ca0132 - Fix build error without CONFIG_PCI
  (bsc#1051510).
- ALSA: compress: Fix stop handling on compressed capture streams
  (bsc#1051510).
- commit cb91271
* Thu Feb  7 2019 jslaby@suse.cz
- Refresh
  patches.kabi/0003-md-fix-md_write_start-deadlock-w-o-metadata-devices.kabi.
- Refresh
  patches.kabi/bpf-fix-partial-copy-of-map_ptr-when-dst-is-scalar.patch.
- Update
  patches.kabi/bpf-move-prev_-insn_idx-into-verifier-env.patch
  (bsc#1068032 CVE-2017-5753).
- Update
  patches.kabi/bpf-prevent-memory-disambiguation-attack.patch
  (bsc#1087082).
- Update
  patches.kabi/bpf-prevent-out-of-bounds-speculation-on-pointer-ari.patch
  (bsc#1068032 CVE-2017-5753).
- Update
  patches.kabi/bpf-properly-enforce-index-mask-to-prevent-out-of-bo.patch
  (bsc#1098425).
- Refresh patches.kabi/fix-kvm-kabi.patch.
- Refresh patches.kabi/kabi-mvpp2-10gkr-support.patch.
- Refresh patches.kabi/kabi-protect-struct-ata_host.patch.
- Refresh patches.kabi/kabi-protect-struct-kvm_sync_regs.patch.
- Refresh
  patches.kabi/kabi-x86-speculation-fix-cpu_tlbstate-issue.patch.
- Refresh
  patches.kabi/mm-numa-Remove-rate-limiting-of-automatic-numa-balancing-migration-kabi.patch.
- Refresh
  patches.kabi/s390-mm-fix-race-on-mm-context-flush_mm.patch.
- Refresh
  patches.kabi/sched-numa-Pass-destination-CPU-as-a-parameter-to-migrate_task_rq-kabi.patch.
- Refresh
  patches.kabi/sched-numa-Stop-multiple-tasks-from-moving-to-the-CPU-at-the-same-time-kabi.patch.
- Refresh
  patches.kabi/x86-cpuinfo_x86-ignore-initialized-member.patch.
  Walked through them to see if they are correct. Fixed some tags, added
  some comments. There are 3 suspicious patches:
  patches.kabi/bpf-fix-partial-copy-of-map_ptr-when-dst-is-scalar.patch
  patches.kabi/bpf-move-prev_-insn_idx-into-verifier-env.patch
  patches.kabi/kabi-protect-struct-ata_host.patch
  An e-mail will be sent to a ML.
- commit e8d529d
* Thu Feb  7 2019 msuchanek@suse.de
- selftests/powerpc: Use snprintf to construct DSCR sysfs
  interface paths (bsc#1124579).
- commit 0a2e5ac
* Wed Feb  6 2019 nsaenzjulienne@suse.de
- xhci: Add quirk to zero 64bit registers on Renesas PCIe controllers (bsc#1120854).
- Refresh patches.fixes/0001-USB-xhci-fix-broken_suspend-placement-in-struct-xchi.patch.
- Refresh patches.kabi/0001-kABI-fix-xhci-kABI-stability.patch.
- commit c70c2f5
* Wed Feb  6 2019 tiwai@suse.de
- drivers/sbus/char: add of_node_put() (bsc#1051510).
- sbus: char: add of_node_put() (bsc#1051510).
- commit ace85bb
* Wed Feb  6 2019 tiwai@suse.de
- jffs2: Fix use of uninitialized delayed_work, lockdep breakage
  (bsc#1051510).
- iscsi target: fix session creation failure handling
  (bsc#1051510).
- commit a9a3d74
* Wed Feb  6 2019 tiwai@suse.de
- ide: pmac: add of_node_put() (bsc#1051510).
- commit 311323c
* Wed Feb  6 2019 tiwai@suse.de
- hfsplus: do not free node before using (bsc#1051510).
- hfs: do not free node before using (bsc#1051510).
- hfs: prevent btree data loss on root split (bsc#1051510).
- hfsplus: prevent btree data loss on root split (bsc#1051510).
- commit 3942f5f
* Wed Feb  6 2019 tiwai@suse.de
- fork: don't copy inconsistent signal handler state to child
  (bsc#1051510).
- commit 70695af
* Wed Feb  6 2019 tiwai@suse.de
- fat: validate ->i_start before using (bsc#1051510).
- commit 62fdadf
* Wed Feb  6 2019 tiwai@suse.de
- exportfs: do not read dentry after free (bsc#1051510).
- commit 2f5aef2
* Wed Feb  6 2019 tiwai@suse.de
- blacklist.conf: add an gcc-8 warning entry that breaks kABI, too
- commit 5da88ca
* Wed Feb  6 2019 tiwai@suse.de
- e1000e: allow non-monotonic SYSTIM readings (bsc#1051510).
- dmaengine: at_hdmac: fix module unloading (bsc#1051510).
- dmaengine: at_hdmac: fix memory leak in at_dma_xlate()
  (bsc#1051510).
- dmaengine: dma-jz4780: Return error if not probed from DT
  (bsc#1051510).
- commit 6c30b58
* Wed Feb  6 2019 tiwai@suse.de
- dlm: memory leaks on error path in dlm_user_request()
  (bsc#1051510).
- dlm: lost put_lkb on error path in receive_convert() and
  receive_unlock() (bsc#1051510).
- dlm: possible memory leak on error path in create_lkb()
  (bsc#1051510).
- dlm: fixed memory leaks after failed ls_remove_names allocation
  (bsc#1051510).
- cpufreq: imx6q: add return value check for voltage scale
  (bsc#1051510).
- blk-mq: fix kernel oops in blk_mq_tag_idle() (bsc#1051510).
- commit 05f0e41
* Wed Feb  6 2019 tiwai@suse.de
- acpi/nfit: Fix command-supported detection (bsc#1051510).
- acpi/nfit: Block function zero DSMs (bsc#1051510).
- 9p/net: put a lower bound on msize (bsc#1051510).
- 9p locks: fix glock.client_id leak in do_lock (bsc#1051510).
- 9p: clear dangling pointers in p9stat_free (bsc#1051510).
- 6lowpan: iphc: reset mac_header after decompress to fix panic
  (bsc#1051510).
- af_iucv: Move sockaddr length checks to before accessing
  sa_family in bind and connect handlers (bsc#1051510).
- commit 52ff03c
* Wed Feb  6 2019 bp@suse.de
- x86/CPU/hygon: Fix phys_proc_id calculation logic for multi-die
  processors (fate#327735).
- commit aa3eec2
* Wed Feb  6 2019 bp@suse.de
- x86/microcode: Fix microcode hotplug state (bsc#1114279).
- commit 2832c39
* Tue Feb  5 2019 ddiss@suse.de
- scripts/git_sort/git_sort.py: Add mkp/scsi 5.0/scsi-fixes
- commit 07f58d4
* Tue Feb  5 2019 jslaby@suse.cz
- signal: Always deliver the kernel's SIGKILL and SIGSTOP to a
  pid namespace init (git-fixes).
- fork: unconditionally clear stack on fork (git-fixes).
- commit b70c690
* Tue Feb  5 2019 ddiss@suse.de
- scsi: target: make the pi_prot_format ConfigFS path readable
  (bsc#1123933).
- commit 81ce83a
* Tue Feb  5 2019 jslaby@suse.cz
- kernel/exit.c: release ptraced tasks before zap_pid_ns_processes
  (git-fixes).
- commit e589946
* Tue Feb  5 2019 jslaby@suse.cz
- sched/wait: Fix rcuwait_wake_up() ordering (git-fixes).
- fork: record start_time late (git-fixes).
- commit a4d5606
* Tue Feb  5 2019 bp@suse.de
- x86/microcode, cpuhotplug: Add a microcode loader CPU hotplug
  callback (bsc#1114279).
- commit 40d8928
* Tue Feb  5 2019 bp@suse.de
- RAS/CEC: Convert the timer callback to a workqueue
  (bsc#1114279).
- commit fd5fdc3
* Tue Feb  5 2019 jroedel@suse.de
- KVM: x86: fix L1TF's MMIO GFN calculation (bsc#1124204).
- commit b944bfa
* Tue Feb  5 2019 bp@suse.de
- RAS/CEC: Fix binary search function (bsc#1114279).
- commit 1a4f4fc
* Tue Feb  5 2019 bp@suse.de
- x86/CPU/AMD: Don't force the CPB cap when running under a
  hypervisor (bsc#1114279).
- commit 4f1c425
* Tue Feb  5 2019 bp@suse.de
- kvm: x86: Include CPUID leaf 0x8000001e in kvm's supported CPUID
  (bsc#1114279).
- commit 1e9cec2
* Tue Feb  5 2019 bp@suse.de
- kvm: x86: Include multiple indices with CPUID leaf 0x8000001d
  (bsc#1114279).
- commit b6e5bfb
* Mon Feb  4 2019 jack@suse.cz
- Update metadata in
  patches.fixes/mm-migrate-Make-buffer_migrate_page_norefs-actually-.patch.
- commit 2ab8e72
* Mon Feb  4 2019 jslaby@suse.cz
- ipmi:pci: Blacklist a Realtek "IPMI" device (git-fixes).
- commit 88a6bc3
* Mon Feb  4 2019 neilb@suse.com
- blacklist.conf: add more commits
- commit 9f66d64
* Mon Feb  4 2019 neilb@suse.com
- NFS: Fix up return value on fatal errors in
  nfs_page_async_flush() (git-fixes).
- sunrpc: handle ENOMEM in rpcb_getport_async (git-fixes).
- commit 2458747
* Fri Feb  1 2019 tiwai@suse.de
- media: v4l: ioctl: Validate num_planes for debug messages
  (bsc#1051510).
- media: firewire: Fix app_info parameter type in
  avc_ca{,_app}_info (bsc#1051510).
- media: vb2: be sure to unlock mutex on errors (bsc#1051510).
- media: vivid: free bitmap_cap when updating std/timings/etc
  (bsc#1051510).
- media: v4l2-tpg: array index could become negative
  (bsc#1051510).
- media: vivid: set min width/height to a value > 0 (bsc#1051510).
- media: vivid: fix error handling of kthread_run (bsc#1051510).
- media: vb2: vb2_mmap: move lock up (bsc#1051510).
- commit b4f8e97
* Fri Feb  1 2019 tiwai@suse.de
- pstore/ram: Avoid allocation and leak of platform data
  (bsc#1051510).
- pstore/ram: Avoid NULL deref in ftrace merging failure path
  (bsc#1051510).
- pstore/ram: Do not treat empty buffers as valid (bsc#1051510).
- pstore/ram: Correctly calculate usable PRZ bytes (bsc#1051510).
- commit 15e90ac
* Fri Feb  1 2019 tiwai@suse.de
- selinux: Add __GFP_NOWARN to allocation at str_read()
  (bsc#1051510).
- commit 1df5685
* Fri Feb  1 2019 tiwai@suse.de
- selinux: fix GPF on invalid policy (bsc#1051510).
- commit e75d966
* Fri Feb  1 2019 tiwai@suse.de
- serial: uartps: Fix interrupt mask issue to handle the RX
  interrupts properly (bsc#1051510).
- serial: imx: fix error handling in console_setup (bsc#1051510).
- serial: set suppress_bind_attrs flag only if builtin
  (bsc#1051510).
- serial/sunsu: fix refcount leak (bsc#1051510).
- Revert "serial: 8250: Fix clearing FIFOs in RS485 mode again"
  (bsc#1051510).
- commit fe5d174
* Fri Feb  1 2019 tiwai@suse.de
- thermal: int340x_thermal: Fix a NULL vs IS_ERR() check
  (bsc#1051510).
- commit e14f856
* Fri Feb  1 2019 tiwai@suse.de
- tty: Handle problem if line discipline does not have receive_buf
  (bsc#1051510).
- tty/n_hdlc: fix __might_sleep warning (bsc#1051510).
- tty/serial: do not free trasnmit buffer page under port lock
  (bsc#1051510).
- commit e89abf7
* Fri Feb  1 2019 tiwai@suse.de
- uart: Fix crash in uart_write and uart_put_char (bsc#1051510).
- commit ce01626
* Fri Feb  1 2019 tiwai@suse.de
- vt: invoke notifier on screen size change (bsc#1051510).
- commit c2e299a
* Fri Feb  1 2019 tiwai@suse.de
- platform/x86: asus-wmi: Tell the EC the OS will handle the
  display off hotkey (bsc#1051510).
- commit 348f00f
* Fri Feb  1 2019 tiwai@suse.de
- LSM: Check for NULL cred-security on free (bsc#1051510).
- commit 6401087
* Fri Feb  1 2019 tiwai@suse.de
- gpio: vf610: Mask all GPIO interrupts (bsc#1051510).
- gpio: altera-a10sr: Set proper output level for direction_output
  (bsc#1051510).
- gpio: pl061: Move irq_chip definition inside struct pl061
  (bsc#1051510).
- commit 2bf709f
* Fri Feb  1 2019 tiwai@suse.de
- Cramfs: fix abad comparison when wrap-arounds occur
  (bsc#1051510).
- commit a72fdad
* Fri Feb  1 2019 tiwai@suse.de
- checkstack.pl: fix for aarch64 (bsc#1051510).
- commit 0300f4e
* Fri Feb  1 2019 tiwai@suse.de
- char/mwave: fix potential Spectre v1 vulnerability
  (bsc#1051510).
- commit 2a37e23
* Fri Feb  1 2019 tiwai@suse.de
- can: bcm: check timer values before ktime conversion
  (bsc#1051510).
- can: dev: __can_get_echo_skb(): fix bogous check for
  non-existing skb by removing it (bsc#1051510).
- commit 10af29b
* Fri Feb  1 2019 tiwai@suse.de
- kABI workaround for snd_hda_bus.bus_probing addition
  (bsc#1122944).
- ALSA: hda - Serialize codec registrations (bsc#1122944).
- commit 80a1f31
* Fri Feb  1 2019 tiwai@suse.de
- ALSA: hda - Add mute LED support for HP ProBook 470 G5
  (bsc#1051510).
- commit a0e8ecb
* Fri Feb  1 2019 tiwai@suse.de
- arm: KVM: Fix VTTBR_BADDR_MASK BUG_ON off-by-one (bsc#1051510).
- commit a3b1bde
* Fri Feb  1 2019 tiwai@suse.de
- Input: xpad - add support for SteelSeries Stratus Duo
  (bsc#1111666).
- commit efa6587
* Fri Feb  1 2019 tiwai@suse.de
- staging: rtl8188eu: Add device code for D-Link DWA-121 rev B1
  (bsc#1051510).
- commit 09bd81f
* Fri Feb  1 2019 nsaenzjulienne@suse.de
- Input: raspberrypi-ts - fix link error (git-fixes).
- commit f79a072
* Fri Feb  1 2019 tiwai@suse.de
- drm/nouveau/tmr: detect stalled gpu timer and break out of waits
  (bsc#1123538).
- commit 312f392
* Fri Feb  1 2019 tiwai@suse.de
- ALSA: hda/realtek - Fixed hp_pin no value (bsc#1051510).
- ALSA: usb-audio: Add Opus #3 to quirks for native DSD support
  (bsc#1051510).
- commit cab9efd
* Thu Jan 31 2019 lyan@suse.com
- KVM: arm/arm64: VGIC/ITS save/restore: protect kvm_read_guest()
  calls (bsc#1117155).
- KVM: arm/arm64: VGIC/ITS: protect kvm_read_guest() calls with
  SRCU lock (bsc#1117155).
- KVM: arm/arm64: VGIC/ITS: Promote irq_lock() in update_affinity
  (bsc#1117155).
- KVM: arm/arm64: Properly protect VGIC locks from IRQs
  (bsc#1117155).
- commit dc96a61
* Thu Jan 31 2019 tbogendoerfer@suse.de
- amd-xgbe: Fix mdio access for non-zero ports and clause 45 PHYs
  (bsc#1122927).
- commit b966f6a
* Thu Jan 31 2019 tbogendoerfer@suse.de
- bnx2x: Fix NULL pointer dereference in bnx2x_del_all_vlans()
  on some hw (bsc#1086323 FATE#324899).
- bnx2x: Send update-svid ramrod with retry/poll flags enabled
  (bsc#1086323 FATE#324899).
- bnx2x: Remove configured vlans as part of unload sequence
  (bsc#1086323 FATE#324899).
- bnx2x: Clear fip MAC when fcoe offload support is disabled
  (bsc#1086323 FATE#324899).
- drivers/net/ethernet/qlogic/qed/qed_rdma.h: fix typo
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- bnx2x: Assign unique DMAE channel number for FW DMAE
  transactions (bsc#1086323 FATE#324899).
- be2net: don't flip hw_features when VXLANs are added/deleted
  (bsc#1050252 FATE#322920).
- commit 4798b45
* Thu Jan 31 2019 tbogendoerfer@suse.de
- net: hns3: rename the interface for init_client_instance and
  uninit_client_instance (bsc#1104353 FATE#326415).
- Refresh
  patches.drivers/net-hns3-Clear-client-pointer-when-initialize-client.patch.
- commit 530dc8a
* Thu Jan 31 2019 tbogendoerfer@suse.de
- qed: Fix an error code qed_ll2_start_xmit() (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix command number mismatch between driver and the mfw
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- i40e: fix mac filter delete when setting mac address
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- qed: Fix QM getters to always return a valid pq (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix bitmap_weight() check (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix reading wrong value in loop condition (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix rdma_info structure allocation (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix PTT leak in qed_drain() (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix potential memory corruption (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix blocking/unlimited SPQ entries leak (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix memory/entry leak in qed_init_sp_request() (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- i40e: restore NETIF_F_GSO_IPXIP to netdev features (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- net: hns3: add error handler for hns3_nic_init_vector_data()
  (bsc#1104353 FATE#326415).
- RDMA/core: Fix unwinding flow in case of error to register
  device (bsc#1046306 FATE#322942).
- net: hns3: fix for multiple unmapping DMA problem (bsc#1104353
  FATE#326415).
- net: hns3: rename hns_nic_dma_unmap (bsc#1104353 FATE#326415).
- net: hns3: add handling for big TX fragment (bsc#1104353
  FATE#326415).
- net: hns3: move DMA map into hns3_fill_desc (bsc#1104353
  FATE#326415).
- net: hns3: remove hns3_fill_desc_tso (bsc#1104353 FATE#326415).
- net: hns3: Fix tqp array traversal condition for vf (bsc#1104353
  FATE#326415).
- net: hns3: Fix client initialize state issue when roce client
  initialize failed (bsc#1104353 FATE#326415).
- net: hns3: Fix for loopback selftest failed problem (bsc#1104353
  FATE#326415).
- i40e: report correct statistics when XDP is enabled (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- qed: Avoid implicit enum conversion in qed_iwarp_parse_rx_pkt
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed: Avoid constant logical operation warning in
  qed_vf_pf_acquire (bsc#1086314 FATE#324886 bsc#1086313
  FATE#324885 bsc#1086301 FATE#3248881).
- qed: Avoid implicit enum conversion in qed_roce_mode_to_flavor
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed: Fix mask parameter in qed_vf_prep_tunn_req_tlv (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Avoid implicit enum conversion in qed_set_tunn_cls_info
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- net: hns3: Fix tc setup when netdev is first up (bsc#1104353
  FATE#326415).
- commit 6fffd51
* Thu Jan 31 2019 jroedel@suse.de
- iommu/amd: Fix IOMMU page flush when detach device from a domain
  (bsc#1106105).
- iommu/vt-d: Fix memory leak in intel_iommu_put_resv_regions()
  (bsc#1106105).
- iommu/amd: Unmap all mapped pages in error path of map_sg
  (bsc#1106105).
- iommu/amd: Call free_iova_fast with pfn in map_sg (bsc#1106105).
- commit 7ea2e24
* Thu Jan 31 2019 ptesarik@suse.cz
- Refresh
  patches.fixes/0001-usb-dwc3-gadget-Clear-req-needs_extra_trb-flag-on-cl.patch.
- commit e7aa023
* Wed Jan 30 2019 palcantara@suse.de
- CIFS: make 'nodfs' mount opt a superblock flag (bsc#1051510).
- commit 6ee531a
* Wed Jan 30 2019 mwilck@suse.com
- rpm/kernel-binary.spec.in: fix initrd permissions (bsc#1123697)
  dracut has been using permissions 0600 for the initrd for a long
  time. On SLE15 or higher, that leads to a permission mismatch
  reported by "rpm -V". Set the permissions correctly for our
  ghost file.
- commit 9e5e2a5
* Wed Jan 30 2019 hare@suse.de
- mpt3sas: check sense buffer before copying sense data (bsc#1106811).
- bsg: allocate sense buffer if requested (bsc#1106811).
- commit b3f8d07
* Tue Jan 29 2019 tiwai@suse.de
- kABI workaround for deleted snd_hda_register_beep_device()
  (bsc#1122944).
- commit 5af1bdb
* Tue Jan 29 2019 tiwai@suse.de
- ALSA: hda - Use standard device registration for beep
  (bsc#1122944).
- commit 07f7acd
* Tue Jan 29 2019 palcantara@suse.de
- Don't log expected error on DFS referral request (bsc#1051510).
- commit 3970eda
* Tue Jan 29 2019 palcantara@suse.de
- CIFS: don't log STATUS_NOT_FOUND errors for DFS (bsc#1051510).
- commit 57b09a4
* Tue Jan 29 2019 tiwai@suse.de
- drm/i915: Add missing access_ok() checks (CVE-2018-20669,
  bsc#1122971).
- commit 47941af
* Tue Jan 29 2019 oneukum@suse.com
- usb: dwc3: gadget: Clear req->needs_extra_trb flag on cleanup
  (bsc#1120902).
- commit 2792d36
* Tue Jan 29 2019 oneukum@suse.com
- USB: Add USB_QUIRK_DELAY_CTRL_MSG quirk for Corsair K70 RGB
  (bsc#1120902).
- Refresh
  patches.drivers/usb-quirks-add-delay-quirks-for-Corsair-Strafe.patch.
- commit 40b3ef4
* Tue Jan 29 2019 oneukum@suse.com
- Add delay-init quirk for Corsair K70 RGB keyboards
  (bsc#1087092).
- Refresh
  patches.fixes/0001-usb-quirks-add-control-message-delay-for-1b1c-1b20.patch.
- commit 7378825
* Tue Jan 29 2019 oneukum@suse.com
- USB: storage: add quirk for SMI SM3350 (bsc#1120902).
- commit b3e7816
* Tue Jan 29 2019 oneukum@suse.com
- USB: storage: don't insert sane sense for SPC3+ when bad sense
  specified (bsc#1120902).
- commit ab84067
* Tue Jan 29 2019 oneukum@suse.com
- usb: cdc-acm: send ZLP for Telit 3G Intel based modems
  (bsc#1120902).
- commit 0e9fb7d
* Tue Jan 29 2019 oneukum@suse.com
- USB: serial: option: add Fibocom NL678 series (bsc#1120902).
- USB: serial: pl2303: add ids for Hewlett-Packard HP POS pole
  displays (bsc#1120902).
- commit 1e65057
* Tue Jan 29 2019 oneukum@suse.com
- blacklist.conf: for unused driver
- commit ee462c1
* Tue Jan 29 2019 neilb@suse.com
- SUNRPC: Fix a potential race in xprt_connect() (git-fixes).
- SUNRPC: Fix leak of krb5p encode pages (git-fixes).
- NFSv4: Don't exit the state manager without clearing
  NFS4CLNT_MANAGER_RUNNING (git-fixes).
- nfsd: COPY and CLONE operations require the saved filehandle
  to be set (git-fixes).
- sunrpc: correct the computation for page_ptr when truncating
  (git-fixes).
- lockd: fix access beyond unterminated strings in prints
  (git-fixes).
- nfsd: Fix an Oops in free_session() (git-fixes).
- xprtrdma: Reset credit grant properly after a disconnect
  (git-fixes).
- sunrpc: safely reallow resvport min/max inversion (git-fixes).
- nfs: Fix a missed page unlock after pg_doio() (git-fixes).
- NFSv4.1: Fix the r/wsize checking (git-fixes).
- commit 704ef82
* Mon Jan 28 2019 tiwai@suse.de
- ASoC: rt5514-spi: Fix potential NULL pointer dereference
  (bsc#1051510).
- ASoC: dma-sh7760: cleanup a debug printk (bsc#1051510).
- ipmi:ssif: Fix handling of multi-part return messages
  (bsc#1051510).
- ALSA: bebob: fix model-id of unit for Apogee Ensemble
  (bsc#1051510).
- ALSA: oxfw: add support for APOGEE duet FireWire (bsc#1051510).
- commit 4c891b3
* Mon Jan 28 2019 tiwai@suse.de
- Put the xhci fix patch to the right place in the sorted section
- commit f194c12
* Mon Jan 28 2019 msuchanek@suse.de
- ibmvnic: Add ethtool private flag for driver-defined queue
  limits (bsc#1121726).
- ibmvnic: Introduce driver limits for ring sizes (bsc#1121726).
- ibmvnic: Increase maximum queue size limit (bsc#1121726).
- commit 17984c3
* Mon Jan 28 2019 oneukum@suse.com
- crypto: user - support incremental algorithm dumps
  (bsc#1120902).
- commit d81b50c
* Mon Jan 28 2019 msuchanek@suse.de
- ibmveth: Do not process frames after calling napi_reschedule
  (bcs#1123357).
- commit 31d5f72
* Mon Jan 28 2019 oneukum@suse.com
- blacklist.conf: kABI
- commit c5e5a55
* Mon Jan 28 2019 palcantara@suse.de
- cifs: Do not modify mid entry after submitting I/O in
  cifs_call_async (bsc#1051510).
- commit 7f7a7af
* Mon Jan 28 2019 tiwai@suse.de
- doc/README.SUSE: Correct description for building a kernel (bsc#1123348)
  The obsoleted make cloneconfig is corrected.  Also the order of make
  scripts and make prepare are corrected as well.
- commit 17a2073
* Mon Jan 28 2019 jack@suse.cz
- ext4: Fix crash during online resizing (bsc#1122779).
- commit bb96702
* Mon Jan 28 2019 jgross@suse.com
- ptp_kvm: probe for kvm guest availability (bsc#1098382).
- x86/pvclock: add setter for pvclock_pvti_cpu0_va (bsc#1098382).
- x86/xen/time: set pvclock flags on xen_time_init()
  (bsc#1098382).
- x86/xen/time: setup vcpu 0 time info page (bsc#1098382).
- x86/xen/time: Output xen sched_clock time from 0 (bsc#1098382).
- xen: Fix x86 sched_clock() interface for xen (bsc#1098382).
- x86/kvmclock: set pvti_cpu0_va after enabling kvmclock
  (bsc#1098382).
- Refresh
  patches.fixes/xen-zero-MSR_IA32_SPEC_CTRL-before-suspend.patch.
- commit 33c8d3d
* Mon Jan 28 2019 mgorman@suse.de
- slab: alien caches must not be initialized if the allocation
  of the alien cache failed (git fixes (mm/slab)).
- commit 9d720a9
* Mon Jan 28 2019 mgorman@suse.de
- blacklist.conf: MemAvailable accounting, needs bug to justify the change
- commit 41d09bb
* Mon Jan 28 2019 mgorman@suse.de
- blacklist.conf: SLUB-specific and unsupported
- commit dc3339e
* Mon Jan 28 2019 mgorman@suse.de
- writeback: don't decrement wb->refcnt if !wb->bdi (git fixes
  (writeback)).
- commit e6c3442
* Mon Jan 28 2019 wqu@suse.com
- blacklist.conf: Blacklist 1b3922a8bc74 (btrfs: Use real device structure to verify dev extent)
  Upstream commit 1b3922a8bc74 (btrfs: Use real device structure to verify dev extent)
  has wrong Fixes: tag.
  The correct Fixes: tag is
  05a37c48604c ("btrfs: volumes: Make sure no dev extent is beyond device boundary")
  And that commit hasn't been backported yet.
- commit 6c46ddf
* Mon Jan 28 2019 tiwai@suse.de
- rpm/release-projects: Add SUSE:Maintenance:* for MU kernels (bsc#1123317)
- commit c784b79
* Fri Jan 25 2019 lhenriques@suse.com
- blacklist.conf: added commit 6b5a49b46cf1
- commit 12c67f0
* Fri Jan 25 2019 lhenriques@suse.com
- blacklist.conf: added commit 74827ee29565 ("ceph: quota: cleanup license mess")
- commit 66a8b0e
* Fri Jan 25 2019 jdelvare@suse.de
- watchdog: w83627hf_wdt: Add quirk for Inves system
  (bsc#1106434).
- commit 7e1c7bd
* Fri Jan 25 2019 hare@suse.de
- qla2xxx: Fixup dual-protocol FCP connections (bsc#1108870).
- commit 1ecab3e
* Fri Jan 25 2019 hare@suse.de
- nvme-multipath: round-robin I/O policy (bsc#1110705).
- Refresh patches.kabi/nvme-kABI-fixes-for-nvme_ctrl.patch.
- commit 0ec85da
* Fri Jan 25 2019 jslaby@suse.cz
- blacklist.conf: add one more
- commit a0279a1
* Fri Jan 25 2019 jslaby@suse.cz
- packet: Do not leak dev refcounts on error exit (git-fixes).
- commit 5cbfc79
* Fri Jan 25 2019 jslaby@suse.cz
- net/hamradio/6pack: use mod_timer() to rearm timers
  (networking-stable-19_01_04).
- ip: validate header length on virtual device xmit
  (networking-stable-19_01_04).
- ptr_ring: wrap back ->producer in __ptr_ring_swap_queue()
  (networking-stable-19_01_04).
- ibmveth: fix DMA unmap error in ibmveth_xmit_start error path
  (networking-stable-19_01_04).
- netrom: fix locking in nr_find_socket()
  (networking-stable-19_01_04).
- net/wan: fix a double free in x25_asy_open_tty()
  (networking-stable-19_01_04).
- ax25: fix a use-after-free in ax25_fillin_cb()
  (networking-stable-19_01_04).
- ieee802154: lowpan_header_create check must check daddr
  (networking-stable-19_01_04).
- packet: validate address length if non-zero
  (networking-stable-19_01_04).
- phonet: af_phonet: Fix Spectre v1 vulnerability
  (networking-stable-19_01_04).
- net: core: Fix Spectre v1 vulnerability
  (networking-stable-19_01_04).
- qmi_wwan: Add support for Fibocom NL678 series
  (networking-stable-19_01_04).
- ipv6: tunnels: fix two use-after-free
  (networking-stable-19_01_04).
- packet: validate address length (networking-stable-19_01_04).
- tcp: fix a race in inet_diag_dump_icsk()
  (networking-stable-19_01_04).
- gro_cell: add napi_disable in gro_cells_destroy
  (networking-stable-19_01_04).
- net/mlx5e: Remove the false indication of software timestamping
  support (networking-stable-19_01_04).
- net/mlx5: Typo fix in del_sw_hw_rule
  (networking-stable-19_01_04).
- ipv6: explicitly initialize udp6_addr in udp_sock_create6()
  (networking-stable-19_01_04).
- net/smc: fix TCP fallback socket release
  (networking-stable-19_01_04).
- net: phy: Fix the issue that netif always links up after
  resuming (networking-stable-19_01_04).
- net: macb: restart tx after tx used bit read
  (networking-stable-19_01_04).
- VSOCK: Send reset control packet when socket is partially bound
  (networking-stable-19_01_04).
- qmi_wwan: Added support for Telit LN940 series
  (networking-stable-19_01_04).
- qmi_wwan: Added support for Fibocom NL668 series
  (networking-stable-19_01_04).
- ip6mr: Fix potential Spectre v1 vulnerability
  (networking-stable-19_01_04).
- tipc: compare remote and local protocols in tipc_udp_enable()
  (networking-stable-19_01_04).
- tipc: fix a double kfree_skb() (networking-stable-19_01_04).
- tipc: use lock_sock() in tipc_sk_reinit()
  (networking-stable-19_01_04).
- vhost: make sure used idx is seen before log in
  vhost_add_used_n() (networking-stable-19_01_04).
- ipv4: Fix potential Spectre v1 vulnerability
  (networking-stable-19_01_04).
- sctp: initialize sin6_flowinfo for ipv6 addrs in
  sctp_inet6addr_event (networking-stable-19_01_04).
- commit 7c76a1a
* Thu Jan 24 2019 palcantara@suse.de
- cifs: fix set info (bsc#1051510).
- commit afad726
* Thu Jan 24 2019 tiwai@suse.de
- crypto: authencesn - Avoid twice completion call in decrypt path
  (bsc#1051510).
- crypto: caam - fix zero-length buffer DMA mapping (bsc#1051510).
- crypto: bcm - convert to use crypto_authenc_extractkeys()
  (bsc#1051510).
- crypto: authenc - fix parsing key with misaligned rta_len
  (bsc#1051510).
- can: gw: ensure DLC boundaries after CAN frame modification
  (bsc#1051510).
- gpio: pl061: handle failed allocations (bsc#1051510).
- i2c: dev: prevent adapter retries and timeout being set as
  minus value (bsc#1051510).
- ACPI: power: Skip duplicate power resource references in _PRx
  (bsc#1051510).
- isdn: fix kernel-infoleak in capi_unlocked_ioctl (bsc#1051510).
- cdc-acm: fix abnormal DATA RX issue for Mediatek Preloader
  (bsc#1051510).
- lan78xx: Resolve issue with changing MAC address (bsc#1051510).
- commit ad17c09
* Thu Jan 24 2019 oneukum@suse.com
- kABI: fix xhci kABI stability (bsc#1119086).
- commit 0c7057e
* Thu Jan 24 2019 oneukum@suse.com
- USB: xhci: fix 'broken_suspend' placement in struct xchi_hcd
  (bsc#1119086).
- commit b411b00
* Thu Jan 24 2019 jslaby@suse.cz
- tcp: lack of available data can also cause TSO defer
  (git-fixes).
- commit faf00d7
* Thu Jan 24 2019 msuchanek@suse.de
- rpm/kernel-*.spec.in: replace update srchash dependencies (FATE#325312).
  Due to some limitations version cannot be matched so move the hash into
  the provide name.
- commit 219bcec
* Thu Jan 24 2019 acho@suse.com
- Bluetooth: Verify that l2cap_get_conf_opt provides large enough
  buffer (bsc#1120758 CVE-2019-3459 CVE-2019-3560).
- commit cec7ea4
* Wed Jan 23 2019 palcantara@suse.de
- cifs: fix return value for cifs_listxattr (bsc#1051510).
- commit 279e055
* Wed Jan 23 2019 palcantara@suse.de
- cifs: smb2ops: Fix listxattr() when there are no EAs
  (bsc#1051510).
- commit 3f036ec
* Wed Jan 23 2019 msuchanek@suse.de
- powerpc/xmon: Fix invocation inside lock region (bsc#1122885).
- commit 8b07fd0
* Wed Jan 23 2019 msuchanek@suse.de
- powerpc/tm: Limit TM code inside PPC_TRANSACTIONAL_MEM
  (bsc#1118338).
- commit f332dea
* Wed Jan 23 2019 jslaby@suse.cz
- net: stmmac: Fix PCI module removal leak (git-fixes).
- bonding: update nest level on unlink (git-fixes).
- ip: on queued skb use skb_header_pointer instead of
  pskb_may_pull (git-fixes).
- commit 8026bcd
* Tue Jan 22 2019 jslaby@suse.cz
- neighbour: Avoid writing before skb->head in neigh_hh_output()
  (networking-stable-18_12_12).
- ipv6: Check available headroom in ip6_xmit() even without
  options (networking-stable-18_12_12).
- ipv6: sr: properly initialize flowi6 prior passing to
  ip6_route_output (networking-stable-18_12_12).
- ipv4: ipv6: netfilter: Adjust the frag mem limit when truesize
  changes (networking-stable-18_12_12).
- tcp: fix NULL ref in tail loss probe
  (networking-stable-18_12_12).
- tcp: Do not underestimate rwnd_limited
  (networking-stable-18_12_12).
- rtnetlink: ndo_dflt_fdb_dump() only work for ARPHRD_ETHER
  devices (networking-stable-18_12_12).
- net/mlx4_en: Change min MTU size to ETH_MIN_MTU
  (networking-stable-18_12_12).
- sctp: kfree_rcu asoc (networking-stable-18_12_12).
- kABI: protect struct sctp_association (kabi).
- net: 8139cp: fix a BUG triggered by changing mtu with network
  traffic (networking-stable-18_12_12).
- net: phy: don't allow __set_phy_supported to add unsupported
  modes (networking-stable-18_12_12).
- tun: forbid iface creation with rtnl ops
  (networking-stable-18_12_12).
- virtio-net: keep vnet header zeroed after processing XDP
  (networking-stable-18_12_12).
- commit b6d547e
* Tue Jan 22 2019 oneukum@suse.com
- xhci: workaround CSS timeout on AMD SNPS 3.0 xHC (bsc#1119086).
- commit b161fb8
* Tue Jan 22 2019 oneukum@suse.com
- usb: dwc3: trace: add missing break statement to make compiler
  happy (bsc#1120902).
- commit aadb0d4
* Tue Jan 22 2019 colyli@suse.de
- dm: call blk_queue_split() to impose device limits on bios
  (git-fixes).
- commit 7c2b122
* Tue Jan 22 2019 colyli@suse.de
- blacklist.conf:
- remove 2 entries since now we have them,
  744889b7cbb56a64f957e65ade7cb65fe3f35714
  1adfc5e4136f5967d591c399aff95b3b035f16b7
- add 1 entry
  2bcbd406715dca256912b9c5ae449c7968f15705
- commit b755e64
* Tue Jan 22 2019 colyli@suse.de
- block/swim3: Fix -EBUSY error when re-opening device after
  unmount (git-fixes).
- dm: do not allow readahead to limit IO size (git-fixes).
- dm thin: send event about thin-pool state change _after_
  making it (git-fixes).
- dm zoned: Fix target BIO completion handling (git-fixes).
- dm cache metadata: verify cache has blocks in
  blocks_are_clean_separate_dirty() (git-fixes).
- block: fix 32 bit overflow in __blkdev_issue_discard()
  (git-fixes).
- block: make sure writesame bio is aligned with logical block
  size (git-fixes).
- block: cleanup __blkdev_issue_discard() (git-fixes).
- block: make sure discard bio is aligned with logical block size
  (git-fixes).
- block: don't deal with discard limit in blkdev_issue_discard()
  (git-fixes).
- block: fix infinite loop if the device loses discard capability
  (git-fixes).
- block: break discard submissions into the user defined size
  (git-fixes).
- lib/rbtree-test: lower default params (git-fixes).
- commit 4bd8818
* Tue Jan 22 2019 wqu@suse.com
- btrfs: qgroup: Fix root item corruption when multiple same
  source snapshots are created with quota enabled (bsc#1122324).
- commit 7c01025
* Tue Jan 22 2019 glin@suse.com
- bpf: fix sanitation of alu op with pointer / scalar type from
  different paths (bsc#1068032 CVE-2017-5753).
- commit 194bcb8
* Mon Jan 21 2019 tiwai@suse.de
- Delete patches.suse/drm-i915-CFL-NVMe-breakage-workaround.patch (bsc#1122554)
  The PCI SSID matches with other machine(s?) on the market, and leads to
  the boot problem.  Let's remove the hackish patch for now.
- commit ca68b03
* Mon Jan 21 2019 oneukum@suse.com
- media: usb: pwc: Don't use coherent DMA buffers for ISO transfer
  (bsc#1054610).
- commit 1624e00
* Mon Jan 21 2019 jthumshirn@suse.de
- acpi/nfit: Fix race accessing memdev in nfit_get_smbios_id()
  (bsc#1122662).
- commit bbd5c28
* Mon Jan 21 2019 palcantara@suse.de
- cifs: Use ULL suffix for 64-bit constant (bsc#1051510).
- commit d9c9062
* Mon Jan 21 2019 tzimmermann@suse.de
- omap2fb: Fix stack memory disclosure (bsc#1120902)
- commit eef0a2f
* Mon Jan 21 2019 tzimmermann@suse.de
- drm/i915/gvt: Fix mmap range check (bsc#1120902)
- commit fc802aa
* Mon Jan 21 2019 tzimmermann@suse.de
- drm/fb-helper: Partially bring back workaround for bugs of SDL 1.2 (bsc#1113722)
- commit 16258cd
* Mon Jan 21 2019 glin@suse.com
- bpf: fix inner map masking to prevent oob under speculation
  (bsc#1068032 CVE-2017-5753).
- commit a828d71
* Mon Jan 21 2019 glin@suse.com
- bpf: prevent out of bounds speculation on pointer arithmetic
  (bsc#1068032 CVE-2017-5753).
- kabi: ignore struct bpf_insn_aux_data change (References:
  bsc#1068032 CVE-2017-5753).
- kabi: ignore struct bpf_verifier_env change (References:
  bsc#1068032 CVE-2017-5753).
- Refresh
  patches.kabi/bpf-prevent-memory-disambiguation-attack.patch.
- Refresh
  patches.kabi/bpf-properly-enforce-index-mask-to-prevent-out-of-bo.patch.
- bpf: fix check_map_access smin_value test when pointer contains
  offset (bsc#1068032 CVE-2017-5753).
- bpf: restrict unknown scalars of mixed signed bounds for
  unprivileged (bsc#1068032 CVE-2017-5753).
- bpf: restrict stack pointer arithmetic for unprivileged
  (bsc#1068032 CVE-2017-5753).
- bpf: restrict map value pointer arithmetic for unprivileged
  (bsc#1068032 CVE-2017-5753).
- bpf: move {prev_,}insn_idx into verifier env (bsc#1068032 CVE-2017-5753).
- commit 2aa186c
* Sat Jan 19 2019 mwilck@suse.com
- Revert "ide: unexport DISK_EVENT_MEDIA_CHANGE for ide-gd and ide-cd" (bsc#1110946).
- commit 9c1ee88
* Fri Jan 18 2019 palcantara@suse.de
- CIFS: Fix error mapping for SMB2_LOCK command which caused
  OFD lock problem (bsc#1051510).
- commit 24b90ca
* Fri Jan 18 2019 tiwai@suse.de
- Input: elan_i2c - add ACPI ID for touchpad in ASUS Aspire
  F5-573G (bsc#1051510).
- Input: synaptics - enable SMBus for HP EliteBook 840 G4
  (bsc#1051510).
- Input: synaptics - enable RMI on ThinkPad T560 (bsc#1051510).
- Input: omap-keypad - fix idle configuration to not block SoC
  idle states (bsc#1051510).
- Input: restore EV_ABS ABS_RESERVED (bsc#1051510).
- commit 7577e46
* Fri Jan 18 2019 tiwai@suse.de
- Update patch tag for upstreamed drm patch and move to sorted section
  Refresh patches.drm/drm-nouveau-Don-t-disable-polling-in-fallback-mode.patch
- commit 1799aff
* Fri Jan 18 2019 bp@suse.de
- x86/mm: Drop usage of __flush_tlb_all() in
  kernel_physical_mapping_init() (bsc#1114279).
- x86, modpost: Replace last remnants of RETPOLINE with
  CONFIG_RETPOLINE (bsc#1114279).
- x86/resctrl: Fix rdt_find_domain() return value and checks
  (bsc#1114279).
- x86/speculation: Add RETPOLINE_AMD support to the inline asm
  CALL_NOSPEC variant (bsc#1114279).
- kvm: sev: Fail KVM_SEV_INIT if already initialized
  (bsc#1114279).
- blacklist.conf:
- Refresh
  patches.arch/x86-retpoline-make-config_retpoline-depend-on-compiler-support.patch.
- commit 2fcd2a0
* Fri Jan 18 2019 msuchanek@suse.de
- powerpc/powernv: Clear LPCR[PECE1] via stop-api only for deep
  state offline (bsc#1119766, bsc#1055121).
- powerpc/powernv: Clear PECE1 in LPCR via stop-api only on
  Hotplug (bsc#1119766, bsc#1055121).
- Refresh patches.arch/powerpc-powernv-Provide-a-way-to-force-a-core-into-S.patch.
- commit 4ace38c
* Thu Jan 17 2019 jslaby@suse.cz
- rapidio/rionet: do not free skb before reading its length
  (networking-stable-18_12_03).
- usbnet: ipheth: fix potential recvmsg bug and recvmsg bug 2
  (networking-stable-18_12_03).
- net: thunderx: set tso_hdrs pointer to NULL in
  nicvf_free_snd_queue (networking-stable-18_12_03).
- virtio-net: fail XDP set if guest csum is negotiated
  (networking-stable-18_12_03).
- net: thunderx: set xdp_prog to NULL if bpf_prog_add fails
  (networking-stable-18_12_03).
- net: skb_scrub_packet(): Scrub offload_fwd_mark
  (networking-stable-18_12_03).
- commit 7ce5a63
* Wed Jan 16 2019 msuchanek@suse.de
- powerpc/tm: Avoid machine crash on rt_sigreturn (bsc#1118338).
- commit 1bde3cc
* Wed Jan 16 2019 jack@suse.cz
- fanotify: fix handling of events on child sub-directory
  (bsc#1122019).
- commit 3895cc7
* Wed Jan 16 2019 oneukum@suse.com
- iwlwifi: fix wrong WGDS_WIFI_DATA_SIZE (bsc#1119086).
- commit 00c2467
* Wed Jan 16 2019 tiwai@suse.de
- tty: Don't hold ldisc lock in tty_reopen() if ldisc present
  (bsc#1051510).
- drivers/tty: add missing of_node_put() (bsc#1051510).
- commit 571e131
* Wed Jan 16 2019 oneukum@suse.com
- blacklist.conf: actual code is unchanged
- commit 483a7c7
* Wed Jan 16 2019 oneukum@suse.com
- blacklist.conf: the tag on the patch is wrong. We don't need it
- commit f07e32a
* Wed Jan 16 2019 oneukum@suse.com
- libertas_tf: prevent underflow in process_cmdrequest()
  (bsc#1119086).
- commit fbaf156
* Wed Jan 16 2019 jack@suse.cz
- mm: migrate: Make buffer_migrate_page_norefs() actually succeed
  (bsc#1084216)
- commit c5fc644
* Wed Jan 16 2019 oneukum@suse.com
- iwlwifi: fix non_shared_ant for 22000 devices (bsc#1119086).
- commit 9544c6e
* Wed Jan 16 2019 oneukum@suse.com
- iwlwifi: mvm: don't send GEO_TX_POWER_LIMIT to old firmwares
  (bsc#1119086).
- commit 29e9cde
* Wed Jan 16 2019 tzimmermann@suse.de
- drm/fb-helper: Ignore the value of fb_var_screeninfo.pixclock (bsc#1113722)
- commit 3114d34
* Tue Jan 15 2019 pmladek@suse.com
- tools/lib/lockdep: Rename "trywlock" into "trywrlock"
  (bsc#1121973).
- commit 9d51899
* Tue Jan 15 2019 jack@suse.cz
- vfs: Avoid softlockups in drop_pagecache_sb() (bsc#1118505).
- commit bb624be
* Tue Jan 15 2019 tiwai@suse.de
- PCI: Disable broken RTIT_BAR of Intel TH (bsc#1120318).
- commit 18e649b
* Mon Jan 14 2019 msuchanek@suse.de
- powerpc/fadump: Do not allow hot-remove memory from fadump
  reserved area (bsc#1120937, FATE#321840, FATE#325306).
- powerpc/fadump: Throw proper error message on fadump
  registration failure (bsc#1120937, FATE#321840, FATE#325306).
- powerpc/fadump: Reservationless firmware assisted dump
  (bsc#1120937, FATE#321840, FATE#325306).
- commit dbab739
* Mon Jan 14 2019 jthumshirn@suse.de
- blacklist.conf: backlist 8363dae23463 ("compat_hdio_ioctl: Fix a declaration").
- commit 3a1ce1e
* Mon Jan 14 2019 vbabka@suse.cz
- mm/khugepaged: collapse_shmem() do not crash on Compound
  (VM Functionality, bsc#1121599).
- mm/khugepaged: collapse_shmem() without freezing new_page
  (VM Functionality, bsc#1121599).
- mm/khugepaged: minor reorderings in collapse_shmem() (VM
  Functionality, bsc#1121599).
- mm/khugepaged: collapse_shmem() remember to clear holes (VM
  Functionality, bsc#1121599).
- mm/khugepaged: fix crashes due to misaccounted holes (VM
  Functionality, bsc#1121599).
- mm/khugepaged: collapse_shmem() stop if punched or truncated
  (VM Functionality, bsc#1121599).
- mm/huge_memory: fix lockdep complaint on 32-bit i_size_read()
  (VM Functionality, bsc#1121599).
- mm/huge_memory: splitting set mapping+index before unfreeze
  (VM Functionality, bsc#1121599).
- mm/huge_memory: rename freeze_page() to unmap_page() (VM
  Functionality, bsc#1121599).
- commit 2b8ff43
* Mon Jan 14 2019 vbabka@suse.cz
- shmem: introduce shmem_inode_acct_block (VM Functionality,
  bsc#1121599).
- Refresh patches.fixes/userfaultfd-shmem-add-i_size-checks.patch.
- commit a6911c5
* Mon Jan 14 2019 vbabka@suse.cz
- shmem: shmem_charge: verify max_block is not exceeded before
  inode update (VM Functionality, bsc#1121599).
- commit e10bb19
* Mon Jan 14 2019 gqjiang@suse.com
- md: fix raid10 hang issue caused by barrier (git-fixes).
- commit c42e195
* Mon Jan 14 2019 tiwai@suse.de
- Limit max FW API version for QCA9377 (bsc#1121714, bsc#1121715).
- commit c32270b
* Sun Jan 13 2019 msuchanek@suse.de
- powerpc/tm: Unset MSR[TS] if not recheckpointing (bsc#1118338).
- powerpc/tm: Print scratch value (bsc#1118338).
- powerpc/tm: Save MSR to PACA before RFID (bsc#1118338).
- powerpc/tm: Set MSR[TS] just prior to recheckpoint (bsc#1118338,
  bsc#1120955).
- commit c7abb9d
* Sun Jan 13 2019 msuchanek@suse.de
- powerpc/tm: Reformat comments (bsc#1118338).
- powerpc/tm: Print 64-bits MSR (bsc#1118338).
- powerpc/tm: Remove msr_tm_active() (bsc#1118338).
- powerpc/tm: Fix HTM documentation (bsc#1118338).
- powerpc/tm: Fix HFSCR bit for no suspend case (bsc#1118338).
- powerpc/tm: Remove struct thread_info param from
  tm_reclaim_thread() (bsc#1118338).
- powerpc/tm: Update function prototype comment (bsc#1118338).
- powerpc/tm: Fix endianness flip on trap (bsc#1118338).
- powerpc: Remove facility loadups on transactional {fp, vec,
  vsx} unavailable (bsc#1118338).
- powerpc: Always save/restore checkpointed regs during
  treclaim/trecheckpoint (bsc#1118338).
- powerpc/tm: Don't check for WARN in TM Bad Thing handling
  (bsc#1118338).
- powerpc/tm: P9 disable transactionally suspended sigcontexts
  (bsc#1118338).
- powerpc: Remove redundant FP/Altivec giveup code (bsc#1118338).
- powerpc/tm: Fix comment (bsc#1118338).
- commit 593bb06
* Fri Jan 11 2019 jeyu@suse.de
- Refresh
  patches.suse/0003-modsign-log-module-name-in-the-event-of-an-error.patch.
- Refresh
  patches.suse/0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch.
  Fix bisectability issue due to missing header that didn't get added
  until a later patch.
- commit 2dc2721
* Fri Jan 11 2019 tiwai@suse.de
- ALSA: hda/realtek - Disable headset Mic VREF for headset mode
  of ALC225 (bsc#1051510).
- ALSA: hda/realtek - Add unplug function into unplug state of
  Headset Mode for ALC225 (bsc#1051510).
- ALSA: cs46xx: Potential NULL dereference in probe (bsc#1051510).
- ALSA: hda/realtek - Support Dell headset mode for New AIO
  platform (bsc#1051510).
- ALSA: usb-audio: Fix an out-of-bound read in
  create_composite_quirks (bsc#1051510).
- ALSA: usb-audio: Avoid access before bLength check in
  build_audio_procunit() (bsc#1051510).
- commit 8b66166
* Fri Jan 11 2019 ailiopoulos@suse.com
- xfs: fix quotacheck dquot id overflow infinite loop
  (bsc#1121621).
- commit 1d9d06d
* Fri Jan 11 2019 mhocko@suse.com
- mm: only report isolation failures when offlining memory
  (generic hotplug debugability).
- commit 62a5c72
* Thu Jan 10 2019 ptesarik@suse.cz
- scsi: zfcp: fix posting too many status read buffers leading
  to adapter shutdown (bsc#1121483, LTC#174588).
- commit b8f1228
* Thu Jan 10 2019 ptesarik@suse.cz
- dasd: fix deadlock in dasd_times_out (bsc#1121477, LTC#174111).
- s390/dasd: simplify locking in dasd_times_out
  (bsc#1104967,FATE#325924).
- commit 7519d69
* Thu Jan 10 2019 ptesarik@suse.cz
- s390/qeth: fix length check in SNMP processing (bsc#1117953,
  LTC#173657).
- s390/qeth: sanitize strings in debug messages (bsc#1117953,
  LTC#172960).
- s390/kdump: Make elfcorehdr size calculation ABI compliant
  (bsc#1117953, LTC#171112).
- s390/kdump: Fix elfcorehdr size calculation (bsc#1117953,
  LTC#171112).
- s390/qeth: remove outdated portname debug msg (bsc#1117953,
  LTC#172960).
- commit f50b84f
* Thu Jan 10 2019 nsaenzjulienne@suse.de
- Input: add official Raspberry Pi's touchscreen driver
  (FATE#326921).
- Update config files.
- supported.conf: add raspberrypi-ts driver
- commit 1d3c066
* Thu Jan 10 2019 nsaenzjulienne@suse.de
- soc: bcm2835: sync firmware properties with downstream (FATE#326921)
- Refresh patches.drivers/ARM-bcm2835-Add-GET_THROTTLED-firmware-property.patch
- commit f7dfb08
* Thu Jan 10 2019 tiwai@suse.de
- Rename the confusing patch file name
  Rename a confusing patch file name that actually reverts another.
  The git-format-patch made that name just because the patch subject is
  also confusing...
- commit b8afddc
* Thu Jan 10 2019 mgorman@suse.de
- mm: don't warn about large allocations for slab (git fixes
  (slab)).
- commit b7eb365
* Thu Jan 10 2019 mgorman@suse.de
- mm: hugetlb: yield when prepping struct pages (git fixes
  (memory initialisation)).
- commit 97e4389
* Thu Jan 10 2019 mgorman@suse.de
- blacklist.conf: Problem affects SLUB which is not enabled in kconfig
- commit 523e7a9
* Thu Jan 10 2019 mgorman@suse.de
- blacklist.conf: Problem affects debugging builds only and is harmless
- commit a295926
* Thu Jan 10 2019 mgorman@suse.de
- blacklist.conf: Affected code is already reverted
- commit 0e0559c
* Thu Jan 10 2019 mgorman@suse.de
- blacklist.conf: Build warning applies to unsupported config
- commit b41802e
* Wed Jan  9 2019 vbabka@suse.cz
- mm/huge_memory.c: reorder operations in __split_huge_page_tail()
  (VM Functionality bsc#1119962).
- commit 20600f0
* Wed Jan  9 2019 lhenriques@suse.com
- ceph: don't update importing cap's mseq when handing cap export
  (bsc#1121273).
- commit 1af5ec3
* Wed Jan  9 2019 fdmanana@suse.com
- btrfs: run delayed items before dropping the snapshot
  (bsc#1121263, bsc#1111188).
- commit 9312091
* Wed Jan  9 2019 pmladek@suse.com
- kdb: use memmove instead of overlapping memcpy (bsc#1120954).
- commit 3338727
* Wed Jan  9 2019 jroedel@suse.de
- KVM: X86: Fix scan ioapic use-before-initialization
  (CVE-2018-19407 bsc#1116841).
- commit 16f4823
* Wed Jan  9 2019 hare@suse.de
- nvme-multipath: zero out ANA log buffer (bsc#1105168).
- commit 9b02bfb
* Wed Jan  9 2019 hare@suse.de
- nvme: validate controller state before rescheduling keep alive
  (bsc#1103257).
- commit 0fad491
* Wed Jan  9 2019 jroedel@suse.de
- iommu/amd: Fix amd_iommu=force_isolation (bsc#1106105).
- iommu/vt-d: Handle domain agaw being less than iommu agaw
  (bsc#1106105).
- Revert "iommu/io-pgtable-arm: Check for v7s-incapable systems"
  (bsc#1106105).
- commit 15b88ce
* Wed Jan  9 2019 tiwai@suse.de
- Housekeeping: move upstreamed patches into sorted section
  Also, a kABI fix patch moved to patches.kabi.
- commit a40818b
* Wed Jan  9 2019 tiwai@suse.de
- Update upstreamed patch tags and move to sorted section
- commit e9f612e
* Tue Jan  8 2019 nsaenzjulienne@suse.de
- usb: dwc2: host: use hrtimer for NAK retries (git-fixes).
- commit 3d9a7b6
* Tue Jan  8 2019 tiwai@suse.de
- x86/PCI: Apply VMD's AERSID fixup generically (bsc#1120058).
- x86/PCI: Add additional VMD device root ports to VMD AER quirk
  (bsc#1120058).
- x86/PCI: Enable AMD 64-bit window on resume (bsc#1120058).
- x86/PCI: Move and shrink AMD 64-bit window to avoid conflict
  (bsc#1120058).
- x86/PCI: Add "pci=big_root_window" option for AMD 64-bit windows
  (bsc#1120058).
- x86/PCI: Only enable a 64bit BAR on single-socket AMD Family
  15h (bsc#1120058).
- x86/PCI: Fix infinite loop in search for 64bit BAR placement
  (bsc#1120058).
- x86/PCI: Enable a 64bit BAR on AMD Family 15h (Models 00-1f,
  30-3f, 60-7f) (bsc#1120058).
- x86/PCI: Use is_vmd() rather than relying on the domain number
  (bsc#1120058).
- commit c7775ac
* Tue Jan  8 2019 tiwai@suse.de
- x86/PCI: Avoid AMD SB7xx EHCI USB wakeup defect (bsc#1120058).
- commit a7f3eeb
* Tue Jan  8 2019 tiwai@suse.de
- PCI: Delay after FLR of Intel DC P3700 NVMe (bsc#1120058).
- PCI: Disable Samsung SM961/PM961 NVMe before FLR (bsc#1120058).
- PCI: Export pcie_has_flr() (bsc#1120058).
- commit d3fce7d
* Tue Jan  8 2019 tiwai@suse.de
- PCI: iproc: Activate PAXC bridge quirk for more devices
  (bsc#1120058).
- PCI: Convert device-specific ACS quirks from NULL termination
  to ARRAY_SIZE (bsc#1120058).
- PCI: Mark fall-through switch cases before enabling
  - Wimplicit-fallthrough (bsc#1120058).
- commit cc31f9e
* Tue Jan  8 2019 tiwai@suse.de
- PCI: Add ACS quirk for Ampere root ports (bsc#1120058).
- PCI: Mark Ceton InfiniTV4 INTx masking as broken (bsc#1120058).
- PCI: Add ACS quirk for APM X-Gene devices (bsc#1120058).
- x86/PCI: Move VMD quirk to x86 fixups (bsc#1120058).
- PCI: Mark Intel XXV710 NIC INTx masking as broken (bsc#1120058).
- commit 42a6a1d
* Tue Jan  8 2019 tiwai@suse.de
- ALSA: hda/tegra: clear pending irq handlers (bsc#1051510).
- ALSA: hda/realtek: Enable the headset mic auto detection for
  ASUS laptops (bsc#1051510).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX391UA with
  ALC294 (bsc#1051510).
- ALSA: emu10k1: Fix potential Spectre v1 vulnerabilities
  (bsc#1051510).
- ALSA: rme9652: Fix potential Spectre v1 vulnerability
  (bsc#1051510).
- ALSA: hda: add mute LED support for HP EliteBook 840 G4
  (bsc#1051510).
- ALSA: hda: fix front speakers on Huawei MBXP (bsc#1051510).
- ALSA: pcm: Fix potential Spectre v1 vulnerability (bsc#1051510).
- ALSA: emux: Fix potential Spectre v1 vulnerabilities
  (bsc#1051510).
- commit 0656a1b
* Tue Jan  8 2019 tiwai@suse.de
- char_dev: Fix off-by-one bugs in find_dynamic_major()
  (bsc#1121058).
- char_dev: extend dynamic allocation of majors into a higher
  range (bsc#1121058).
- commit 16e7b70
* Tue Jan  8 2019 tbogendoerfer@suse.de
- vhost/vsock: fix use-after-free in network stack callers
  (bsc#1106615 CVE-2018-14625).
- commit 1c7e3c2
* Tue Jan  8 2019 mgorman@suse.de
- sched/fair: Fix infinite loop in update_blocked_averages()
  by reverting a9e7f6544b9c (Git fixes (scheduler)).
- commit bc3a0c1
* Tue Jan  8 2019 jgross@suse.com
- xen/netfront: tolerate frags with no data (bnc#1119804).
- commit a96373a
* Tue Jan  8 2019 tiwai@suse.de
- Fix the breakage of KMP build on x86_64 (bsc#1121017)
  The backport of the commit 4cd24de3a098 broke KMP builds because of the
  failure of make kernelrelease call in spec file.  Clear the blacklist and
  backport the fix from the upstream.
- commit 83c2f81
* Tue Jan  8 2019 rgoldwyn@suse.com
- splice: don't read more than available pipe space (bsc#1119212).
- commit 81f665a
* Mon Jan  7 2019 mgorman@suse.de
- blacklist.conf: Minor vmstat issue but potentially breaks vmstat parsers if removed
- commit da9734f
* Mon Jan  7 2019 mgorman@suse.de
- mm: shmem.c: Correctly annotate new inodes for lockdep
  (Git fixes: shmem).
- commit d6cabaf
* Mon Jan  7 2019 fdmanana@suse.com
- Btrfs: fix fsync of files with multiple hard links in new
  directories (1120173).
- commit 7eeaea9
* Mon Jan  7 2019 ailiopoulos@suse.com
- xfs: xfs_buf: drop useless LIST_HEAD (git-fixes).
- commit 8704d41
* Mon Jan  7 2019 tiwai@suse.de
- Update patch reference for a usb hso fix (CVE-2018-19985, bsc#1120743).
- commit 91f72a0
* Mon Jan  7 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915/gen9+: Fix initial readout for Y tiled framebuffers'
- commit 8b49aea
* Mon Jan  7 2019 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Handle incomplete Z_FINISH for compressed error states'
- commit 60f6775
* Mon Jan  7 2019 tzimmermann@suse.de
- drm: rcar-du: Fix external clock error checks (bsc#1113722)
- commit 3da9c2e
* Mon Jan  7 2019 tzimmermann@suse.de
- drm: rcar-du: Fix vblank initialization (bsc#1113722)
- commit d3ae83f
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/vc4: ->x_scaling[1] should never be set to VC4_SCALING_NONE (bsc#1113722)
- commit b56b9d7
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/vc4: Set ->is_yuv to false when num_planes == 1 (bsc#1113722)
- commit 560bb22
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/rockchip: psr: do not dereference encoder before it is null (bsc#1113722)
- commit edf3d3a
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/ioctl: Fix Spectre v1 vulnerabilities (bsc#1113722)
- commit 299de51
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/nouveau/kms: Fix memory leak in nv50_mstm_del() (bsc#1113722)
- commit 869702a
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/amdgpu: update SMC firmware image for polaris10 variants (bsc#1113722)
- commit d9a7aaf
* Mon Jan  7 2019 nborisov@suse.com
- btrfs: Fix error handling in btrfs_cleanup_ordered_extents
  (git-fixes).
- btrfs: Always try all copies when reading extent buffers
  (git-fixes).
- btrfs: Fix memory barriers usage with device stats counters
  (git-fixes).
- commit f618435
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/i915/execlists: Apply a full mb before execution for Braswell (bsc#1113722)
- commit 4b50b29
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/amdgpu/gmc8: update MC firmware for polaris (bsc#1113722)
- commit 8a55dfd
* Mon Jan  7 2019 tiwai@suse.de
- Correct patch-mainline tags
- commit db08aa7
* Mon Jan  7 2019 tzimmermann@suse.de
- drm/amdgpu: update mc firmware image for polaris12 variants (bsc#1113722)
- commit 343b80f
* Mon Jan  7 2019 tzimmermann@suse.de
- drm: set is_master to 0 upon drm_new_set_master() failure (bsc#1113722)
- commit 5d50e19
* Mon Jan  7 2019 tzimmermann@suse.de
- fbdev: fbcon: Fix unregister crash when more than one framebuffer (bsc#1113722)
- commit af14719
* Mon Jan  7 2019 tzimmermann@suse.de
- fbdev: fbmem: behave better with small rotated displays and many CPUs (bsc#1113722)
- commit c3cb61a
* Mon Jan  7 2019 nborisov@suse.com
- Btrfs: fix error handling in btrfs_truncate() (bsc#1111469).
- commit ffc620c
* Mon Jan  7 2019 tiwai@suse.de
- Update & sort upstremed patches
- commit 48660df
* Mon Jan  7 2019 tiwai@suse.de
- Correct patch-mainline tag from v4.21 to v5.0
- commit d218f41
* Mon Jan  7 2019 wqu@suse.com
- btrfs: tree-checker: Don't check max block group size
  as  current max chunk size limit is unreliable (fixes
  for bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875).
- commit 6ea44d8
* Mon Jan  7 2019 wqu@suse.com
- btrfs: qgroup: Dirty all qgroups before rescan (bsc#1120036).
- commit e71dd19
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: reserve space for O_TMPFILE orphan item deletion (bsc#1111469).
- commit db60351
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: renumber BTRFS_INODE_ runtime flags and switch to enums (bsc#1111469).
- commit 98606ab
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: get rid of unused orphan infrastructure (bsc#1111469).
- commit 2ea39bd
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: stop creating orphan items for truncate (bsc#1111469).
- commit b89578f
* Fri Jan  4 2019 jack@suse.cz
- patches.fixes/ubifs-Handle-re-linking-of-inodes-correctly-while-re.patch:
  Fixup compilation failure due to different ubifs_assert() prototype.
- commit bf2faff
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: fix ENOSPC caused by orphan items reservations (bsc#1111469).
- commit 6041c7b
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: refactor btrfs_evict_inode() reserve refill dance (bsc#1111469).
- commit 09ea38c
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: don't return ino to ino cache if inode item removal fails (bsc#1111469).
- commit 2823ef8
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: delete dead code in btrfs_orphan_commit_root() (bsc#1111469).
- commit 3280514
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: get rid of BTRFS_INODE_HAS_ORPHAN_ITEM (bsc#1111469).
- commit 0374fb2
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: fix use-after-free on root->orphan_block_rsv   (bsc#1111469).
- commit d45eb09
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: don't BUG_ON() in btrfs_truncate_inode_items()
  (bsc#1111469).
- Btrfs: update stale comments referencing vmtruncate()
  (bsc#1111469).
- commit 0f0d10f
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: fix error handling in btrfs_truncate_inode_items() (bsc#1111469).
- commit ac4ef70
* Fri Jan  4 2019 nborisov@suse.com
- btrfs: move btrfs_truncate_block out of trans handle (bsc#1111469).
- commit 91a1ca2
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: delete dead code in btrfs_orphan_add() (bsc#1111469).
- commit c2b7c23
* Fri Jan  4 2019 nborisov@suse.com
- Btrfs: do not check inode's runtime flags under root->orphan_lock (bsc#1111469).
- commit 5a9867d
* Thu Jan  3 2019 jeffm@suse.com
- blacklist.conf: add a pair of gfs2 commits; we don't support it read-write
- commit 0f2617c
* Thu Jan  3 2019 ailiopoulos@suse.com
- xfs: Align compat attrlist_by_handle with native implementation
  (git-fixes).
- commit 6359899
* Thu Jan  3 2019 ailiopoulos@suse.com
- xfs: Fix xqmstats offsets in /proc/fs/xfs/xqmstat (git-fixes).
- commit 836b5b8
* Thu Jan  3 2019 ailiopoulos@suse.com
- fs/xfs: Use %%pS printk format for direct addresses (git-fixes).
- commit 3897315
* Thu Jan  3 2019 yousaf.kaukab@suse.com
- arm64: dma-mapping: Fix FORCE_CONTIGUOUS buffer clearing
  (bsc#1120633).
- arm64: Fix /proc/iomem for reserved but not memory regions
  (bsc#1120632).
- commit 36d66c2
* Thu Jan  3 2019 jack@suse.cz
- blkdev: avoid migration stalls for blkdev pages (bsc#1084216).
- commit 32da7b4
* Thu Jan  3 2019 jack@suse.cz
- mm: migrate: provide buffer_migrate_page_norefs() (bsc#1084216).
- commit f94c281
* Thu Jan  3 2019 jack@suse.cz
- mm: migrate: lock buffers before migrate_page_move_mapping()
  (bsc#1084216).
- commit a63c547
* Thu Jan  3 2019 jack@suse.cz
- mm: migration: factor out code to compute expected number of
  page references (bsc#1084216).
- commit 2baf0a5
* Thu Jan  3 2019 yousaf.kaukab@suse.com
- config: arm64: enable erratum 1024718
- commit 63f186f
* Thu Jan  3 2019 yousaf.kaukab@suse.com
- arm64/numa: Unify common error path in numa_init()
  (bsc#1120621).
- arm64/numa: Report correct memblock range for the dummy node
  (bsc#1120620).
- arm64: lse: remove -fcall-used-x0 flag (bsc#1120618).
- arm64: mm: always enable CONFIG_HOLES_IN_ZONE (bsc#1120617).
- arm64: remove no-op -p linker flag (bsc#1120616).
- arm64: cpu_errata: include required headers (bsc#1120615).
- arm64: lse: Add early clobbers to some input/output asm operands
  (bsc#1120614).
- arm64: Add work around for Arm Cortex-A55 Erratum 1024718
  (bsc#1120612).
- arm64: atomics: Remove '&' from '+&' asm constraint in lse
  atomics (bsc#1120613).
- cpufreq: CPPC: fix build in absence of v3 support (bsc#1117115).
- commit 78882ed
* Thu Jan  3 2019 jack@suse.cz
- blacklist.conf: Blacklist 368686a95e55
- commit 1cfcaa5
* Thu Jan  3 2019 jack@suse.cz
- x86/mm: Fix decoy address handling vs 32-bit builds
  (bsc#1120606).
- commit 195b599
* Thu Jan  3 2019 jack@suse.cz
- ext4: fix EXT4_IOC_GROUP_ADD ioctl (bsc#1120604).
- commit e61d54c
* Thu Jan  3 2019 jack@suse.cz
- ext4: missing unlock/put_page() in
  ext4_try_to_write_inline_data() (bsc#1120603).
- commit 0cfc4f4
* Thu Jan  3 2019 jack@suse.cz
- ext4: fix possible use after free in ext4_quota_enable
  (bsc#1120602).
- commit 3e1f5da
* Thu Jan  3 2019 jack@suse.cz
- blacklist.conf: Blacklist fb265c9cb49e
- commit d6b792f
* Thu Jan  3 2019 jack@suse.cz
- gfs2: Fix loop in gfs2_rbm_find (bsc#1120601).
- commit bd84a55
* Thu Jan  3 2019 jack@suse.cz
- gfs2: Get rid of potential double-freeing in gfs2_create_inode
  (bsc#1120600).
- commit 43bc90e
* Thu Jan  3 2019 jack@suse.cz
- ubifs: Handle re-linking of inodes correctly while recovery
  (bsc#1120598).
- commit a545e2b
* Thu Jan  3 2019 jack@suse.cz
- aio: fix spectre gadget in lookup_ioctx (bsc#1120594).
- commit d60e318
* Thu Jan  3 2019 tiwai@suse.de
- Input: nomadik-ske-keypad - fix a loop timeout test
  (bsc#1051510).
- rtc: m41t80: Correct alarm month range with RTC reads
  (bsc#1051510).
- power: supply: olpc_battery: correct the temperature units
  (bsc#1051510).
- iwlwifi: add new cards for 9560, 9462, 9461 and killer series
  (bsc#1051510).
- iwlwifi: pcie: don't reset TXQ write pointer (bsc#1051510).
- platform-msi: Free descriptors in platform_msi_domain_free()
  (bsc#1051510).
- device property: fix fwnode_graph_get_next_endpoint()
  documentation (bsc#1051510).
- spi: bcm2835: Unbreak the build of esoteric configs
  (bsc#1051510).
- USB: serial: option: add Telit LN940 series (bsc#1051510).
- USB: serial: option: add Fibocom NL668 series (bsc#1051510).
- USB: serial: option: add Simcom SIM7500/SIM7600 (MBIM mode)
  (bsc#1051510).
- USB: serial: option: add GosunCn ZTE WeLink ME3630
  (bsc#1051510).
- USB: serial: option: add HP lt4132 (bsc#1051510).
- xhci: Don't prevent USB2 bus suspend in state check intended
  for USB3 only (bsc#1051510).
- mmc: core: Use a minimum 1600ms timeout when enabling CACHE ctrl
  (bsc#1051510).
- mmc: core: Allow BKOPS and CACHE ctrl even if no HPI support
  (bsc#1051510).
- mmc: core: Reset HPI enabled state during re-init and in case
  of errors (bsc#1051510).
- mmc: omap_hsmmc: fix DMA API warning (bsc#1051510).
- USB: hso: Fix OOB memory access in hso_probe/hso_get_config_data
  (bsc#1051510).
- USB: omap_udc: fix USB gadget functionality on Palm Tungsten E
  (bsc#1051510).
- USB: omap_udc: fix omap_udc_start() on 15xx machines
  (bsc#1051510).
- USB: omap_udc: fix crashes on probe error and module removal
  (bsc#1051510).
- USB: omap_udc: use devm_request_irq() (bsc#1051510).
- rtc: pcf2127: fix a kmemleak caused in pcf2127_i2c_gather_write
  (bsc#1051510).
- cdrom: don't attempt to fiddle with cdo->capability
  (bsc#1051510).
- rtc: snvs: Add timeouts to avoid kernel lockups (bsc#1051510).
- device property: Define type of PROPERTY_ENRTY_*() macros
  (bsc#1051510).
- commit 9d680ce
* Wed Jan  2 2019 ddiss@suse.de
- target: se_dev_attrib.emulate_pr ABI stability (bsc#1091405).
- scsi: target: drop unused pi_prot_format attribute storage
  (bsc#1091405).
- scsi: target: add emulate_pr backstore attr to toggle PR support
  (bsc#1091405).
- target/iscsi: avoid NULL dereference in CHAP auth error path
  (bsc#1117165).
- commit 0239433
* Wed Jan  2 2019 yousaf.kaukab@suse.com
- cpufreq / CPPC: Add cpuinfo_cur_freq support for CPPC
  (bsc#1117115).
- ACPI / CPPC: Check for valid PCC subspace only if PCC is used
  (bsc#1117115).
- ACPI / CPPC: Update all pr_(debug/err) messages to log the
  susbspace id (bsc#1117115).
- commit 366d7ad
* Wed Jan  2 2019 tiwai@suse.de
- staging: wilc1000: fix missing read_write setting when reading
  data (bsc#1051510).
- mmc: bcm2835: reset host on timeout (bsc#1051510).
- wireless: airo: potential buffer overflow in sprintf()
  (bsc#1051510).
- rtl8xxxu: Fix missing break in switch (bsc#1051510).
- wlcore: Fix the return value in case of error in
  'wlcore_vendor_cmd_smart_config_start()' (bsc#1051510).
- spi: bcm2835: Fix race on DMA termination (bsc#1051510).
- spi: bcm2835: Fix book-keeping of DMA termination (bsc#1051510).
- spi: bcm2835: Avoid finishing transfer prematurely in IRQ mode
  (bsc#1051510).
- libata: whitelist all SAMSUNG MZ7KM* solid-state disks
  (bsc#1051510).
- media: omap3isp: Unregister media device as first (bsc#1051510).
- media: em28xx: make v4l2-compliance happier by starting sequence
  on zero (bsc#1051510).
- media: em28xx: Fix use-after-free when disconnecting
  (bsc#1051510).
- commit 0d2a4b5
* Wed Jan  2 2019 tiwai@suse.de
- intel_th: msu: Fix an off-by-one in attribute store
  (bsc#1051510).
- gpiolib: Fix return value of gpio_to_desc() stub if !GPIOLIB
  (bsc#1051510).
- crypto: bcm - fix normal/non key hash algorithm failure
  (bsc#1051510).
- can: flexcan: flexcan_irq(): fix indention (bsc#1051510).
- gpio: mvebu: only fail on missing clk if pwm is actually to
  be used (bsc#1051510).
- gpio: max7301: fix driver for use with CONFIG_VMAP_STACK
  (bsc#1051510).
- gpiolib-acpi: Only defer request_irq for GpioInt ACPI event
  handlers (bsc#1051510).
- i2c: scmi: Fix probe error on devices with an empty SMB0001
  ACPI device node (bsc#1051510).
- i2c: axxia: properly handle master timeout (bsc#1051510).
- Input: omap-keypad - fix keyboard debounce configuration
  (bsc#1051510).
- Input: synaptics - enable SMBus for HP 15-ay000 (bsc#1051510).
- commit 2171735
* Wed Jan  2 2019 tiwai@suse.de
- staging: bcm2835-camera: Abort probe if there is no camera
  (bsc#1051510).
- ath6kl: Only use match sets when firmware supports it
  (bsc#1051510).
- b43: Fix error in cordic routine (bsc#1051510).
- ath10k: don't assume this is a PCI dev in generic code
  (bsc#1051510).
- commit 5e336ca
* Wed Jan  2 2019 tiwai@suse.de
- ASoC: Intel: mrfld: fix uninitialized variable access
  (bsc#1051510).
- ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for
  Chromebook Gnawty (bsc#1051510).
- ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for
  Chromebook Clapper (bsc#1051510).
- ALSA: fireface: fix for state to fetch PCM frames (bsc#1051510).
- ALSA: firewire-lib: use the same print format for
  'without_header' tracepoints (bsc#1051510).
- ALSA: firewire-lib: fix wrong assignment for
  'out_packet_without_header' tracepoint (bsc#1051510).
- ALSA: firewire-lib: fix wrong handling payload_length as
  payload_quadlet (bsc#1051510).
- ALSA: hda/ca0132 - make pci_iounmap() call conditional
  (bsc#1051510).
- ALSA: x86: Fix runtime PM for hdmi-lpe-audio (bsc#1051510).
- ASoC: omap-dmic: Add pm_qos handling to avoid overruns with
  CPU_IDLE (bsc#1051510).
- ASoC: omap-mcpdm: Add pm_qos handling to avoid under/overruns
  with CPU_IDLE (bsc#1051510).
- ASoC: omap-mcbsp: Fix latency value calculation for pm_qos
  (bsc#1051510).
- ASoC: dapm: Recalculate audio map forcely when card instantiated
  (bsc#1051510).
- ASoC: omap-abe-twl6040: Fix missing audio card caused by
  deferred probing (bsc#1051510).
- ASoC: wm_adsp: Fix dma-unsafe read of scratch registers
  (bsc#1051510).
- ASoC: rsnd: fixup clock start checker (bsc#1051510).
- commit d45ceab
* Wed Jan  2 2019 msuchanek@suse.de
- powerpc/powernv: Fix save/restore of SPRG3 on entry/exit from
  stop (idle) (bsc#1055121).
- commit fe3e770
* Wed Jan  2 2019 neilb@suse.com
- kabi fix for sunrpc-use-after-free-in-svc_process_common.patch
  (bsc#1119946 CVE-2018-16884).
- sunrpc: use-after-free in svc_process_common() (bsc#1119946
  CVE-2018-16884).
- sunrpc: use SVC_NET() in svcauth_gss_* functions (bsc#1119946
  CVE-2018-16884).
- commit 5834865
* Fri Dec 28 2018 msuchanek@suse.de
- ibmvnic: Fix non-atomic memory allocation in IRQ context
  (FATE#326521).
- ibmvnic: Convert reset work item mutex to spin lock
  (FATE#326521).
- commit ef920be
* Fri Dec 28 2018 msuchanek@suse.de
- scripts/git-pre-commit: make executable.
- commit b879431
* Wed Dec 26 2018 glin@suse.com
- bpf: fix check of allowed specifiers in bpf_trace_printk
  (bsc#1083647).
- commit 3c5ea31
* Sun Dec 23 2018 msuchanek@suse.de
- powerpc/pkeys: Fix handling of pkey state across fork()
  (FATE#322447, bsc#1078248, git-fixes).
- powerpc/64s/radix: Fix process table entry cache invalidation
  (bsc#1055186, fate#323286, git-fixes).
- Refresh patches.arch/05-arch-mm-allow-arch_dup_mmap-to-fail.patch.
- commit e8de755
* Sun Dec 23 2018 bp@suse.de
- x86/bugs: Fix the AMD SSBD usage of the SPEC_CTRL MSR
  (bsc#1106913).
- x86/bugs: Switch the selection of mitigation from CPU vendor
  to CPU features (bsc#1106913).
- blacklist.conf:
- Refresh
  patches.arch/x86-speculation-prepare-for-per-task-indirect-branch-speculation-control.patch.
- commit 274ffb2
* Sun Dec 23 2018 bp@suse.de
- x86/kabi: Fix cpu_tlbstate issue (bsc#1106913).
- commit 22a85b9
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Provide IBPB always command line options
  (bsc#1106913).
- commit 454668f
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Add seccomp Spectre v2 user space protection
  mode (bsc#1106913).
- commit 4569ae5
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Enable prctl mode for spectre_v2_user
  (bsc#1106913).
- commit 85a36e0
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Add prctl() control for indirect branch
  speculation (bsc#1106913).
- commit bfed86f
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Prepare arch_smt_update() for PRCTL mode
  (bsc#1106913).
- commit 8b2b603
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Prevent stale SPEC_CTRL msr content
  (bsc#1106913).
- commit f0e109e
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Split out TIF update (bsc#1106913).
- commit 7fbe02c
* Sun Dec 23 2018 bp@suse.de
- ptrace: Remove unused ptrace_may_access_sched() and MODE_IBRS
  (bsc#1106913).
- commit c169bf3
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Prepare for conditional IBPB in switch_mm()
  (bsc#1106913).
- commit 87f418f
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Avoid __switch_to_xtra() calls (bsc#1106913).
- commit 8c217e5
* Sun Dec 23 2018 bp@suse.de
- x86/process: Consolidate and simplify switch_to_xtra() code
  (bsc#1106913).
- commit 6aeb224
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Prepare for per task indirect branch
  speculation control (bsc#1106913).
- commit 4fbb7ac
* Sun Dec 23 2018 bp@suse.de
- x86/speculation: Add command line control for indirect branch
  speculation (bsc#1106913).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit 3d8c402
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Unify conditional spectre v2 print functions
  (bsc#1106913).
- commit a45c3e8
* Sat Dec 22 2018 bp@suse.de
- x86/speculataion: Mark command line parser data __initdata
  (bsc#1106913).
- commit ff50ca5
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Mark string arrays const correctly
  (bsc#1106913).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit 37a1ec5
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Reorder the spec_v2 code (bsc#1106913).
- Refresh
  patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit dd2aa4a
* Sat Dec 22 2018 bp@suse.de
- x86/l1tf: Show actual SMT state (bsc#1106913).
- commit f2c3675
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Rework SMT state change (bsc#1106913).
- commit fb0cab3
* Sat Dec 22 2018 bp@suse.de
- sched/smt: Expose sched_smt_present static key (bsc#1106913).
- commit 09b97a1
* Sat Dec 22 2018 bp@suse.de
- sched/smt: Make sched_smt_present track topology (bsc#1106913).
- commit 1abdd34
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Reorganize speculation control MSRs update
  (bsc#1106913).
- commit 7366d5a
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Rename SSBD update functions (bsc#1106913).
- commit f4cf7f8
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Disable STIBP when enhanced IBRS is in use
  (bsc#1106913).
- commit dd2f7d6
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Move STIPB/IBPB string conditionals out of
  cpu_show_common() (bsc#1106913).
- commit a5e5561
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Remove unnecessary ret variable in
  cpu_show_common() (bsc#1106913).
- commit cd83897
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Clean up spectre_v2_parse_cmdline()
  (bsc#1106913).
- commit 26ab139
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Update the TIF_SSBD comment (bsc#1106913).
- commit a59356b
* Sat Dec 22 2018 bp@suse.de
- x86/retpoline: Remove minimal retpoline support (bsc#1106913).
- Refresh patches.suse/0001-x86-speculation-Add-basic-IBRS-support-infrastructur.patch.
- commit 37af788
* Sat Dec 22 2018 bp@suse.de
- x86/retpoline: Make CONFIG_RETPOLINE depend on compiler support
  (bsc#1106913).
- commit 7fb52c2
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Propagate information about RSB filling
  mitigation to sysfs (bsc#1106913).
- commit cfc6ecb
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Enable cross-hyperthread spectre v2 STIBP
  mitigation (bsc#1106913).
- commit 560a01f
* Sat Dec 22 2018 bp@suse.de
- x86/speculation: Apply IBPB more strictly to avoid cross-process
  data leak (bsc#1106913).
- commit b48428f
* Sat Dec 22 2018 bp@suse.de
- x86/bugs: Add AMD's SPEC_CTRL MSR usage (bsc#1106913).
- commit 6019324
* Sat Dec 22 2018 bp@suse.de
- sched/core: Fix cpu.max vs. cpuhotplug deadlock (bsc#1106913).
- commit 973faf3
* Sat Dec 22 2018 bp@suse.de
- locking/static_keys: Improve uninitialized key warning
  (bsc#1106913).
- commit 854a799
* Sat Dec 22 2018 bp@suse.de
- jump_label: Split out code under the hotplug lock (bsc#1106913).
- commit e23515a
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: ftrace: memory leak in pretty advanced scenario
- commit 109722b
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: ftrace: should not normally happen; not worth it
- commit 2da5b26
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: graph_trace; possible miscalculation with non-default
  options; non-trivial; ignore until people complains
- commit b689bcc
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: bpf: only prevents WARN() when using wrong format
  in bpf_trace_printk()
- commit 0853f31
* Fri Dec 21 2018 pmladek@suse.com
- ring-buffer: Allow for rescheduling when removing pages
  (bsc#1120238).
- commit 0335a28
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: tracing: old and not serious bug
- commit 9ddd9ba
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: tracing/kprobes: old bug; hard to trigger;
  rather just annoying
- commit 3ff091f
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: tracing: just a small annoyance when switching buffer snapshot
- commit ec9dc6f
* Fri Dec 21 2018 pmladek@suse.com
- tracing: Fix possible double free in event_enable_trigger_func()
  (bsc#1120235).
- commit d21d238
* Fri Dec 21 2018 pmladek@suse.com
- tracing: Fix double free of event_trigger_data (bsc#1120234).
- commit cebb208
* Fri Dec 21 2018 pmladek@suse.com
- tracing: Fix missing return symbol in function_graph output
  (bsc#1120232).
- commit 9988fec
* Fri Dec 21 2018 pmladek@suse.com
- tracing: Fix crash when freeing instances with event triggers
  (bsc#1120230).
- commit 4e6ced7
* Fri Dec 21 2018 pmladek@suse.com
- sched, tracing: Fix trace_sched_pi_setprio() for deboosting
  (bsc#1120228).
- commit c29a2ac
* Fri Dec 21 2018 pmladek@suse.com
- tracing: Fix regex_match_front() to not over compare the test
  string (bsc#1120223).
- commit 2b5bf5f
* Fri Dec 21 2018 pmladek@suse.com
- tracing: Fix bad use of igrab in trace_uprobe.c (bsc#1120046).
- commit 270ef83
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: tracing: incomplete filtering events; new feature
- commit 6153583
* Fri Dec 21 2018 pmladek@suse.com
- blacklist.conf: tracing: dependency fix found by randconfig;
  prevents a huge build
- commit bd08e07
* Fri Dec 21 2018 pmladek@suse.com
- tracing: Fix possible double free on failure of allocating
  trace buffer (bsc#1120214).
- commit 579bdb1
* Fri Dec 21 2018 tiwai@suse.de
- Fix a typo in the previous USB fix
  It caused a build error on Leap kernel with OTG config enabled.
  Refresh:
  patches.kabi/0001-USB-check-usb_get_extra_descriptor-for-proper-size-F.patch
- commit 0947a02
* Thu Dec 20 2018 pmladek@suse.com
- tracing: Fix crash when it fails to alloc ring buffer
  (bsc#1120097).
- commit 96c92ef
* Thu Dec 20 2018 pmladek@suse.com
- ring-buffer: Do no reuse reader page if still in use
  (bsc#1120096).
- commit 1b0ce63
* Thu Dec 20 2018 pmladek@suse.com
- blacklist.conf: ring_buffer: just an optimization
- commit 03fef22
* Thu Dec 20 2018 pmladek@suse.com
- ring-buffer: Mask out the info bits when returning buffer page
  length (bsc#1120094).
- commit f77f6e1
* Thu Dec 20 2018 pmladek@suse.com
- blacklist.conf: tracing: just a memory optimization
- commit 563bc21
* Thu Dec 20 2018 pmladek@suse.com
- tracing: Remove RCU work arounds from stack tracer
  (bsc#1120092).
- commit 5189425
* Thu Dec 20 2018 pmladek@suse.com
- extable: Enable RCU if it is not watching in
  kernel_text_address() (bsc#1120092).
- commit bdbc690
* Thu Dec 20 2018 msuchanek@suse.de
- ibmvscsi: Fix empty event pool access during host removal
  (bsc#1119019).
- commit f101e38
* Thu Dec 20 2018 pmladek@suse.com
- extable: Consolidate *kernel_text_address() functions
  (bsc#1120092).
- commit ed3b605
* Thu Dec 20 2018 pmladek@suse.com
- rcu: Allow for page faults in NMI handlers (bsc#1120092).
- Refresh
  patches.suse/rcu-Use-lockdep-to-assert-IRQs-are-disabled-enabled.patch.
- commit 27a7cf8
* Thu Dec 20 2018 pmladek@suse.com
- tracing: Fix trace_pipe behavior for instance traces
  (bsc#1120088).
- commit e723e1c
* Thu Dec 20 2018 jack@suse.cz
- dax: Don't access a freed inode (bsc#1120055).
- commit ecd8623
* Thu Dec 20 2018 jack@suse.cz
- dax: Check page->mapping isn't NULL (bsc#1120054).
- commit 337d19b
* Thu Dec 20 2018 jack@suse.cz
- kernfs: Replace strncpy with memcpy (bsc#1120053).
- commit 2df0d28
* Wed Dec 19 2018 palcantara@suse.de
- smb3: on kerberos mount if server doesn't specify auth type
  use krb5 (bsc#1051510).
- commit ddb7363
* Wed Dec 19 2018 palcantara@suse.de
- smb3: do not attempt cifs operation in smb3 query info error
  path (bsc#1051510).
- commit 2186c48
* Wed Dec 19 2018 palcantara@suse.de
- smb3: allow stats which track session and share reconnects to
  be reset (bsc#1051510).
- commit f64d315
* Wed Dec 19 2018 palcantara@suse.de
- CIFS: fix wrapping bugs in num_entries() (bsc#1051510).
- commit 11891e6
* Wed Dec 19 2018 palcantara@suse.de
- cifs: prevent integer overflow in nxt_dir_entry() (bsc#1051510).
- commit 96ceeea
* Wed Dec 19 2018 palcantara@suse.de
- smb3: check for and properly advertise directory lease support
  (bsc#1051510).
- commit 4b461a1
* Wed Dec 19 2018 palcantara@suse.de
- fs/cifs: require sha512 (bsc#1051510).
- commit 8cb120b
* Wed Dec 19 2018 palcantara@suse.de
- smb3: simplify code by removing CONFIG_CIFS_SMB311
  (bsc#1051510).
- Refresh
  patches.fixes/cifs-add-missing-support-for-ACLs-in-SMB-3.11.patch.
- commit 2b7565c
* Wed Dec 19 2018 mhocko@suse.com
- mm: sections are not offlined during memory hotremove
  (bnc#1119968).
- commit 3bf1a33
* Wed Dec 19 2018 oneukum@suse.com
- Revert "USB: check usb_get_extra_descriptor for proper size"
  (bsc#1119714 CVE-2018-20169).
- commit 2b5ce60
* Wed Dec 19 2018 tbogendoerfer@suse.de
- kabi protect hnae_ae_ops (bsc#1104353 FATE#326415).
- commit 673e002
* Wed Dec 19 2018 tbogendoerfer@suse.de
- net/mlx4_core: Correctly set PFC param if global pause is
  turned off (bsc#1046299 FATE#322947).
- RDMA/hns: Bugfix pbl configuration for rereg mr (bsc#1104427
  FATE#326416).
- RDMA/bnxt_re: Avoid accessing the device structure after it
  is freed (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Fix system hang when registration with L2 driver
  fails (bsc#1086283 FATE#324874).
- net: ena: update driver version from 2.0.1 to 2.0.2 (bsc#1111696
  bsc#1117561).
- net: ena: fix crash during ena_remove() (bsc#1111696
  bsc#1117561).
- net: hns3: Fix for out-of-bounds access when setting pfc back
  pressure (bsc#1104353 FATE#326415).
- net: hns3: bugfix for rtnl_lock's range in the hclgevf_reset()
  (bsc#1104353 FATE#326415).
- net: hns3: bugfix for handling mailbox while the command queue
  reinitialized (bsc#1104353 FATE#326415).
- net: hns3: bugfix for hclge_mdio_write and hclge_mdio_read
  (bsc#1104353 FATE#326415).
- net: hns3: bugfix for is_valid_csq_clean_head() (bsc#1104353
  FATE#326415).
- net: hns3: remove unnecessary queue reset in the
  hns3_uninit_all_ring() (bsc#1104353 FATE#326415).
- net: hns3: bugfix for the initialization of command queue's
  spin lock (bsc#1104353 FATE#326415).
- net: hns3: bugfix for reporting unknown vector0 interrupt
  repeatly problem (bsc#1104353 FATE#326415).
- net: hns3: bugfix for buffer not free problem during resetting
  (bsc#1104353 FATE#326415).
- RDMA/bnxt_re: Avoid NULL check after accessing the pointer
  (bsc#1086283 FATE#324874).
- RDMA/bnxt_re: Add missing spin lock initialization (bsc#1050244
  FATE#322915).
- IB/hfi1: Add mtu check for operational data VLs (bsc#1060463
  FATE#323043).
- qed: Add support for virtual link (bsc#1111795).
- net: hns3: Fix for rx vlan id handle to support Rev 0x21
  hardware (bsc#1104353 FATE#326415).
- qede: Add driver support for 20G link speed (bsc#1110558).
- qed: Add driver support for 20G link speed (bsc#1110558).
- net: hns3: Fix loss of coal configuration while doing reset
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for netdev not up problem when setting mtu
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for packet buffer setting bug (bsc#1104353
  FATE#326415).
- net: hns3: Add nic state check before calling
  netif_tx_wake_queue (bsc#1104353 FATE#326415).
- net: hns3: Fix ets validate issue (bsc#1104353 FATE#326415).
- net: hns3: Fix parameter type for q_id in
  hclge_tm_q_to_qs_map_cfg() (bsc#1104353 FATE#326415).
- net: hns3: Clear client pointer when initialize client failed
  or unintialize finished (bsc#1104353 FATE#326415).
- net: hns3: Fix cmdq registers initialization issue for vf
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for setting speed for phy failed problem
  (bsc#1104353 FATE#326415).
- net: hns3: Check hdev state when getting link status
  (bsc#1104353 FATE#326415).
- net: hns3: Set STATE_DOWN bit of hdev state when stopping net
  (bsc#1104353 FATE#326415).
- net: hns3: Add support for hns3_nic_netdev_ops.ndo_do_ioctl
  (bsc#1104353 FATE#326415).
- net: hns3: Preserve vlan 0 in hardware table (bsc#1104353
  FATE#326415).
- net: hns3: Fix ping exited problem when doing lp selftest
  (bsc#1104353 FATE#326415).
- net: hns3: Fix error of checking used vlan id (bsc#1104353
  FATE#326415).
- net: hns3: Fix for vf vlan delete failed problem (bsc#1104353
  FATE#326415).
- bnxt_en: get the reduced max_irqs by the ones used by RDMA
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix enables field in HWRM_QUEUE_COS2BW_CFG request
  (bsc#1086282 FATE#324873).
- bnxt_en: Fix VNIC reservations on the PF (bsc#1086282
  FATE#324873).
- bnxt_en: don't try to offload VLAN 'modify' action (bsc#1050242
  FATE#32291).
- commit cff74c8
* Tue Dec 18 2018 palcantara@suse.de
- SMB3.1.1 dialect is no longer experimental (bsc#1051510).
- commit 568b46f
* Tue Dec 18 2018 palcantara@suse.de
- CIFS: fix sha512 check in cifs_crypto_secmech_release
  (bsc#1051510).
- commit 5bcc721
* Tue Dec 18 2018 palcantara@suse.de
- SMB3: Fix length checking of SMB3.11 negotiate request
  (bsc#1051510).
- commit 67e1742
* Tue Dec 18 2018 palcantara@suse.de
- SMB311: Fix reconnect (bsc#1051510).
- commit 2f56ec3
* Tue Dec 18 2018 palcantara@suse.de
- CIFS: implement v3.11 preauth integrity (bsc#1051510).
- Refresh
  patches.fixes/smb3-on-reconnect-set-PreviousSessionId-field.patch.
- commit 931aacd
* Tue Dec 18 2018 palcantara@suse.de
- CIFS: add sha512 secmech (bsc#1051510).
- commit 6751a85
* Tue Dec 18 2018 palcantara@suse.de
- CIFS: refactor crypto shash/sdesc allocation&free (bsc#1051510).
- commit 3087f38
* Tue Dec 18 2018 palcantara@suse.de
- [SMB3] Improve security, move default dialect to SMB3 from
  old CIFS (bsc#1051510).
- commit 2a8d00b
* Tue Dec 18 2018 palcantara@suse.de
- SMB3: Backup intent flag missing for directory opens with
  backupuid mounts (bsc#1051510).
- commit 5c33399
* Tue Dec 18 2018 palcantara@suse.de
- smb3: enumerating snapshots was leaving part of the data off
  end (bsc#1051510).
- commit ac5ab8c
* Tue Dec 18 2018 palcantara@suse.de
- smb3: Do not send SMB3 SET_INFO if nothing changed
  (bsc#1051510).
- commit 69765ec
* Tue Dec 18 2018 palcantara@suse.de
- smb3: don't request leases in symlink creation and query
  (bsc#1051510).
- commit c9b7903
* Tue Dec 18 2018 palcantara@suse.de
- cifs: add missing debug entries for kconfig options
  (bsc#1051510).
- commit eef0de5
* Tue Dec 18 2018 nsaenzjulienne@suse.de
- kbuild: make missing $DEPMOD a Warning instead of an Error
  (git-fixes).
- mtd: Fix comparison in map_word_andequal() (git-fixes).
- Fix tracing sample code warning (git-fixes).
- commit 33a3dc7
* Tue Dec 18 2018 palcantara@suse.de
- cifs: Fix memory leak in smb2_set_ea() (bsc#1051510).
- commit 5e91284
* Tue Dec 18 2018 palcantara@suse.de
- cifs: For SMB2 security informaion query, check for minimum
  sized security descriptor instead of sizeof FileAllInformation
  class (bsc#1051510).
- commit da30ffb
* Tue Dec 18 2018 palcantara@suse.de
- cifs: add missing support for ACLs in SMB 3.11 (bsc#1051510).
- commit bea9260
* Tue Dec 18 2018 palcantara@suse.de
- cifs: hide unused functions (bsc#1051510).
- commit 7ac6c1a
* Tue Dec 18 2018 palcantara@suse.de
- cifs: Add support for writing attributes on SMB2+ (bsc#1051510).
- commit f4a82ef
* Tue Dec 18 2018 palcantara@suse.de
- cifs: Add support for reading attributes on SMB2+ (bsc#1051510).
- commit 1d63a60
* Tue Dec 18 2018 palcantara@suse.de
- smb3: fix various xid leaks (bsc#1051510).
- commit 077f859
* Tue Dec 18 2018 palcantara@suse.de
- cifs: Use smb 2 - 3 and cifsacl mount options setacl function
  (bsc#1051510).
- commit f8e76f0
* Tue Dec 18 2018 oneukum@suse.com
- USB: check usb_get_extra_descriptor for proper size (For SUSE)
  (bsc#1119714 CVE-2018-20169).
- commit e3f18fc
* Tue Dec 18 2018 palcantara@suse.de
- cifs: hide unused functions (bsc#1051510).
- commit 1177701
* Tue Dec 18 2018 palcantara@suse.de
- cifs: Use smb 2 - 3 and cifsacl mount options getacl functions
  (bsc#1051510).
- commit 2c8fac4
* Tue Dec 18 2018 palcantara@suse.de
- cifs: prototype declaration and definition for smb 2 - 3 and
  cifsacl mount options (bsc#1051510).
- commit e35127a
* Tue Dec 18 2018 palcantara@suse.de
- cifs: prototype declaration and definition to set acl for smb
  2 - 3 and cifsacl mount options (bsc#1051510).
- commit 0164b47
* Tue Dec 18 2018 nsaenzjulienne@suse.de
- USB: check usb_get_extra_descriptor for proper size (bsc#1119714
  CVE-2018-20169).
- commit 300dd87
* Tue Dec 18 2018 nsaenzjulienne@suse.de
- tools/power/cpupower: fix compilation with STATIC=true
  (git-fixes).
- watchdog/core: Add missing prototypes for weak functions
  (git-fixes).
- dt-bindings: pwm: renesas: tpu: Fix "compatible" prop
  description (git-fixes).
- cpupower: remove stringop-truncation waring (git-fixes).
- gpio: davinci: Remove unused member of davinci_gpio_controller
  (git-fixes).
- perf tools: Fix tracing_path_mount proper path (git-fixes).
- kbuild: allow to use GCC toolchain not in Clang search path
  (git-fixes).
- tools: hv: fcopy: set 'error' in case an unknown operation
  was requested (git-fixes).
- Tools: hv: Fix a bug in the key delete code (git-fixes).
- disable stringop truncation warnings for now (git-fixes).
- bpf: use per htab salt for bucket hash (git-fixes).
- kobject: Replace strncpy with memcpy (git-fixes).
- kbuild: verify that $DEPMOD is installed (git-fixes).
- dt-bindings: clock: add rk3399 DDR3 standard speed bins
  (git-fixes).
- kprobes: Make list and blacklist root user read only
  (git-fixes).
- Mark HI and TASKLET softirq synchronous (git-fixes).
- compiler-gcc.h: Add __attribute__((gnu_inline)) to all inline
  declarations (git-fixes).
- net: dsa: qca8k: Add QCA8334 binding documentation (git-fixes).
- tools/power turbostat: fix possible sprintf buffer overflow
  (git-fixes).
- dt-bindings: panel: lvds: Fix path to display timing bindings
  (git-fixes).
- dt-bindings: clock: mediatek: add binding for fixed-factor
  clock axisel_d4 (git-fixes).
- dt-bindings: arm: Document SoC compatible value for
  Armadillo-800 EVA (git-fixes).
- tools: hv: include string.h in hv_fcopy_daemon (git-fixes).
- net: dsa: mv88e6xxx: Fix binding documentation for MDIO busses
  (git-fixes).
- nospec: Kill array_index_nospec_mask_check() (git-fixes).
- gcc-plugins: Use dynamic initializers (git-fixes).
- gcc-plugins: Add include required by GCC release 8 (git-fixes).
- Kbuild: suppress packed-not-aligned warning for default setting
  only (git-fixes).
- mtd: cfi: convert inline functions to macros (git-fixes).
- x86/pti: Document fix wrong index (git-fixes).
- kbuild: rpm-pkg: keep spec file until make mrproper (git-fixes).
- kbuild: fix linker feature test macros when cross compiling
  with Clang (git-fixes).
- dt-bindings: add compatible string for Allwinner V3s SoC
  (git-fixes).
- .gitignore: sort normal pattern rules alphabetically
  (git-fixes).
- initramfs: fix initramfs rebuilds w/ compression after disabling
  (git-fixes).
- tracing/samples: Fix creation and deletion of simple_thread_fn
  creation (git-fixes).
- dt-bindings: mfd: axp20x: Add AXP806 to supported list of chips
  (git-fixes).
- dt-bindings: iio: update STM32 timers clock names (git-fixes).
- dt-bindings: phy: sun4i-usb-phy: Add property descriptions
  for H3 (git-fixes).
- dt-bindings: net: Remove duplicate NSP Ethernet MAC binding
  document (git-fixes).
- dt-bindings: pwm: Update STM32 timers clock names (git-fixes).
- dt-bindings: rcar-dmac: Document missing error interrupt
  (git-fixes).
- commit 014d990
* Tue Dec 18 2018 palcantara@suse.de
- SMB3: Add support for multidialect negotiate (SMB2.1 and later)
  (bsc#1051510).
- Refresh
  patches.fixes/SMB-fix-leak-of-validate-negotiate-info-response-buf.patch.
- commit d5fd9bf
* Tue Dec 18 2018 nsaenzjulienne@suse.de
- nospec: Allow index argument to have const-qualified type (git-fixes)
- Refresh patches.suse/14-prctl-add-speculation-control-prctls.patch
- commit b5c6e5f
* Tue Dec 18 2018 tiwai@suse.de
- r8152: disable RX aggregation on new Dell TB16 dock
  (bsc#1119749).
- drivers/net/usb/r8152: remove the unneeded variable "ret"
  in rtl8152_system_suspend (bsc#1119749).
- net: usb: r8152: use irqsave() in USB's complete callback
  (bsc#1119749).
- r8152: set rx mode early when linking on (bsc#1119749).
- r8152: fix wrong checksum status for received IPv4 packets
  (bsc#1119749).
- r8152: disable RX aggregation on Dell TB16 dock (bsc#1119749).
- drivers/net/usb: add device id for TP-LINK UE300 USB 3.0
  Ethernet (bsc#1119749).
- r8152: add Linksys USB3GIGV1 id (bsc#1119749).
- net: usb: r8152: constify usb_device_id (bsc#1119749).
- r8152: correct the definition (bsc#1119749).
- r8152: move calling delay_autosuspend function (bsc#1119749).
- r8152: split rtl8152_resume function (bsc#1119749).
- r8152: add byte_enable for ocp_read_word function (bsc#1119749).
- r8152: support RTL8153B (bsc#1119749).
- r8152: support new chip 8050 (bsc#1119749).
- r8152: replace napi_complete with napi_complete_done
  (bsc#1119749).
- r8152: avoid rx queue more than 1000 packets (bsc#1119749).
- r8152: check if disabling ALDPS is finished (bsc#1119749).
- r8152: move the initialization to reset_resume function
  (bsc#1119749).
- r8152: move the default coalesce setting for RTL8153
  (bsc#1119749).
- r8152: adjust U2P3 for RTL8153 (bsc#1119749).
- r8152: adjust rtl8153_runtime_enable function (bsc#1119749).
- r8152: move the setting of rx aggregation (bsc#1119749).
- r8152: adjust the settings about MAC clock speed down for
  RTL8153 (bsc#1119749).
- r8152: adjust lpm settings for RTL8153 (bsc#1119749).
- r8152: add r8153_phy_status function (bsc#1119749).
- commit 36d48f3
* Tue Dec 18 2018 oneukum@suse.com
- usb: usbip: Fix BUG: KASAN: slab-out-of-bounds in
  vhci_hub_control() (bsc#1106110).
- commit d07d73f
* Tue Dec 18 2018 jgross@suse.com
- blacklist.conf: add 123664101aa2156d05251704fc63f9bcbf77741a
- commit ba13bcc
* Tue Dec 18 2018 oneukum@suse.com
- usbip: vhci_hcd: check rhport before using in vhci_hub_control()
  (bsc#1090888).
- blacklist.conf: removed entry. Unneeded by itself without SS support
  in USBIP but needed by later fix
- commit a0baab2
* Tue Dec 18 2018 colyli@suse.de
- dm cache metadata: ignore hints array being too small during
  resize (Git-fixes).
- commit 2c012bc
* Tue Dec 18 2018 colyli@suse.de
- blacklist.conf: add 50b977481fce90aa5fbda55e330b9d722733e358
- commit a8538c3
* Mon Dec 17 2018 palcantara@suse.de
- [SMB3] Remove ifdef since SMB3 (and later) now STRONGLY
  preferred (bsc#1051510).
- Refresh patches.fixes/0001-CIFS-make-IPC-a-regular-tcon.patch.
- Refresh
  patches.fixes/0001-Fix-encryption-labels-and-lengths-for-SMB3.1.1.patch.
- Refresh
  patches.fixes/0001-cifs-Select-all-required-crypto-modules.patch.
- commit c1cb91e
* Mon Dec 17 2018 palcantara@suse.de
- smb3: directory sync should not return an error (bsc#1051510).
- commit 1b695a1
* Mon Dec 17 2018 palcantara@suse.de
- smb3: Fix root directory when server returns inode number of
  zero (bsc#1051510).
- commit d7bc2d0
* Mon Dec 17 2018 palcantara@suse.de
- fix smb3-encryption breakage when CONFIG_DEBUG_SG=y
  (bsc#1051510).
- commit a320a13
* Mon Dec 17 2018 bp@suse.de
- Refresh patches.arch/x86-vdso-fix-vdso-build-if-a-retpoline-is-emitted.patch.
  Fix mismerge.
- commit ab99dcd
* Mon Dec 17 2018 mbrugger@suse.com
- Refresh
  patches.drivers/thermal-bcm2835-enable-hwmon-explicitly.patch.
- commit 923a050
* Mon Dec 17 2018 msuchanek@suse.de
- powerpc/boot: Fix build failures with -j 1 (bsc#1065729).
- commit 2c1301d
* Mon Dec 17 2018 nsaenzjulienne@suse.de
- HID: Add quirk for Primax PIXART OEM mice (bsc#1119410).
- commit 5bf5901
* Mon Dec 17 2018 msuchanek@suse.de
- powerpc/boot: Expose Kconfig symbols to wrapper (bsc#1065729).
- commit fc1b477
* Mon Dec 17 2018 msuchanek@suse.de
- powerpc/traps: restore recoverability of machine_check
  interrupts (bsc#1094244).
- powerpc/64s: consolidate MCE counter increment (bsc#1094244).
- commit 7504c8e
* Mon Dec 17 2018 vbabka@suse.cz
- userfaultfd: check VM_MAYWRITE was set after verifying the
  uffd is registered (CVE-2018-18397, bsc#1117656).
- commit 68dc6a5
* Mon Dec 17 2018 colyli@suse.de
- fscache: Fix race in fscache_op_complete() due to split
  atomic_sub & read (Git-fixes).
- dm zoned: fix various dmz_get_mblock() issues (Git-fixes).
- dm zoned: fix metadata block ref counting (Git-fixes).
- dm ioctl: harden copy_params()'s copy_from_user() from malicious
  users (Git-fixes).
- cpufeature: avoid warning when compiling with clang (Git-fixes).
- keys: Fix the use of the C++ keyword "private" in
  uapi/linux/keyctl.h (Git-fixes).
- bcache: fix miss key refill->end in writeback (Git-fixes).
- bcache: trace missed reading by cache_missed (Git-fixes).
- dm linear: fix linear_end_io conditional definition (Git-fixes).
- dm linear: eliminate linear_end_io call if CONFIG_DM_ZONED
  disabled (Git-fixes).
- dm: fix report zone remapping to account for partition offset
  (Git-fixes).
- dm cache: destroy migration_cache if cache target registration
  failed (Git-fixes).
- dm cache: fix resize crash if user doesn't reload cache table
  (Git-fixes).
- nbd: don't allow invalid blocksize settings (Git-fixes).
- tracing/blktrace: Fix to allow setting same value (Git-fixes).
- dm writecache: fix a crash due to reading past end of
  dirty_bitmap (Git-fixes).
- dm crypt: don't decrease device limits (Git-fixes).
- dm cache metadata: set dirty on all cache blocks after a crash
  (Git-fixes).
- dm cache metadata: save in-core policy_hint_size to on-disk
  superblock (Git-fixes).
- dm thin: stop no_space_timeout worker when switching to
  write-mode (Git-fixes).
- dm writecache: report start_sector in status line (Git-fixes).
- dm integrity: change 'suspending' variable from bool to int
  (Git-fixes).
- dm cache: only allow a single io_mode cache feature to be
  requested (Git-fixes).
- block: really disable runtime-pm for blk-mq (Git-fixes).
- block: blk_init_allocated_queue() set q->fq as NULL in the
  fail case (Git-fixes).
- block: allow max_discard_segments to be stacked (Git-fixes).
- blk-mq: remove synchronize_rcu() from blk_mq_del_queue_tag_set()
  (Git-fixes).
- block: reset bi_iter.bi_done after splitting bio (Git-fixes).
- dm thin: handle running out of data space vs concurrent discard
  (Git-fixes).
- dm thin metadata: remove needless work from __commit_transaction
  (Git-fixes).
- sbitmap: fix race in wait batch accounting (Git-fixes).
- block/swim: Fix array bounds check (Git-fixes).
- fscache: Pass the correct cancelled indications to
  fscache_op_complete() (Git-fixes).
- rbd: whitelist RBD_FEATURE_OPERATIONS feature bit (Git-fixes).
- reset: remove remaining WARN_ON() in <linux/reset.h>
  (Git-fixes).
- commit a41ae63
* Mon Dec 17 2018 colyli@suse.de
- locking/barriers: Convert users of lockless_dereference()
  to READ_ONCE() (Git-fixes).
- Refresh for the above change,
  patches.arch/07-x86-ldt-rework-locking.patch.
  patches.fixes/ovl-fix-failure-to-fsync-lower-dir.patch.
  patches.suse/dm-mpath-accept-failed-paths.
- commit 1641962
* Mon Dec 17 2018 colyli@suse.de
- dm: allocate struct mapped_device with kvzalloc (Git-fixes).
- skd: Submit requests to firmware before triggering the doorbell
  (Git-fixes).
- skd: Avoid that module unloading triggers a use-after-free
  (Git-fixes).
- commit fdeb1d6
* Mon Dec 17 2018 colyli@suse.de
- blacklist.conf: add following commits from git-fixes suggestion,
    6a934bb81476e7e90baaf2ff766e6b6f04b5febb
    1dc3039bc87ae7d19a990c3ee71cfd8a9068f428
    e4b069e0945fa14c71cf8b5b89f8b1b2aa68dbc2
    744889b7cbb56a64f957e65ade7cb65fe3f35714
    1adfc5e4136f5967d591c399aff95b3b035f16b7
    5618cf031fecda63847cafd1091e7b8bd626cdb1
  We don't have them because other non-stable patches required.
- commit eb991b4
* Sat Dec 15 2018 bp@suse.de
- Blacklist 5182f26f6f74 crypto: ccp - Make function sev_get_firmware() static
- commit 8ec2ad4
* Sat Dec 15 2018 jslaby@suse.cz
- x86/speculation: IBRS, forbid shooting in foot (bsc#1068032
  CVE-2017-5753 bnc#1119065).
- commit f452980
* Fri Dec 14 2018 mwilck@suse.com
- Refresh
  patches.fixes/rdma_rxe-make-rxe-work-over-802.1q-VLAN-devices.patch.
  Fix warning about unused variable.
- commit f31a549
* Fri Dec 14 2018 mhocko@suse.com
- mm: don't miss the last page because of round-off error
  (bnc#1118798).
- commit 0be53f2
* Fri Dec 14 2018 mwilck@suse.com
- rdma_rxe: make rxe work over 802.1q VLAN devices (bsc#1082387).
- commit 64d14d8
* Fri Dec 14 2018 mwilck@suse.com
- IB/rxe: support for 802.1q VLAN on the listener (bsc#1082387).
- commit 05157dd
* Fri Dec 14 2018 tiwai@suse.de
- mmc: sdhci: fix the timeout check window for clock and reset
  (bsc#1051510).
- MMC: OMAP: fix broken MMC on OMAP15XX/OMAP5910/OMAP310
  (bsc#1051510).
- xhci: Prevent U1/U2 link pm states if exit latency is too long
  (bsc#1051510).
- usb: quirk: add no-LPM quirk on SanDisk Ultra Flair device
  (bsc#1051510).
- usb: appledisplay: Add 27" Apple Cinema Display (bsc#1051510).
- commit 43f7b55
* Fri Dec 14 2018 tiwai@suse.de
- blacklist.conf: Add entries that fix the already blacklisted commits
- commit 3842eb7
* Fri Dec 14 2018 tiwai@suse.de
- mac80211: ignore NullFunc frames in the duplicate detection
  (bsc#1051510).
- mac80211: fix reordering of buffered broadcast packets
  (bsc#1051510).
- mac80211: Clear beacon_int in ieee80211_do_stop (bsc#1051510).
- mac80211_hwsim: Timer should be initialized before device
  registered (bsc#1051510).
- commit 4da2a47
* Fri Dec 14 2018 tiwai@suse.de
- HID: multitouch: Add pointstick support for Cirque Touchpad
  (bsc#1051510).
- HID: input: Ignore battery reported by Symbol DS4308
  (bsc#1051510).
- commit 137ef89
* Fri Dec 14 2018 tiwai@suse.de
- ALSA: hda/realtek: Enable audio jacks of ASUS UX433FN/UX333FA
  with ALC294 (bsc#1051510).
- ALSA: hda/realtek: Enable audio jacks of ASUS UX533FD with
  ALC294 (bsc#1051510).
- ALSA: hda/realtek: ALC294 mic and headset-mode fixups for ASUS
  X542UN (bsc#1051510).
- ALSA: fireface: fix reference to wrong register for clock
  configuration (bsc#1051510).
- ALSA: hda/realtek - Fix the mute LED regresion on Lenovo X1
  Carbon (bsc#1051510).
- ALSA: hda/realtek - Fixed headphone issue for ALC700
  (bsc#1051510).
- commit defdb99
* Fri Dec 14 2018 hare@suse.de
- nvme-fc: resolve io failures during connect (bsc#1116803).
- commit d63fbbc
* Fri Dec 14 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: change SCSI git repos to make series sorting
  more failsafe.
- commit 19a60e4
* Thu Dec 13 2018 msuchanek@suse.de
- git_sort.py: Remove non-existent remote tj/libata
- commit 431c944
* Thu Dec 13 2018 hare@suse.de
- scsi: lpfc: Enable Management features for IF_TYPE=6
  (bsc#1119322).
- Revert "scsi: lpfc: ls_rjt erroneus FLOGIs" (bsc#1119322).
- commit 2235aaf
* Thu Dec 13 2018 oneukum@suse.com
- blacklist.conf: this breaks kABI
- commit bd4bb25
* Thu Dec 13 2018 hare@suse.de
- scsi: lpfc: update driver version to 12.0.0.9 (bsc#1118215).
- scsi: lpfc: Fix dif and first burst use in write commands
  (bsc#1118215).
- scsi: lpfc: Fix driver release of fw-logging buffers
  (bsc#1118215).
- scsi: lpfc: Correct topology type reporting on G7 adapters
  (bsc#1118215).
- scsi: lpfc: Correct code setting non existent bits in sli4
  ABORT WQE (bsc#1118215).
- scsi: lpfc: Defer LS_ACC to FLOGI on point to point logins
  (bsc#1118215).
- scsi: lpfc: ls_rjt erroneus FLOGIs (bsc#1118215).
- scsi: lpfc: rport port swap discovery issue (bsc#1118215).
- scsi: lpfc: Cap NPIV vports to 256 (bsc#1118215).
- scsi: lpfc: Fix kernel Oops due to null pring pointers
  (bsc#1118215).
- scsi: lpfc: Fix a duplicate 0711 log message number
  (bsc#1118215).
- scsi: lpfc: Fix discovery failures during port failovers with
  lots of vports (bsc#1118215).
- scsi: lpfc: refactor mailbox structure context fields
  (bsc#1118215).
- scsi: lpfc: update manufacturer attribute to reflect Broadcom
  (bsc#1118215).
- scsi: lpfc: Fix panic when FW-log buffsize is not initialized
  (bsc#1118215).
- commit 295ca60
* Thu Dec 13 2018 nsaenzjulienne@suse.de
- xhci: Add quirk to workaround the errata seen on Cavium
  Thunder-X2 Soc (bsc#1117162).
- commit b707d84
* Thu Dec 13 2018 gqjiang@suse.com
- blacklist.conf: Blacklist 29e270fc3219
- commit 6e668f6
* Wed Dec 12 2018 msuchanek@suse.de
- powerpc/pseries: Track LMB nid instead of using device tree
  (bsc#1108270).
- commit 748cd4b
* Wed Dec 12 2018 mhocko@suse.com
- kabi: hwpoison, memory_hotplug: allow hwpoisoned pages to be
  offlined (bnc#1116336).
- hwpoison, memory_hotplug: allow hwpoisoned pages to be offlined
  (bnc#1116336).
- mm: put_and_wait_on_page_locked() while page is migrated
  (bnc#1109272).
- mm, memory_hotplug: be more verbose for memory offline failures
  (generic hotplug debugability).
- mm, memory_hotplug: print reason for the offlining failure
  (generic hotplug debugability).
- mm, memory_hotplug: drop pointless block alignment checks from
  __offline_pages (generic hotplug debugability).
- mm: lower the printk loglevel for __dump_page messages (generic
  hotplug debugability).
- mm: print more information about mapping in __dump_page
  (generic hotplug debugability).
- mm: migration: fix migration of huge PMD shared pages
  (bnc#1086423).
- commit ba75629
* Wed Dec 12 2018 bp@suse.de
- x86/speculation/mds: Add 'mitigations=' support for MDS
  (bsc#1111331).
- commit 88cac77
* Wed Dec 12 2018 bp@suse.de
- x86/speculation/mds: Print SMT vulnerable on MSBDS with
  mitigations off (bsc#1111331).
- commit b517dcb
* Wed Dec 12 2018 bp@suse.de
- x86/speculation/mds: Add SMT warning message (bsc#1111331).
- commit 3dc297b
* Wed Dec 12 2018 bp@suse.de
- x86/speculation: Move arch_smt_update() call to after mitigation
  decisions (bsc#1111331).
- commit b18763b
* Wed Dec 12 2018 bp@suse.de
- x86/speculation/mds: Add mds=full,nosmt cmdline option
  (bsc#1111331).
- commit 681a34e
* Tue Dec 11 2018 rgoldwyn@suse.com
- fuse: fix use-after-free in fuse_direct_IO() (git-fixes).
- fuse: fix possibly missed wake-up after abort (git-fixes).
- fuse: fix leaked notify reply (git-fixes).
- apparmor: Fix uninitialized value in aa_split_fqname
  (git-fixes).
- apparmor: don't try to replace stale label in ptraceme check
  (git-fixes).
- apparmor: don't try to replace stale label in ptrace access
  check (git-fixes).
- fuse: fix blocked_waitq wakeup (git-fixes).
- fuse: set FR_SENT while locked (git-fixes).
- fuse: Fix use-after-free in fuse_dev_do_write() (git-fixes).
- fuse: Fix use-after-free in fuse_dev_do_read() (git-fixes).
- commit 50f36c2
* Tue Dec 11 2018 oneukum@suse.com
- iwlwifi: nvm: get num of hw addresses from firmware
  (bsc#1119086).
- commit d5ffb2f
* Tue Dec 11 2018 mkubecek@suse.cz
- Update
  patches.suse/socket-close-race-condition-between-sock_close-and-s.patch
  references (add CVE-2018-12232 bsc#1097593).
- commit 3b472e9
* Tue Dec 11 2018 mkubecek@suse.cz
- Update
  patches.suse/net-Set-sk_prot_creator-when-cloning-sockets-to-the-.patch
  references (add CVE-2018-9568 bsc#1118319).
- commit 541b753
* Tue Dec 11 2018 mhocko@suse.com
- x86/speculation/l1tf: Drop the swap storage limit restriction
  when l1tf=off (bnc#1114871).
- commit e14c0db
* Tue Dec 11 2018 oneukum@suse.com
- iwlwifi: fix LED command capability bit (bsc#1119086).
- commit b627932
* Tue Dec 11 2018 bp@suse.de
- kvm: x86: Report STIBP on GET_SUPPORTED_CPUID (bsc#1111331).
- commit 32eb036
* Tue Dec 11 2018 bp@suse.de
- x86/cpu: Sanitize FAM6_ATOM naming (bsc#1111331).
- Refresh
  patches.arch/intel_idle-add-support-for-Jacobsville.patch.
- Refresh
  patches.arch/powercap-intel_rapl-add-support-for-Jacobsville.patch.
- Refresh patches.arch/x86-cpu-Add-Atom-Tremont-Jacobsville.patch.
- commit 99038ef
* Tue Dec 11 2018 bp@suse.de
- x86/speculation: Prevent deadlock on ssb_state::lock
  (bsc#1114279).
- blacklist.conf: blacklist "unimportant" commits
- commit 60a2462
* Tue Dec 11 2018 dbueso@suse.de
- blacklist.conf: Add WW mutexes selftest
- commit b4479d9
* Tue Dec 11 2018 dbueso@suse.de
- series.conf: Fix tree bisection
  As of 435924b4381 (housekeeping: move epoll and lib patches
  to sorted section) we are breaking bisection if the whole
  series.conf is not fully applied.
- commit abd22af
* Mon Dec 10 2018 tiwai@suse.de
- staging: rts5208: fix gcc-8 logic error warning (bsc#1051510).
- commit 370f20c
* Mon Dec 10 2018 tiwai@suse.de
- mac80211: ignore tx status for PS stations in
  ieee80211_tx_status_ext (bsc#1051510).
- mac80211_hwsim: fix module init error paths for netlink
  (bsc#1051510).
- commit 179ed22
* Mon Dec 10 2018 tiwai@suse.de
- unifdef: use memcpy instead of strncpy (bsc#1051510).
- commit 76e2791
* Mon Dec 10 2018 tiwai@suse.de
- team: no need to do team_notify_peers or team_mcast_rejoin
  when disabling port (bsc#1051510).
- commit 4f1d4b3
* Mon Dec 10 2018 tiwai@suse.de
- linux/bitmap.h: fix type of nbits in bitmap_shift_right()
  (bsc#1051510).
- commit 396aaca
* Mon Dec 10 2018 tiwai@suse.de
- tty: serial: 8250_mtk: always resume the device in probe
  (bsc#1051510).
- tty: do not set TTY_IO_ERROR flag if console port (bsc#1051510).
- commit c9a99ff
* Mon Dec 10 2018 tiwai@suse.de
- clk: mmp: Off by one in mmp_clk_add() (bsc#1051510).
- clk: mvebu: Off by one bugs in cp110_of_clk_get() (bsc#1051510).
- commit e7433a2
* Mon Dec 10 2018 tiwai@suse.de
- usb: core: quirks: add RESET_RESUME quirk for Cherry G230
  Stream series (bsc#1051510).
- USB: usb-storage: Add new IDs to ums-realtek (bsc#1051510).
- commit adebe09
* Mon Dec 10 2018 tiwai@suse.de
- Revert commit ef9209b642f "staging: rtl8723bs: Fix indenting
  errors and an off-by-one mistake in core/rtw_mlme_ext.c"
  (bsc#1051510).
- staging: rtl8712: Fix possible buffer overrun (bsc#1051510).
- staging: rtl8723bs: Add missing return for
  cfg80211_rtw_get_station (bsc#1051510).
- commit 46ab97b
* Mon Dec 10 2018 tiwai@suse.de
- net: bgmac: Fix endian access in bgmac_dma_tx_ring_free()
  (bsc#1051510).
- commit 2e678f9
* Mon Dec 10 2018 tiwai@suse.de
- integrity/security: fix digsig.c build error with header file
  (bsc#1051510).
- commit 1164ce0
* Mon Dec 10 2018 tiwai@suse.de
- test_hexdump: use memcpy instead of strncpy (bsc#1051510).
- commit b9eb9f7
* Mon Dec 10 2018 tiwai@suse.de
- lib/ubsan.c: don't mark __ubsan_handle_builtin_unreachable as
  noreturn (bsc#1051510).
- lib/raid6: Fix arm64 test build (bsc#1051510).
- commit 3efaede
* Mon Dec 10 2018 tiwai@suse.de
- ieee802154: fakelb: switch from BUG_ON() to WARN_ON() on problem
  (bsc#1051510).
- ieee802154: at86rf230: use __func__ macro for debug messages
  (bsc#1051510).
- ieee802154: at86rf230: switch from BUG_ON() to WARN_ON()
  on problem (bsc#1051510).
- ieee802154: 6lowpan: set IFLA_LINK (bsc#1051510).
- commit 150624b
* Mon Dec 10 2018 tiwai@suse.de
- Revert "PCI/ASPM: Do not initialize link state when
  aspm_disabled is set" (bsc#1051510).
- commit 54b5481
* Mon Dec 10 2018 tiwai@suse.de
- Input: xpad - quirk all PDP Xbox One gamepads (bsc#1051510).
- Input: synaptics - add PNP ID for ThinkPad P50 to SMBus
  (bsc#1051510).
- Input: elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15ARR
  (bsc#1051510).
- Input: elan_i2c - add support for ELAN0621 touchpad
  (bsc#1051510).
- Input: hyper-v - fix wakeup from suspend-to-idle (bsc#1051510).
- Input: cros_ec_keyb - fix button/switch capability reports
  (bsc#1051510).
- Input: elan_i2c - add ELAN0620 to the ACPI table (bsc#1051510).
- Input: matrix_keypad - check for errors from of_get_named_gpio()
  (bsc#1051510).
- commit d326384
* Mon Dec 10 2018 tiwai@suse.de
- ALSA: trident: Suppress gcc string warning (bsc#1051510).
- commit 416d408
* Mon Dec 10 2018 tiwai@suse.de
- Revert wlcore patch to follow stable tree develpment
- blacklist.conf:
- Delete
  patches.drivers/wlcore-Add-missing-PM-call-for-wlcore_cmd_wait_for_e.patch.
- commit 3549f81
* Mon Dec 10 2018 nsaenzjulienne@suse.de
- ethernet: fman: fix wrong of_node_put() in probe function
  (bsc#1119017).
- commit 446ab4d
* Mon Dec 10 2018 mbenes@suse.cz
- objtool: Fix segfault in .cold detection with
  - ffunction-sections (bsc#1058115).
- commit ea0ae7a
* Mon Dec 10 2018 mbenes@suse.cz
- objtool: Fix double-free in .cold detection error path
  (bsc#1058115).
- commit d60fe8f
* Mon Dec 10 2018 jthumshirn@suse.de
- libnvdimm, pfn: Pad pfn namespaces relative to other regions
  (bsc#1118962).
- commit 0150ece
* Mon Dec 10 2018 mbenes@suse.cz
- objtool: Fix GCC 8 cold subfunction detection for aliased
  functions (bsc#1058115).
- commit e0da98b
* Mon Dec 10 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/net-ibmvnic-Fix-RTNL-deadlock-during-device-reset.patch.
- Refresh
  patches.drivers/scsi-lpfc-Correct-invalid-EQ-doorbell-write-on-if_ty.patch.
- Refresh
  patches.drivers/scsi-lpfc-Correct-irq-handling-via-locks-when-taking.patch.
- Refresh
  patches.drivers/scsi-lpfc-Correct-race-with-abort-on-completion-path.patch.
- Refresh
  patches.drivers/scsi-lpfc-Correct-soft-lockup-when-running-mds-diagn.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-GFT_ID-and-PRLI-logic-for-RSCN.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-errors-in-log-messages.patch.
- Refresh
  patches.drivers/scsi-lpfc-Raise-nvme-defaults-to-support-a-larger-io.patch.
- Refresh
  patches.drivers/scsi-lpfc-Remove-set-but-not-used-variable-sgl_size.patch.
- Refresh
  patches.drivers/scsi-lpfc-Synchronize-access-to-remoteport-via-rport.patch.
- Refresh
  patches.drivers/scsi-lpfc-add-support-to-retrieve-firmware-logs.patch.
- Refresh
  patches.drivers/scsi-lpfc-raise-sg-count-for-nvme-to-use-available-s.patch.
- Refresh
  patches.drivers/scsi-lpfc-reduce-locking-when-updating-statistics.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.7.patch.
- commit 43950be
* Mon Dec 10 2018 mgorman@suse.de
- mm/vmstat.c: fix NUMA statistics updates (git fixes).
- commit 09a6612
* Sun Dec  9 2018 mwilck@suse.com
- scsi: lpfc: fix block guard enablement on SLI3 adapters
  (bsc#1079935).
- commit 236bf95
* Sun Dec  9 2018 bp@suse.de
- x86/MCE/AMD, EDAC/mce_amd: Add new error descriptions for some
  SMCA bank types (bsc#1128415).
- commit b1869fe
* Sun Dec  9 2018 bp@suse.de
- x86/MCE/AMD, EDAC/mce_amd: Add new McaTypes for CS, PSP,
  and SMU units (bsc#1128415).
- commit 805b84e
* Sun Dec  9 2018 bp@suse.de
- x86/MCE/AMD, EDAC/mce_amd: Add new MP5, NBIO, and PCIE SMCA
  bank types (bsc#1128415).
- commit 14a6d42
* Sun Dec  9 2018 bp@suse.de
- x86/mce: Handle varying MCA bank counts (bsc#1128415).
- commit e5eb953
* Sat Dec  8 2018 bp@suse.de
- crypto: ccp - Add DOWNLOAD_FIRMWARE SEV command (fate#325981).
- crypto: ccp - Add GET_ID SEV command (fate#325981).
- crypto: ccp - Add psp enabled message when initialization
  succeeds (fate#325981).
- crypto: ccp - Add support for new CCP/PSP device ID
  (fate#325981).
- crypto: ccp - Allow SEV firmware to be chosen based on Family
  and Model (fate#325981).
- crypto: ccp - Fix static checker warning (fate#325981).
- crypto: ccp - Remove unused #defines (fate#325981).
- crypto: ccp - Support register differences between PSP devices
  (fate#325981).
- firmware: add firmware_request_nowarn() - load firmware without
  warnings (fate#325981).
- Update
  patches.drivers/crypto-ccp-add-timeout-support-in-the-sev-command.patch
  (fate#325981).
- commit 3812d91
* Sat Dec  8 2018 tiwai@suse.de
- Update config files: update forgotten armv7l configs, too
- commit b075a26
* Sat Dec  8 2018 msuchanek@suse.de
- Include modules.fips in kernel-binary as well as kernel-binary-base
  (FATE#323247).
- commit e42315d
* Fri Dec  7 2018 mbrugger@suse.com
- mmc: dw_mmc-bluefield: Add driver extension (bsc#1118752).
- Update config files.
- supported.conf: whitelist bluefield eMMC driver
- commit 57adc01
* Fri Dec  7 2018 jack@suse.cz
- userfaultfd: remove uffd flags from vma->vm_flags if
  UFFD_EVENT_FORK fails (bsc#1118809).
- commit 9f69851
* Fri Dec  7 2018 mbenes@suse.cz
- objtool: Detect RIP-relative switch table references, part 2
  (bsc#1058115).
- commit 7b81f06
* Fri Dec  7 2018 mbenes@suse.cz
- objtool: Detect RIP-relative switch table references
  (bsc#1058115).
- commit 5107b1b
* Fri Dec  7 2018 vbabka@suse.cz
- userfaultfd: shmem: UFFDIO_COPY: set the page dirty if VM_WRITE
  is not set (CVE-2018-18397, bsc#1117656).
- userfaultfd: shmem: add i_size checks (CVE-2018-18397,
  bsc#1117656).
- userfaultfd: shmem/hugetlbfs: only allow to register VM_MAYWRITE
  vmas (CVE-2018-18397, bsc#1117656).
- userfaultfd: shmem: allocate anonymous memory for MAP_PRIVATE
  shmem (CVE-2018-18397, bsc#1117656).
- userfaultfd: use ENOENT instead of EFAULT if the atomic copy
  user fails (CVE-2018-18397, bsc#1117656).
- userfaultfd: mcopy_atomic: introduce mfill_atomic_pte helper
  (CVE-2018-18397, bsc#1117656).
- commit a2c856b
* Fri Dec  7 2018 mbenes@suse.cz
- objtool: Support GCC 8 switch tables (bsc#1058115).
- commit e8d97c7
* Fri Dec  7 2018 mbenes@suse.cz
- objtool: Support GCC 8's cold subfunctions (bsc#1058115).
- commit 7456771
* Fri Dec  7 2018 jack@suse.cz
- blacklist.conf: Blacklist f2fs
- commit 5e683ec
* Fri Dec  7 2018 mbenes@suse.cz
- objtool: Fix "noreturn" detection for recursive sibling calls
  (bsc#1058115).
- commit 984dd5f
* Fri Dec  7 2018 mbenes@suse.cz
- objtool: Fix another switch table detection issue (bsc#1058115).
- commit 6353778
* Fri Dec  7 2018 mbrugger@suse.com
- mmc: dw_mmc-k3: add sd support for hi3660 (bsc#1118752).
- commit 00455a1
* Fri Dec  7 2018 jack@suse.cz
- ext2: fix potential use after free (bsc#1118775).
- commit 3d51c42
* Fri Dec  7 2018 jack@suse.cz
- udf: Allow mounting volumes with incorrect identification
  strings (bsc#1118774).
- commit 5de280f
* Fri Dec  7 2018 jack@suse.cz
- exportfs: fix 'passing zero to ERR_PTR()' warning (bsc#1118773).
- commit 183b4e1
* Fri Dec  7 2018 mbenes@suse.cz
- x86/decoder: Fix and update the opcodes map (bsc#1058115).
- commit 8874a84
* Fri Dec  7 2018 jack@suse.cz
- blacklist.conf: Blacklist c4b7d1ba7d26
- commit 6ea903d
* Fri Dec  7 2018 jack@suse.cz
- gfs2: Put bitmap buffers in put_super (bsc#1118772).
- commit 51cd91c
* Fri Dec  7 2018 jack@suse.cz
- blacklist.conf: Blacklist 9f2df09a33aa
- commit d63c0a3
* Fri Dec  7 2018 jack@suse.cz
- v9fs_dir_readdir: fix double-free on p9stat_read error
  (bsc#1118771).
- commit 36a4d0d
* Fri Dec  7 2018 jack@suse.cz
- gfs2: Don't leave s_fs_info pointing to freed memory in init_sbd
  (bsc#1118769).
- commit b2b431d
* Fri Dec  7 2018 jack@suse.cz
- gfs2_meta: ->mount() can get NULL dev_name (bsc#1118768).
- commit 6afc912
* Fri Dec  7 2018 jack@suse.cz
- jffs2: free jffs2_sb_info through jffs2_kill_sb() (bsc#1118767).
- commit fbcf7c1
* Fri Dec  7 2018 jack@suse.cz
- blacklist.conf: Blacklist f0a7d1883d9f
- commit 1ed7bf5
* Fri Dec  7 2018 jack@suse.cz
- namei: allow restricted O_CREAT of FIFOs and regular files
  (bsc#1118766).
- commit 169572d
* Fri Dec  7 2018 jack@suse.cz
- fs: fix lost error code in dio_complete (bsc#1118762).
- commit 6aed8a5
* Fri Dec  7 2018 jack@suse.cz
- userfaultfd: clear the vma->vm_userfaultfd_ctx if
  UFFD_EVENT_FORK fails (bsc#1118761).
- commit d968347
* Fri Dec  7 2018 jack@suse.cz
- mm: cleancache: fix corruption on missed inode invalidation
  (bsc#1117186 CVE-2018-16862).
- commit f2fe539
* Fri Dec  7 2018 jack@suse.cz
- ext4: avoid possible double brelse() in add_new_gdb() on error
  path (bsc#1118760).
- commit d45f182
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton
  Z4860G/Z6860G (bsc#1051510).
- commit 36b2bc7
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4660G
  (bsc#1051510).
- commit 9209bc5
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: hda/realtek - Add support for Acer Aspire C24-860 headset
  mic (bsc#1051510).
- commit 9222f53
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: hda/realtek: ALC286 mic and headset-mode fixups for Acer
  Aspire U27-880 (bsc#1051510).
- commit 2af8124
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: hda/realtek - Fix speaker output regression on Thinkpad
  T570 (bsc#1051510).
- commit 57bcdfc
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: pcm: Fix interval evaluation with openmin/max
  (bsc#1051510).
- commit af04472
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: hda: Add support for AMD Stoney Ridge (bsc#1051510).
- commit 10368dc
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: usb-audio: Add SMSL D1 to quirks for native DSD support
  (bsc#1051510).
- commit b3172a5
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: pcm: Fix starvation on down_write_nonblock()
  (bsc#1051510).
- commit 2464577
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: usb-audio: Add support for Encore mDSD USB DAC
  (bsc#1051510).
- commit f9b9013
* Fri Dec  7 2018 tiwai@suse.de
- ALSA: pcm: Call snd_pcm_unlink() conditionally at closing
  (bsc#1051510).
- commit 1bcdb7f
* Fri Dec  7 2018 tiwai@suse.de
- Move USB-audio UAF fix patch to sorted section
- commit 223ad04
* Thu Dec  6 2018 tiwai@suse.de
- crypto: user - fix leaking uninitialized memory to userspace
  (CVE-2018-19854,bsc#1118428).
- commit d1a5811
* Thu Dec  6 2018 msuchanek@suse.de
- KVM: PPC: Book3S PR: Enable use on POWER9 inside HPT-mode guests
  (bsc#1118484).
- commit 30072d1
* Thu Dec  6 2018 tiwai@suse.de
- Move dell_rbu fix to sorted section (bsc#1087978).
- commit cbdb29d
* Wed Dec  5 2018 tiwai@suse.de
- usb: xhci: Prevent bus suspend if a port connect change or
  polling state is detected (bsc#1051510).
- usb: xhci: fix uninitialized completion when USB3 port got
  wrong status (bsc#1051510).
- commit 9ec64cd
* Wed Dec  5 2018 tiwai@suse.de
- termios, tty/tty_baudrate.c: fix buffer overrun (bsc#1051510).
- commit b668b0f
* Wed Dec  5 2018 tiwai@suse.de
- rtc: hctosys: Add missing range error reporting (bsc#1051510).
- commit 4bb0c35
* Wed Dec  5 2018 tiwai@suse.de
- tmpfs: make lseek(SEEK_DATA/SEK_HOLE) return ENXIO with a
  negative offset (bsc#1051510).
- commit a7d3616
* Wed Dec  5 2018 tiwai@suse.de
- efi: Move some sysfs files to be read-only by root
  (bsc#1051510).
- commit 7977ec7
* Wed Dec  5 2018 mbenes@suse.cz
- blacklist.conf: Blacklist objtool inat.h sync fix
  Not needed. We do not have 32d0b95300db03c2b23b2ea2c94769a4a138e79d.
- commit e3e06b4
* Wed Dec  5 2018 pmladek@suse.com
- panic: avoid deadlocks in re-entrant console drivers
  (bsc#1088386).
- commit a547974
* Tue Dec  4 2018 msuchanek@suse.de
- Refresh patches.drivers/net-ibmvnic-Fix-RTNL-deadlock-during-device-reset.patch.
- commit 13326cf
* Tue Dec  4 2018 jroedel@suse.de
- blacklist.conf: Blacklist MAINTAINERS file
- commit 9c408b6
* Tue Dec  4 2018 lhenriques@suse.com
- libceph: fall back to sendmsg for slab pages (bsc#1118316).
- commit 5c17df1
* Tue Dec  4 2018 jslaby@suse.cz
- blacklist.conf: add one mlx5 entry
- commit 23e07aa
* Tue Dec  4 2018 jslaby@suse.cz
- Delete
  patches.suse/net-mlx5e-Set-vlan-masks-for-all-offloaded-TC-rules.patch.
  The patch causes a regression, see upstream commit d3a80bb5a3ea. But
  we cannot apply the commit as we are missing whole match_level logic
  in the driver yet.
- commit 892558d
* Tue Dec  4 2018 jgross@suse.com
- xen/x86: add diagnostic printout to xen_mc_flush() in case of
  error (bnc#1116183).
- commit a950cb1
* Mon Dec  3 2018 tiwai@suse.de
- ALSA: usb-audio: Fix UAF decrement if card has no live
  interfaces in card.c (CVE-2018-19824,bsc#1118152).
- commit 9e1724a
* Mon Dec  3 2018 bp@suse.de
- x86/MCE/AMD: Fix the thresholding machinery initialization order
  (bsc#1114279).
- blacklist.conf: one amd64_edac commit for client parts
- kvm: svm: Ensure an IBPB on all affected CPUs when freeing a
  vmcb (bsc#1114279).
- EDAC, skx_edac: Fix logical channel intermediate decoding
  (bsc#1114279).
- EDAC, {i7core,sb,skx}_edac: Fix uncorrected error counting
  (bsc#1114279).
- commit ccae0b6
* Mon Dec  3 2018 tiwai@suse.de
- Really drop the disabled DRM patches
  Some DRM patches have been disabled due to regressions, and they have no
  chance for revive on SLE15-SP0, at least.  So better to drop them for
  avoiding confusion.  No code change in the expanded tree by this.
- commit fd2445a
* Mon Dec  3 2018 fdmanana@suse.com
- Btrfs: send, fix infinite loop due to directory rename
  dependencies (bsc#1118138).
- commit 3add617
* Mon Dec  3 2018 tiwai@suse.de
- Delete patches.drm/drm-dp_mst-Skip-validating-ports-during-destruction-.patch (bsc#1051510)
  The commit was reverted in the upstream.  Put both in the blacklist now.
- commit 9ee57e7
* Mon Dec  3 2018 jthumshirn@suse.de
- Refresh
  patches.fixes/dax-remove-VM_MIXEDMAP-for-fsdax-and-device-dax.patch.
  Fixed missing hunk (bsc#1118102).
- commit 478866a
* Mon Dec  3 2018 msuchanek@suse.de
- net/ibmvnic: Fix RTNL deadlock during device reset
  (bnc#1115431).
- commit 87ebdb1
* Mon Dec  3 2018 fdmanana@suse.com
- Btrfs: fix cur_offset in the error case for nocow (bsc#1118140).
- commit 3a69a03
* Mon Dec  3 2018 fdmanana@suse.com
- Btrfs: fix assertion on fsync of regular file when using
  no-holes feature (bsc#1118137).
- commit 823bf85
* Mon Dec  3 2018 fdmanana@suse.com
- Btrfs: fix assertion failure during fsync in no-holes mode
  (bsc#1118136).
- commit 8293c74
* Mon Dec  3 2018 jthumshirn@suse.de
- nvme: Free ctrl device name on init failure (FATE#323952,
  FATE#322506).
- commit 96184ea
* Mon Dec  3 2018 bp@suse.de
- x86/speculation: Support Enhanced IBRS on future CPUs (fate#326564).
- commit 4c67d46
* Mon Dec  3 2018 jroedel@suse.de
- KVM: VMX: re-add ple_gap module parameter (bsc#1106240).
- commit 1a2fbf9
* Mon Dec  3 2018 jroedel@suse.de
- PCI: imx6: Fix link training status detection in link up check
  (bsc#1109806).
- KVM: x86: Fix kernel info-leak in KVM_HC_CLOCK_PAIRING hypercall
  (bsc#1106240).
- commit 098af81
* Mon Dec  3 2018 neilb@suse.com
- fscache: fix race between enablement and dropping of object
  (bsc#1107385).
- commit a260cc5
* Sat Dec  1 2018 tiwai@suse.de
- blacklist.conf: Add a can driver entry that breaks kABI
- commit 017d064
* Sat Dec  1 2018 tiwai@suse.de
- include/linux/pfn_t.h: force '~' to be parsed as an unary
  operator (bsc#1051510).
- commit fb714c8
* Sat Dec  1 2018 tiwai@suse.de
- staging: rtl8723bs: Fix the return value in case of error in
  'rtw_wx_read32()' (bsc#1051510).
- iwlwifi: mvm: fix regulatory domain update when the firmware
  starts (bsc#1051510).
- commit db7a366
* Sat Dec  1 2018 tiwai@suse.de
- staging: vchiq_arm: fix compat VCHIQ_IOC_AWAIT_COMPLETION
  (bsc#1051510).
- commit 4a2214c
* Sat Dec  1 2018 tiwai@suse.de
- iio:st_magn: Fix enable device after trigger (bsc#1051510).
- commit 9634d68
* Sat Dec  1 2018 tiwai@suse.de
- tty: wipe buffer if not echoing data (bsc#1051510).
- tty: wipe buffer (bsc#1051510).
- commit 9898d59
* Sat Dec  1 2018 tiwai@suse.de
- drm/meson: add support for 1080p25 mode (bsc#1051510).
- drm/meson: Fix OOB memory accesses in meson_viu_set_osd_lut()
  (bsc#1051510).
- drm/meson: Enable fast_io in meson_dw_hdmi_regmap_config
  (bsc#1051510).
- drm/dp_mst: Skip validating ports during destruction, just ref
  (bsc#1051510).
- drm/ast: Fix incorrect free on ioregs (bsc#1051510).
- drm/ast: fixed cursor may disappear sometimes (bsc#1051510).
- commit e1e4948
* Sat Dec  1 2018 tiwai@suse.de
- crypto: simd - correctly take reqsize of wrapped skcipher into
  account (bsc#1051510).
- commit d816314
* Sat Dec  1 2018 tiwai@suse.de
- can: rx-offload: introduce can_rx_offload_get_echo_skb()
  and can_rx_offload_queue_sorted() functions (bsc#1051510).
- can: dev: __can_get_echo_skb(): print error message, if trying
  to echo non existing skb (bsc#1051510).
- can: dev: __can_get_echo_skb(): Don't crash the kernel if
  can_priv::echo_skb is accessed out of bounds (bsc#1051510).
- can: dev: __can_get_echo_skb(): replace struct can_frame by
  canfd_frame to access frame length (bsc#1051510).
- can: dev: can_get_echo_skb(): factor out non sending code to
  __can_get_echo_skb() (bsc#1051510).
- can: hi311x: Use level-triggered interrupt (bsc#1051510).
- can: raw: check for CAN FD capable netdev in raw_sendmsg()
  (bsc#1051510).
- commit 4787d2f
* Sat Dec  1 2018 tiwai@suse.de
- usb: gadget: u_ether: fix unsafe list iteration (bsc#1051510).
- USB: omap_udc: fix rejection of out transfers when DMA is used
  (bsc#1051510).
- Revert "usb: dwc3: gadget: skip Set/Clear Halt when invalid"
  (bsc#1051510).
- usb: core: Fix hub port connection events lost (bsc#1051510).
- usb: dwc3: core: Clean up ULPI device (bsc#1051510).
- usb: xhci: fix timeout for transition from RExit to U0
  (bsc#1051510).
- xhci: Add check for invalid byte size error when UAS devices
  are connected (bsc#1051510).
- commit a583c32
* Sat Dec  1 2018 tiwai@suse.de
- brcmfmac: fix reporting support for 160 MHz channels
  (bsc#1051510).
- commit 7d8455c
* Sat Dec  1 2018 tiwai@suse.de
- ACPI/IORT: Fix iort_get_platform_device_domain() uninitialized
  pointer value (bsc#1051510).
- commit cf6b9f3
* Sat Dec  1 2018 tiwai@suse.de
- ALSA: oss: Use kvzalloc() for local buffer allocations
  (bsc#1051510).
- commit 4a5203a
* Sat Dec  1 2018 tiwai@suse.de
- Input: synaptics - avoid using uninitialized variable when
  probing (bsc#1051510).
- Input: xpad - add support for Xbox1 PDP Camo series gamepad
  (bsc#1051510).
- Input: xpad - avoid using __set_bit() for capabilities
  (bsc#1051510).
- Input: xpad - fix some coding style issues (bsc#1051510).
- Input: xpad - add PDP device id 0x02a4 (bsc#1051510).
- commit 50187b9
* Fri Nov 30 2018 tiwai@suse.de
- qmi_wwan: Support dynamic config on Quectel EP06 (bsc#1051510).
- commit e3c5218
* Fri Nov 30 2018 tiwai@suse.de
- qmi_wwan: apply SET_DTR quirk to the SIMCOM shared device ID
  (bsc#1051510).
- Refresh patches.drivers/qmi_wwan-add-support-for-Quectel-EG91.
- commit 988931a
* Fri Nov 30 2018 tiwai@suse.de
- net: qmi_wwan: add Wistron Neweb D19Q1 (bsc#1051510).
- commit f74e3c9
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: usb-audio: Add vendor and product name for Dell WD19 Dock
  (bsc#1051510).
- commit 824cc71
* Fri Nov 30 2018 tiwai@suse.de
- ASoC: sun8i-codec: fix crash on module removal (bsc#1051510).
- commit 9f6d6c5
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - Support ALC300 (bsc#1051510).
- commit 74cbb22
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - Add auto-mute quirk for HP Spectre x360
  laptop (bsc#1051510).
- commit 4ebe796
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - fix the pop noise on headphone for lenovo
  laptops (bsc#1051510).
- commit cf3e918
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: control: Fix race between adding and removing a user
  element (bsc#1051510).
- commit 5859ab7
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: sparc: Fix invalid snd_free_pages() at error path
  (bsc#1051510).
- commit 1f787cb
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: wss: Fix invalid snd_free_pages() at error path
  (bsc#1051510).
- commit 0073c9a
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - fix headset mic detection for MSI MS-B171
  (bsc#1051510).
- commit 7600c31
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda: Add ASRock N68C-S UCC the power_save blacklist
  (bsc#1051510).
- commit cff4e83
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: ac97: Fix incorrect bit shift at AC97-SPSA control write
  (bsc#1051510).
- commit d4f8e03
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - Fix HP Headset Mic can't record
  (bsc#1051510).
- commit 2ff6b4d
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - Simplify Dell XPS13 GPIO handling
  (bsc#1051510).
- commit 0c92109
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - Add GPIO data update helper (bsc#1051510).
- commit 9347d34
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - Manage GPIO bits commonly (bsc#1051510).
- commit d536d4a
* Fri Nov 30 2018 tiwai@suse.de
- ALSA: hda/realtek - Allow skipping spec->init_amp detection
  (bsc#1051510).
- commit 2691b89
* Fri Nov 30 2018 tiwai@suse.de
- ASoC: intel: cht_bsw_max98090_ti: Add quirk for boards using
  pmc_plt_clk_0 (bsc#1051510).
- commit 55c95c9
* Fri Nov 30 2018 tiwai@suse.de
- ASoC: Intel: cht_bsw_max98090: add support for Baytrail
  (bsc#1051510).
- Refresh
  patches.drivers/ASoC-Intel-cht_bsw_max98090-remove-useless-code-alig.
- commit 24015e1
* Fri Nov 30 2018 vliaskovitis@suse.com
- xen/blkfront: avoid NULL blkfront_info dereference on device
  removal (bsc#1111062).
- commit f67d52b
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/perf: Update raw-event code encoding comment for power8
  (bsc#1065729).
- commit 389a6ff
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/mm: Fix typo in comments (bsc#1065729).
- commit 386cf53
* Thu Nov 29 2018 msuchanek@suse.de
- Revert "powerpc/64: Fix checksum folding in csum_add()"
  (bsc#1065729).
- commit 108fe12
* Thu Nov 29 2018 msuchanek@suse.de
- KABI: powerpc: Revert npu callback signature change
  (bsc#1055120).
- commit a32ccad
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/powernv/pci: Work around races in PCI bridge enabling
  (bsc#1055120).
- commit 3be0d95
* Thu Nov 29 2018 msuchanek@suse.de
- blacklist.conf: blacklist fix of timer rewrite
- commit 978ea6b
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/boot: Fix opal console in boot wrapper (bsc#1065729).
- commit 8879e99
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/powernv: Fix opal_event_shutdown() called with
  interrupts disabled (bsc#1065729).
- commit 1cf9bbd
* Thu Nov 29 2018 msuchanek@suse.de
- Revert "blacklist.conf: blacklist inapplicable commits"
  This reverts commit 88bd1b2b53990d5518b819968445522fb1392bee.
  We only build with VIRT_CPU_ACCOUNTING_NATIVE on s390
- commit 6663d9b
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/pseries: Fix how we iterate over the DTL entries
  (bsc#1065729).
- powerpc/pseries: Fix DTL buffer registration (bsc#1065729).
- commit 7308f80
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/powernv: Fix concurrency issue with npu->mmio_atsd_usage
  (bsc#1055120).
- powerpc/powernv/npu: Prevent overwriting of
  pnv_npu2_init_contex() callback parameters (bsc#1055120).
- powerpc/powernv/npu: Add lock to prevent race in concurrent
  context init/destroy (bsc#1055120).
- Refresh patches.arch/powerpc-powernv-npu-Do-a-PID-GPU-TLB-flush-when-inva.patch
- powerpc/npu-dma.c: Fix crash after __mmu_notifier_register
  failure (bsc#1055120).
- powerpc/powernv/npu: Fix deadlock in mmio_invalidate()
  (bsc#1055120).
- powerpc/powernv/npu: Don't explicitly flush nmmu tlb
  (bsc#1055120).
- powerpc/powernv/npu: Use flush_all_mm() instead of
  flush_tlb_mm() (bsc#1055120).
- commit 9f05f8c
* Thu Nov 29 2018 jack@suse.cz
- fs: Make extension of struct super_block transparent
  (bsc#1117822).
- commit 5d62a88
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/64s/hash: Do not use PPC_INVALIDATE_ERAT on CPUs before
  POWER9 (bsc#1065729).
- commit 77a1107
* Thu Nov 29 2018 jack@suse.cz
- blacklist.conf: Blacklist f1782c9bc547
- commit 596e059
* Thu Nov 29 2018 tiwai@suse.de
- Update config files: Fix ppc64le/vanilla config
- commit 6b794fe
* Thu Nov 29 2018 jack@suse.cz
- blacklist.conf: Blacklist 25bbe21bf427
- commit c785e30
* Thu Nov 29 2018 msuchanek@suse.de
- blacklist.conf: blacklist inapplicable commits
- commit 88bd1b2
* Thu Nov 29 2018 msuchanek@suse.de
- blacklist.conf: blacklist vermagic update.
- commit e63e2fc
* Thu Nov 29 2018 jslaby@suse.cz
- net: ipv4: don't let PMTU updates increase route MTU
  (git-fixes).
- commit e14d9f4
* Thu Nov 29 2018 jack@suse.cz
- blacklist.conf: Blacklist 53692ec074d0
- commit ae3ddcf
* Thu Nov 29 2018 msuchanek@suse.de
- powerpc/powernv: Don't select the cpufreq governors (bsc#1065729).
- Update config files to match other architectures.
- commit da7be07
* Thu Nov 29 2018 jack@suse.cz
- blacklist.conf: Blacklist ecaaf408478b
- commit d7afd37
* Thu Nov 29 2018 jack@suse.cz
- fsnotify: Fix busy inodes during unmount (bsc#1117822).
- commit 955d702
* Thu Nov 29 2018 jack@suse.cz
- ocfs2: free up write context when direct IO failed
  (bsc#1117821).
- commit ad2eade
* Thu Nov 29 2018 jack@suse.cz
- mount: Prevent MNT_DETACH from disconnecting locked mounts
  (bsc#1117820).
- commit c37e013
* Thu Nov 29 2018 jack@suse.cz
- mount: Don't allow copying MNT_UNBINDABLE|MNT_LOCKED mounts
  (bsc#1117819).
- commit 287394f
* Thu Nov 29 2018 jack@suse.cz
- mount: Retest MNT_LOCKED in do_umount (bsc#1117818).
- commit 9d5b9fb
* Thu Nov 29 2018 jack@suse.cz
- ocfs2: fix a misuse a of brelse after failing
  ocfs2_check_dir_entry (bsc#1117817).
- commit ca46bd5
* Thu Nov 29 2018 jack@suse.cz
- blacklist.conf: 1ccbeeb888ac
- commit b4ae641
* Thu Nov 29 2018 jack@suse.cz
- ocfs2: fix locking for res->tracking and dlm->tracking_list
  (bsc#1117816).
- commit 9bd98e3
* Thu Nov 29 2018 jack@suse.cz
- blacklist.conf: Blacklist a725356b6659
- commit 95e5733
* Thu Nov 29 2018 jack@suse.cz
- ocfs2: fix ocfs2 read block panic (bsc#1117815).
- commit 858b7f0
* Thu Nov 29 2018 jslaby@suse.cz
- flow_dissector: do not dissect l4 ports for fragments
  (networking-stable-18_11_21).
- ip_tunnel: don't force DF when MTU is locked
  (networking-stable-18_11_21).
- ipv4: lock mtu in fnhe when received PMTU <
  net.ipv4.route.min_pmtu (networking-stable-18_11_21).
- ipv6: Fix PMTU updates for UDP/raw sockets in presence of VRF
  (networking-stable-18_11_21).
- mlxsw: spectrum: Fix IP2ME CPU policer configuration
  (networking-stable-18_11_21).
- net: bcmgenet: protect stop from timeout
  (networking-stable-18_11_21).
- net-gro: reset skb->pkt_type in napi_reuse_skb()
  (networking-stable-18_11_21).
- net/mlx5e: Fix selftest for small MTUs
  (networking-stable-18_11_21).
- net: phy: mdio-gpio: Fix working over slow can_sleep GPIOs
  (networking-stable-18_11_21).
- net: smsc95xx: Fix MTU range (networking-stable-18_11_21).
- net: systemport: Protect stop from timeout
  (networking-stable-18_11_21).
- sctp: fix strchange_flags name for Stream Change Event
  (networking-stable-18_11_21).
- sctp: not allow to set asoc prsctp_enable by sockopt
  (networking-stable-18_11_21).
- sctp: not increase stream's incnt before sending addstrm_in
  request (networking-stable-18_11_21).
- tg3: Add PHY reset for 5717/5719/5720 in change ring and flow
  control paths (networking-stable-18_11_21).
- tipc: don't assume linear buffer when reading ancillary data
  (networking-stable-18_11_21).
- tuntap: fix multiqueue rx (networking-stable-18_11_21).
- kABI: protect struct fib_nh_exception (kabi).
- kABI: protect struct rtable (kabi).
- Refresh
  patches.suse/ipv4-fix-fnhe-usage-by-non-cached-routes.patch.
- commit fd26935
* Thu Nov 29 2018 jack@suse.cz
- ocfs2: subsystem.su_mutex is required while accessing the
  item->ci_parent (bsc#1117808).
- commit f6093fc
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix buffer leak in __ext4_read_dirblock() on error path
  (bsc#1117807).
- commit ed4f7e0
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix buffer leak in ext4_xattr_move_to_block() on error
  path (bsc#1117806).
- commit b566650
* Thu Nov 29 2018 jack@suse.cz
- ext4: release bs.bh before re-using in ext4_xattr_block_find()
  (bsc#1117805).
- commit bea0c8a
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix possible leak of s_journal_flag_rwsem in error path
  (bsc#1117804).
- commit 963524a
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix possible leak of sbi->s_group_desc_leak in error path
  (bsc#1117803).
- commit cbfd876
* Thu Nov 29 2018 jack@suse.cz
- ext4: avoid buffer leak in ext4_orphan_add() after prior errors
  (bsc#1117802).
- commit 35e0007
* Thu Nov 29 2018 jack@suse.cz
- ext4: avoid buffer leak on shutdown in ext4_mark_iloc_dirty()
  (bsc#1117801).
- commit d392ba9
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix possible inode leak in the retry loop of
  ext4_resize_fs() (bsc#1117799).
- commit 5ae5e79
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix missing cleanup if ext4_alloc_flex_bg_array() fails
  while resizing (bsc#1117798).
- commit a780306
* Thu Nov 29 2018 jack@suse.cz
- ext4: add missing brelse() update_backups()'s error path
  (bsc#1117796).
- commit 371cf85
* Thu Nov 29 2018 jack@suse.cz
- ext4: add missing brelse() add_new_gdb_meta_bg()'s error path
  (bsc#1117795).
- commit 2f4d91f
* Thu Nov 29 2018 jack@suse.cz
- ext4: add missing brelse() in set_flexbg_block_bitmap()'s
  error path (bsc#1117794).
- commit eb98ade
* Thu Nov 29 2018 jack@suse.cz
- ext4: avoid potential extra brelse in
  setup_new_flex_group_blocks() (bsc#1117792).
- commit cb8da4a
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix use-after-free race in ext4_remount()'s error path
  (bsc#1117791).
- commit ca15955
* Thu Nov 29 2018 jack@suse.cz
- ext4: propagate error from dquot_initialize() in
  EXT4_IOC_FSSETXATTR (bsc#1117790).
- commit 3d6d857
* Thu Nov 29 2018 jack@suse.cz
- ext4: fix setattr project check in fssetxattr ioctl
  (bsc#1117789).
- commit a5cc193
* Thu Nov 29 2018 jack@suse.cz
- ext4: initialize retries variable in
  ext4_da_write_inline_data_begin() (bsc#1117788).
- commit fec1d63
* Thu Nov 29 2018 tiwai@suse.de
- Update config files.
- commit ca1d0a2
* Wed Nov 28 2018 msuchanek@suse.de
- blacklist.conf: blacklist unapplicable powerpc commits.
- commit 5c5ec19
* Wed Nov 28 2018 bp@suse.de
- nospec: Include <asm/barrier.h> dependency (bsc#1114279).
- Refresh
  patches.suse/17-nospec-allow-getting-setting-on-non-current-task.patch.
- commit 6ad7da7
* Wed Nov 28 2018 tiwai@suse.de
- clk: samsung: exynos5420: Enable PERIS clocks for suspend
  (bsc#1051510).
- ataflop: fix error handling during setup (bsc#1051510).
- ptp: fix Spectre v1 vulnerability (bsc#1051510).
- pxa168fb: prepare the clock (bsc#1051510).
- commit ae524af
* Wed Nov 28 2018 tiwai@suse.de
- hwmon: (ibmpowernv) Remove bogus __init annotations
  (bsc#1051510).
- commit 9ba3a4d
* Wed Nov 28 2018 tiwai@suse.de
- drm/edid: Add 6 bpc quirk for BOE panel (bsc#1051510).
- commit 2d713c3
* Wed Nov 28 2018 tiwai@suse.de
- ipmi: Fix timer race with module unload (bsc#1051510).
- commit c6b0329
* Wed Nov 28 2018 tiwai@suse.de
- configfs: replace strncpy with memcpy (bsc#1051510).
- commit a7464c8
* Wed Nov 28 2018 tiwai@suse.de
- kbuild: fix kernel/bounds.c 'W=1' warning (bsc#1051510).
- commit 9c501db
* Wed Nov 28 2018 tiwai@suse.de
- platform/x86: intel_telemetry: report debugfs failure
  (bsc#1051510).
- platform/x86: acerhdf: Add BIOS entry for Gateway LT31 v1.3307
  (bsc#1051510).
- commit 6273f32
* Wed Nov 28 2018 tiwai@suse.de
- ACPI / platform: Add SMB0001 HID to forbidden_id_list
  (bsc#1051510).
- ACPI / watchdog: Prefer iTCO_wdt always when WDAT table uses
  RTC SRAM (bsc#1051510).
- commit 6426c3c
* Wed Nov 28 2018 tiwai@suse.de
- usb: cdc-acm: add entry for Hiro (Conexant) modem (bsc#1051510).
- USB: misc: appledisplay: add 20" Apple Cinema Display
  (bsc#1051510).
- USB: quirks: Add no-lpm quirk for Raydium touchscreens
  (bsc#1051510).
- usb: quirks: Add delay-init quirk for Corsair K70 LUX RGB
  (bsc#1051510).
- commit c4726ed
* Wed Nov 28 2018 tbogendoerfer@suse.de
- net: ena: fix crash during failed resume from hibernation
  (bsc#1111696 bsc#1117561).
- commit 59142b4
* Wed Nov 28 2018 tbogendoerfer@suse.de
- Update config files.
  Enabled ENA (Amazon network driver) for arm64.
- commit e774ad6
* Wed Nov 28 2018 tbogendoerfer@suse.de
- net: ena: fix compilation error in xtensa architecture
  (bsc#1111696 bsc#1117561).
- net: ena: enable Low Latency Queues (bsc#1111696 bsc#1117561).
- net: ena: Fix Kconfig dependency on X86 (bsc#1111696
  bsc#1117561).
- net: ena: fix indentations in ena_defs for better readability
  (bsc#1111696 bsc#1117561).
- net: ena: update driver version to 2.0.1 (bsc#1111696
  bsc#1117561).
- net: ena: remove redundant parameter in ena_com_admin_init()
  (bsc#1111696 bsc#1117561).
- net: ena: change rx copybreak default to reduce kernel memory
  pressure (bsc#1111696 bsc#1117561).
- net: ena: limit refill Rx threshold to 256 to avoid latency
  issues (bsc#1111696 bsc#1117561).
- net: ena: explicit casting and initialization, and clearer
  error handling (bsc#1111696 bsc#1117561).
- net: ena: use CSUM_CHECKED device indication to report skb's
  checksum status (bsc#1111696 bsc#1117561).
- net: ena: add functions for handling Low Latency Queues in
  ena_netdev (bsc#1111696 bsc#1117561).
- net: ena: add functions for handling Low Latency Queues in
  ena_com (bsc#1111696 bsc#1117561).
- net: ena: introduce Low Latency Queues data structures according
  to ENA spec (bsc#1111696 bsc#1117561).
- net: ena: complete host info to match latest ENA spec
  (bsc#1111696 bsc#1117561).
- net: ena: minor performance improvement (bsc#1111696
  bsc#1117561).
- net: ena: fix auto casting to boolean (bsc#1111696 bsc#1117561).
- net: ena: fix NULL dereference due to untimely napi
  initialization (bsc#1111696 bsc#1117561).
- net: ena: fix rare bug when failed restart/resume is followed
  by driver removal (bsc#1111696 bsc#1117561).
- net: ena: fix warning in rmmod caused by double iounmap
  (bsc#1111696 bsc#1117561).
- net: ena: remove ndo_poll_controller (bsc#1111696 bsc#1117561).
- commit 75cf80b
* Tue Nov 27 2018 tiwai@suse.de
- hwmon: (w83795) temp4_type has writable permission
  (bsc#1051510).
- hwmon: (ina2xx) Fix current value calculation (bsc#1051510).
- hwmon: (raspberrypi) Fix initial notify (bsc#1051510).
- hwmon (ina2xx) Fix NULL id pointer in probe() (bsc#1051510).
- hwmon: (nct6775) Fix potential Spectre v1 (bsc#1051510).
- commit 00f652b
* Tue Nov 27 2018 jslaby@suse.cz
- net: bridge: remove ipv6 zero address check in mcast queries
  (git-fixes).
- commit c7547b7
* Tue Nov 27 2018 jdelvare@suse.de
- drm/ast: change resolution may cause screen blurred
  (boo#1112963).
- commit 87247be
* Tue Nov 27 2018 jdelvare@suse.de
- Rename and update patches.drm/0001-drm-ast-Remove-existing-framebuffers-before-loading-.patch
  Use the same name as in SLE12-SP3, add upstream reference and
  mention a second bug (bsc#1111174).
- commit 036f252
* Mon Nov 26 2018 msuchanek@suse.de
- Refresh upstreamed pkey patches.
- commit 94769d4
* Mon Nov 26 2018 msuchanek@suse.de
- powerpc/mm/keys: Move pte bits to correct headers (FATE#322447,
  bsc#1078248).
- commit 972269f
* Mon Nov 26 2018 tiwai@suse.de
- gpio: don't free unallocated ida on gpiochip_add_data_with_key()
  error path (bsc#1051510).
- clk: s2mps11: Add used attribute to s2mps11_dt_match
  (bsc#1051510).
- mfd: menelaus: Fix possible race condition and leak
  (bsc#1051510).
- commit 87b9a96
* Mon Nov 26 2018 tiwai@suse.de
- drm/i915: Write GPU relocs harder with gen3 (bsc#1051510).
- commit 2094252
* Mon Nov 26 2018 tiwai@suse.de
- soc: ti: QMSS: Fix usage of irq_set_affinity_hint (bsc#1051510).
- soc: fsl: qbman: qman: avoid allocating from non existing
  gen_pool (bsc#1051510).
- commit 318a29c
* Mon Nov 26 2018 tiwai@suse.de
- HID: uhid: forbid UHID_CREATE under KERNEL_DS or elevated
  privileges (bsc#1051510).
- commit bfec37b
* Mon Nov 26 2018 tiwai@suse.de
- iwlwifi: mvm: don't use SAR Geo if basic SAR is not used
  (bsc#1051510).
- iwlwifi: mvm: support sta_statistics() even on older firmware
  (bsc#1051510).
- brcmutil: really fix decoding channel info for 160 MHz bandwidth
  (bsc#1051510).
- commit 04cdc07
* Mon Nov 26 2018 tiwai@suse.de
- ALSA: hda/ca0132 - Call pci_iounmap() instead of iounmap()
  (bsc#1051510).
- commit 9d9ccd2
* Mon Nov 26 2018 tiwai@suse.de
- ata: Fix racy link clearance (bsc#1107866).
- commit 6a91770
* Mon Nov 26 2018 mwilck@suse.com
- target: fix buffer offset in core_scsi3_pri_read_full_status
  (bsc1117349).
- commit e2ae560
* Mon Nov 26 2018 msuchanek@suse.de
- ibmvnic: Update driver queues after change in ring size support
  (FATE#326521).
- net/ibmnvic: Fix deadlock problem in reset (FATE#326521).
- ibmvnic: fix accelerated VLAN handling (FATE#326521).
- net: ibm: fix return type of ndo_start_xmit function
  (FATE#326521).
- ibmvnic: remove ndo_poll_controller (FATE#326521).
- commit 7895e39
* Mon Nov 26 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-fix-index-in-release_rx_pools.patch
- commit b026761
* Mon Nov 26 2018 tzimmermann@suse.de
- mach64: fix image corruption due to reading accelerator registers (bsc#1113722)
- commit b3c9593
* Mon Nov 26 2018 tzimmermann@suse.de
- mach64: fix display corruption on big endian machines (bsc#1113722)
- commit 01b3304
* Mon Nov 26 2018 jroedel@suse.de
- iommu/vt-d: Use memunmap to free memremap (bsc#1106105).
- amd/iommu: Fix Guest Virtual APIC Log Tail Address Register
  (bsc#1106105).
- iommu/ipmmu-vmsa: Fix crash on early domain free (bsc#1106105).
- iommu/vt-d: Fix NULL pointer dereference in prq_event_thread()
  (bsc#1106105).
- commit 474cc93
* Fri Nov 23 2018 tiwai@suse.de
- xhci: Fix leaking USB3 shared_hcd at xhci removal (bsc#1051510).
- commit 6880c8a
* Fri Nov 23 2018 pmladek@suse.com
- tracing: Erase irqsoff trace with empty write (bsc#1117189).
- commit 591b34f
* Fri Nov 23 2018 pmladek@suse.com
- tracing: Apply trace_clock changes to instance max buffer
  (bsc#1117188).
- commit 93ce4e2
* Fri Nov 23 2018 pmladek@suse.com
- blacklist.conf: add b16503baa891 signal: send_sig_all no longer
  needs SEND_SIG_FORCED
- commit 0ff41be
* Fri Nov 23 2018 pmladek@suse.com
- ftrace: Remove incorrect setting of glob search field
  (bsc#1117184).
- commit 44507ac
* Fri Nov 23 2018 pmladek@suse.com
- ftrace: Fix kmemleak in unregister_ftrace_graph (bsc#1117181).
- commit 254d70b
* Fri Nov 23 2018 pmladek@suse.com
- ftrace: Fix memleak when unregistering dynamic ops when tracing
  disabled (bsc#1117174).
- commit 5a7d6af
* Fri Nov 23 2018 pmladek@suse.com
- ftrace: Fix debug preempt config name in
  stack_tracer_{en,dis}able (bsc#1117172).
- commit b37345d
* Fri Nov 23 2018 pmladek@suse.com
- printk: Fix panic caused by passing log_buf_len to command line
  (bsc#1117168).
- commit 98d9037
* Fri Nov 23 2018 tiwai@suse.de
- uio: Fix an Oops on load (bsc#1051510).
- can: rcar_can: Fix erroneous registration (bsc#1051510).
- floppy: fix race condition in __floppy_read_block_0()
  (bsc#1051510).
- pinctrl: meson: fix pinconf bias disable (bsc#1051510).
- tty: check name length in tty_find_polling_driver()
  (bsc#1051510).
- staging:iio:ad7606: fix voltage scales (bsc#1051510).
- uio: make symbol 'uio_class_registered' static (bsc#1051510).
- w1: omap-hdq: fix missing bus unregister at removal
  (bsc#1051510).
- power: supply: max8998-charger: Fix platform data retrieval
  (bsc#1051510).
- commit 8a307aa
* Fri Nov 23 2018 tiwai@suse.de
- libertas: don't set URB_ZERO_PACKET on IN USB transfer
  (bsc#1051510).
- commit 695f283
* Fri Nov 23 2018 tiwai@suse.de
- vhost/scsi: truncate T10 PI iov_iter to prot_bytes
  (bsc#1051510).
- vhost: Fix Spectre V1 vulnerability (bsc#1051510).
- commit 663338b
* Fri Nov 23 2018 tiwai@suse.de
- test_firmware: fix error return getting clobbered (bsc#1051510).
- commit ad74964
* Fri Nov 23 2018 tiwai@suse.de
- usb: dwc3: gadget: fix ISOC TRB type on unaligned transfers
  (bsc#1051510).
- usb: dwc3: gadget: Properly check last unaligned/zero chain TRB
  (bsc#1051510).
- commit 3ae49d6
* Fri Nov 23 2018 tiwai@suse.de
- clockevents/drivers/i8253: Add support for PIT shutdown quirk
  (bsc#1051510).
- commit 3276977
* Fri Nov 23 2018 tiwai@suse.de
- batman-adv: Expand merged fragment buffer for full packet
  (bsc#1051510).
- batman-adv: Use explicit tvlv padding for ELP packets
  (bsc#1051510).
- commit c3f27db
* Fri Nov 23 2018 tiwai@suse.de
- iio: ad5064: Fix regulator handling (bsc#1051510).
- iio: accel: adxl345: convert address field usage in
  iio_chan_spec (bsc#1051510).
- commit fcef7bd
* Thu Nov 22 2018 tiwai@suse.de
- tty: Don't return -EAGAIN in blocking read (bsc#1116040).
- commit b62d6c8
* Thu Nov 22 2018 tiwai@suse.de
- drm/i915/execlists: Force write serialisation into context
  image vs execution (bsc#1051510).
- drm/dp_mst: Check if primary mstb is null (bsc#1051510).
- drm/i915: Don't oops during modeset shutdown after lpe audio
  deinit (bsc#1051510).
- drm/i915: Mark pin flags as u64 (bsc#1051510).
- drm/i915/hdmi: Add HDMI 2.0 audio clock recovery N values
  (bsc#1051510).
- drm/i915: Large page offsets for pread/pwrite (bsc#1051510).
- drm/i915: Skip vcpi allocation for MSTB ports that are gone
  (bsc#1051510).
- drm/i915: Don't unset intel_connector->mst_port (bsc#1051510).
- drm/nouveau: Check backlight IDs are >= 0, not > 0
  (bsc#1051510).
- drm/omap: fix memory barrier bug in DMM driver (bsc#1051510).
- drm/amdgpu: add missing CHIP_HAINAN in
  amdgpu_ucode_get_load_type (bsc#1051510).
- drm/rockchip: Allow driver to be shutdown on reboot/kexec
  (bsc#1051510).
- commit bbb89cd
* Wed Nov 21 2018 msuchanek@suse.de
- powerpc/pseries/mobility: Extend start/stop topology update scope
  (bsc#1116950, bsc#1115709).
- Refresh patches.arch/hotplug-cpu-Add-operation-queuing-function.patch.
- Refresh patches.arch/powerpc-rtas-Fix-a-potential-race-between-CPU-Offlin.patch.
- commit 4350dc0
* Wed Nov 21 2018 jslaby@suse.cz
- openvswitch: Fix push/pop ethernet validation
  (networking-stable-18_11_02).
- net: stmmac: Fix stmmac_mdio_reset() when building stmmac as
  modules (networking-stable-18_11_02).
- rtnetlink: Disallow FDB configuration for non-Ethernet device
  (networking-stable-18_11_02).
- bonding: fix length of actor system
  (networking-stable-18_11_02).
- net: sched: gred: pass the right attribute to
  gred_change_table_def() (networking-stable-18_11_02).
- bridge: do not add port to router list when receives query
  with source 0.0.0.0 (networking-stable-18_11_02).
- ipv6/ndisc: Preserve IPv6 control buffer if protocol error
  handlers are called (networking-stable-18_11_02).
- net: udp: fix handling of CHECKSUM_COMPLETE packets
  (networking-stable-18_11_02).
- net/ipv6: Fix index counter for unicast addresses in
  in6_dump_addrs (networking-stable-18_11_02).
- ip6_tunnel: Fix encapsulation layout
  (networking-stable-18_11_02).
- net: socket: fix a missing-check bug
  (networking-stable-18_11_02).
- net: sched: Fix for duplicate class dump
  (networking-stable-18_11_02).
- r8169: fix NAPI handling under high load
  (networking-stable-18_11_02).
- net: ipmr: fix unresolved entry dumps
  (networking-stable-18_11_02).
- virtio_net: avoid using netif_tx_disable() for serializing tx
  routine (networking-stable-18_11_02).
- sctp: fix race on sctp_id2asoc (networking-stable-18_11_02).
- net: fec: don't dump RX FIFO register when not available
  (networking-stable-18_11_02).
- ipv6: mcast: fix a use-after-free in inet6_mc_check
  (networking-stable-18_11_02).
- net: bcmgenet: Poll internal PHY for GENETv5
  (networking-stable-18_11_02).
- llc: set SOCK_RCU_FREE in llc_sap_add_socket()
  (networking-stable-18_11_02).
- net/mlx5: Take only bit 24-26 of wqe.pftype_wq for page fault
  type (networking-stable-18_11_02).
- commit dc4cd19
* Wed Nov 21 2018 jthumshirn@suse.de
- libnvdimm, region: Fail badblocks listing for inactive regions
  (bsc#1116899).
- commit d115f51
* Wed Nov 21 2018 jthumshirn@suse.de
- acpi, nfit: Fix ARS overflow continuation (bsc#1116895).
- commit 33ca1e5
* Wed Nov 21 2018 jthumshirn@suse.de
- libnvdimm: Hold reference on parent while scheduling async init
  (bsc#1116891).
- commit 92606a2
* Wed Nov 21 2018 fdmanana@suse.com
- Btrfs: fix data corruption due to cloning of eof block
  (bsc#1116878).
- commit 49524d4
* Wed Nov 21 2018 fdmanana@suse.com
- Btrfs: fix infinite loop on inode eviction after deduplication
  of eof block (bsc#1116877).
- commit a415fec
* Wed Nov 21 2018 fdmanana@suse.com
- Btrfs: fix deadlock on tree root leaf when finding free extent
  (bsc#1116876).
- commit ad8024d
* Wed Nov 21 2018 fdmanana@suse.com
- btrfs: protect space cache inode alloc with GFP_NOFS
  (bsc#1116863).
- commit d79ecfd
* Wed Nov 21 2018 fdmanana@suse.com
- Btrfs: fix use-after-free when dumping free space (bsc#1116862).
- commit 31cbb21
* Wed Nov 21 2018 lhenriques@suse.com
- ceph: quota: fix null pointer dereference in quota check
  (bsc#1114839).
- commit d046d9a
* Wed Nov 21 2018 fdmanana@suse.com
- Btrfs: fix use-after-free during inode eviction (bsc#1116701).
- commit 86f6de8
* Wed Nov 21 2018 bpoirier@suse.com
- Move more btrfs upstream patches to sorted series section
  Looking at the resulting diff on the expanded tree, the changes are
  whitespace only and they all converge back to the upstream version, where
  applicable.
- commit 0c2905c
* Tue Nov 20 2018 fdmanana@suse.com
- btrfs: move some btrfs upstream patches to sorted series section
  For btrfs we have a lot of patches that are upstream but are in the
  unsorted section of series.conf, for reasons I do not know. This change
  moves some of them.
  Such large amounts of btrfs upstream patches in our unsorted section is
  making the work of backporting upstream fixes harder and harder, for
  example I can't backport at least a handful of upstream fixes that landed
  in 4.20-rcX if I add them to the sorted section. This will only encourage
  people to keep adding backports from upstream to the unsorted section,
  defeating the purpose of having a sorted section.
  Some patches in the unsorted section, mostly related to qgroups, are
  big and fat touching important files like fs/btrfs/inode.c and
  fs/btrfs/extent-tree.c for example, which are updated very frequently
  upstream. I really want to be able to add upstream fixes to the sorted
  section, as not doing it will only make life harder for everyone else
  too.
  Tested with sequence-patch.sh that this new order succeeds.
- commit c45d742
* Tue Nov 20 2018 fdmanana@suse.com
- Refresh
  patches.fixes/btrfs-fix-error-handling-in-btrfs_dev_replace_start.patch.
- commit 5a5eca3
* Tue Nov 20 2018 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-fix-error-handling-in-free_log_tree.patch.
- commit 7226834
* Tue Nov 20 2018 fdmanana@suse.com
- Btrfs: fix deadlock when writing out free space caches
  (bsc#1116700).
- commit 28a4ce0
* Tue Nov 20 2018 fdmanana@suse.com
- btrfs: make sure we create all new block groups (bsc#1116699).
- commit 2382de4
* Tue Nov 20 2018 fdmanana@suse.com
- Btrfs: fix null pointer dereference on compressed write path
  error (bsc#1116698).
- commit ef6b1ee
* Tue Nov 20 2018 fdmanana@suse.com
- Btrfs: fix wrong dentries after fsync of file that got its
  parent replaced (bsc#1116693).
- commit d64d2a9
* Tue Nov 20 2018 fdmanana@suse.com
- Btrfs: fix warning when replaying log after fsync of a tmpfile
  (bsc#1116692).
- commit cfb0d6d
* Tue Nov 20 2018 neilb@suse.com
- MD: fix invalid stored role for a disk - try2 (git-fixes).
- commit 14bab3c
* Tue Nov 20 2018 wqu@suse.com
- Refresh
  patches.fixes/btrfs-check-integrity-Fix-NULL-pointer-dereference-f.patch.
  Fix compile error for CONFIG_BTRFS_FS_CHECK_INTEGRITY=y
- commit c6b30fe
* Mon Nov 19 2018 jroedel@suse.de
- x86/corruption-check: Fix panic in memory_corruption_check()
  when boot option without value is provided (bsc#1110006).
- blacklist.conf: Add 706d51681d63 x86/speculation: Support Enhanced IBRS on future CPUs
- x86, hibernate: Fix nosave_regions setup for hibernation
  (bsc#1110006).
- commit bd7a215
* Mon Nov 19 2018 jroedel@suse.de
- PCI: vmd: White list for fast interrupt handlers (bsc#1109806).
- PCI: vmd: Assign vector zero to all bridges (bsc#1109806).
- commit d845c3b
* Mon Nov 19 2018 jack@suse.cz
- xfs: Properly detect when DAX won't be used on any device
  (bsc#1115976).
  patches.kabi/kabi-fixup-bdev_dax_supported.patch: Refresh
- commit 17d1dc1
* Mon Nov 19 2018 jgross@suse.com
- blacklist.conf: added 0ce0bba4e5e0eb: we don't support Xen on ARM
- commit b3ee751
* Mon Nov 19 2018 jgross@suse.com
- xen/pvh: don't try to unplug emulated devices (bnc#1065600).
- commit 6be5c3d
* Mon Nov 19 2018 jgross@suse.com
- xen/balloon: Support xend-based toolstack (bnc#1065600).
- commit e3d50da
* Mon Nov 19 2018 jgross@suse.com
- xen/pvh: increase early stack size (bnc#1065600).
- commit a9a97b2
* Mon Nov 19 2018 jgross@suse.com
- xen: fix xen_qlock_wait() (bnc#1107256).
- xen: make xen_qlock_wait() nestable (bnc#1107256).
- xen: fix race in xen_qlock_wait() (bnc#1107256).
- commit 811202c
* Mon Nov 19 2018 jgross@suse.com
- x86/xen: Fix boot loader version reported for PVH guests
  (bnc#1065600).
- commit f796a50
* Mon Nov 19 2018 jgross@suse.com
- xen-swiotlb: use actually allocated size on check physical
  continuous (bnc#1065600).
- commit 1b90103
* Mon Nov 19 2018 glin@suse.com
- kabi: mask raw in struct bpf_reg_state (bsc#1083647).
- commit a880313
* Mon Nov 19 2018 glin@suse.com
- bpf: fix partial copy of map_ptr when dst is scalar
  (bsc#1083647).
- bpf: wait for running BPF programs when updating map-in-map
  (bsc#1083647).
- commit 52c0e4a
* Sat Nov 17 2018 lduncan@suse.com
- scsi: target: tcmu: add read length support (bsc#1097755).
- commit 610833c
* Fri Nov 16 2018 tiwai@suse.de
- clk: fixed-factor: fix of_node_get-put imbalance (bsc#1051510).
- clk: fixed-rate: fix of_node_get-put imbalance (bsc#1051510).
- clk: s2mps11: Fix matching when built as module and DT node
  contains compatible (bsc#1051510).
- clk: rockchip: Fix static checker warning in
  rockchip_ddrclk_get_parent call (bsc#1051510).
- clk: mmp2: fix the clock id for sdh2_clk and sdh3_clk
  (bsc#1051510).
- clk: at91: Fix division by zero in PLL recalc_rate()
  (bsc#1051510).
- commit 519bab7
* Fri Nov 16 2018 tiwai@suse.de
- ACPI / LPSS: Add alternative ACPI HIDs for Cherry Trail DMA
  controllers (bsc#1051510).
- commit 91aa691
* Fri Nov 16 2018 tiwai@suse.de
- cachefiles: fix the race between cachefiles_bury_object()
  and rmdir(2) (bsc#1051510).
- commit abdcf95
* Fri Nov 16 2018 ptesarik@suse.cz
- s390/mm: Check for valid vma before zapping in gmap_discard
  (git-fixes).
- s390/mm: correct allocate_pgste proc_handler callback
  (git-fixes).
- s390/cpum_sf: Add data entry sizes to sampling trailer entry
  (git-fixes).
- perf: fix invalid bit in diagnostic entry (git-fixes).
- s390/qeth: handle failure on workqueue creation (git-fixes).
- s390/sclp_tty: enable line mode tty even if there is an ascii
  console (git-fixes).
- s390: revert ELF_ET_DYN_BASE base changes (git-fixes).
- commit 7c8037c
* Fri Nov 16 2018 ptesarik@suse.cz
- s390/qeth: report 25Gbit link speed (bnc#1113501, LTC#172959).
- s390/qeth: fix HiperSockets sniffer (bnc#1113501, LTC#172953).
- s390: qeth: Fix potential array overrun in cmd/rc lookup
  (bnc#1113501, LTC#172682).
- s390: qeth_core_mpc: Use ARRAY_SIZE instead of reimplementing
  its function (bnc#1113501, LTC#172682).
- net/af_iucv: fix skb handling on HiperTransport xmit error
  (bnc#1113501, LTC#172679).
- net/af_iucv: drop inbound packets with invalid flags
  (bnc#1113501, LTC#172679).
- s390/kvm: fix deadlock when killed by oom (bnc#1113501,
  LTC#172235).
- commit c4f4a6d
* Thu Nov 15 2018 ptesarik@suse.cz
- KVM: s390: vsie: copy wrapping keys to right place (git-fixes).
- commit 752534b
* Thu Nov 15 2018 tzimmermann@suse.de
- drm/ast: Remove existing framebuffers before loading driver (boo#1112963)
- commit d74bdf1
* Wed Nov 14 2018 jslaby@suse.cz
- net: dsa: bcm_sf2: Call setup during switch resume
  (networking-stable-18_10_16).
- net: dsa: bcm_sf2: Fix unbind ordering
  (networking-stable-18_10_16).
- net: mvpp2: Extract the correct ethtype from the skb for tx
  csum offload (networking-stable-18_10_16).
- ipv6: take rcu lock in rawv6_send_hdrinc()
  (networking-stable-18_10_16).
- rtnetlink: fix rtnl_fdb_dump() for ndmsg header
  (networking-stable-18_10_16).
- commit 2e7ba9d
* Wed Nov 14 2018 jslaby@suse.cz
- net/packet: fix packet drop as of virtio gso
  (networking-stable-18_10_16).
- bnxt_en: free hwrm resources, if driver probe fails
  (networking-stable-18_10_16).
- net/usb: cancel pending work when unbinding smsc75xx
  (networking-stable-18_10_16).
- net/mlx5e: Set vlan masks for all offloaded TC rules
  (networking-stable-18_10_16).
- net/mlx5: E-Switch, Fix out of bound access when setting vport
  rate (networking-stable-18_10_16).
- net: systemport: Fix wake-up interrupt race during resume
  (networking-stable-18_10_16).
- rtnl: limit IFLA_NUM_TX_QUEUES and IFLA_NUM_RX_QUEUES to 4096
  (networking-stable-18_10_16).
- bonding: fix warning message (networking-stable-18_10_16).
- inet: make sure to grab rcu_read_lock before using
  ireq->ireq_opt (networking-stable-18_10_16).
- bnxt_en: Fix TX timeout during netpoll
  (networking-stable-18_10_16).
- bonding: avoid possible dead-lock (networking-stable-18_10_16).
- bonding: pass link-local packets to bonding master also
  (networking-stable-18_10_16).
- tipc: fix flow control accounting for implicit connect
  (networking-stable-18_10_16).
- net: hns: fix for unmapping problem when SMMU is on
  (networking-stable-18_10_16).
- ip_tunnel: be careful when accessing the inner header
  (networking-stable-18_10_16).
- net: aquantia: memory corruption on jumbo frames
  (networking-stable-18_10_16).
- net/ipv6: Display all addresses in output of /proc/net/if_inet6
  (networking-stable-18_10_16).
- netlabel: check for IPV4MASK in addrinfo_get
  (networking-stable-18_10_16).
- sctp: update dst pmtu with the correct daddr
  (networking-stable-18_10_16).
- ip6_tunnel: be careful when accessing the inner header
  (networking-stable-18_10_16).
- net: mvpp2: fix a txq_done race condition
  (networking-stable-18_10_16).
- net: stmmac: Fixup the tail addr setting in xmit path
  (networking-stable-18_10_16).
- commit 75e8ae6
* Wed Nov 14 2018 tzimmermann@suse.de
- ASoC: dwc: Added a quirk DW_I2S_QUIRK_16BIT_IDX_OVERRIDE to dwc (bsc#1085535)
- commit bc6b192
* Wed Nov 14 2018 tiwai@suse.de
- Refresh
  patches.suse/drm-i915-CFL-NVMe-breakage-workaround.patch.
  Enable LSPCON instead of blindly disabling HDMI
- commit 263e523
* Wed Nov 14 2018 tiwai@suse.de
- uio: ensure class is registered before devices (bsc#1051510).
- commit 18bdb23
* Wed Nov 14 2018 tiwai@suse.de
- ALSA: ca0106: Disable IZD on SB0570 DAC to fix audio pops
  (bsc#1051510).
- commit 496d342
* Wed Nov 14 2018 tiwai@suse.de
- brcmfmac: fix for proper support of 160MHz bandwidth
  (bsc#1051510).
- ath10k: schedule hardware restart if WMI command times out
  (bsc#1051510).
- commit fcb3851
* Wed Nov 14 2018 tiwai@suse.de
- HID: hiddev: fix potential Spectre v1 (bsc#1051510).
- driver/dma/ioat: Call del_timer_sync() without holding prep_lock
  (bsc#1051510).
- Bluetooth: btbcm: Add entry for BCM4335C0 UART bluetooth
  (bsc#1051510).
- commit bba0171
* Wed Nov 14 2018 tiwai@suse.de
- hwmon: (core) Fix double-free in __hwmon_device_register()
  (bsc#1051510).
- hwmon: (pmbus) Fix page count auto-detection (bsc#1051510).
- hwmon: (pwm-fan) Set fan speed to 0 on suspend (bsc#1051510).
- commit f37d881
* Wed Nov 14 2018 tiwai@suse.de
- iwlwifi: mvm: check return value of rs_rate_from_ucode_rate()
  (bsc#1051510).
- iwlwifi: pcie: avoid empty free RB queue (bsc#1051510).
- iwlwifi: mvm: fix BAR seq ctrl reporting (bsc#1051510).
- commit b630745
* Wed Nov 14 2018 tiwai@suse.de
- ima: fix showing large 'violations' or
  'runtime_measurements_count' (bsc#1051510).
- commit e719b53
* Wed Nov 14 2018 tiwai@suse.de
- bitops: protect variables in bit_clear_unless() macro
  (bsc#1051510).
- bitops: protect variables in set_mask_bits() macro
  (bsc#1051510).
- commit 6b40d91
* Wed Nov 14 2018 tiwai@suse.de
- kgdboc: Passing ekgdboc to command line causes panic
  (bsc#1051510).
- pcmcia: Implement CLKRUN protocol disabling for Ricoh bridges
  (bsc#1051510).
- mmc: sdhci-pci-o2micro: Add quirk for O2 Micro dev 0x8620 rev
  0x01 (bsc#1051510).
- mmc: dw_mmc-rockchip: correct property names in debug
  (bsc#1051510).
- commit a863538
* Wed Nov 14 2018 tiwai@suse.de
- usbip:vudc: BUG kmalloc-2048 (Not tainted): Poison overwritten
  (bsc#1051510).
- usb: host: ohci-at91: fix request of irq for optional gpio
  (bsc#1051510).
- usb: gadget: udc: atmel: handle at91sam9rl PMC (bsc#1051510).
- commit 906f4ab
* Wed Nov 14 2018 tiwai@suse.de
- PCI/MSI: Warn and return error if driver enables MSI/MSI-X twice
  (bsc#1051510).
- PCI: Add Device IDs for Intel GPU "spurious interrupt" quirk
  (bsc#1051510).
- commit 43db261
* Wed Nov 14 2018 tiwai@suse.de
- blacklist.conf: Add iwlwifi fix that breaks kABI
- commit 970c9b2
* Wed Nov 14 2018 tiwai@suse.de
- blacklist.conf: Add ALSA hda entry that breaks kABI
- commit 58c3e52
* Tue Nov 13 2018 bp@suse.de
- x86/ldt: Remove unused variable in map_ldt_struct()
  (bsc#1114279).
- commit baa51fd
* Tue Nov 13 2018 yousaf.kaukab@suse.com
- ACPI/APEI: Handle GSIV and GPIO notification types
  (bsc#1115567).
  Refresh:
  patches.drivers/0024-acpi-apei-handle-SEA-notification-type-for-ARMv8.patch
- commit e2df716
* Tue Nov 13 2018 msuchanek@suse.de
- Add kernel-subpackage-build.spec (FATE#326579).
  - add kernel-subpackage-build.spec.in and support scripts
  - hook it in mkspec
  - extend the mechanism that copies dependencies inside
  kernel-binary.spec.in from kernel-%%build_flavor to
  kernel-%%build_flavor-base to also handle
  kernel-subpackage-build.spec.in using BINARY DEPS marker.
  - expand %%name in kernel-%%build_flavor so the dependencies are expanded
  correctly in kernel-subpackage-build.spec.in
- commit 9b3ca32
* Tue Nov 13 2018 bp@suse.de
- x86/cpu/vmware: Do not trace vmware_sched_clock() (bsc#1114279).
- blacklist.conf: blacklist some unneeded git-fixes patches
- x86/ldt: Unmap PTEs for the slot before freeing LDT pages
  (bsc#1114279).
- acpi/nfit, x86/mce: Validate a MCE's address before using it
  (bsc#1114279).
- acpi/nfit, x86/mce: Handle only uncorrectable machine checks
  (bsc#1114279).
- x86/mm/pat: Disable preemption around __flush_tlb_all()
  (bsc#1114279).
- x86/ldt: Split out sanity check in map_ldt_struct()
  (bsc#1114279).
- x86/MCE: Make correctable error detection look at the Deferred
  bit (bsc#1114279).
- kbuild: move "_all" target out of $(KBUILD_SRC) conditional
  (bsc#1114279).
- percpu: make this_cpu_generic_read() atomic w.r.t. interrupts
  (bsc#1114279).
- commit 26a9f67
* Tue Nov 13 2018 mhocko@suse.com
- Refresh
  patches.fixes/0001-mm-rework-memcg-kernel-stack-accounting.patch.
- commit 17a04dd
* Tue Nov 13 2018 mhocko@suse.com
- mm: handle no memcg case in memcg_kmem_charge() properly (bnc#1113677).
- mm: rework memcg kernel stack accounting (bnc#1113677).
- commit 563fd07
* Tue Nov 13 2018 nsaenzjulienne@suse.de
- usb: dwc2: host: do not delay retries for CONTROL IN transfers
  (bsc#1114385).
- commit 4302976
* Tue Nov 13 2018 neilb@suse.com
- md: allow metadata updates while suspending an array - fix
  (git-fixes).
- commit 82c160f
* Tue Nov 13 2018 bpoirier@suse.com
- Revert "move changes without Git-commit out of sorted section"
  This reverts commit cbf049ebedc611cdffd443910686956c1f4b7554.
  The log for cbf049ebedc61 is:
  move changes without Git-commit out of sorted section
  However, the purpose of the out-of-tree section is precisely to contain
  patches without Git-commit tags.
  After discussion, it seems that this commit was made in an attempt to fix
  an unrelated and unreproduced problem.
  Patches which are in "Patch-mainline: Submitted" state are moved back to
  the out-of-tree subsection while they wait for a Git-commit tag.
  Patches which seem to be in "Patch-mainline: Never" state are moved to a
  position relevant to their subsystem after the sorted section.
- commit a389aee
* Tue Nov 13 2018 neilb@suse.com
- KABI fix for "NFSv4.1: Fix up replays of interrupted requests"
  (git-fixes).
- commit 7ec87ef
* Mon Nov 12 2018 msuchanek@suse.de
- tpm: replace msleep() with  usleep_range() in TPM 1.2/2.0
  generic drivers (bsc#1082555).
- commit 87d9b39
* Mon Nov 12 2018 tiwai@suse.de
- genirq: Fix race on spurious interrupt detection (bsc#1051510).
- commit 1a06ab9
* Mon Nov 12 2018 tiwai@suse.de
- Documentation/l1tf: Remove Yonah processors from not vulnerable
  list (bsc#1051510).
- Documentation/l1tf: Fix typos (bsc#1051510).
- commit 06cf579
* Mon Nov 12 2018 tiwai@suse.de
- drm/i915: Fix ilk+ watermarks when disabling pipes
  (bsc#1051510).
- drm/i915/glk: Remove 99%% limitation (bsc#1051510).
- Input: elan_i2c - add ACPI ID for Lenovo IdeaPad 330-15IGM
  (bsc#1051510).
- usb: gadget: storage: Fix Spectre v1 vulnerability
  (bsc#1051510).
- cdc-acm: correct counting of UART states in serial state
  notification (bsc#1051510).
- cdc-acm: do not reset notification buffer index upon urb
  unlinking (bsc#1051510).
- USB: serial: option: add two-endpoints device-id flag
  (bsc#1051510).
- USB: serial: option: improve Quectel EP06 detection
  (bsc#1051510).
- USB: serial: option: drop redundant interface-class test
  (bsc#1051510).
- commit 7fc48e6
* Mon Nov 12 2018 tiwai@suse.de
- blacklist.conf: Add media v4l commit that breaks kABI
- commit a539f70
* Mon Nov 12 2018 tiwai@suse.de
- Add the cherry-picked dup id for PCI dwc fix
- commit 0c333ba
* Mon Nov 12 2018 tzimmermann@suse.de
- drm: fb-helper: Reject all pixel format changing requests (bsc#1113722)
- commit fe0c42d
* Mon Nov 12 2018 tzimmermann@suse.de
- drm/edid: Add 6 bpc quirk for BOE panel in HP Pavilion 15-n233sl (bsc#1113722)
- commit 04b4e07
* Mon Nov 12 2018 jdelvare@suse.de
- block: copy ioprio in __bio_clone_fast() (bsc#1082653).
- commit 4274c43
* Mon Nov 12 2018 jthumshirn@suse.de
- block: respect virtual boundary mask in bvecs (bsc#1113412).
- commit cd94c7f
* Fri Nov  9 2018 msuchanek@suse.de
- tpm: move the delay_msec increment after sleep in tpm_transmit()
  (bsc#1082555).
- tpm: fix intermittent failure with self tests (bsc#1082555).
- tpm: consolidate the TPM startup code (bsc#1082555).
- tpm: move endianness conversion of ordinals to tpm_input_header
  (bsc#1082555).
- tpm: move endianness conversion of TPM_TAG_RQU_COMMAND to
  tpm_input_header (bsc#1082555).
- commit 969f738
* Fri Nov  9 2018 msuchanek@suse.de
- tpm2-cmd: allow more attempts for selftest execution
  (bsc#1082555).
- tpm: React correctly to RC_TESTING from TPM 2.0 self tests
  (bsc#1082555).
- tpm: Use dynamic delay to wait for TPM 2.0 self test result
  (bsc#1082555).
- tpm: Trigger only missing TPM 2.0 self tests (bsc#1082555).
- tpm: do not suspend/resume if power stays on (bsc#1082555).
- tpm: use tpm2_pcr_read() in tpm2_do_selftest() (bsc#1082555).
- tpm: use tpm_buf functions in tpm2_pcr_read() (bsc#1082555).
- commit bd1b5fb
* Fri Nov  9 2018 ptesarik@suse.cz
- Delete
  patches.drivers/s390-qeth-fix-using-of-ref-counter-for-rxip-addresse.patch.
  Removed instead of backporting upstream revert from commit
  4964c66fd49b2e2342da35358f2ff74614bcbaee.
- Refresh
  patches.arch/s390-qeth-fix-ip-address-lookup-for-l3-devices.patch.
- commit 06ff2c6
* Fri Nov  9 2018 msuchanek@suse.de
- ibmvnic: fix index in release_rx_pools (bsc#1115440,
  bsc#1115433).
- commit 6f8b745
* Fri Nov  9 2018 ailiopoulos@suse.com
- xfs: Fix error code in 'xfs_ioc_getbmap()' (git-fixes).
- commit 8b3f368
* Fri Nov  9 2018 hare@suse.de
- scsi: lpfc: update driver version to 12.0.0.8 (bsc#1114015).
- scsi: lpfc: add Trunking support (bsc#1114015).
- scsi: lpfc: Implement GID_PT on Nameserver query to support
  faster failover (bsc#1114015).
- scsi: lpfc: Correct loss of fc4 type on remote port address
  change (bsc#1114015).
- scsi: lpfc: Fix odd recovery in duplicate FLOGIs in
  point-to-point (bsc#1114015).
- scsi: lpfc: Correct LCB RJT handling (bsc#1114015).
- scsi: lpfc: fcoe: Fix link down issue after 1000+ link bounces
  (bsc#1114015).
- scsi: lpfc: Correct errors accessing fw log (bsc#1114015).
- scsi: lpfc: Reset link or adapter instead of doing infinite
  nameserver PLOGI retry (bsc#1114015).
- scsi: lpfc: Fix LOGO/PLOGI handling when triggerd by ABTS
  Timeout event (bsc#1114015).
- scsi: lpfc: Fix lpfc_sli4_read_config return value check
  (bsc#1114015).
- scsi: lpfc: Correct speeds on SFP swap (bsc#1114015).
- scsi: lpfc: Remove set but not used variable 'sgl_size'
  (bsc#1114015).
- scsi: lpfc: update driver version to 12.0.0.7 (bsc#1114015).
- scsi: lpfc: add support to retrieve firmware logs (bsc#1114015).
- scsi: lpfc: reduce locking when updating statistics
  (bsc#1114015).
- scsi: lpfc: Fix errors in log messages (bsc#1114015).
- scsi: lpfc: Correct invalid EQ doorbell write on if_type=6
  (bsc#1114015).
- scsi: lpfc: Correct irq handling via locks when taking adapter
  offline (bsc#1114015).
- scsi: lpfc: Correct soft lockup when running mds diagnostics
  (bsc#1114015).
- scsi: lpfc: Correct race with abort on completion path
  (bsc#1114015).
- scsi: lpfc: Raise nvme defaults to support a larger io and
  more connectivity (bsc#1114015).
- scsi: lpfc: raise sg count for nvme to use available sg
  resources (bsc#1114015).
- scsi: lpfc: Fix GFT_ID and PRLI logic for RSCN (bsc#1114015).
- scsi: lpfc: Synchronize access to remoteport via rport
  (bsc#1114015).
- commit a8db0f4
* Fri Nov  9 2018 hare@suse.de
- scripts/git_sort/git_sort.py: add mkp/scsi.git 4.21/scsi-queue
- commit 0c66a4b
* Fri Nov  9 2018 jslaby@suse.cz
- udp6: fix encap return code for resubmitting (git-fixes).
- commit 3c4f718
* Thu Nov  8 2018 jdelvare@suse.de
- firmware: dcdbas: include linux/io.h (bsc#1089350 FATE#325723).
- commit a34f097
* Thu Nov  8 2018 yousaf.kaukab@suse.com
- pci: dwc: remove duplicate fix
  References: bsc#1115269
  Patch has been already applied by the following commit:
  9f73db8b7c PCI: dwc: Fix enumeration end when reaching root subordinate (bsc#1051510)
- commit 7e8c957
* Thu Nov  8 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add patches.drm for moved DRM patches
- commit d5fcbc2
* Thu Nov  8 2018 jdelvare@suse.de
- firmware: dcdbas: Add support for WSMT ACPI table (bsc#1089350
  FATE#325723).
- ACPICA: Tables: Add WSMT support (bsc#1089350 FATE#325723).
- commit da04cb0
* Thu Nov  8 2018 jslaby@suse.cz
- bpf, net: add skb_mac_header_len helper
  (networking-stable-18_09_24).
- Refresh
  patches.fixes/bpf-fix-bpf_skb_adjust_net-bpf_skb_proto_xlat-to-dea.patch.
- commit 7abeaa3
* Thu Nov  8 2018 jslaby@suse.cz
- ipv6: fix possible use-after-free in ip6_xmit()
  (networking-stable-18_09_24).
- net: hp100: fix always-true check for link up state
  (networking-stable-18_09_24).
- pppoe: fix reception of frames with no mac header
  (networking-stable-18_09_24).
- udp6: add missing checks on edumux packet processing
  (networking-stable-18_09_24).
- udp4: fix IP_CMSG_CHECKSUM for connected sockets
  (networking-stable-18_09_24).
- net/sched: act_sample: fix NULL dereference in the data path
  (networking-stable-18_09_24).
- gso_segment: Reset skb->mac_len after modifying network header
  (networking-stable-18_09_24).
- neighbour: confirm neigh entries when ARP packet is received
  (networking-stable-18_09_24).
- net/appletalk: fix minor pointer leak to userspace in
  SIOCFINDIPDDPRT (networking-stable-18_09_24).
- commit 1c616f8
* Thu Nov  8 2018 jroedel@suse.de
- Refresh
  patches.arch/kvm-nvmx-move-check_vmentry_postreqs-call-to-nested_vmx_enter_non_root_mode.
  Fix compile warnings
- commit 69ce36e
* Thu Nov  8 2018 jslaby@suse.cz
- rds: fix two RCU related problems (networking-stable-18_09_18).
- net/mlx5: Check for error in mlx5_attach_interface
  (networking-stable-18_09_18).
- net/mlx5: E-Switch, Fix memory leak when creating switchdev
  mode FDB tables (networking-stable-18_09_18).
- net/mlx5: Fix debugfs cleanup in the device init/remove flow
  (networking-stable-18_09_18).
- net/mlx5: Fix use-after-free in self-healing flow
  (networking-stable-18_09_18).
- net: qca_spi: Fix race condition in spi transfers
  (networking-stable-18_09_18).
- commit f54ed43
* Thu Nov  8 2018 jslaby@suse.cz
- doc/README.SUSE: correct GIT url
  No more gitorious, github we use.
- commit 31864f3
* Thu Nov  8 2018 neilb@suse.com
- NFSv4.1 fix infinite loop on I/O (git-fixes).
- NFSv4.0 fix client reference leak in callback (git-fixes).
- NFSv4.1: Fix a potential layoutget/layoutrecall deadlock
  (git-fixes).
- sunrpc: Don't use stack buffer with scatterlist (git-fixes).
- nfsd: fix corrupted reply to badly ordered compound (git-fixes).
- pNFS: Always free the session slot on error in
  nfs4_layoutget_handle_exception (git-fixes).
- skip LAYOUTRETURN if layout is invalid (git-fixes).
- NFSv4.1: Fix the client behaviour on NFS4ERR_SEQ_FALSE_RETRY
  (git-fixes).
- NFSv4: Fix a typo in nfs41_sequence_process (git-fixes).
- pnfs: Don't release the sequence slot until we've processed
  layoutget on open (git-fixes).
- nfsd: fix potential use-after-free in nfsd4_decode_getdeviceinfo
  (git-fixes).
- nfsd: restrict rd_maxcount to svc_max_payload in
  nfsd_encode_readdir (git-fixes).
- NFS: Fix unstable write completion (git-fixes).
- pNFS: Prevent the layout header refcount going to zero in
  pnfs_roc() (git-fixes).
- NFS: Fix an incorrect type in struct nfs_direct_req (git-fixes).
- nfsd4: permit layoutget of executable-only files (git-fixes).
- NFS: commit direct writes even if they fail partially
  (git-fixes).
- nfs: don't wait on commit in nfs_commit_inode() if there were
  no commit requests (git-fixes).
- SUNRPC: Allow connect to return EHOSTUNREACH (git-fixes).
- nfsd: check for use of the closed special stateid (git-fixes).
- grace: replace BUG_ON by WARN_ONCE in exit_net hook (git-fixes).
- nfsd: Ensure we check stateid validity in the seqid operation
  checks (git-fixes).
- nfsd: CLOSE SHOULD return the invalid special stateid for
  NFSv4.x (x>0) (git-fixes).
- nfsd: Fix another OPEN stateid race (git-fixes).
- nfsd: Fix stateid races between OPEN and CLOSE (git-fixes).
- nfsd: deal with revoked delegations appropriately (git-fixes).
- SUNRPC: Fix tracepoint storage issues with svc_recv and
  svc_rqst_status (git-fixes).
- NFS: Fix typo in nomigration mount option (git-fixes).
- NFS: Fix a typo in nfs_rename() (git-fixes).
- sunrpc: Fix rpc_task_begin trace point (git-fixes).
- NFS: Avoid RCU usage in tracepoints (git-fixes).
- NFSv4.1: Fix up replays of interrupted requests (git-fixes).
- xprtrdma: Don't defer fencing an async RPC's chunks (git-fixes).
- commit cbfcac5
* Wed Nov  7 2018 mbrugger@suse.com
- arm64: KVM: Sanitize PSTATE.M when being set from userspace
  (bsc#1110998).
- arm64: KVM: Tighten guest core register access from userspace
  (bsc#1110998).
- KVM: arm/arm64: Introduce vcpu_el1_is_32bit (bsc#1110998).
- arm64: KVM: Move CPU ID reg trap setup off the world switch path
  (bsc#1110998).
- commit 3534306
* Wed Nov  7 2018 lduncan@suse.com
- scsi: core: Avoid that SCSI device removal through sysfs
  triggers a deadlock (bsc#1114578).
- scsi: sysfs: Introduce sysfs_{un,}break_active_protection()
  (bsc#1114578).
- scsi: target/tcm_loop: Avoid that static checkers warn about
  dead code (bsc#1114577).
- scsi: libsas: remove irq save in sas_ata_qc_issue()
  (bsc#1114580).
- scsi: sg: fix minor memory leak in error path (bsc#1114584).
- scsi: qlogicpti: Fix an error handling path in
  'qpti_sbus_probe()' (bsc#1114581).
- scsi: scsi_transport_srp: Fix shost to rport translation
  (bsc#1114582).
- scsi: target: Fix fortify_panic kernel exception (bsc#1114576).
- commit 018bccb
* Wed Nov  7 2018 pvorel@suse.cz
- fsnotify: fix ignore mask logic in fsnotify() (bsc#1115074).
- commit f6cfe4b
* Wed Nov  7 2018 lduncan@suse.com
- Blacklist commit that modifies Scsi_Host/kabi (bsc#1114579)
- commit 80c9d85
* Wed Nov  7 2018 lduncan@suse.com
- Blacklist virtio patch that uses bio_integrity_bytes() (bsc#1114585)
- commit ba0cd5c
* Wed Nov  7 2018 lduncan@suse.com
- Blacklist sd_zbc patch that is too invasive (bsc#1114583)
- commit ef29119
* Wed Nov  7 2018 jroedel@suse.de
- KVM: nVMX: move check_vmentry_postreqs() call to
  nested_vmx_enter_non_root_mode() (bsc#1106240).
- KVM: nVMX: Always reflect #NM VM-exits to L1 (bsc#1106240).
- commit aa4e0d0
* Wed Nov  7 2018 tzimmermann@suse.de
- Move 2308 patches to patches.drm/ (FATE#326265)
- commit ebf85ed
* Wed Nov  7 2018 tiwai@suse.de
- usbnet: smsc95xx: disable carrier check while suspending
  (bsc#1051510).
- reset: hisilicon: fix potential NULL pointer dereference
  (bsc#1051510).
- VMCI: Resource wildcard match fixed (bsc#1051510).
- mailbox: PCC: handle parse error (bsc#1051510).
- mfd: omap-usb-host: Fix dts probe of children (bsc#1051510).
- reset: imx7: Fix always writing bits as 0 (bsc#1051510).
- remoteproc: qcom: Fix potential device node leaks (bsc#1051510).
- commit 6ce5a67
* Wed Nov  7 2018 jroedel@suse.de
- PCI: vmd: Detach resources after stopping root bus
  (bsc#1109806).
- PCI: iproc: Remove PAXC slot check to allow VF support
  (bsc#1109806).
- commit ff5615e
* Wed Nov  7 2018 jroedel@suse.de
- iommu/arm-smmu: Ensure that page-table updates are visible
  before TLBI (bsc#1106237).
- commit 6326887
* Wed Nov  7 2018 mbrugger@suse.com
- thermal: bcm2835: enable hwmon explicitly (bsc#1108468).
- commit ef2889b
* Wed Nov  7 2018 ohering@suse.de
- PCI: hv: Use effective affinity mask (bsc#1109772).
- commit 28be1aa
* Wed Nov  7 2018 ohering@suse.de
- x86/irq: implement irq_data_get_effective_affinity_mask()
  for v4.12 (bsc#1109772).
- commit 723ad43
* Tue Nov  6 2018 lhenriques@suse.com
- libceph: bump CEPH_MSG_MAX_DATA_LEN (bsc#1114839).
- ceph: fix dentry leak in ceph_readdir_prepopulate (bsc#1114839).
- Revert "ceph: fix dentry leak in splice_dentry()" (bsc#1114839).
- commit adb4b87
* Tue Nov  6 2018 tiwai@suse.de
- blacklist.conf: Add ipv6 stable commit that has been reverted later
- commit 3ed2020
* Tue Nov  6 2018 tiwai@suse.de
- tun: Consistently configure generic netdev params via rtnetlink
  (bsc#1051510).
- commit 69de7a4
* Tue Nov  6 2018 tiwai@suse.de
- pwm: lpss: Release runtime-pm reference from the driver's
  remove callback (bsc#1051510).
- thermal: da9062/61: Prevent hardware access during system
  suspend (bsc#1051510).
- thermal: rcar_thermal: Prevent hardware access during system
  suspend (bsc#1051510).
- commit 512e9c6
* Tue Nov  6 2018 tiwai@suse.de
- pinctrl: qcom: spmi-mpp: Fix err handling of pmic_mpp_set_mux
  (bsc#1051510).
- pinctrl: at91-pio4: fix has_config check in
  atmel_pctl_dt_subnode_to_map() (bsc#1051510).
- pinctrl: qcom: spmi-mpp: Fix drive strength setting
  (bsc#1051510).
- pinctrl: spmi-mpp: Fix pmic_mpp_config_get() to be compliant
  (bsc#1051510).
- pinctrl: ssbi-gpio: Fix pm8xxx_pin_config_get() to be compliant
  (bsc#1051510).
- commit 8be2637
* Tue Nov  6 2018 tiwai@suse.de
- Sort the previously merged mm fix patches
  Refresh:
  patches.fixes/0001-mremap-properly-flush-TLB-before-releasing-the-page.patch
  patches.suse/mremap-Remove-LATENCY_LIMIT-from-mremap-to-reduce-the-number-of-TLB-shootdowns.patch
- commit 64c8ca6
* Mon Nov  5 2018 msuchanek@suse.de
- tpm: Restore functionality to xen vtpm driver (bsc#1082555).
- commit 538d633
* Mon Nov  5 2018 nsaenzjulienne@suse.de
- usb: dwc2: host: Don't retry NAKed transactions right away
  (bsc#1114385).
- commit 54bdf43
* Mon Nov  5 2018 msuchanek@suse.de
- tpm: fix response size validation in tpm_get_random()
  (bsc#1082555).
- commit d159511
* Mon Nov  5 2018 msuchanek@suse.de
- tpm: add retry logic (bsc#1082555).
- Refresh patches.drivers/tpm-separate-cmd_ready-go_idle-from-runtime_pm.patch.
- Refresh patches.kabi/KABI-tpm-do-keep-the-cmd_ready-and-go_idle-as-pm-ops.patch.
- tpm: self test failure should not cause suspend to fail
  (bsc#1082555).
- tpm: tpm-interface: fix tpm_transmit/_cmd kdoc (bsc#1082555).
- Refresh patches.drivers/tpm-separate-cmd_ready-go_idle-from-runtime_pm.patch.
- commit 2dd1eb5
* Mon Nov  5 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add macros.s into kernel-*-devel
  Starting with 4.20-rc1, file arch/*/kernel/macros.s is needed to build out
  of tree modules. Add it to kernel-${flavor}-devel packages if it exists.
- commit 09d14c8
* Mon Nov  5 2018 msuchanek@suse.de
- blacklist.conf: add TPM commits not applicable to SLE15.
  c382babccba2 tpm_tis: Move ilb_base_addr to tpm_tis_data
  764325add6c2 tpm: delete the TPM_TIS_CLK_ENABLE flag
  With the update in SP1 these may be relevant there.
- commit f3d0aec
* Mon Nov  5 2018 tiwai@suse.de
- PCI/ASPM: Do not initialize link state when aspm_disabled is
  set (bsc#1051510).
- commit ac78802
* Mon Nov  5 2018 tiwai@suse.de
- iwlwifi: don't WARN on trying to dump dead firmware
  (bsc#1051510).
- cfg80211: fix use-after-free in reg_process_hint()
  (bsc#1051510).
- Bluetooth: SMP: fix crash in unpairing (bsc#1051510).
- nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds
  (bsc#1051510).
- mac80211_hwsim: do not omit multicast announce of first added
  radio (bsc#1051510).
- nl80211: Fix possible Spectre-v1 for NL80211_TXRATE_HT
  (bsc#1051510).
- mac80211: fix TX status reporting for ieee80211s (bsc#1051510).
- mac80211: TDLS: fix skb queue/priority assignment (bsc#1051510).
- cfg80211: Address some corner cases in scan result channel
  updating (bsc#1051510).
- mac80211: Always report TX status (bsc#1051510).
- ARM: dts: at91: add new compatibility string for macb on sama5d3
  (bsc#1051510).
- iwlwifi: dbg: allow wrt collection before ALIVE (bsc#1051510).
- iwlwifi: mvm: check for short GI only for OFDM (bsc#1051510).
- commit e806438
* Mon Nov  5 2018 jack@suse.cz
- Refresh
  patches.fixes/libnvdimm-pmem-Restore-page-attributes-when-clearing.patch
  patches.fixes/x86-memory_failure-Introduce-set-clear-_mce_nospec.patch
  to reflect presence of linux/set_memory.h.
- commit ade6096
* Mon Nov  5 2018 jack@suse.cz
- provide linux/set_memory.h (bsc#1113295).
- commit 94a6a0b
* Mon Nov  5 2018 jslaby@suse.cz
- net: sched: action_ife: take reference to meta module
  (networking-stable-18_09_11).
- act_ife: fix a potential use-after-free
  (networking-stable-18_09_11).
- tcp: do not restart timewait timer on rst reception
  (networking-stable-18_09_11).
- nfp: wait for posted reconfigs when disabling the device
  (networking-stable-18_09_11).
- net: bcmgenet: use MAC link status for fixed phy
  (networking-stable-18_09_11).
- net/sched: act_pedit: fix dump of extended layered op
  (networking-stable-18_09_11).
- tipc: fix a missing rhashtable_walk_exit()
  (networking-stable-18_09_11).
- sctp: hold transport before accessing its asoc in
  sctp_transport_get_next (networking-stable-18_09_11).
- net: sched: Fix memory exposure from short TCA_U32_SEL
  (networking-stable-18_09_11).
- net: macb: do not disable MDIO bus at open/close time
  (networking-stable-18_09_11).
- ipv4: tcp: send zero IPID for RST and ACK sent in SYN-RECV
  and TIME-WAIT state (networking-stable-18_09_11).
- hv_netvsc: ignore devices that are not PCI
  (networking-stable-18_09_11).
- ip6_vti: fix a null pointer deference when destroy vti6 tunnel
  (networking-stable-18_09_11).
- commit 63d88d9
* Mon Nov  5 2018 tzimmermann@suse.de
- blacklist.conf: Append 'drm: rcar-du: Improve non-DPLL clock selection'
- commit 76849a6
* Mon Nov  5 2018 tzimmermann@suse.de
- fbdev: fix broken menu dependencies (bsc#1113722)
- commit ac9f687
* Mon Nov  5 2018 mhocko@suse.com
- mremap: properly flush TLB before releasing the page
  (bnc#1113769, CVE-2018-18281).
- Refresh
  patches.suse/mremap-Remove-LATENCY_LIMIT-from-mremap-to-reduce-the-number-of-TLB-shootdowns.patch.
- commit 8f5c07d
* Mon Nov  5 2018 mhocko@suse.com
- memory_hotplug: cond_resched in __remove_pages (bnc#1114178).
- commit f1cc90a
* Sun Nov  4 2018 mkubecek@suse.cz
- rpm: use syncconfig instead of silentoldconfig where available
  Since mainline commit 0085b4191f3e ("kconfig: remove silentoldconfig
  target"), "make silentoldconfig" can be no longer used. Use "make
  syncconfig" instead if available.
- commit a239c6e
* Fri Nov  2 2018 mbenes@suse.cz
- livepatch: create and include UAPI headers (fate#326849).
- commit a00eabe
* Fri Nov  2 2018 mbenes@suse.cz
- modpost: ignore livepatch unresolved relocations (fate#326849).
- commit ac36eb6
* Fri Nov  2 2018 msuchanek@suse.de
- powerpc/cacheinfo: Report the correct shared_cpu_map on
  big-cores (bsc#1109695).
- powerpc: Use cpu_smallcore_sibling_mask at SMT level on bigcores
  (bsc#1109695).
- powerpc: Detect the presence of big-cores via "ibm,
  thread-groups" (bsc#1109695).
- powerpc/setup: Add cpu_to_phys_id array (FATE#326757,
  bsc#1109695).
- powerpc: make use of for_each_node_by_type() instead of
  open-coding it (FATE#326757, bsc#1109695).
- commit 2a27b15
* Thu Nov  1 2018 bp@suse.de
- EDAC, thunderx: Fix memory leak in thunderx_l2c_threaded_isr()
  (bsc#1114279).
- blacklist.conf:
- resource: Include resource end in walk_*() interfaces
  (bsc#1114279).
- x86/kexec: Correct KEXEC_BACKUP_SRC_END off-by-one error
  (bsc#1114279).
- commit 9ab91ee
* Thu Nov  1 2018 jslaby@suse.cz
- tty: Don't block on IO when ldisc change is pending
  (bnc#1105428).
- Refresh
  patches.suse/tty-Hold-tty_ldisc_lock-during-tty_reopen.patch.
- Refresh
  patches.suse/tty-Simplify-tty-count-math-in-tty_reopen.patch.
- Refresh
  patches.suse/tty-ldsem-Add-lockdep-asserts-for-ldisc_sem.patch.
- Refresh
  patches.suse/tty-ldsem-Convert-to-regular-lockdep-annotations.patch.
- Refresh
  patches.suse/tty-ldsem-Decrement-wait_readers-on-timeouted-down_r.patch.
- Refresh
  patches.suse/tty-ldsem-Wake-up-readers-after-timed-out-down_write.patch.
  Update to v6 of the patchset. It should fix the potential deadlocks.
- commit b10485a
* Thu Nov  1 2018 neilb@suse.com
- RAID10 BUG_ON in raise_barrier when force is true and
  conf->barrier is 0 (git-fixes).
- md/raid5-cache: disable reshape completely (git-fixes).
- autofs: fix autofs_sbi() does not check super block type
  (git-fixes).
- vfs: fix freeze protection in mnt_want_write_file() for
  overlayfs (git-fixes).
- fs/dcache.c: fix kmemcheck splat at take_dentry_name_snapshot()
  (git-fixes).
- md/raid5: fix data corruption of replacements after originals
  dropped (git-fixes).
- make sure that __dentry_kill() always invalidates d_seq,
  unhashed or not (git-fixes).
- autofs: fix slab out of bounds read in getname_kernel()
  (git-fixes).
- md/raid10: fix that replacement cannot complete recovery after
  reassemble (git-fixes).
- md/raid1: add error handling of read error from FailFast device
  (git-fixes).
- md: fix NULL dereference of mddev->pers in
  remove_and_add_spares() (git-fixes).
- autofs: mount point create should honour passed in mode
  (git-fixes).
- Don't leak MNT_INTERNAL away from internal mounts (git-fixes).
- getname_kernel() needs to make sure that ->name != ->iname in
  long case (git-fixes).
- fs: dcache: Use READ_ONCE when accessing i_dir_seq (git-fixes).
- fs: dcache: Avoid livelock between d_alloc_parallel and __d_add
  (git-fixes).
- lockd: fix "list_add double add" caused by legacy signal
  interface (git-fixes).
- race of lockd inetaddr notifiers vs nlmsvc_rqst change
  (git-fixes).
- badblocks: fix wrong return value in badblocks_set if badblocks
  are disabled (git-fixes).
- commit 6d8bf1d
* Thu Nov  1 2018 neilb@suse.com
- VFS: close race between getcwd() and d_move() (git-fixes).
- Refresh patches.fixes/d-lookup-fairness.fix.
- commit 76815af
* Thu Nov  1 2018 neilb@suse.com
- pipe: match pipe_max_size data type with procfs (git-fixes).
- Refresh
  patches.suse/pipe-avoid-round_pipe_size-nr_pages-overflow-on-32-b.patch.
- commit e8660e8
* Thu Nov  1 2018 neilb@suse.com
- do d_instantiate/unlock_new_inode combinations safely
  (git-fixes).
- Delete
  patches.fixes/f2fs-call-unlock_new_inode-before-d_instantiate.patch.
  These two patch both change the same code - the former is more complete.
- commit 0e081e5
* Thu Nov  1 2018 neilb@suse.com
- Update
  patches.fixes/0002-nfs41-do-not-return-ENOMEM-on-LAYOUTUNAVAILABLE.patch
  (git-fixes, bsc#1103925).
- commit 8d3e28c
* Wed Oct 31 2018 bp@suse.de
- EDAC: Raise the maximum number of memory controllers (bsc#1113780).
- commit 6e99f0f
* Wed Oct 31 2018 tiwai@suse.de
- spi/bcm63xx-hsspi: keep pll clk enabled (bsc#1051510).
- spi: sh-msiof: fix deferred probing (bsc#1051510).
- spi: bcm-qspi: switch back to reading flash using smaller chunks
  (bsc#1051510).
- commit f773242
* Wed Oct 31 2018 tiwai@suse.de
- blacklist.conf: Add a few wifi driver entries that can't be applied
- commit 662fc68
* Wed Oct 31 2018 jlee@suse.com
- x86/boot/KASLR: Work around firmware bugs by excluding
  EFI_BOOT_SERVICES_* and EFI_LOADER_* from KASLR's choice
  (bnc#1112878).
- commit d45cd78
* Wed Oct 31 2018 jthumshirn@suse.de
- libnvdimm, label: Fix sparse warning (bsc#1111921, bsc#1113408,
  FATE#326765, bsc#1113972).
- nvdimm: Use namespace index data to reduce number of label reads
  needed (bsc#1111921, bsc#1113408, FATE#326765, bsc#1113972).
- nvdimm: Split label init out from the logic for getting config
  data (bsc#1111921, bsc#1113408, FATE#326765, bsc#1113972).
- nvdimm: Remove empty if statement (bsc#1111921, bsc#1113408,
  FATE#326765, bsc#1113972).
- nvdimm: Clarify comment in sizeof_namespace_index (bsc#1111921,
  bsc#1113408, FATE#326765, bsc#1113972).
- nvdimm: Sanity check labeloff (bsc#1111921, bsc#1113408,
  FATE#326765, bsc#1113972).
- libnvdimm, dimm: Maximize label transfer size (bsc#1111921,
  bsc#1113408, FATE#326765, bsc#1113972).
- libnvdimm, label: change nvdimm_num_label_slots per UEFI 2.7
  (bsc#1111921, bsc#1113408, FATE#326765, bsc#1113972).
- commit 5a4eeb4
* Wed Oct 31 2018 tiwai@suse.de
- Workaround for mysterious NVMe breakage with i915 CFL
  (bsc#1111040).
- commit 0fa5877
* Wed Oct 31 2018 msuchanek@suse.de
- KABI: hide new member in struct iommu_table from genksyms
  (bsc#1061840).
- commit df25769
* Wed Oct 31 2018 msuchanek@suse.de
- kabi/severities: ignore ppc64 realmode helpers.
  KVM fixes remove exports of realmode_pfn_to_page iommu_tce_xchg_rm
  mm_iommu_lookup_rm mm_iommu_ua_to_hpa_rm. Some are no longer used and
  others are no longer exported because the code was consolideted in one
  place. These helpers are to be called in realmode and linking to them
  from non-KVM modules is a bug. Hence removing them does not break KABI.
- Refresh patches.kabi/KABI-powerpc-mmu_context-provide-old-version-of-mm_i.patch.
- commit 2d0e8e4
* Wed Oct 31 2018 msuchanek@suse.de
- powerpc/powernv: Move TCE manupulation code to its own file
  (bsc#1061840).
- Update patches.arch/powerpc-powernv-ioda2-Reduce-upper-limit-for-DMA-win.patch
  (bsc#1061840, bsc#1055120).
- commit 37fbbd2
* Wed Oct 31 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Avoid crash from THP collapse during
  radix page fault (bsc#1061840).
- KVM: PPC: Book3S HV: Fix guest r11 corruption with POWER9 TM
  workarounds (bsc#1061840).
- KVM: PPC: Book3S HV: Don't use compound_order to determine
  host mapping size (bsc#1061840).
- KVM: PPC: Avoid marking DMA-mapped pages dirty in real mode
  (bsc#1061840).
- KVM: PPC: Book3S HV: Don't truncate HPTE index in xlate function
  (bsc#1061840).
- KVM: PPC: Book3S HV: Read kvm->arch.emul_smt_mode under
  kvm->lock (bsc#1061840).
- KVM: PPC: Book3S HV: Allow creating max number of VCPUs on
  POWER9 (bsc#1061840).
- KVM: PPC: Book3S HV: Pack VCORE IDs to access full VCPU ID space
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix constant size warning (bsc#1061840).
- KVM: PPC: Book3S HV: Add of_node_put() in success path
  (bsc#1061840).
- KVM: PPC: Book3S: Fix matching of hardware and emulated TCE
  tables (bsc#1061840).
- powerpc/powernv/ioda: Allocate indirect TCE levels on demand
  (bsc#1061840).
- powerpc/powernv: Rework TCE level allocation (bsc#1061840).
- powerpc/powernv: Add indirect levels to it_userspace
  (bsc#1061840).
- KVM: PPC: Make iommu_table::it_userspace big endian
  (bsc#1061840).
- powerpc/powernv/ioda: Finish removing explicit max window size
  check (bsc#1061840).
- commit 091ec6b
* Wed Oct 31 2018 tzimmermann@suse.de
- Fix Patch-mainline for "drm/amdgpu: update tmr mc address"
  The Patch-mainline tag was incorrect. References is being updated as well.
- commit ce8535e
* Wed Oct 31 2018 msuchanek@suse.de
- KVM: PPC: Book3S PR: Add guest MSR parameter for
  kvmppc_save_tm()/kvmppc_restore_tm() (bsc#1061840).
- KVM: PPC: Book3S PR: Move kvmppc_save_tm/kvmppc_restore_tm to
  separate file (bsc#1061840).
- KVM: PPC: Book3S HV: Factor fake-suspend handling out of
  kvmppc_save/restore_tm (bsc#1061840).
- KVM: PPC: Book3S HV: Send kvmppc_bad_interrupt NMIs to Linux
  handlers (bsc#1061840).
- KVM: PPC: Book3S HV: Fix kvmppc_bad_host_intr for real mode
  interrupts (bsc#1061840).
- KVM: PPC: Book3S HV: radix: Do not clear partition PTE when
  RC or write bits do not match (bsc#1061840).
- KVM: PPC: Book3S HV: radix: Refine IO region partition scope
  attributes (bsc#1061840).
- KVM: PPC: Book3S HV: Recursively unmap all page table entries
  when unmapping (bsc#1061840).
- KVM: PPC: Book3S HV: Use a helper to unmap ptes in the radix
  fault path (bsc#1061840).
- KVM: PPC: Book3S HV: Lockless tlbie for HPT hcalls
  (bsc#1061840).
- KVM: PPC: Fix a mmio_host_swabbed uninitialized usage issue
  (bsc#1061840).
- KVM: PPC: Move nip/ctr/lr/xer registers to pt_regs in
  kvm_vcpu_arch (bsc#1061840).
- KVM: PPC: Add pt_regs into kvm_vcpu_arch and move
  vcpu->arch.gpr[] into it (bsc#1061840).
- KVM: PPC: Book3S: Check KVM_CREATE_SPAPR_TCE_64 parameters
  (bsc#1061840).
- KVM: PPC: Book3S: Allow backing bigger guest IOMMU pages with
  smaller physical pages (bsc#1061840).
- KVM: PPC: Book3S: Use correct page shift in H_STUFF_TCE
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix inaccurate comment (bsc#1061840).
- KVM: PPC: Book3S HV: Set RWMR on POWER8 so PURR/SPURR count
  correctly (bsc#1061840).
- KVM: PPC: Book3S HV: Add 'online' register to ONE_REG interface
  (bsc#1061840).
- powerpc/kvm: Switch kvm pmd allocator to custom allocator
  (bsc#1061840).
- KVM: PPC: Book 3S HV: Do ptesync in radix guest exit path
  (bsc#1061840).
- KVM: PPC: Book3S HV: XIVE: Resend re-routed interrupts on CPU
  priority change (bsc#1061840).
- KVM: PPC: Book3S HV: Make radix clear pte when unmapping
  (bsc#1061840).
- KVM: PPC: Book3S HV: Make radix use correct tlbie sequence in
  kvmppc_radix_tlbie_page (bsc#1061840).
- KVM: PPC: Book3S HV: Snapshot timebase offset on guest entry
  (bsc#1061840).
- powerpc/kvm/booke: Fix altivec related build break
  (bsc#1061840).
- KVM: PPC: Book3S HV: Use __gfn_to_pfn_memslot() in page fault
  handler (bsc#1061840).
- KVM: PPC: Book3S HV: Handle 1GB pages in radix page fault
  handler (bsc#1061840).
- KVM: PPC: Book3S HV: Streamline setting of reference and change
  bits (bsc#1061840).
- KVM: PPC: Book3S HV: Radix page fault handler optimizations
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix duplication of host SLB entries
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix trap number return from
  __kvmppc_vcore_entry (bsc#1061840).
- KVM: PPC: Book3S HV: Fix VRMA initialization with 2MB or 1GB
  memory backing (bsc#1061840).
- KVM: PPC: Book3S HV: Fix handling of large pages in radix page
  fault handler (bsc#1061840).
- KVM: PPC: Book3S: Fix compile error that occurs with some gcc
  versions (bsc#1061840).
- KVM: PPC: Book3S: Add MMIO emulation for VMX instructions
  (bsc#1061840).
- KVM: PPC: Book3S HV: Make HPT resizing work on POWER9
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix handling of secondary HPTEG in HPT
  resizing code (bsc#1061840).
- KVM: PPC: Book3S HV: Keep XIVE escalation interrupt masked
  unless ceded (bsc#1061840).
- KVM: PPC: Book3S HV: Make xive_pushed a byte, not a word
  (bsc#1061840).
- KVM: PPC: Book3S HV: Check DR not IR to chose real vs virt
  mode MMIOs (bsc#1061840).
- KVM: PPC: Book3S HV: Don't use existing "prodded" flag for
  XIVE escalations (bsc#1061840).
- KVM: PPC: Book3S HV: Allow HPT and radix on the same core for
  POWER9 v2.2 (bsc#1061840).
- KVM: PPC: Book3S HV: Do SLB load/unload with guest LPCR value
  loaded (bsc#1061840).
- KVM: PPC: Book3S HV: Enable migration of decrementer register
  (bsc#1061840).
- KVM: PPC: Use seq_puts() in kvmppc_exit_timing_show()
  (bsc#1061840).
- KVM: PPC: Book3S HV: Remove vcpu->arch.dec usage (bsc#1061840).
- KVM: PPC: Book3S: Eliminate some unnecessary checks
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix conditions for starting vcpu
  (bsc#1061840).
- KVM: PPC: Book3S HV: Remove useless statement (bsc#1061840).
- KVM: PPC: Book3S HV: Fix typo in kvmppc_hv_get_dirty_log_radix()
  (bsc#1061840).
- KVM: PPC: Book3S HV: Avoid shifts by negative amounts
  (bsc#1061840).
- KVM: PPC: Book3S HV: Improve handling of debug-trigger HMIs
  on POWER9 (bsc#1061840).
- powerpc/xive: Move definition of ESB bits (bsc#1061840).
- powerpc/powernv/ioda: Remove explicit max window size check
  (bsc#1061840).
- powerpc/xmon: Add ISA v3.0 SPRs to SPR dump (bsc#1061840).
- commit 2bdb006
* Wed Oct 31 2018 tiwai@suse.de
- drm/nouveau: Don't disable polling in fallback mode
  (bsc#1103356).
- Delete
  patches.suse/Revert-drm-nouveau-drm-therm-fan-add-a-fallback-if-n.
- commit aa0c431
* Tue Oct 30 2018 jthumshirn@suse.de
- Refresh
  patches.fixes/0001-drm-amdgpu-powerplay-fix-missing-break-in-switch-sta.patch.
- Refresh
  patches.fixes/0001-drm-hisilicon-hibmc-Do-not-carry-error-code-in-HiBMC.patch.
- Refresh
  patches.fixes/0001-drm-hisilicon-hibmc-Don-t-overwrite-fb-helper-surfac.patch.
- Refresh
  patches.fixes/0001-drm-i915-audio-Hook-up-component-bindings-even-if-di.patch.
- Refresh
  patches.fixes/0001-drm-i915-gen9-Fix-initial-readout-for-Y-tiled-frameb.patch.
- Refresh
  patches.fixes/0001-drm-sti-do-not-remove-the-drm_bridge-that-was-never-.patch.
- Refresh
  patches.fixes/0001-drm-virtio-fix-bounds-check-in-virtio_gpu_cmd_get_ca.patch.
- commit 652fab5
* Tue Oct 30 2018 tiwai@suse.de
- soc/tegra: pmc: Fix child-node lookup (bsc#1051510).
- serial: 8250: Fix clearing FIFOs in RS485 mode again
  (bsc#1051510).
- staging: comedi: ni_mio_common: protect register write overflow
  (bsc#1051510).
- iio: adc: at91: fix wrong channel number in triggered buffer
  mode (bsc#1051510).
- iio: adc: at91: fix acking DRDY irq on simple conversions
  (bsc#1051510).
- iio: adc: imx25-gcq: Fix leak of device_node in
  mx25_gcq_setup_cfgs() (bsc#1051510).
- commit 9f4f0cc
* Tue Oct 30 2018 tiwai@suse.de
- media: v4l2-tpg: fix kernel oops when enabling HFLIP and OSD
  (bsc#1051510).
- media: cx231xx: fix potential sign-extension overflow on large
  shift (bsc#1051510).
- media: pci: cx23885: handle adding to list failure
  (bsc#1051510).
- media: vsp1: Fix YCbCr planar formats pitch calculation
  (bsc#1051510).
- media: tvp5150: fix switch exit in set control handler
  (bsc#1051510).
- media: tvp5150: fix width alignment during set_selection()
  (bsc#1051510).
- media: em28xx: fix input name for Terratec AV 350 (bsc#1051510).
- media: em28xx: use a default format if TRY_FMT fails
  (bsc#1051510).
- media: tvp5150: avoid going past array on v4l2_querymenu()
  (bsc#1051510).
- media: dvb: fix compat ioctl translation (bsc#1051510).
- media: uvcvideo: Fix uvc_alloc_entity() allocation alignment
  (bsc#1051510).
- commit 0831c5e
* Tue Oct 30 2018 tiwai@suse.de
- drm/i915/dp: Link train Fallback on eDP only if fallback link
  BW can fit panel's native mode (bsc#1051510).
- drm/i915: Restore vblank interrupts earlier (bsc#1051510).
- commit daf120f
* Tue Oct 30 2018 jslaby@suse.cz
- tools build: fix # escaping in .cmd files for future Make
  (git-fixes).
- Kbuild: fix # escaping in .cmd files for future Make
  (git-fixes).
- commit 8f11ec3
* Tue Oct 30 2018 jdelvare@suse.de
- Add reference to bsc#1104124 to
  patches.fixes/fs-aio-fix-the-increment-of-aio-nr-and-counting-agai.patch
- commit f60e64b
* Tue Oct 30 2018 jslaby@suse.cz
- blacklist.conf: add a kasan fix
- commit c85e2d1
* Tue Oct 30 2018 jslaby@suse.cz
- random: rate limit unseeded randomness warnings (git-fixes).
- commit be52b92
* Tue Oct 30 2018 ohering@suse.de
- move changes without Git-commit out of sorted section
- commit cbf049e
* Tue Oct 30 2018 jmoreira@suse.de
- Add version information to KLP_SYMBOLS file
- commit f77f8d2
* Mon Oct 29 2018 tiwai@suse.de
- Refresh patch tag of upstreamed patches and move to sorted section
- commit a966b56
* Mon Oct 29 2018 tiwai@suse.de
- usb: gadget: fsl_udc_core: fixup struct_udc_setup documentation
  (bsc#1051510).
- usb: gadget: fsl_udc_core: check allocation return value and
  cleanup on failure (bsc#1051510).
- commit c1b7b66
* Mon Oct 29 2018 tiwai@suse.de
- blacklist.conf: Add ASoC and USB entries that may break kABI
- commit 199a072
* Mon Oct 29 2018 tiwai@suse.de
- NFC: nfcmrvl_uart: fix OF child-node lookup (bsc#1051510).
- kernfs: update comment about kernfs_path() return value
  (bsc#1051510).
- usbip: tools: fix atoi() on non-null terminated string
  (bsc#1051510).
- USB: serial: cypress_m8: fix interrupt-out transfer length
  (bsc#1051510).
- usb: chipidea: Prevent unbalanced IRQ disable (bsc#1051510).
- commit 6c9d1e7
* Mon Oct 29 2018 msuchanek@suse.de
- powerpc/pseries: Fix "OF: ERROR: Bad of_node_put() on /cpus" during DLPAR (FATE#326628, bsc#1113295).
- Refresh patches.arch/hotplug-cpu-Conditionally-acquire-release-DRC-index.patch.
- commit cf3caf9
* Mon Oct 29 2018 jslaby@suse.cz
- tty: fix data race between tty_init_dev and flush of buf
  (bnc#1105428).
- commit d1662c6
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/i915/gen9+: Fix initial readout for Y tiled framebuffers (bsc#1113722)
- commit 0e8f289
* Mon Oct 29 2018 msuchanek@suse.de
- powerpc: pseries: remove dlpar_attach_node dependency on full
  path (FATE#326628, bsc#1113295).
- Refresh patches.arch/powerpc-pseries-Fix-parent_dn-reference-leak-in-add_.patch.
- commit 01fc86e
* Mon Oct 29 2018 jslaby@suse.cz
- tty/ldsem: Decrement wait_readers on timeouted down_read()
  (bnc#1105428).
- commit cb04f9d
* Mon Oct 29 2018 jslaby@suse.cz
- tty/ldsem: Add lockdep asserts for ldisc_sem (bnc#1105428).
- commit ac6d068
* Mon Oct 29 2018 jslaby@suse.cz
- tty/ldsem: Convert to regular lockdep annotations (bnc#1105428).
- commit 7d9663d
* Mon Oct 29 2018 jslaby@suse.cz
- tty: Simplify tty->count math in tty_reopen() (bnc#1105428).
- commit 26f737e
* Mon Oct 29 2018 jslaby@suse.cz
- tty: Hold tty_ldisc_lock() during tty_reopen() (bnc#1105428).
- commit cdebccb
* Mon Oct 29 2018 jslaby@suse.cz
- tty/ldsem: Wake up readers after timed out down_write()
  (bnc#1105428).
- commit b5397b5
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/amdgpu/powerplay: fix missing break in switch statements (bsc#1113722)
- commit d8335be
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/hisilicon: hibmc: Don't overwrite fb helper surface depth (bsc#1113722)
- commit 724e354
* Mon Oct 29 2018 tiwai@suse.de
- cdrom: fix improper type cast, which can leat to information
  leak (CVE-2018-18710,bsc#1113751).
- commit 1ead5be
* Mon Oct 29 2018 jack@suse.cz
- blacklist.conf: Blacklist 078d5039a13d
- commit ad5c0a6
* Mon Oct 29 2018 jack@suse.cz
- blacklist.conf: Blacklist 573e1784817c
- commit eda7ca6
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/hisilicon: hibmc: Do not carry error code in HiBMC framebuffer (bsc#1113722)
- commit bd3852b
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/i915/audio: Hook up component bindings even if displays are (bsc#1113722)
- commit 717c07b
* Mon Oct 29 2018 tzimmermann@suse.de
- blacklist.conf: Append 'drm/i915: Restore user forcewake domains across suspend'
- commit 9ac3dbb
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/virtio: fix bounds check in virtio_gpu_cmd_get_capset() (bsc#1113722)
- commit 0a4cfd8
* Mon Oct 29 2018 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm: crc: Wait for a frame before returning from open()"'
- commit d49a532
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/sti: do not remove the drm_bridge that was never added (bsc#1100132)
- commit 473bdf0
* Mon Oct 29 2018 tzimmermann@suse.de
- of: add helper to lookup compatible child node (bsc#1106110)
- commit 289c86e
* Mon Oct 29 2018 msuchanek@suse.de
- powerpc/mm/hugetlb: initialize the pagetable cache correctly
  for hugetlb (bsc#1091800).
- commit 3c8d710
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/msm: fix OF child-node lookup (bsc#1106110)
- commit b8a96ce
* Mon Oct 29 2018 tzimmermann@suse.de
- drm/mediatek: fix OF sibling-node lookup (bsc#1106110)
- commit abf06ce
* Mon Oct 29 2018 wqu@suse.com
- btrfs: Ensure btrfs_trim_fs can trim the whole filesystem
  (bsc#1113667).
- commit ea270ee
* Mon Oct 29 2018 wqu@suse.com
- btrfs: Enhance btrfs_trim_fs function to handle error  better
  (Dependency for bsc#1113667).
- commit e04f37d
* Fri Oct 26 2018 tiwai@suse.de
- Refresh & sort upstreamed scsi patches that landed in 4.20-rc1
- commit 1c95aa5
* Fri Oct 26 2018 tiwai@suse.de
- blacklist.conf: Add entries that were reverted in stable tree
- commit 7da9695
* Fri Oct 26 2018 tiwai@suse.de
- Documentation/l1tf: Fix small spelling typo (bsc#1051510).
- Refresh
  patches.arch/kvm-vmx-tell-the-nested-hypervisor-to-skip-l1d-flush-on-vmentry.
- blacklist.conf: Remove the documentation fix commit we're adding here
- commit 324f5d6
* Fri Oct 26 2018 tiwai@suse.de
- hwrng: core - document the quality field (bsc#1051510).
- crypto: lrw - Fix out-of bounds access on counter overflow
  (bsc#1051510).
- crypto: tcrypt - fix ghash-generic speed test (bsc#1051510).
- crypto: caam - fix implicit casts in endianness helpers
  (bsc#1051510).
- PCI/ASPM: Fix link_state teardown on device removal
  (bsc#1051510).
- mfd: arizona: Correct calling of runtime_put_sync (bsc#1051510).
- commit 3a46ec1
* Fri Oct 26 2018 tiwai@suse.de
- ASoC: intel: skylake: Add missing break in skl_tplg_get_token()
  (bsc#1051510).
- ALSA: hda: Add 2 more models to the power_save blacklist
  (bsc#1051510).
- ALSA: hda - Add mic quirk for the Lenovo G50-30 (17aa:3905)
  (bsc#1051510).
- ALSA: hda/realtek - Fix the problem of the front MIC on the
  Lenovo M715 (bsc#1051510).
- ALSA: hda - Fix headphone pin config for ASUS G751
  (bsc#1051510).
- ALSA: hda - Add quirk for ASUS G751 laptop (bsc#1051510).
- ALSA: usb-audio: update quirk for B&W PX to remove microphone
  (bsc#1051510).
- ALSA: hda: fix unused variable warning (bsc#1051510).
- commit e738dd9
* Thu Oct 25 2018 msuchanek@suse.de
- powerpc/mm: Rename find_linux_pte_or_hugepte() (bsc#1061840).
- KABI: powerpc: export __find_linux_pte as __find_linux_pte_or_hugepte (bsc#1061840).
- Refresh patches.arch/KVM-PPC-Book3S-Fix-guest-DMA-when-guest-partially-ba.patch.
- Refresh patches.arch/KVM-PPC-Book3S-HV-Fix-handling-of-large-pages-in-rad.patch.
- Refresh patches.arch/KVM-PPC-Check-if-IOMMU-page-is-contained-in-the-pinn.patch.
- Refresh patches.arch/powerpc-introduce-get_mm_addr_key-helper.patch
- commit 65dca83
* Thu Oct 25 2018 mwilck@suse.com
- rpm/kernel-binary.spec.in: allow unsupported modules for -extra
  (bsc#1111183). SLE-15 and later only.
- commit 0d585a8
* Thu Oct 25 2018 msuchanek@suse.de
- kabi/severities: ignore __xive_vm_h_* KVM internal symbols.
- commit 48671d6
* Thu Oct 25 2018 msuchanek@suse.de
- Update patches.arch/KVM-PPC-Book3S-HV-Snapshot-timebase-offset-on-guest-.patch (bsc#1061840, bsc#1086196).
- Delete patches.arch/KVM-PPC-Book3S-HV-Disable-tb_offset.patch.
- commit 1e43c4c
* Thu Oct 25 2018 tiwai@suse.de
- Move x86 patches that have been upstreamed into the sorted section
  Refreshed some patches to be applied cleanly, too.
  The expanded result is 100%% identical with the state before this change.
- commit d2d8b17
* Thu Oct 25 2018 tiwai@suse.de
- Update patch tag: patches.arch/x86-pti-xenpv-dont-report-as-vulnerable.patch
- commit f902aac
* Thu Oct 25 2018 ailiopoulos@suse.com
- xfs: don't fail when converting shortform attr to long form
  during ATTR_REPLACE (bsc#1105025).
- commit 23725d0
* Thu Oct 25 2018 tiwai@suse.de
- iwlwifi: pcie gen2: check iwl_pcie_gen2_set_tb() return value
  (bsc#1051510).
- iwlwifi: pcie: gen2: build A-MSDU only for GSO (bsc#1051510).
- commit ae71040
* Thu Oct 25 2018 tiwai@suse.de
- Update & sort upstreamed nvme patches
- commit 9487773
* Thu Oct 25 2018 mkubecek@suse.cz
- xfrm: use complete IPv6 addresses for hash (bsc#1109330).
- commit edb4e4e
* Thu Oct 25 2018 mkubecek@suse.cz
- ethtool: fix a privilege escalation bug (bsc#1076830).
- commit eb308cd
* Thu Oct 25 2018 jroedel@suse.de
- blacklist.conf: Add 60ca05c3b445 Documentation/l1tf: Fix small spelling typo
- commit bcf8eae
* Thu Oct 25 2018 jack@suse.cz
- loop: fix LOOP_GET_STATUS lock imbalance (bsc#1113284).
- commit 5201e63
* Thu Oct 25 2018 tiwai@suse.de
- USB: remove LPM management from usb_driver_claim_interface()
  (bsc#1051510).
- Refresh
  patches.drivers/USB-fix-error-handling-in-usb_driver_claim_interface.patch.
- commit 2bd2e21
* Thu Oct 25 2018 jgross@suse.com
- blacklist.conf: added 0ce0bba4e5e0 as it has too many dependencies on
  other patches and is only a small enhancement (no bug correction)
- commit c03f1e9
* Thu Oct 25 2018 jgross@suse.com
- Refresh patches.fixes/xen-xsa270-fix.patch: add upstream commit-id and
  move it to the sorted area in series.conf
- commit 072bdae
* Thu Oct 25 2018 jack@suse.cz
- jbd2: fix use after free in jbd2_log_do_checkpoint()
  (bsc#1113257).
- commit 596d6c3
* Thu Oct 25 2018 jroedel@suse.de
- signal: Properly deliver SIGSEGV from x86 uprobes (bsc#1110006).
- commit 3269a6e
* Wed Oct 24 2018 tiwai@suse.de
- mac80211: minstrel: fix using short preamble CCK rates on HT
  clients (bsc#1051510).
- iwlwifi: mvm: clear HW_RESTART_REQUESTED when stopping the
  interface (bsc#1051510).
- iwlwifi: mvm: check for n_profiles validity in EWRD ACPI
  (bsc#1051510).
- iwlwifi: mvm: Allow TKIP for AP mode (bsc#1051510).
- iwlwifi: dbg: don't crash if the firmware crashes in the middle
  of a debug dump (bsc#1051510).
- iwlwifi: mvm: send BCAST management frames to the right station
  (bsc#1051510).
- ACPI / processor: Fix the return value of
  acpi_processor_ids_walk() (bsc#1051510).
- i2c: rcar: cleanup DMA for all kinds of failure (bsc#1051510).
- drm/edid: VSDB yCBCr420 Deep Color mode bit definitions
  (bsc#1051510).
- clocksource/drivers/ti-32k: Add CLOCK_SOURCE_SUSPEND_NONSTOP
  flag for non-am43 SoCs (bsc#1051510).
- drm: mali-dp: Call drm_crtc_vblank_reset on device init
  (bsc#1051510).
- media: af9035: prevent buffer overflow on write (bsc#1051510).
- drm/i915/glk: Add Quirk for GLK NUC HDMI port issues
  (bsc#1051510).
- commit d3ef3e7
* Wed Oct 24 2018 jroedel@suse.de
- x86/eisa: Add missing include (bsc#1110006).
- Refresh
  patches.arch/x86-eisa-don-t-probe-eisa-bus-for-xen-pv-guests.
- commit 57cec9b
* Wed Oct 24 2018 jroedel@suse.de
- x86/fpu: Remove second definition of fpu in __fpu__restore_sig()
  (bsc#1110006).
- commit b660f5e
* Wed Oct 24 2018 jroedel@suse.de
- x86/time: Correct the attribute on jiffies' definition
  (bsc#1110006).
- commit 885e86c
* Wed Oct 24 2018 jroedel@suse.de
- x86/percpu: Fix this_cpu_read() (bsc#1110006).
- commit 0233af7
* Wed Oct 24 2018 jroedel@suse.de
- x86/boot: Move EISA setup to a separate file (bsc#1110006).
- x86/EISA: Don't probe EISA bus for Xen PV guests (bsc#1110006).
- Refresh
  patches.arch/19-x86-entry-64-move-the-ist-stacks-into-struct-cpu_entry_area.patch.
- commit a5799f5
* Wed Oct 24 2018 jroedel@suse.de
- kprobes/x86: Fix %%p uses in error messages (bsc#1110006).
- commit fb3eeb4
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add b7b73cd5d746 crypto: x86/salsa20 - remove x86 salsa20 implementations
- commit c51f1c8
* Wed Oct 24 2018 jroedel@suse.de
- x86/MCE: Fix stack out-of-bounds write in mce-inject.c:
  Flags_read() (bsc#1110006).
- commit 3dc5215
* Wed Oct 24 2018 jroedel@suse.de
- x86/acpi: Prevent X2APIC id 0xffffffff from being accounted
  (bsc#1110006).
- commit 274ac9d
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add arch/x86/um
- commit 7688a2d
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 4d1a535b8ec5 um: Use POSIX ucontext_t instead of struct ucontext
- commit a390c7e
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 8a331f4a0863 x86/mce/AMD: Carve out SMCA get_block_address() code
- commit 6260365
* Wed Oct 24 2018 jroedel@suse.de
- x86/cpufeatures: Add Intel Total Memory Encryption cpufeature
  (bsc#1110006).
- commit f0bb5db
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add d5028ba8ee5a objtool, retpolines: Integrate objtool with retpoline support more closely
- commit 1d09c07
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 700b7c5409c3 x86/asm: Improve how GEN_*_SUFFIXED_RMWcc() specify clobbers
- commit c180f6a
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 3b3a9268bba6 x86/mm: Remove stale comment about KMEMCHECK
- commit feffe23
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add b399151cb48d x86/cpu: Rename cpu_data.x86_mask to cpu_data.x86_stepping
- commit b15eecb
* Wed Oct 24 2018 jroedel@suse.de
- x86/kasan: Panic if there is not enough memory to boot
  (bsc#1110006).
- commit fb9f1fc
* Wed Oct 24 2018 jroedel@suse.de
- x86/cpufeature: Add User-Mode Instruction Prevention definitions
  (bsc#1110006).
- commit 0e0e81a
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 4675ff05de2d kmemcheck: rip it out
- commit 949cfa4
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add d8be75663cec kmemcheck: remove whats left of NOTRACK flags
- commit 5904402
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 75f296d93bce kmemcheck: stop using GFP_NOTRACK and SLAB_NOTRACK
- commit 90f82ae
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 2d0b95300db x86/insn-eval: Add utility functions to get segment selector
- commit f98113f
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add f3a624e901c6 x86/cpufeatures: Fix various details in the feature definitions
- commit 5b5313e
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add acbc845ffefd x86/cpufeatures: Re-tabulate the X86_FEATURE definitions
- commit 520e9bf
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 4375c29985f1 x86/xen: Provide pre-built page tables only for CONFIG_XEN_PV=y and CONFIG_XEN_PVH=y
- commit bdc9e91
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 12a8cc7fcf54 x86/kasan: Use the same shadow offset for 4- and 5-level paging
- commit 55c2333
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 3c52b5c64326 x86/asm: Remove unnecessary \n\t in front of CC_SET() from asm templates
- commit 1572a99
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Add 890da9cf0983 Revert "x86: do not use cpufreq_quick_get() for /proc/cpuinfo "cpu MHz""
- commit 65a0d66
* Wed Oct 24 2018 jgross@suse.com
- xen: Remove unnecessary BUG_ON from __unbind_from_irq()
  (bnc#1065600).
- commit 23eb96a
* Wed Oct 24 2018 jroedel@suse.de
- blacklist.conf: Blacklist tools/testing/selftests/
- commit 774f832
* Wed Oct 24 2018 jgross@suse.com
- xen-swiotlb: fix the check condition for
  xen_swiotlb_free_coherent (bnc#1065600).
- commit 02af14f
* Wed Oct 24 2018 hare@suse.de
- scsi: core: Allow state transitions from OFFLINE to BLOCKED
  (bsc#1112246).
- commit 034f4ab
* Wed Oct 24 2018 jgross@suse.com
- xen/gntdev: avoid out of bounds access in case of partial
  gntdev_mmap() (bnc#1065600).
- commit e8abcae
* Wed Oct 24 2018 hare@suse.de
- scsi: libfc: check fc_frame_payload_get() return value for null
  (bsc#1104731).
- commit 4a5ddfb
* Wed Oct 24 2018 hare@suse.de
- scsi: libfc: retry PRLI if we cannot analyse the payload
  (bsc#1104731).
- commit b5e815d
* Wed Oct 24 2018 jgross@suse.com
- x86/paravirt: Fix some warning messages (bnc#1065600).
- commit 5532422
* Wed Oct 24 2018 neilb@suse.com
- rculist: Improve documentation for
  list_for_each_entry_from_rcu() (bsc#1084760).
- NFS: Avoid quadratic search when freeing delegations
  (bsc#1084760).
- rculist: add list_for_each_entry_from_rcu() (bsc#1084760).
- commit 73b9891
* Tue Oct 23 2018 jroedel@suse.de
- kvm: x86: Set highest physical address bits in non-present/reserved SPTEs (bsc#1106240).
- commit 423e118
* Tue Oct 23 2018 jroedel@suse.de
- KVM: SVM: Add MSR-based feature support for serializing LFENCE
  (bsc#1106240).
- KVM: VMX: support MSR_IA32_ARCH_CAPABILITIES as a feature MSR
  (bsc#1106240).
- KVM: VMX: Tell the nested hypervisor to skip L1D flush on
  vmentry (bsc#1106240).
- KVM: x86: Add a framework for supporting MSR-based features
  (bsc#1106240).
- KVM: X86: Introduce kvm_get_msr_feature() (bsc#1106240).
- kABI: Hide get_msr_feature() in kvm_x86_ops (bsc#1106240).
- blacklist.conf: Add 518e7b94817a KVM: X86: Allow userspace to define the microcode version
- Refresh
  patches.arch/36-x86-bugs-kvm-extend-speculation-control-for-virt_spec_ctrl.patch.
- Refresh
  patches.arch/44-kvm-svm-implement-virt_spec_ctrl-support-for-ssbd.patch.
- Refresh patches.kabi/fix-kvm-kabi.patch.
- commit 7c74fa0
* Tue Oct 23 2018 aaptel@suse.com
- smb2: fix missing files in root share directory listing
  (bsc#1112907).
- commit 46fa9a8
* Tue Oct 23 2018 aaptel@suse.com
- smb3: fix reset of bytes read and written stats (bsc#1112906).
- commit 37b0dd6
* Tue Oct 23 2018 aaptel@suse.com
- smb3: fill in statfs fsid and correct namelen (bsc#1112905).
- commit 3170c32
* Tue Oct 23 2018 aaptel@suse.com
- cifs: Fix use after free of a mid_q_entry (bsc#1112903).
- commit 59c5474
* Tue Oct 23 2018 aaptel@suse.com
- CIFS: check for STATUS_USER_SESSION_DELETED (bsc#1112902).
- commit fc3cc61
* Tue Oct 23 2018 aaptel@suse.com
- smb3: on reconnect set PreviousSessionId field (bsc#1112899).
- commit 37c1dc0
* Tue Oct 23 2018 aaptel@suse.com
- cifs: fix memory leak in SMB2_open() (bsc#1112894).
- commit 00b7823
* Tue Oct 23 2018 tiwai@suse.de
- HID: quirks: fix support for Apple Magic Keyboards
  (bsc#1051510).
- commit a6ba2b6
* Tue Oct 23 2018 jslaby@suse.cz
- rpmsg: Correct support for MODULE_DEVICE_TABLE() (git-fixes).
- commit a6ff26a
* Tue Oct 23 2018 jgross@suse.com
- series.conf: moved some Xen patches to the sorted region
  xen/blkfront: correct purging of persistent grants
  (bnc#1112514).
- commit 269a89f
* Mon Oct 22 2018 msuchanek@suse.de
- powerpc/pseries: Fix CONFIG_NUMA=n build (FATE#323745, FATE#322022, bsc#1067906, git-fixes).
- powerpc/pseries: Fix build break for SPLPAR=n and CPU hotplug (FATE#323746, bsc#1079524, git-fixes).
- Refresh patches.arch/powerpc-topology-Get-topology-for-shared-processors-.patch.
- commit 1ac9292
* Mon Oct 22 2018 jeffm@suse.com
- blacklist.conf: add debugfs removal protection rework (bsc#1109911).
  This introduces semantic changes that break the kABI in a way that is
  not worth working around.
- commit 9a0c809
* Mon Oct 22 2018 jroedel@suse.de
- blacklist.conf: Add a stable patch that is reverted
  95e057e25892 KVM: X86: Fix SMRAM accessing even if VM is shutdown
  2c151b25441a Revert "KVM: X86: Fix SMRAM accessing even if VM is shutdown"
- commit 5cd21ff
* Mon Oct 22 2018 jroedel@suse.de
- blacklist.conf: Blacklist PCI stable commits 7506dc798993 and 79aa801e8994
  79aa801e8994 PCI: hv: Use effective affinity mask
  7506dc798993 PCI: Add wrappers for dev_printk()
- commit 21a280c
* Mon Oct 22 2018 jroedel@suse.de
- PCI: hv: Do not wait forever on a device that has disappeared
  (bsc#1109806).
- Refresh
  patches.suse/msft-hv-1728-PCI-hv-Disable-enable-IRQs-rather-than-BH-in-hv_comp.patch.
- commit 9972a8c
* Mon Oct 22 2018 jslaby@suse.cz
- blacklist.conf: add some clang and typo fixes
- commit 413a83a
* Mon Oct 22 2018 jack@suse.cz
- bdi: Preserve kabi when adding cgwb_release_mutex (bsc#1112746).
- commit 8f875e8
* Mon Oct 22 2018 jroedel@suse.de
- iommu/vt-d: Fix dev iotlb pfsid use (bsc#1106237).
- iommu/vt-d: Add definitions for PFSID (bsc#1106237).
- commit 3ec7bb4
* Mon Oct 22 2018 jroedel@suse.de
- iommu/arm-smmu: Error out only if not enough context interrupts
  (bsc#1106237).
- commit ee44345
* Mon Oct 22 2018 jroedel@suse.de
- iommu/vt-d: Fix scatterlist offset handling (bsc#1106237).
- commit 6b0b30d
* Mon Oct 22 2018 jroedel@suse.de
- blacklist.conf: Add two x86 selftest fixes
  327d53d005ca selftests/x86/entry_from_vm86: Exit with 1 if we fail
  78393fdde2a4 selftests/x86/entry_from_vm86: Add test cases for POPF
- commit ad5b66b
* Mon Oct 22 2018 tzimmermann@suse.de
- drm/sun4i: Fix an ulong overflow in the dotclock driver (bsc#1106110)
- commit 2ecbb1f
* Mon Oct 22 2018 jack@suse.cz
- blacklist.conf: Blacklist 2fa147bdbf67
- commit aa66291
* Mon Oct 22 2018 jack@suse.cz
- bdi: Fix another oops in wb_workfn() (bsc#1112746).
- commit 09dea87
* Mon Oct 22 2018 jack@suse.cz
- fs/quota: Fix spectre gadget in do_quotactl (bsc#1112745).
- commit 58e0987
* Mon Oct 22 2018 jack@suse.cz
- ext4: don't mark mmp buffer head dirty (bsc#1112743).
- commit e1b1717
* Mon Oct 22 2018 jack@suse.cz
- ext4: show test_dummy_encryption mount option in /proc/mounts
  (bsc#1112741).
- commit bf6af08
* Mon Oct 22 2018 jack@suse.cz
- ext4: fix online resizing for bigalloc file systems with a 1k
  block size (bsc#1112740).
- commit 755fb2e
* Mon Oct 22 2018 jack@suse.cz
- ext4: fix online resize's handling of a too-small final block
  group (bsc#1112739).
- commit 4241727
* Mon Oct 22 2018 jack@suse.cz
- ext4: recalucate superblock checksum after updating free
  blocks/inodes (bsc#1112738).
- commit d66ab05
* Mon Oct 22 2018 jack@suse.cz
- ext4: avoid arithemetic overflow that can trigger a BUG
  (bsc#1112736).
- commit 568d77e
* Mon Oct 22 2018 jack@suse.cz
- ext4: avoid divide by zero fault when deleting corrupted inline
  directories (bsc#1112735).
- commit 60df32c
* Mon Oct 22 2018 jack@suse.cz
- ext4: check to make sure the rename(2)'s destination is not
  freed (bsc#1112734).
- commit 1e2b6d8
* Mon Oct 22 2018 jack@suse.cz
- ext4: fix spectre gadget in ext4_mb_regular_allocator()
  (bsc#1112733).
- commit 43aee3f
* Mon Oct 22 2018 jack@suse.cz
- ext4: check for NUL characters in extended attribute's name
  (bsc#1112732).
- commit 051f809
* Mon Oct 22 2018 jack@suse.cz
- ext4: reset error code in ext4_find_entry in fallback
  (bsc#1112731).
- commit 2423ca0
* Mon Oct 22 2018 tzimmermann@suse.de
- blacklist.conf: Append 'drm/syncobj: Don't leak fences when WAIT_FOR_SUBMIT is set'
- commit 8d4c3e3
* Mon Oct 22 2018 tiwai@suse.de
- cdc-acm: fix race between reset and control messaging
  (bsc#1051510).
- Input: atakbd - fix Atari CapsLock behaviour (bsc#1051510).
- Input: atakbd - fix Atari keymap (bsc#1051510).
- intel_th: pci: Add Ice Lake PCH support (bsc#1051510).
- batman-adv: fix hardif_neigh refcount on queue_work() failure
  (bsc#1051510).
- batman-adv: fix backbone_gw refcount on queue_work() failure
  (bsc#1051510).
- batman-adv: Avoid probe ELP information leak (bsc#1051510).
- commit d93a6b6
* Mon Oct 22 2018 tiwai@suse.de
- blacklist.conf: Add a cpufreq reverting commit
- commit a201876
* Mon Oct 22 2018 jack@suse.cz
- blk-mq: I/O and timer unplugs are inverted in blktrace
  (bsc#1112713).
- commit d64676d
* Mon Oct 22 2018 jack@suse.cz
- block: bfq: swap puts in bfqg_and_blkg_put (bsc#1112712).
- commit 3937d10
* Mon Oct 22 2018 jack@suse.cz
- loop: add recursion validation to LOOP_CHANGE_FD (bsc#1112711).
- commit ff26b7f
* Mon Oct 22 2018 jack@suse.cz
- blacklist.conf: Blacklist d3349b6b3c37
- commit 09777ad
* Mon Oct 22 2018 jack@suse.cz
- loop: don't call into filesystem while holding lo_ctl_mutex
  (bsc#1112710).
- commit 63bdbdf
* Mon Oct 22 2018 jack@suse.cz
- block, bfq: fix wrong init of saved start time for weight
  raising (bsc#1112708).
- commit b8dbd55
* Mon Oct 22 2018 tzimmermann@suse.de
- drm/amdgpu: Fix vce work queue was not cancelled when suspend (bsc#1106110)
- commit 223f5ac
* Mon Oct 22 2018 neilb@suse.com
- Fix kABI for "Ensure we commit after writeback is complete" (bsc#1111809).
- commit e67052d
* Mon Oct 22 2018 neilb@suse.com
- NFS: Ensure we commit after writeback is complete (bsc#1111809).
- commit f42d953
* Fri Oct 19 2018 jeffm@suse.com
- reiserfs: don't panic on bad directory entries (bsc#1109818).
- reiserfs: add check to detect corrupted directory entry
  (bsc#1109818).
- commit deb9838
* Fri Oct 19 2018 jroedel@suse.de
- kvm: Make VM ioctl do valloc for some archs (bsc#1111506).
- KVM: x86: define SVM/VMX specific kvm_arch_[alloc|free]_vm
  (bsc#1111506).
- kvm/x86: kABI fix for vm_alloc/vm_free changes (bsc#1111506).
- Refresh
  patches.arch/01-x86-KVM-Warn-user-if-KVM-is-loaded-SMT-and-L1TF-CPU-.patch.
- Refresh
  patches.arch/44-kvm-svm-implement-virt_spec_ctrl-support-for-ssbd.patch.
- Refresh patches.kabi/fix-kvm-kabi.patch.
- commit be44bf0
* Fri Oct 19 2018 jack@suse.cz
- dax: Fix deadlock in dax_lock_mapping_entry() (bsc#1109951).
- commit 6f280f7
* Fri Oct 19 2018 jack@suse.cz
- ext2, dax: set ext2_dax_aops for dax files (bsc#1112554).
- commit dd35f89
* Fri Oct 19 2018 tiwai@suse.de
- blacklist.conf: Import more entries from "easter egg"
  The blacklist entries for stable trees that have been kept internally are
  imported here.  Some commit IDs are for stable git tree, not Linus tree.
- commit 02f457e
* Fri Oct 19 2018 mgorman@suse.de
- sched/numa: Limit the conditions where scan period is reset
  (fate#326522).
- commit 3699e54
* Fri Oct 19 2018 jack@suse.cz
- Update tags
  patches.fixes/mm-Preserve-_PAGE_DEVMAP-across-mprotect-calls.patch.
- commit f0e8a69
* Fri Oct 19 2018 glin@suse.com
- bpf/verifier: disallow pointer subtraction (bsc#1083647).
- commit 0dd7d65
* Fri Oct 19 2018 glin@suse.com
- bpf: 32-bit RSH verification must truncate input before the
  ALU op (bsc#1112372 CVE-2018-18445).
- commit 9004fee
* Fri Oct 19 2018 msuchanek@suse.de
- powerpc/powernv/ioda2: Reduce upper limit for DMA window size
  (bsc#1055120).
- commit 5723dd6
* Thu Oct 18 2018 ohering@suse.de
- hv: avoid crash in vmbus sysfs files (bnc#1108377).
- commit 1dc9562
* Thu Oct 18 2018 tiwai@suse.de
- scripts/series2git: Revert the change mistakenly taken
  A "fix" for series2git went in mistakenly among other patches.
  Revert it here.  It'll be picked up from a proper branch if need.
- commit 4463d2b
* Thu Oct 18 2018 tiwai@suse.de
- mach64: detect the dot clock divider correctly on sparc
  (bsc#1051510).
- drm/amdgpu: Fix SDMA HQD destroy error on gfx_v7 (bsc#1051510).
- commit 6ef7e4c
* Thu Oct 18 2018 tiwai@suse.de
- mmc: block: avoid multiblock reads for the last sector in SPI
  mode (bsc#1051510).
- qmi_wwan: Added support for Gemalto's Cinterion ALASxx WWAN
  interface (bsc#1051510).
- i2c: i2c-scmi: fix for i2c_smbus_write_block_data (bsc#1051510).
- xhci: Don't print a warning when setting link state for disabled
  ports (bsc#1051510).
- commit 4765254
* Thu Oct 18 2018 tiwai@suse.de
- clk: x86: Stop marking clocks as CLK_IS_CRITICAL (bsc#1051510).
- clk: x86: add "ether_clk" alias for Bay Trail / Cherry Trail
  (bsc#1051510).
- commit 98a57f6
* Thu Oct 18 2018 tiwai@suse.de
- ASoC: Intel: Skylake: Reset the controller in probe
  (bsc#1051510).
- ASoC: rsnd: adg: care clock-frequency size (bsc#1051510).
- ASoC: rsnd: don't fallback to PIO mode when -EPROBE_DEFER
  (bsc#1051510).
- ASoC: rt5514: Fix the issue of the delay volume applied again
  (bsc#1051510).
- ASoC: sigmadsp: safeload should not have lower byte limit
  (bsc#1051510).
- ASoC: wm8804: Add ACPI support (bsc#1051510).
- sound: don't call skl_init_chip() to reset intel skl soc
  (bsc#1051510).
- sound: enable interrupt after dma buffer initialization
  (bsc#1051510).
- scripts/series2git:
- commit 0b6b9ae
* Thu Oct 18 2018 pmladek@suse.com
- blacklist.conf: tracing: we do not have support for recording
  tgid of tasks (bsc#1112221)
- commit 44f8248
* Thu Oct 18 2018 jslaby@suse.cz
- Update
  patches.suse/n_tty-fix-EXTPROC-vs-ICANON-interaction-with-TIOCINQ.patch
  (bnc#1094825 bnc#1094825 bnc#1110711 CVE-2018-18386).
  Add few more bug references.
- commit 4828f50
* Wed Oct 17 2018 ohering@suse.de
- Use upstream version of pci-hyperv patch (35a88a1)
- commit 8e9eeb6
* Wed Oct 17 2018 ohering@suse.de
- hv_netvsc: fix schedule in RCU context (fate#323887).
- commit 0b48504
* Wed Oct 17 2018 ohering@suse.de
- rename a hv patch to reduce conflicts in -AZURE
- commit fe9e48c
* Wed Oct 17 2018 bp@suse.de
- blacklist.conf:
  Blacklsit a fix for a selftest for which the corresponding commit
  is not in the tree.
- commit b571af7
* Wed Oct 17 2018 tiwai@suse.de
- tools/vm/page-types.c: fix "defined but not used" warning
  (bsc#1051510).
- tools/vm/slabinfo.c: fix sign-compare warning (bsc#1051510).
- commit c619f32
* Wed Oct 17 2018 tiwai@suse.de
- orangefs_kill_sb(): deal with allocation failures (bsc#1051510).
- orangefs: fix deadlock; do not write i_size in read_iter
  (bsc#1051510).
- orangefs: initialize op on loop restart in orangefs_devreq_read
  (bsc#1051510).
- orangefs: use list_for_each_entry_safe in purge_waiting_ops
  (bsc#1051510).
- commit 4e459f9
* Wed Oct 17 2018 tiwai@suse.de
- lib/ubsan: add type mismatch handler for new GCC/Clang
  (bsc#1051510).
- lib/ubsan.c: s/missaligned/misaligned/ (bsc#1051510).
- commit 3c2ef75
* Wed Oct 17 2018 tiwai@suse.de
- hfs: prevent crash on exit from failed search (bsc#1051510).
- hfsplus: don't return 0 when fill_super() failed (bsc#1051510).
- hfsplus: stop workqueue when fill_super() failed (bsc#1051510).
- commit 0c45ade
* Wed Oct 17 2018 tiwai@suse.de
- enic: do not call enic_change_mtu in enic_probe (bsc#1051510).
- enic: handle mtu change for vf properly (bsc#1051510).
- enic: initialize enic->rfs_h.lock in enic_probe (bsc#1051510).
- commit 301b62d
* Wed Oct 17 2018 tiwai@suse.de
- eeprom: at24: change nvmem stride to 1 (bsc#1051510).
- eeprom: at24: check at24_read/write arguments (bsc#1051510).
- eeprom: at24: correctly set the size for at24mac402
  (bsc#1051510).
- commit 8527cec
* Wed Oct 17 2018 tiwai@suse.de
- e1000: ensure to free old tx/rx rings in set_ringparam()
  (bsc#1051510).
- e1000: check on netif_running() before calling e1000_up()
  (bsc#1051510).
- commit 7b92e7c
* Wed Oct 17 2018 tiwai@suse.de
- coda: fix 'kernel memory exposure attempt' in fsync
  (bsc#1051510).
- commit c648d53
* Wed Oct 17 2018 tiwai@suse.de
- clocksource/drivers/timer-atmel-pit: Properly handle error cases
  (bsc#1051510).
- commit dae9c32
* Wed Oct 17 2018 pmladek@suse.com
- tracing: Add barrier to trace_printk() buffer nesting
  modification (bsc#1112219).
- commit b1ad634
* Wed Oct 17 2018 pmladek@suse.com
- blacklist.conf: blktrace: fix races with init/start-stop/teardown
  and registering that were there for ages; not worth it
- commit 275fc72
* Wed Oct 17 2018 pmladek@suse.com
- blacklist.conf: kmemcheck removal; not for released products
- commit 5a49cb1
* Wed Oct 17 2018 pmladek@suse.com
- blacklist.conf: fixes rather rare races in CPU hotplug; there are many
  followup fixes; not worth the risk
- commit de48873
* Wed Oct 17 2018 pmladek@suse.com
- printk/tracing: Do not trace printk_nmi_enter() (bsc#1112208).
- commit 8f680aa
* Wed Oct 17 2018 pmladek@suse.com
- blacklist.conf: Blacklisted few printk/NMI fixes because we do not
  have the original problematic commit (bsc#1112173)
- commit c538ae6
* Wed Oct 17 2018 tiwai@suse.de
- ath10k: fix kernel panic issue during pci probe (bsc#1051510).
- commit 2680c3f
* Wed Oct 17 2018 tiwai@suse.de
- ath10k: fix scan crash due to incorrect length calculation
  (bsc#1051510).
- ath10k: fix use-after-free in ath10k_wmi_cmd_send_nowait
  (bsc#1051510).
- commit 6e6eb28
* Wed Oct 17 2018 tiwai@suse.de
- Refresh / sort upstreamed patches
- commit 9130ba4
* Wed Oct 17 2018 ddiss@suse.de
- target: stash sess_err_stats on Data-Out timeout (bsc#1095805).
- target: split out helper for cxn timeout error stashing
  (bsc#1095805).
- target: log NOP ping timeouts as errors (bsc#1095805).
- target: log Data-Out timeouts as errors (bsc#1095805).
- target: use ISCSI_IQN_LEN in iscsi_target_stat (bsc#1095805).
- commit b8a53d1
* Wed Oct 17 2018 bp@suse.de
- blacklist.conf:
  Backporting 5132ede0fe8092b043dae09a7cc32b8ae7272baa will actually cause kABI
  breakage because there should be no KMPs built with pre-retpoline compilers,
  says jikos.
- commit 80c676e
* Wed Oct 17 2018 pmladek@suse.com
- printk: drop in_nmi check from printk_safe_flush_on_panic()
  (bsc#1112170).
- commit f0a602e
* Tue Oct 16 2018 jslaby@suse.cz
- Update
  patches.suse/n_tty-fix-EXTPROC-vs-ICANON-interaction-with-TIOCINQ.patch
  (bnc#1094825 CVE-2018-18386).
- commit 54b2299
* Tue Oct 16 2018 tiwai@suse.de
- Annotate CVE/bug number for ocfs2 fix (CVE-2017-18224,bsc#1084831)
- commit 9c90e15
* Tue Oct 16 2018 jroedel@suse.de
- blacklist.conf: Add fd97d39b0aa4 Revert "x86/asm: Allow again using asm.h when building for the 'bpf' clang target"
  Not a bug fix.
- commit 9ecf1a2
* Tue Oct 16 2018 tiwai@suse.de
- Annotate CVE/bug number for a usbhid fix (CVE-2017-16533,bsc#1066674).
- commit edf3e7e
* Tue Oct 16 2018 lhenriques@suse.com
- ceph: avoid a use-after-free in ceph_destroy_options()
  (bsc#1111983).
- commit 62ceccd
* Tue Oct 16 2018 tiwai@suse.de
- r8169: Clear RTL_FLAG_TASK_*_PENDING when clearing
  RTL_FLAG_TASK_ENABLED (bsc#1051510).
- commit c971fb2
* Tue Oct 16 2018 tiwai@suse.de
- qrtr: add MODULE_ALIAS macro to smd (bsc#1051510).
- commit 31d8b8f
* Tue Oct 16 2018 tiwai@suse.de
- PCI: Reprogram bridge prefetch registers on resume
  (bsc#1051510).
- commit ec49c2b
* Tue Oct 16 2018 tiwai@suse.de
- libertas: call into generic suspend code before turning off
  power (bsc#1051510).
- commit 5d728bf
* Tue Oct 16 2018 tiwai@suse.de
- iwlwifi: mvm: open BA session only when sta is authorized
  (bsc#1051510).
- commit a7e605a
* Tue Oct 16 2018 tiwai@suse.de
- hypfs_kill_super(): deal with failed allocations (bsc#1051510).
- commit 87c9070
* Tue Oct 16 2018 tiwai@suse.de
- fbdev/omapfb: fix omapfb_memory_read infoleak (bsc#1051510).
- debugobjects: Make stack check warning more informative
  (bsc#1051510).
- commit 2756190
* Tue Oct 16 2018 tiwai@suse.de
- crypto: chelsio - Fix memory corruption in DMA Mapped buffers
  (bsc#1051510).
- HID: sensor-hub: Restore fixup for Lenovo ThinkPad Helix 2
  sensor hub report (bsc#1051510).
- HID: hid-sensor-hub: Force logical minimum to 1 for power and
  report state (bsc#1051510).
- commit 287d1a2
* Tue Oct 16 2018 bpoirier@suse.com
- Fix some patch headers which diverge from RFC5322
  Manually fix some patches which have an invalid header.
- s390/sthyi: reorganize sthyi implementation (FATE#324258,
  LTC#160415, bsc#1068273).
- s390/sthyi: add cache to store hypervisor info (FATE#324258,
  LTC#160415, bsc#1068273).
- s390/sthyi: add s390_sthyi system call (FATE#324258, LTC#160415,
  bsc#1068273).
- Refresh
  patches.drivers/scsi-qla2xxx-remove-irq-save-in-qla2x00_poll.patch.
- Refresh
  patches.fixes/xen-fix-booting-ballooned-down-hvm-guest.patch.
- xen/netfront: don't bug in case of too many frags (bnc#1104824).
- Refresh
  patches.fixes/xen-support-more-32-vcpus-at-domain-restore.patch.
- Refresh
  patches.fixes/xen-vcpu-simplify-xen_vcpu-related-code.patch.
- commit f488e5f
* Tue Oct 16 2018 lduncan@suse.com
- scsi: target: prefer dbroot of /etc/target over /var/target
  (bsc#1111928).
- commit 90cccba
* Mon Oct 15 2018 msuchanek@suse.de
- powerpc/rtas: Fix a potential race between CPU-Offline &
  Migration (bsc#1111870).
- commit 026dc74
* Mon Oct 15 2018 fdmanana@suse.com
- Btrfs: send, fix invalid access to commit roots due to
  concurrent snapshotting (bsc#1111904).
- commit a1ef375
* Mon Oct 15 2018 fdmanana@suse.com
- Btrfs: fix mount failure after fsync due to hard link recreation
  (bsc#1103543).
- commit 9fad86c
* Mon Oct 15 2018 fdmanana@suse.com
- Btrfs: fix file data corruption after cloning a range and fsync
  (bsc#1111901).
- commit 944429a
* Mon Oct 15 2018 tiwai@suse.de
- sock_diag: fix use-after-free read in __sk_free (bsc#1051510).
- commit bff757c
* Mon Oct 15 2018 tiwai@suse.de
- squashfs: more metadata hardening (bsc#1051510).
- commit 6ea48dd
* Mon Oct 15 2018 tiwai@suse.de
- stm: Potential read overflow in stm_char_policy_set_ioctl()
  (bsc#1051510).
- commit 680b150
* Mon Oct 15 2018 tiwai@suse.de
- switchtec: Fix Spectre v1 vulnerability (bsc#1051510).
- commit 6f8d9b6
* Mon Oct 15 2018 tiwai@suse.de
- team: Forbid enslaving team device to itself (bsc#1051510).
- commit 5340d75
* Mon Oct 15 2018 rgoldwyn@suse.com
- proc: restrict kernel stack dumps to root (git-fixes).
  blacklist.conf:
- ovl: fix format of setxattr debug (git-fixes).
- sysfs: Do not return POSIX ACL xattrs via listxattr (git-fixes).
- apparmor: Check buffer bounds when mapping permissions mask
  (git-fixes).
- aio: fix io_destroy(2) vs. lookup_ioctx() race (git-fixes).
- commit b947702
* Mon Oct 15 2018 rgoldwyn@suse.com
- ovl: Sync upper dirty data when syncing overlayfs (git-fixes).
- commit ff5cd46
* Mon Oct 15 2018 tiwai@suse.de
- vmbus: don't return values for uninitalized channels
  (bsc#1051510).
- commit da72041
* Mon Oct 15 2018 tiwai@suse.de
- vti6: remove !skb->ignore_df check from vti6_xmit()
  (bsc#1051510).
- vti6: fix PMTU caching and reporting on xmit (bsc#1051510).
- vti4: Don't count header length twice on tunnel setup
  (bsc#1051510).
- commit c6608bb
* Mon Oct 15 2018 tiwai@suse.de
- usb: xhci-mtk: resume USB3 roothub first (bsc#1051510).
- USB: serial: simple: add Motorola Tetra MTP6550 id
  (bsc#1051510).
- usb: gadget: fotg210-udc: Fix memory leak of fotg210->ep[i]
  (bsc#1051510).
- USB: yurex: Check for truncation in yurex_read() (bsc#1051510).
- commit b76815c
* Mon Oct 15 2018 tiwai@suse.de
- xhci: Add missing CAS workaround for Intel Sunrise Point xHCI
  (bsc#1051510).
- commit 18db61b
* Mon Oct 15 2018 msuchanek@suse.de
- powerpc/smp: Add Power9 scheduler topology (bsc#1109695).
- Refresh patches.arch/powerpc-topology-Get-topology-for-shared-processors-.patch.
- powerpc/smp: Add cpu_l2_cache_map (bsc#1109695).
- powerpc/smp: Rework CPU topology construction (bsc#1109695).
- powerpc/smp: Use cpu_to_chip_id() to find core siblings
  (bsc#1109695).
- commit 35958e3
* Mon Oct 15 2018 msuchanek@suse.de
- scsi: ipr: Eliminate duplicate barriers (FATE#326436).
- scsi: ipr: Use dma_pool_zalloc() (FATE#326436).
- scsi: ipr: fix incorrect indentation of assignment statement
  (FATE#326436).
- commit 954903e
* Mon Oct 15 2018 jthumshirn@suse.de
- mm: fix BUG_ON() in vmf_insert_pfn_pud() from VM_MIXEDMAP
  removal (bsc#1111841).
- commit c82ee64
* Mon Oct 15 2018 oneukum@suse.com
- blacklist.conf: depends on blacklisted patch (kABI reasons)
- commit fc0e041
* Mon Oct 15 2018 oneukum@suse.com
- blacklist.conf: breaks kABI by changing observable behavior
- commit d003299
* Mon Oct 15 2018 jthumshirn@suse.de
- block: bvec_nr_vecs() returns value for wrong slab
  (bsc#1111834).
- commit 0a7a1e1
* Mon Oct 15 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix memory leak for allocating abort IOCB
  (bsc#1111830).
- commit 92a8229
* Mon Oct 15 2018 vbabka@suse.cz
- ksm: fix unlocked iteration over vmas in cmp_and_merge_page()
  (VM Functionality bsc#1111806).
- commit 6cf1086
* Mon Oct 15 2018 jthumshirn@suse.de
- blkdev_report_zones_ioctl(): Use vmalloc() to allocate large
  buffers (bsc#1111819).
- commit a16c62f
* Mon Oct 15 2018 vbabka@suse.cz
- x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit
  (bsc#1105536).
- Refresh
  patches.arch/0001-x86-speculation-l1tf-Fix-off-by-one-error-when-warni.patch.
- Refresh
  patches.arch/0001-x86-speculation-l1tf-Increase-l1tf-memory-limit-for-.patch.
- Refresh
  patches.arch/x86-speculation-l1tf-extend-64bit-swap-file-size-limit.
- Refresh
  patches.arch/x86-speculation-l1tf-protect-pae-swap-entries-against-l1tf.
- commit 5db1aea
* Fri Oct 12 2018 msuchanek@suse.de
- mm/migrate: Use spin_trylock() while resetting rate limit (FATE#326522).
- Refresh patches.suse/mm-numa-Remove-rate-limiting-of-automatic-numa-balancing-migration.patch
- commit afe3f1b
* Fri Oct 12 2018 msuchanek@suse.de
- Refresh patches.suse/mm-numa-Migrate-pages-to-local-nodes-quicker-early-in-the-lifetime-of-a-task.patch.
- Refresh patches.suse/mm-numa-Remove-rate-limiting-of-automatic-numa-balancing-migration.patch.
- Refresh patches.suse/sched-numa-Avoid-task-migration-for-small-NUMA-improvement.patch.
- Refresh patches.suse/sched-numa-Pass-destination-CPU-as-a-parameter-to-migrate_task_rq.patch.
- Refresh patches.suse/sched-numa-Remove-numa_has_capacity.patch.
- Refresh patches.suse/sched-numa-Reset-scan-rate-whenever-task-moves-across-nodes.patch.
- Refresh patches.suse/sched-numa-Stop-multiple-tasks-from-moving-to-the-CPU-at-the-same-time.patch.
- commit 16d8ab6
* Fri Oct 12 2018 hare@suse.de
- scsi: qla2xxx: Return switch command on a timeout (bsc#1108870).
- commit 8e38f2a
* Fri Oct 12 2018 tiwai@suse.de
- rpc_pipefs: fix double-dput() (bsc#1051510).
- commit 1a15e26
* Fri Oct 12 2018 tiwai@suse.de
- soreuseport: initialise timewait reuseport field (bsc#1051510).
- commit bda2dcc
* Fri Oct 12 2018 tiwai@suse.de
- Squashfs: Compute expected length from inode size rather than
  block length (bsc#1051510).
- commit 0c4a663
* Fri Oct 12 2018 hare@suse.de
- scsi: qla2xxx: Move log messages before issuing command to
  firmware (bsc#1108870).
- scsi: qla2xxx: Fix for double free of SRB structure
  (bsc#1108870).
- scsi: qla2xxx: Fix recursive mailbox timeout (bsc#1108870).
- scsi: qla2xxx: Fix driver hang when FC-NVMe LUNs are configured
  (bsc#1108870).
- scsi: qla2xxx: Fix re-using LoopID when handle is in use
  (bsc#1108870).
- scsi: qla2xxx: Fix duplicate switch database entries
  (bsc#1108870).
- scsi: qla2xxx: Fix NVMe Target discovery (bsc#1108870).
- scsi: qla2xxx: Fix NVMe session hang on unload (bsc#1108870).
- scsi: qla2xxx: don't allow negative thresholds (bsc#1108870).
- commit 50fe149
* Fri Oct 12 2018 tiwai@suse.de
- squashfs metadata 2: electric boogaloo (bsc#1051510).
- squashfs: more metadata hardening (bsc#1051510).
- squashfs: be more careful about metadata corruption
  (bsc#1051510).
- commit 9bfac39
* Fri Oct 12 2018 msuchanek@suse.de
- powerpc/numa: Skip onlining a offline node in kdump path
  (bsc#1109784).
- commit df87e51
* Fri Oct 12 2018 tzimmermann@suse.de
- README: Clean-up trailing whitespace
- commit 06542f9
* Fri Oct 12 2018 tiwai@suse.de
- Update config files: update forgotten armv7hl configs
- commit 7bae3a6
* Thu Oct 11 2018 bp@suse.de
- crypto: ccp - add timeout support in the SEV command
  (bsc#1106838).
- commit 912dad4
* Thu Oct 11 2018 tzimmermann@suse.de
- README: Update documentation wrt. Patch-mainline
  Common practice is to set Patch-mainline to a Linux release tag. More
  than 95%% of all patches follow this convention. The remaining 5%% have
  been fixed accordingly in SLE15.
  The README file is inconsistent wrt. to the content of Patch-mainline.
  In some places it refers to a release tag, in others it refers to a version
  number. With this cleanup, it refers to release tags everywhere.
  This change is a follow-up for commit 1d81d2699cd3.
- commit 57326f5
* Thu Oct 11 2018 tzimmermann@suse.de
- Fix Patch-mainline tags to refer to Linux release tag
  It is expected that Patch-mainline tags refer to a release tag
  in the Linux git tree, such as v4.15. Several patches contain a
  Patch-mainline tags that instead refer to a Linux version number,
  such as 4.15. This inconsistency complicates grepping and
  automation.
  871 of 18000 patches are affected by this problem.
- commit 1d81d26
* Thu Oct 11 2018 tzimmermann@suse.de
- blacklist.conf: Append 'Revert "drm: Use a flexible array member for blob property data"'
- commit ddc67eb
* Thu Oct 11 2018 tiwai@suse.de
- Disable DRM patches that broke vbox video driver KMP (bsc#1111076)
- commit 23943c6
* Thu Oct 11 2018 tzimmermann@suse.de
- blacklist.conf: Append 'drm/amd/pp: initialize result to before or'ing in data'
- commit d2edcd9
* Thu Oct 11 2018 tzimmermann@suse.de
- drm/amdgpu: fix error handling in amdgpu_cs_user_fence_chunk (bsc#1106110)
- commit 273a6bd
* Wed Oct 10 2018 tiwai@suse.de
- blacklist.conf: Add blacklist of inapplicable revert commits
  They are either not applicable or requiring more backports that aren't
  suitable for SLE15
- commit 987dd44
* Wed Oct 10 2018 tiwai@suse.de
- mwifiex: handle race during mwifiex_usb_disconnect
  (bsc#1051510).
- Revert "mwifiex: handle race during mwifiex_usb_disconnect"
  (bsc#1051510).
- media: videobuf-dma-sg: Fix dma_{sync,unmap}_sg() calls
  (bsc#1051510).
- Revert "mwifiex: fix incorrect ht capability problem"
  (bsc#1051510).
- PM / Domains: Fix genpd to deal with drivers returning 1 from
  - >prepare() (bsc#1051510).
- Revert "pinctrl: sunxi: Don't enforce bias disable (for now)"
  (bsc#1051510).
- commit fb6c36a
* Wed Oct 10 2018 tiwai@suse.de
- HID: hid-saitek: Add device ID for RAT 7 Contagion
  (bsc#1051510).
- mac80211: shorten the IBSS debug messages (bsc#1051510).
- mac80211: don't Tx a deauth frame if the AP forbade Tx
  (bsc#1051510).
- mac80211: Fix station bandwidth setting after channel switch
  (bsc#1051510).
- mac80211: fix a race between restart and CSA flows
  (bsc#1051510).
- mac80211: do not convert to A-MSDU if frag/subframe limited
  (bsc#1051510).
- mac80211: mesh: fix HWMP sequence numbering to follow standard
  (bsc#1051510).
- mac80211_hwsim: correct use of IEEE80211_VHT_CAP_RXSTBC_X
  (bsc#1051510).
- mac80211: correct use of IEEE80211_VHT_CAP_RXSTBC_X
  (bsc#1051510).
- mac80211_hwsim: require at least one channel (bsc#1051510).
- mac80211: Run TXQ teardown code before de-registering interfaces
  (bsc#1051510).
- hwmon: (adt7475) Make adt7475_read_word() return errors
  (bsc#1051510).
- hwmon: (ina2xx) fix sysfs shunt resistor read access
  (bsc#1051510).
- commit af836cd
* Wed Oct 10 2018 mbrugger@suse.com
- supported.conf: mark raspberrypi-hwmon as supported
- commit af8ddda
* Wed Oct 10 2018 mbrugger@suse.com
- arm64: Update config files.
  Enable SENSORS_RASPBERRYPI_HWMON
- commit 2a83945
* Wed Oct 10 2018 tiwai@suse.de
- ALSA: hda/realtek - Cannot adjust speaker's volume on Dell
  XPS 27 7760 (bsc#1051510).
- crypto: qat - Fix KASAN stack-out-of-bounds bug in adf_probe()
  (bsc#1051510).
- crypto: mxs-dcp - Fix wait logic on chan threads (bsc#1051510).
- floppy: Do not copy a kernel pointer to user memory in FDGETPRM
  ioctl (bsc#1051510).
- HID: add support for Apple Magic Keyboards (bsc#1051510).
- gpio: Fix crash due to registration race (bsc#1051510).
- gpiolib-acpi: Register GpioInt ACPI event handlers from a
  late_initcall (bsc#1051510).
- gpio: adp5588: Fix sleep-in-atomic-context bug (bsc#1051510).
- cfg80211: fix a type issue in
  ieee80211_chandef_to_operating_class() (bsc#1051510).
- Revert "gpio: set up initial state from .get_direction()"
  (bsc#1051510).
- gpio: mb86s70: Revert "Return error if requesting an already
  assigned gpio" (bsc#1051510).
- commit 2759d22
* Wed Oct 10 2018 mbrugger@suse.com
- hwmon: rpi: add module alias to raspberrypi-hwmon (bsc#1108468).
- firmware: raspberrypi: Register hwmon driver (bsc#1108468).
- hwmon: Add support for RPi voltage sensor (bsc#1108468).
- ARM: bcm2835: Add GET_THROTTLED firmware property (bsc#1108468).
- commit 218e534
* Wed Oct 10 2018 tiwai@suse.de
- drm/nouveau/disp: fix DP disable race (bsc#1051510).
- drm/nouveau/TBDdevinit: don't fail when PMU/PRE_OS is missing
  from VBIOS (bsc#1051510).
- drm/amdgpu: add another ATPX quirk for TOPAZ (bsc#1051510).
- Revert "drm/amdgpu: Add an ATPX quirk for hybrid laptop"
  (bsc#1051510).
- Revert "drm/i915/gvt: set max priority for gvt context"
  (bsc#1051510).
- drm/amdgpu: Pulling old prepare and submit for flip back
  (bsc#1051510).
- drm/amdgpu: revert "fix deadlock of reservation between cs
  and gpu reset v2" (bsc#1051510).
- commit c5d4f7a
* Wed Oct 10 2018 tiwai@suse.de
- Add cherry-pick ID and sort the upstreamed drm/i915 patches
- commit 862c3c5
* Wed Oct 10 2018 jroedel@suse.de
- blacklist.conf: fd97d39b0aa4 Revert "x86/asm: Allow again using asm.h when building for the 'bpf' clang target"
- commit ac4dc3f
* Wed Oct 10 2018 jroedel@suse.de
- Revert "iommu/io-pgtable: Avoid redundant TLB syncs"
  (bsc#1106237).
- commit 15db9ba
* Wed Oct 10 2018 ohering@suse.de
- rename remaining hv related patches for pending updates in SLE15-SP1
- commit b23c32c
* Wed Oct 10 2018 ohering@suse.de
- reorder a qedi patch to allow further work in this branch
- commit c6d3048
* Wed Oct 10 2018 tiwai@suse.de
- Update kabi files: import from 4.12.14-lp150.12.19
- commit 641fc17
* Wed Oct 10 2018 tiwai@suse.de
- Update kabi files: import from 4.12.14-25.19.1
- commit 4acc575
* Tue Oct  9 2018 mhocko@suse.com
- Revert "slab: __GFP_ZERO is incompatible with a constructor" (bnc#1108828)
  This reverts commit de0a67303736262e306a3eb23aa38824b28c2764 because we
  still seem to have false possitives in the tree.
- commit 799debc
* Tue Oct  9 2018 mgorman@suse.de
- cpufreq, intel_pstate: Allow unspecified FADT profile to probe
  PPC (bnc#1108841).
- commit d63cba5
* Tue Oct  9 2018 tiwai@suse.de
- Correct the patch-tag in apparmor patch
  A wrong commit ID was put in Git-commit tag.
  After the correction, patches are re-sorted again.
- commit 97e2d48
* Tue Oct  9 2018 jack@suse.cz
- mm: Preserve _PAGE_DEVMAP across mprotect() calls (bsc#1111028).
- commit 1783326
* Tue Oct  9 2018 msuchanek@suse.de
- Revert "Limit kernel-source build to architectures for which we build binaries"
  This reverts commit d6435125446d740016904abe30a60611549ae812.
- commit 48b03c4
* Mon Oct  8 2018 palcantara@suse.de
- cifs: integer overflow in in SMB2_ioctl() (bsc#1051510).
- commit b6e2ad9
* Mon Oct  8 2018 tzimmermann@suse.de
- drm/i915: Handle incomplete Z_FINISH for compressed error states (bsc#1100132)
- commit 64ea054
* Mon Oct  8 2018 tiwai@suse.de
- crypto: caam/jr - fix ablkcipher_edesc pointer arithmetic
  (bsc#1051510).
- crypto: cavium/nitrox - fix for command corruption in queue
  full case with backlog submissions (bsc#1051510).
- commit 4257b34
* Mon Oct  8 2018 tiwai@suse.de
- clk: clk-fixed-factor: Clear OF_POPULATED flag in case of
  failure (bsc#1051510).
- clk: rockchip: Add pclk_rkpwm_pmu to PMU critical clocks in
  rk3399 (bsc#1051510).
- clk: tegra: bpmp: Don't crash when a clock fails to register
  (bsc#1051510).
- commit 48d4c05
* Mon Oct  8 2018 tiwai@suse.de
- ath10k: protect ath10k_htt_rx_ring_free with rx_ring.lock
  (bsc#1051510).
- commit 74154cd
* Mon Oct  8 2018 tiwai@suse.de
- blacklist.conf: Add entries for mvebu-uart patches
- commit adbfb7c
* Mon Oct  8 2018 tiwai@suse.de
- virtio: pci-legacy: Validate queue pfn (bsc#1051510).
- commit b627e9e
* Mon Oct  8 2018 tiwai@suse.de
- tsl2550: fix lux1_input error in low light (bsc#1051510).
- commit 5120650
* Mon Oct  8 2018 tiwai@suse.de
- usb: cdc_acm: Do not leak URB buffers (bsc#1051510).
- commit d469a58
* Mon Oct  8 2018 tiwai@suse.de
- thermal: of-thermal: disable passive polling when thermal zone
  is disabled (bsc#1051510).
- commit 8a954b3
* Mon Oct  8 2018 tiwai@suse.de
- rtc: bq4802: add error handling for devm_ioremap (bsc#1051510).
- commit be9b7c6
* Mon Oct  8 2018 tiwai@suse.de
- PM / core: Clear the direct_complete flag on errors
  (bsc#1051510).
- commit 84e267c
* Mon Oct  8 2018 tiwai@suse.de
- Refresh
  patches.arch/x86-decoder-add-new-test-instruction-pattern.
  Both arch/x86/lib/x86-opcode-map.txt and tools/objtool/arch/x86/....
  have to be synced.  In the upstream, it was done in a merge commit.
- commit 6a08774
* Mon Oct  8 2018 tiwai@suse.de
- mac80211: fix setting IEEE80211_KEY_FLAG_RX_MGMT for AP mode
  keys (bsc#1051510).
- commit 6ea5f12
* Mon Oct  8 2018 tiwai@suse.de
- irq/core: Fix boot crash when the irqaffinity= boot parameter
  is passed on CPUMASK_OFFSTACK=y kernels(v1) (bsc#1051510).
- commit 9c04790
* Mon Oct  8 2018 jroedel@suse.de
- x86/vdso: Fix vDSO syscall fallback asm constraint regression
  (bsc#1110006).
- commit 868515e
* Mon Oct  8 2018 tiwai@suse.de
- hwmon: (nct6775) Set weight source to zero correctly
  (bsc#1051510).
- commit a2eb386
* Mon Oct  8 2018 tiwai@suse.de
- gpiolib: Free the last requested descriptor (bsc#1051510).
- commit 83e4eb4
* Mon Oct  8 2018 tiwai@suse.de
- apparmor: Fix failure to audit context info in build_change_hat
  (bsc#1051510).
- apparmor: Fully initialize aa_perms struct when answering
  userspace query (bsc#1051510).
- fuse: Don't access pipe->buffers without pipe_lock()
  (bsc#1051510).
- apparmor: fix ptrace read check (bsc#1051510).
- apparmor: fix memory leak when deduping profile load
  (bsc#1051510).
- apparmor: fix mediation of prlimit (bsc#1051510).
- commit 1f347b9
* Mon Oct  8 2018 tbogendoerfer@suse.de
- Delete
  patches.drivers/IB-qedr-Remove-GID-add-del-dummy-routines.patch.
  (bsc#1110921)
- commit fb74314
* Mon Oct  8 2018 tiwai@suse.de
- Add a cherry-picked id for apparmor fix
- commit dac39d0
* Mon Oct  8 2018 jslaby@suse.cz
- ipv4: fix use-after-free in ip_cmsg_recv_dstaddr() (git-fixes).
- commit 539511e
* Mon Oct  8 2018 jroedel@suse.de
- iommu/amd: Clear memory encryption mask from physical address
  (bsc#1106105).
- KVM: x86: Do not use kvm_x86_ops->mpx_supported() directly
  (bsc#1106240).
- KVM: nVMX: Do not expose MPX VMX controls when guest MPX
  disabled (bsc#1106240).
- commit 03846bc
* Mon Oct  8 2018 jroedel@suse.de
- blacklist.conf: Add cc51e5428ea5 x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+
  Fixes only an unlikely warning and breaks kABI, not worth
  the effort.
- commit 262c2a7
* Mon Oct  8 2018 jroedel@suse.de
- x86/vdso: Fix asm constraints on vDSO syscall fallbacks
  (bsc#1110006).
- commit 3d4afb6
* Mon Oct  8 2018 mkubecek@suse.cz
- udp: Unbreak modules that rely on external __skb_recv_udp()
  availability (bsc#1109151).
- commit b99f6aa
* Mon Oct  8 2018 jslaby@suse.cz
- PCI: dwc: Fix scheduling while atomic issues (git-fixes).
- commit 7e30d08
* Fri Oct  5 2018 lduncan@suse.com
- scsi: qedi: Initialize the stats mutex lock (bsc#1110538).
- qed: Add missing device config for RoCE EDPM in UFP mode
  (bsc#1109217).
- scsi: qedi: Add the CRC size within iSCSI NVM image
  (bsc#1110538).
- commit 0e0b19c
* Fri Oct  5 2018 tiwai@suse.de
- ARM: 8799/1: mm: fix pci_ioremap_io() offset check
  (bsc#1051510).
- ARM: exynos: Clear global variable on init error path
  (bsc#1051510).
- ARM: hisi: check of_iomap and fix missing of_node_put
  (bsc#1051510).
- ARM: mvebu: declare asm symbols as character arrays in pmsu.c
  (bsc#1051510).
- ARM: hwmod: RTC: Don't assume lock/unlock will be called with
  irq enabled (bsc#1051510).
- commit d307599
* Fri Oct  5 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/EDAC-Add-missing-MEM_LRDDR4-entry-in-edac_mem_types.patch.
  Fix error introduced by patch refresh in commit ee2ef7fc1962.
- commit c2c6686
* Fri Oct  5 2018 tiwai@suse.de
- Revert "cdc-acm: implement put_char() and flush_chars()"
  (bsc#1051510).
- commit 00ebbf6
* Fri Oct  5 2018 tiwai@suse.de
- USB: handle NULL config in usb_find_alt_setting() (bsc#1051510).
- USB: fix error handling in usb_driver_claim_interface()
  (bsc#1051510).
- usb: musb: dsps: do not disable CPPI41 irq in driver teardown
  (bsc#1051510).
- usb: misc: uss720: Fix two sleep-in-atomic-context bugs
  (bsc#1051510).
- usb: host: u132-hcd: Fix a sleep-in-atomic-context bug in
  u132_get_frame() (bsc#1051510).
- usb: Avoid use-after-free by flushing endpoints early in
  usb_set_interface() (bsc#1051510).
- usb: uas: add support for more quirk flags (bsc#1051510).
- USB: Add quirk to support DJI CineSSD (bsc#1051510).
- USB: yurex: Fix buffer over-read in yurex_write() (bsc#1051510).
- USB: add quirk for WORLDE Controller KS49 or Prodipe MIDI 49C
  USB controller (bsc#1051510).
- uwb: hwa-rc: fix memory leak at probe (bsc#1051510).
- usb: wusbcore: security: cast sizeof to int for comparison
  (bsc#1051510).
- commit 325b691
* Fri Oct  5 2018 jroedel@suse.de
- x86/MCE: Report only DRAM ECC as memory errors on AMD systems
  (bsc#1110006).
- commit f4ebbb5
* Fri Oct  5 2018 msuchanek@suse.de
- powerpc/pseries/mm: call H_BLOCK_REMOVE (bsc#1109158).
- powerpc/pseries/mm: factorize PTE slot computation
  (bsc#1109158).
- powerpc/pseries/mm: Introducing FW_FEATURE_BLOCK_REMOVE
  (bsc#1109158).
- powerpc/pseries: Fix duplicate firmware feature for DRC_INFO
  (bsc#1109158).
- powerpc/firmware: Add definitions for new drc-info firmware
  feature (bsc#1109158).
- commit db82c02
* Fri Oct  5 2018 jroedel@suse.de
- KVM: x86: fix #UD address of failed Hyper-V hypercalls
  (bsc#1110006).
- blacklist.conf: Blacklist MCE patch not relevant for SLE
- lib/bug.c: exclude non-BUG/WARN exceptions from report_bug()
  (bsc#1110006).
- PM: cpuidle: Fix cpuidle_poll_state_init() prototype
  (bsc#1110006).
- commit ba6337f
* Fri Oct  5 2018 jthumshirn@suse.de
- EDAC, skx: Fix skx_edac build error when ACPI_NFIT=m
  (bsc#1099125).
- commit bac1e6a
* Fri Oct  5 2018 jthumshirn@suse.de
- kabi protect enum mem_type (bsc#1099125).
- commit 6b120fd
* Fri Oct  5 2018 hare@suse.de
- nvme: call nvme_complete_rq when nvmf_check_ready fails for
  mpath I/O (bsc#1107685).
- Refresh
  patches.kabi/kABI-fixes-for-nvme-if_ready-checks-fail-io-to-deletin.patch.
- commit b135e3b
* Fri Oct  5 2018 tiwai@suse.de
- Refresh patches.drivers/serial-imx-restore-handshaking-irq-for-imx1.patch
  Fix the build error due to forgotten quilt refresh.
- commit 3fe34a7
* Fri Oct  5 2018 tiwai@suse.de
- blacklist.conf: Add a wlcore patch that isn't applicable (git-fixes)
- commit 155b770
* Fri Oct  5 2018 tiwai@suse.de
- serial: 8250_exar: Read INT0 from slave device, too
  (bsc#1051510).
- commit 1b0e22e
* Fri Oct  5 2018 jlee@suse.com
- ACPICA: Reference Counts: increase max to 0x4000 for large
  servers (bsc#1108241).
- commit bbbde90
* Thu Oct  4 2018 tiwai@suse.de
- Revert "ubifs: xattr: Don't operate on deleted inodes"
  (bsc#1051510).
- ubifs: Check for name being NULL while mounting (bsc#1051510).
- commit 91daddc
* Thu Oct  4 2018 tiwai@suse.de
- tty: vt_ioctl: fix potential Spectre v1 (bsc#1051510).
- tty: Drop tty->count on tty_reopen() failure (bsc#1051510).
- tty: serial: lpuart: avoid leaking struct tty_struct
  (bsc#1051510).
- tty: rocket: Fix possible buffer overwrite on register_PCI
  (bsc#1051510).
- drivers/tty: add error handling for pcmcia_loop_config
  (bsc#1051510).
- tty: serial: exar: Relocate sleep wake-up handling
  (bsc#1051510).
- commit 8bfe969
* Thu Oct  4 2018 jack@suse.cz
- patches.fixes/x86-memory_failure-Introduce-set-clear-_mce_nospec.patch:
  One more fixup to avoid even warning about statement without effect.
- commit ad22175
* Thu Oct  4 2018 tiwai@suse.de
- spi: rspi: Fix interrupted DMA transfers (bsc#1051510).
- spi: rspi: Fix invalid SPI use during system suspend
  (bsc#1051510).
- spi: sh-msiof: Fix handling of write value for SISTR register
  (bsc#1051510).
- spi: sh-msiof: Fix invalid SPI use during system suspend
  (bsc#1051510).
- spi: tegra20-slink: explicitly enable/disable clock
  (bsc#1051510).
- commit e15b3cc
* Thu Oct  4 2018 tbogendoerfer@suse.de
- Update config files.
- supported.conf: added cavium_ptp
- commit b02b8f1
* Thu Oct  4 2018 tiwai@suse.de
- soc: fsl: qe: Fix copy/paste bug in ucc_get_tdm_sync_shift()
  (bsc#1051510).
- soc: mediatek: pwrap: fix cipher init setting error
  (bsc#1051510).
- commit 493cc64
* Thu Oct  4 2018 tiwai@suse.de
- serial: imx: restore handshaking irq for imx1 (bsc#1051510).
- serial: cpm_uart: return immediately from console poll
  (bsc#1051510).
- commit 6e6efed
* Thu Oct  4 2018 tiwai@suse.de
- qmi_wwan: set DTR for modems in forced USB2 mode (bsc#1051510).
- media: davinci: vpif_display: Mix memory leak on probe error
  path (bsc#1051510).
- media: s5p-mfc: Fix buffer look up in s5p_mfc_handle_frame_{new,
  copy_time} functions (bsc#1051510).
- media: helene: fix xtal frequency setting at power on
  (bsc#1051510).
- media: videobuf2-core: check for q->error in vb2_core_qbuf()
  (bsc#1051510).
- media: fsl-viu: fix error handling in viu_of_probe()
  (bsc#1051510).
- media: soc_camera: ov772x: correct setting of banding filter
  (bsc#1051510).
- media: s3c-camif: ignore -ENOIOCTLCMD from v4l2_subdev_call
  for s_power (bsc#1051510).
- media: tm6000: add error handling for dvb_register_adapter
  (bsc#1051510).
- NFC: trf7970a: fix check of clock frequencies, use && instead
  of || (bsc#1051510).
- commit e9d3fa4
* Thu Oct  4 2018 tiwai@suse.de
- evm: Don't deadlock if a crypto algorithm is unavailable
  (bsc#1051510).
- ethtool: Remove trailing semicolon for static inline
  (bsc#1051510).
- commit 266906c
* Thu Oct  4 2018 tiwai@suse.de
- declance: Fix continuation with the adapter identification
  message (bsc#1051510).
- drm/amdgpu: add new polaris pci id (bsc#1051510).
- drm: udl: Destroy framebuffer only if it was initialized
  (bsc#1051510).
- drm/nouveau/drm/nouveau: Don't forget to cancel hpd_work on
  suspend/unload (bsc#1051510).
- drm/nouveau/drm/nouveau: Prevent handling ACPI HPD events too
  early (bsc#1051510).
- drm/nouveau: Fix deadlocks in nouveau_connector_detect()
  (bsc#1051510).
- drm/nouveau/drm/nouveau: Use pm_runtime_get_noresume() in
  connector_detect() (bsc#1051510).
- drm/amdgpu: Update power state at the end of smu hw_init
  (bsc#1051510).
- drm/amdgpu: Enable/disable gfx PG feature in rlc safe mode
  (bsc#1051510).
- dmaengine: pl330: fix irq race with terminate_all (bsc#1051510).
- drm/amdkfd: Fix error codes in kfd_get_process (bsc#1051510).
- drm/nouveau: tegra: Detach from ARM DMA/IOMMU mapping
  (bsc#1051510).
- drm/nouveau: Fix runtime PM leak in drm_open() (bsc#1051510).
- drm/nouveau/debugfs: Wake up GPU before doing any reclocking
  (bsc#1051510).
- drm/sun4i: Fix releasing node when enumerating enpoints
  (bsc#1051510).
- commit 022b73c
* Thu Oct  4 2018 tiwai@suse.de
- batman-adv: Prevent duplicated tvlv handler (bsc#1051510).
- batman-adv: Prevent duplicated global TT entry (bsc#1051510).
- batman-adv: Prevent duplicated softif_vlan entry (bsc#1051510).
- batman-adv: Prevent duplicated nc_node entry (bsc#1051510).
- batman-adv: Prevent duplicated gateway_node entry (bsc#1051510).
- batman-adv: Fix segfault when writing to sysfs elp_interval
  (bsc#1051510).
- batman-adv: Fix segfault when writing to throughput_override
  (bsc#1051510).
- batman-adv: Fix multicast TT issues with bogus ROAM flags
  (bsc#1051510).
- commit 2541a15
* Thu Oct  4 2018 tiwai@suse.de
- asix: Check for supported Wake-on-LAN modes (bsc#1051510).
- drivers/base: stop new probing during shutdown (bsc#1051510).
- audit: fix use-after-free in audit_add_watch (bsc#1051510).
- commit f16e19d
* Thu Oct  4 2018 jthumshirn@suse.de
- EDAC: Add new memory type for non-volatile DIMMs (bsc#1099125).
- Refresh
  patches.drivers/EDAC-Add-missing-MEM_LRDDR4-entry-in-edac_mem_types.patch.
- commit ee2ef7f
* Thu Oct  4 2018 tbogendoerfer@suse.de
- qlcnic: fix Tx descriptor corruption on 82xx devices
  (bsc#1050540 FATE#322896).
- commit 15269ed
* Thu Oct  4 2018 jroedel@suse.de
- Backport stable-patches for x86 architecture
- cpu/hotplug: Fix SMT supported evaluation (bsc#1110006).
- efi: Avoid potential crashes, fix the 'struct
  efi_pci_io_protocol_32' definition for mixed mode (bsc#1110006).
- kprobes/x86: Disable preemption in ftrace-based jprobes
  (bsc#1110006).
- kprobes/x86: Prohibit probing on exception masking instructions
  (bsc#1110006).
- KVM: lapic: stop advertising DIRECTED_EOI when in-kernel IOAPIC
  is in use (bsc#1110006).
- kvm, mm: account shadow page tables to kmemcg (bsc#1110006).
- KVM: nVMX: Don't halt vcpu when L1 is injecting events to L2
  (bsc#1110006).
- KVM/VMX: Optimize vmx_vcpu_run() and svm_vcpu_run() by marking
  the RDMSR path as unlikely() (bsc#1110006).
- KVM: VMX: raise internal error for exception during invalid
  protected mode state (bsc#1110006).
- KVM: vmx: track host_state.loaded using a loaded_vmcs pointer
  (bsc#1110006).
- KVM: vmx: use local variable for current_vmptr when emulating
  VMPTRST (bsc#1110006).
- KVM: x86: fix escape of guest dr6 to the host (bsc#1110006).
- KVM: X86: fix incorrect reference of trace_kvm_pi_irte_update
  (bsc#1110006).
- kvm: x86: fix KVM_XEN_HVM_CONFIG ioctl (bsc#1110006).
- KVM: X86: Fix reserved bits check for MOV to CR3 (bsc#1110006).
- KVM: x86: remove APIC Timer periodic/oneshot spikes
  (bsc#1110006).
- KVM: x86: Update cpuid properly when CR4.OSXAVE or CR4.PKE is
  changed (bsc#1110006).
- kvmclock: fix TSC calibration for nested guests (bsc#1110006).
- objtool, kprobes/x86: Sync the latest <asm/insn.h> header with
  tools/objtool/arch/x86/include/asm/insn.h (bsc#1110006).
- perf/x86/amd/ibs: Don't access non-started event (bsc#1110006).
- perf/x86/cstate: Fix possible Spectre-v1 indexing for pkg_msr
  (bsc#1110006).
- perf/x86: Fix possible Spectre-v1 indexing for hw_perf_event
  cache_* (bsc#1110006).
- perf/x86: Fix possible Spectre-v1 indexing for
  x86_pmu::event_map() (bsc#1110006).
- perf/x86/intel: Don't accidentally clear high bits in
  bdw_limit_period() (bsc#1110006).
- perf/x86/intel: Fix event update for auto-reload (bsc#1110006).
- perf/x86/intel: Fix large period handling on Broadwell CPUs
  (bsc#1110006).
- perf/x86/intel: Fix linear IP of PEBS real_ip on Haswell and
  later CPUs (bsc#1110006).
- perf/x86/intel/lbr: Fix incomplete LBR call stack (bsc#1110006).
- perf/x86/intel: Properly save/restore the PMU state in the
  NMI handler (bsc#1110006).
- perf/x86/intel/uncore: Correct fixed counter index check for
  NHM (bsc#1110006).
- perf/x86/intel/uncore: Correct fixed counter index check in
  generic code (bsc#1110006).
- perf/x86/intel/uncore: Fix Skylake UPI event format
  (bsc#1110006).
- perf/x86/msr: Fix possible Spectre-v1 indexing in the MSR driver
  (bsc#1110006).
- ptrace,x86: Make user_64bit_mode() available to 32-bit builds
  (bsc#1110006).
- selftests/x86: Add tests for the STR and SLDT instructions
  (bsc#1110006).
- selftests/x86: Add tests for User-Mode Instruction Prevention
  (bsc#1110006).
- tracing/x86/xen: Remove zero data size trace events
  trace_xen_mmu_flush_tlb{_all} (bsc#1110006).
- uprobes/x86: Prohibit probing on MOV SS instruction
  (bsc#1110006).
- vfs/proc/kcore, x86/mm/kcore: Fix SMAP fault when dumping
  vsyscall user page (bsc#1110006).
- x86-64/realmode: Add instruction suffix (bsc#1110006).
- x86: Add check for APIC access address for vmentry of L2 guests
  (bsc#1110006).
- x86/alternatives: Fixup alternative_call_2 (bsc#1110006).
- x86/apic: Set up through-local-APIC mode on the boot CPU if
  'noapic' specified (bsc#1110006).
- x86/asm: Add _ASM_ARG* constants for argument registers to
  <asm/asm.h> (bsc#1110006).
- x86/asm: Allow again using asm.h when building for the 'bpf'
  clang target (bsc#1110006).
- x86/asm: Don't use the confusing '.ifeq' directive
  (bsc#1110006).
- x86/boot/64: Verify alignment of the LOAD segment (bsc#1110006).
- x86/boot/compressed/64: Print error if 5-level paging is not
  supported (bsc#1110006).
- x86/boot: Fix if_changed build flip/flop bug (bsc#1110006).
- x86/boot: Relocate definition of the initial state of CR0
  (bsc#1110006).
- x86/build: Beautify build log of syscall headers (bsc#1110006).
- x86: Call fixup_exception() before notify_die() in math_error()
  (bsc#1110006).
- x86/CPU: Add a microcode loader callback (bsc#1110006).
- x86/cpu/AMD: Apply the Erratum 688 fix when the BIOS doesn't
  (bsc#1110006).
- x86/CPU/AMD: Have smp_num_siblings and cpu_llc_id always be
  present (bsc#1110006).
- x86/CPU: Check CPU feature bits after microcode upgrade
  (bsc#1110006).
- x86/cpu/intel: Add missing TLB cpuid values (bsc#1110006).
- x86/cpufeatures: Add Intel PCONFIG cpufeature (bsc#1110006).
- x86/debug: Handle warnings before the notifier chain, to fix
  KGDB crash (bsc#1110006).
- x86/decoder: Add new TEST instruction pattern (bsc#1110006).
- x86: Delay skip of emulated hypercall instruction (bsc#1110006).
- x86/efi: Fix efi_call_phys_epilog() with CONFIG_X86_5LEVEL=y
  (bsc#1110006).
- x86/entry/64: Add two more instruction suffixes (bsc#1110006).
- x86/entry/64: Use 'xorl' for faster register clearing
  (bsc#1110006).
- x86/entry: Reduce the code footprint of the 'idtentry' macro
  (bsc#1110006).
- x86/entry: Use SYSCALL_DEFINE() macros for sys_modify_ldt()
  (bsc#1110006).
- x86/fpu/debug: Remove unused 'x86_fpu_state' and
  'x86_fpu_deactivate_state' tracepoints (bsc#1110006).
- x86/fpu: Make XSAVE check the base CPUID features before
  enabling (bsc#1110006).
- x86/fpu: Parse clearcpuid= as early XSAVE argument
  (bsc#1110006).
- x86/fpu: Remove the explicit clearing of XSAVE dependent
  features (bsc#1110006).
- x86/hyperv: Check for required priviliges in hyperv_init()
  (bsc#1110006).
- x86: i8259: Add missing include file (bsc#1110006).
- x86/intel_rdt: Enable CMT and MBM on new Skylake stepping
  (bsc#1110006).
- x86/intel_rdt: Fix incorrect returned value when creating
  rdgroup sub-directory in resctrl file system (bsc#1110006).
- x86/intel_rdt: Fix potential deadlock during resctrl mount
  (bsc#1110006).
- x86/intel_rdt: Fix potential deadlock during resctrl unmount
  (bsc#1110006).
- x86/irq: Remove an old outdated comment about context tracking
  races (bsc#1110006).
- x86/Kconfig: Limit NR_CPUS on 32-bit to a sane amount
  (bsc#1110006).
- x86/kexec: Make kexec (mostly) work in 5-level paging mode
  (bsc#1110006).
- x86/kprobes: Fix kernel crash when probing .entry_trampoline
  code (bsc#1110006).
- x86: kvm: avoid unused variable warning (bsc#1110006).
- x86/KVM/VMX: Don't set l1tf_flush_l1d from
  vmx_handle_external_intr() (bsc#1110006).
- x86/KVM/VMX: Don't set l1tf_flush_l1d to true from
  vmx_l1d_flush() (bsc#1110006).
- x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush()
  (bsc#1110006).
- x86/kvm/vmx: Remove duplicate l1d flush definitions
  (bsc#1110006).
- x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with
  'vmx_l1d_flush_cond' (bsc#1110006).
- x86/LDT: Avoid warning in 32-bit builds with older gcc
  (bsc#1110006).
- x86/mce: Add notifier_block forward declaration (bsc#1110006).
- x86/MCE/AMD: Define a function to get SMCA bank type
  (bsc#1110006).
- x86/mce/AMD: Get address from already initialized block
  (bsc#1110006).
- x86/mce: Check for alternate indication of machine check
  recovery on Skylake (bsc#1110006).
- x86/mce: Do not overwrite MCi_STATUS in mce_no_way_out()
  (bsc#1110006).
- x86/mce: Fix incorrect "Machine check from unknown source"
  message (bsc#1110006).
- x86/MCE: Remove min interval polling limitation (bsc#1110006).
- x86/MCE: Serialize sysfs changes (bsc#1110006).
- x86/microcode: Allow late microcode loading with SMT disabled
  (bsc#1110006).
- x86/microcode: Attempt late loading only when new microcode
  is present (bsc#1110006).
- x86/microcode: Do not exit early from __reload_late()
  (bsc#1110006).
- x86/microcode: Do not upload microcode if CPUs are offline
  (bsc#1110006).
- x86/microcode: Fix CPU synchronization routine (bsc#1110006).
- x86/microcode: Get rid of struct apply_microcode_ctx
  (bsc#1110006).
- x86/microcode/intel: Check microcode revision before updating
  sibling threads (bsc#1110006).
- x86/microcode/intel: Fix memleak in save_microcode_patch()
  (bsc#1110006).
- x86/microcode/intel: Look into the patch cache first
  (bsc#1110006).
- x86/microcode/intel: Save microcode patch unconditionally
  (bsc#1110006).
- x86/microcode/intel: Writeback and invalidate caches before
  updating microcode (bsc#1110006).
- x86/microcode: Make sure boot_cpu_data.microcode is up-to-date
  (bsc#1110006).
- x86/microcode: Make the late update update_lock a raw lock
  for RT (bsc#1110006).
- x86/microcode: Propagate return value from updating functions
  (bsc#1110006).
- x86/microcode: Request microcode on the BSP (bsc#1110006).
- x86/microcode: Synchronize late microcode loading (bsc#1110006).
- x86/microcode: Update the new microcode revision unconditionally
  (bsc#1110006).
- x86/mm/32: Initialize the CR4 shadow before __flush_tlb_all()
  (bsc#1110006).
- x86/mm/64: Rename the register_page_bootmem_memmap() 'size'
  parameter to 'nr_pages' (bsc#1110006).
- x86/mm: Define _PAGE_TABLE using _KERNPG_TABLE (bsc#1110006).
- x86/mm: Do not forbid _PAGE_RW before init for __ro_after_init
  (bsc#1110006).
- x86/mm: Fix bogus warning during EFI bootup, use boot_cpu_has()
  instead of this_cpu_has() in build_cr3_noflush() (bsc#1110006).
- x86/mm/kmmio: Fix mmiotrace for page unaligned addresses
  (bsc#1110006).
- x86/mm/kmmio: Make the tracer robust against L1TF (bsc#1110006).
- x86/mm/pat: Make set_memory_np() L1TF safe (bsc#1110006).
- x86/mm/pti: Add an overflow check to pti_clone_pmds()
  (bsc#1110006).
- x86/mm/pti: Fix PTI comment in entry_SYSCALL_64() (bsc#1110006).
- x86/mm: Relocate page fault error codes to traps.h
  (bsc#1110006).
- x86/mm: Remove in_nmi() warning from vmalloc_fault()
  (bsc#1110006).
- x86/nmi: Fix NMI uaccess race against CR3 switching
  (bsc#1110006).
- x86/numa_emulation: Fix emulated-to-physical node mapping
  (bsc#1110006).
- x86/oprofile: Fix bogus GCC-8 warning in nmi_setup()
  (bsc#1110006).
- x86/pae: use 64 bit atomic xchg function in
  native_ptep_get_and_clear (bsc#1110006).
- x86/paravirt: Remove 'noreplace-paravirt' cmdline option
  (bsc#1110006).
- x86/pgtable: Don't set huge PUD/PMD on non-leaf entries
  (bsc#1110006).
- x86: PM: Make APM idle driver initialize polling state
  (bsc#1110006).
- x86/power: Fix swsusp_arch_resume prototype (bsc#1110006).
- x86/pti: Check the return value of pti_user_pagetable_walk_p4d()
  (bsc#1110006).
- x86/pti: Check the return value of pti_user_pagetable_walk_pmd()
  (bsc#1110006).
- x86/retpoline/checksum32: Convert assembler indirect jumps
  (bsc#1110006).
- x86/retpoline/irq32: Convert assembler indirect jumps
  (bsc#1110006).
- x86/smp: fix non-SMP broken build due to redefinition of
  apic_id_is_primary_thread (bsc#1110006).
- x86/smpboot: Don't use mwait_play_dead() on AMD systems
  (bsc#1110006).
- x86/spectre: Fix spelling mistake: "vunerable"-> "vulnerable"
  (bsc#1110006).
- x86/speculation/l1tf: Exempt zeroed PTEs from inversion
  (bsc#1110006).
- x86/speculation/l1tf: Extend 64bit swap file size limit
  (bsc#1110006).
- x86/speculation/l1tf: Fix up pte->pfn conversion for PAE
  (bsc#1110006).
- x86/speculation/l1tf: Invert all not present mappings
  (bsc#1110006).
- x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert
  (bsc#1110006).
- x86/speculation/l1tf: Protect PAE swap entries against L1TF
  (bsc#1110006).
- x86/speculation, objtool: Annotate indirect calls/jumps for
  objtool on 32-bit kernels (bsc#1110006).
- x86/speculation: Simplify sysfs report of VMX L1TF vulnerability
  (bsc#1110006).
- x86/topology: Update the 'cpu cores' field in /proc/cpuinfo
  correctly across CPU hotplug operations (bsc#1110006).
- x86/tsc: Add missing header to tsc_msr.c (bsc#1110006).
- x86/tsc: Allow TSC calibration without PIT (bsc#1110006).
- x86/tsc: Prevent 32bit truncation in calc_hpet_ref()
  (bsc#1110006).
- x86/xen: Delay get_cpu_cap until stack canary is established
  (bsc#1110006).
- x86/xen: don't write ptes directly in 32-bit PV guests
  (bsc#1110006).
- x86/xen: Drop 5-level paging support code from the XEN_PV code
  (bsc#1110006).
- x86/xen: Reset VCPU0 info pointer after shared_info remap
  (bsc#1110006).
- xen: Fix {set,clear}_foreign_p2m_mapping on autotranslating
  guests (bsc#1110006).
- xen/PVH: Set up GS segment for stack canary (bsc#1110006).
- xen/x86/vpmu: Zero struct pt_regs before calling into sample
  handling code (bsc#1110006).
- blacklist.conf:
- Refresh
  patches.arch/00-x86-cpufeatures-Add-detection-of-L1D-cache-flush-sup.patch.
- Refresh
  patches.arch/0010-x86-bugs-kvm-Introduce-boot-time-control-of-L1TF-mit.patch.
- Refresh
  patches.arch/06-x86-KVM-VMX-Split-the-VMX-MSR-LOAD-structures-to-hav.patch.
- Refresh
  patches.arch/35-x86-speculation-handle-ht-correctly-on-amd.patch.
- Refresh
  patches.arch/36-x86-bugs-kvm-extend-speculation-control-for-virt_spec_ctrl.patch.
- Refresh
  patches.arch/kvm-nvmx-use-nested_run_pending-rather-than-from_vmentry.
- Refresh
  patches.arch/kvm-x86-svm-call-x86_spec_ctrl_set_guest-host-with-interrupts-disabled.patch.
- Refresh
  patches.arch/x86-cpu-amd-derive-cpu-topology-from-cpuid-function-0xb-when-available.
- Refresh
  patches.arch/x86-intel_rdt-enable-l2-cdp-in-msr-ia32_l2_qos_cfg.patch.
- Refresh
  patches.arch/x86-kvm-fix-lapic-timer-drift-when-guest-uses-periodic-mode.
- Refresh
  patches.fixes/x86-entry-64-remove-ebx-handling-from-error_entry-exit.patch.
- Refresh
  patches.suse/0005-x86-enter-Use-IBRS-on-syscall-and-interrupts.patch.
- Refresh
  patches.suse/05-x86-bugs-kvm-support-the-combination-of-guest-and-host-ibrs.patch.
- Refresh patches.suse/suse-hv-guest-os-id.patch.
- commit 12e3157
* Thu Oct  4 2018 tbogendoerfer@suse.de
- qed: Fix shmem structure inconsistency between driver and the
  mfw (bsc#1110561).
- commit 0963e4d
* Thu Oct  4 2018 tbogendoerfer@suse.de
- qed: Do not add VLAN 0 tag to untagged frames in multi-function
  mode (bsc#1050536 FATE#322898).
- qed: Fix populating the invalid stag value in multi function
  mode (bsc#1050536 FATE#322898).
- qed: Avoid sending mailbox commands when MFW is not responsive
  (bsc#1050536 FATE#322898).
- qed: Prevent a possible deadlock during driver load and unload
  (bsc#1050536 FATE#322898).
- qed: Wait for MCP halt and resume commands to take place
  (bsc#1050536 FATE#322898).
- qed: Wait for ready indication before rereading the shmem
  (bsc#1050536 FATE#322898).
- commit 95b5684
* Thu Oct  4 2018 jthumshirn@suse.de
- EDAC, ghes: Add DDR4 and NVDIMM memory types (bsc#1099125).
- EDAC, skx_edac: Detect non-volatile DIMMs (bsc#1099125).
- firmware, DMI: Add function to look up a handle and return
  DIMM size (bsc#1099125).
- acpi, nfit: Add function to look up nvdimm device and provide
  SMBIOS handle (bsc#1099125).
- commit e90cd46
* Thu Oct  4 2018 tbogendoerfer@suse.de
- liquidio: fix hang when re-binding VF host drv after running
  DPDK VF driver (bsc#1067126).
- liquidio: fix kernel panic in VF driver (bsc#1067126).
- commit dd69911
* Thu Oct  4 2018 yousaf.kaukab@suse.com
- ipmi:ssif: Add support for multi-part transmit messages >
  2 parts (bsc#1103308).
- commit dfd810d
* Thu Oct  4 2018 tbogendoerfer@suse.de
- bnx2x: Fix invalid memory access in rss hash config path
  (bsc#1050319 FATE#322906).
- bnx2x: Fix receiving tx-timeout in error or recovery state
  (bsc#1050319 FATE#322906).
- commit 003a93c
* Thu Oct  4 2018 tbogendoerfer@suse.de
- cxgb4: fix abort_req_rss6 struct (bsc#1046540 FATE#322930).
- cxgb4: when disabling dcb set txq dcb priority to 0 (bsc#1046540
  FATE#322930).
- commit 4477b4f
* Thu Oct  4 2018 tbogendoerfer@suse.de
- be2net: Fix memory leak in be_cmd_get_profile_config()
  (bsc#1086288 FATE#324877).
- be2net: remove unused old custom busy-poll fields (bsc#1086288
  FATE#324877).
- be2net: remove unused old AIC info (bsc#1086288 FATE#324877).
- commit e3890c0
* Thu Oct  4 2018 tbogendoerfer@suse.de
- net: thunderx: add timestamping support (bsc#1110096).
- Refresh
  patches.suse/0001-net-ethernet-cavium-Correct-Cavium-Thunderx-NIC-driv.patch.
- commit 0831771
* Thu Oct  4 2018 tbogendoerfer@suse.de
- net: thunderx: check for failed allocation lmac->dmacs
  (bsc#1110096).
- net: thunderx: prevent concurrent data re-writing by
  nicvf_set_rx_mode (bsc#1110096).
- bpf: make cavium thunder compatible w/ bpf_xdp_adjust_tail
  (bsc#1110096).
- net: thunderx: rework mac addresses list to u64 array
  (bsc#1110096).
- net: thunderx: add ndo_set_rx_mode callback implementation
  for VF (bsc#1110096).
- net: thunderx: add workqueue control structures for handle
  ndo_set_rx_mode request (bsc#1110096).
- net: thunderx: add XCAST messages handlers for PF (bsc#1110096).
- net: thunderx: add new messages for handle ndo_set_rx_mode
  callback (bsc#1110096).
- net: thunderx: add multicast filter management support
  (bsc#1110096).
- net: thunderx: add MAC address filter tracking for LMAC
  (bsc#1110096).
- net: thunderx: move filter register related macro into proper
  place (bsc#1110096).
- net: cavium: use module_pci_driver to simplify the code
  (bsc#1110096).
- net: cavium: fix NULL pointer dereference in cavium_ptp_put
  (bsc#1110096).
- net: thunder: change q_len's type to handle max ring size
  (bsc#1110096).
- net: add support for Cavium PTP coprocessor (bsc#1110096).
- net: thunderx: Set max queue count taking XDP_TX into account
  (bsc#1110096).
- net: thunderx: fix double free error (bsc#1110096).
- net: thunderx: remove a couple of redundant assignments
  (bsc#1110096).
- commit 1196f57
* Thu Oct  4 2018 tbogendoerfer@suse.de
- RDMA/bnxt_re: Fix system crash during RDMA resource
  initialization (bsc#1086283 FATE#324874).
- commit a963788
* Thu Oct  4 2018 jack@suse.cz
- patches.fixes/x86-memory_failure-Introduce-set-clear-_mce_nospec.patch:
  Fixup compilation breakage on s390 and arm due to missing
  clear_mce_nospec().
- commit faef795
* Thu Oct  4 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1110716)
  Enable ST LPS25H pressure sensor.
- commit 69c6902
* Thu Oct  4 2018 tiwai@suse.de
- smsc95xx: Check for Wake-on-LAN modes (bsc#1051510).
- smsc75xx: Check for Wake-on-LAN modes (bsc#1051510).
- r8152: Check for supported Wake-on-LAN Modes (bsc#1051510).
- sr9800: Check for supported Wake-on-LAN modes (bsc#1051510).
- lan78xx: Check for supported Wake-on-LAN modes (bsc#1051510).
- ax88179_178a: Check for supported Wake-on-LAN modes
  (bsc#1051510).
- mac80211: fix pending queue hang due to TX_DROP (bsc#1051510).
- cfg80211: reg: Init wiphy_idx in regulatory_hint_core()
  (bsc#1051510).
- Input: elantech - enable middle button of touchpad on ThinkPad
  P72 (bsc#1051510).
- regulator: fix crash caused by null driver data (bsc#1051510).
- pinctrl: cannonlake: Fix HOSTSW_OWN register offset of H variant
  (bsc#1051510).
- intel_th: Fix device removal logic (bsc#1051510).
- NFC: Fix possible memory corruption when handling SHDLC I-Frame
  commands (bsc#1051510).
- platform/x86: alienware-wmi: Correct a memory leak
  (bsc#1051510).
- xhci: Fix use after free for URB cancellation on a reallocated
  endpoint (bsc#1051510).
- mei: ignore not found client in the enumeration (bsc#1051510).
- i2c: i801: Allow ACPI AML access I/O ports not reserved for
  SMBus (bsc#1051510).
- fbdev/via: fix defined but not used warning (bsc#1051510).
- video: goldfishfb: fix memory leak on driver remove
  (bsc#1051510).
- fbdev: Distinguish between interlaced and progressive modes
  (bsc#1051510).
- platform/x86: toshiba_acpi: Fix defined but not used build
  warnings (bsc#1051510).
- mfd: 88pm860x-i2c: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT)
  (bsc#1051510).
- input: rohm_bu21023: switch to i2c_lock_bus(...,
  I2C_LOCK_SEGMENT) (bsc#1051510).
- HID: hid-ntrig: add error handling for sysfs_create_group
  (bsc#1051510).
- mfd: ti_am335x_tscadc: Fix struct clk memory leak (bsc#1051510).
- mmc: sdhci: do not try to use 3.3V signaling if not supported
  (bsc#1051510).
- mmc: sdhci-of-esdhc: set proper dma mask for ls104x chips
  (bsc#1051510).
- parport: sunbpp: fix error return code (bsc#1051510).
- coresight: Handle errors in finding input/output ports
  (bsc#1051510).
- mei: bus: type promotion bug in mei_nfc_if_version()
  (bsc#1051510).
- gpio: pxa: Fix potential NULL dereference (bsc#1051510).
- gpiolib: Mark gpio_suffixes array with __maybe_unused
  (bsc#1051510).
- gpu: ipu-v3: csi: pass back mbus_code_to_bus_cfg error codes
  (bsc#1051510).
- crypto: sharah - Unregister correct algorithms for SAHARA 3
  (bsc#1051510).
- crypto: skcipher - Fix -Wstringop-truncation warnings
  (bsc#1051510).
- Bluetooth: Use lock_sock_nested in bt_accept_enqueue
  (bsc#1051510).
- Bluetooth: Add a new Realtek 8723DE ID 0bda:b009 (bsc#1051510).
- mac80211: restrict delayed tailroom needed decrement
  (bsc#1051510).
- wlcore: Add missing PM call for
  wlcore_cmd_wait_for_event_or_timeout() (bsc#1051510).
- commit e266792
* Thu Oct  4 2018 wqu@suse.com
- btrfs: scrub: Don't use inode page cache in
  scrub_handle_errored_block() (follow up for bsc#1108096).
- commit 3f91c84
* Thu Oct  4 2018 tiwai@suse.de
- ASoC: cs4265: fix MMTLR Data switch control (bsc#1051510).
- ALSA: fireworks: fix memory leak of response buffer at error
  path (bsc#1051510).
- ALSA: bebob: fix memory leak for M-Audio FW1814 and ProjectMix
  I/O at error path (bsc#1051510).
- ALSA: emu10k1: fix possible info leak to userspace on
  SNDRV_EMU10K1_IOCTL_INFO (bsc#1051510).
- ALSA: bebob: use address returned by kmalloc() instead of
  kernel stack for streaming DMA mapping (bsc#1051510).
- ASoC: rt5514: Fix the issue of the delay volume applied
  (bsc#1051510).
- ASoC: dapm: Fix potential DAI widget pointer deref when linking
  DAIs (bsc#1051510).
- ALSA: msnd: Fix the default sample sizes (bsc#1051510).
- ALSA: usb-audio: Fix multiple definitions in AU0828_DEVICE()
  macro (bsc#1051510).
- ALSA: pcm: Fix snd_interval_refine first/last with open min/max
  (bsc#1051510).
- ALSA: hda: Add AZX_DCAPS_PM_RUNTIME for AMD Raven Ridge
  (bsc#1051510).
- ASoC: rt5514: Add the missing register in the readable table
  (bsc#1051510).
- ASoC: rt5514: Eliminate the noise in the ASRC case
  (bsc#1051510).
- ASoC: rt5514: Add the I2S ASRC support (bsc#1051510).
- commit 4eba9c8
* Thu Oct  4 2018 wqu@suse.com
- btrfs: scrub: Don't use inode pages for device replace (follow
  up for bsc#1108096).
- commit c865775
* Thu Oct  4 2018 wqu@suse.com
- btrfs: check-integrity: Fix NULL pointer dereference for
  degraded mount (bsc#1107947).
- commit 77b2277
* Thu Oct  4 2018 wqu@suse.com
- btrfs: tests/qgroup: Fix wrong tree backref level (bsc#1107928).
- commit a5e154c
* Thu Oct  4 2018 tiwai@suse.de
- README.BRANCH: SLE15-SP1 branch maintainer changes
  Add ptesarik as co-maintainer, keep tiwai as the primary maintainer
- commit 83aea11
* Thu Oct  4 2018 neilb@suse.com
- VFS: don't test owner for NFS in set_posix_acl() (bsc#1103405).
- commit 36f977a
* Thu Oct  4 2018 neilb@suse.com
- nfs/filelayout: fix oops when freeing filelayout segment
  (bsc#1105190).
- NFS/filelayout: Fix racy setting of fl->dsaddr in
  filelayout_check_deviceid() (bsc#1105190).
- commit d6d0fab
* Wed Oct  3 2018 jslaby@suse.cz
- watchdog: Mark watchdog touch functions as notrace (git-fixes).
- commit 8b53193
* Wed Oct  3 2018 fdmanana@suse.com
- Btrfs: fix send failure when root has deleted files still open
  (bsc#1110650).
- commit f52554d
* Wed Oct  3 2018 fdmanana@suse.com
- btrfs: Remove unused parameters from various functions
  (bsc#1110649).
- commit c97c657
* Wed Oct  3 2018 fdmanana@suse.com
- Btrfs: fix data corruption when deduplicating between different
  files (bsc#1110647).
- commit 669848c
* Wed Oct  3 2018 fdmanana@suse.com
- Btrfs: sync log after logging new name (bsc#1110646).
- commit 7260d6b
* Wed Oct  3 2018 fdmanana@suse.com
- Btrfs: fix return value on rename exchange failure
  (bsc#1110645).
- commit 532729c
* Wed Oct  3 2018 fdmanana@suse.com
- Btrfs: fix duplicate extents after fsync of file with prealloc
  extents (bsc#1110644).
- commit c4ec603
* Wed Oct  3 2018 fdmanana@suse.com
- Btrfs: fix loss of prealloc extents past i_size after fsync
  log replay (bsc#1110643).
- commit 974e057
* Wed Oct  3 2018 fdmanana@suse.com
- Btrfs: fix fsync after hole punching when using no-holes feature
  (bsc#1110642).
- commit 3f19b40
* Wed Oct  3 2018 fdmanana@suse.com
- btrfs: log csums for all modified extents (bsc#1110639).
- commit d6f9d10
* Wed Oct  3 2018 nsaenzjulienne@suse.de
- usb: dwc2: Turn on uframe_sched on "stm32f4x9_fsotg" platforms
  (bsc#1102881).
- usb: dwc2: Turn on uframe_sched on "amlogic" platforms
  (bsc#1102881).
- usb: dwc2: Turn on uframe_sched on "his" platforms
  (bsc#1102881).
- usb: dwc2: Turn on uframe_sched on "bcm" platforms
  (bsc#1102881).
- commit 9cf9d2f
* Wed Oct  3 2018 acho@suse.com
- Bluetooth: btsdio: Do not bind to non-removable BCM43430
  (bsc#1103587).
- commit 498c957
* Wed Oct  3 2018 bpoirier@suse.com
- Update Git-commit tag after upstream rebase
  The nvme-4.20 branch was rebased.
  Refresh
  patches.fixes/nvme_fc-add-nvme_discovery-sysfs-attribute-to-fc-tra.patch.
- commit 1cb7a6b
* Wed Oct  3 2018 neilb@suse.com
- Update config files for NFSv4.2
  Enable NFSv4.2 support - jsc@PM-231
  This requires a module parameter for NFSv4.2 to actually be
  available on SLE12 and SLE15-SP0
- commit 44703ec
* Tue Oct  2 2018 mgorman@suse.de
- sched/numa: Pass destination CPU as a parameter to
  migrate_task_rq kabi (bnc#1101669 optimise numa balancing for
  fast migrate).
- commit 58f5499
* Tue Oct  2 2018 mgorman@suse.de
- sched/numa: Stop multiple tasks from moving to the CPU at
  the same time kabi (bnc#1101669 optimise numa balancing for
  fast migrate).
- commit 1562dfb
* Tue Oct  2 2018 mgorman@suse.de
- mm, numa: Remove rate-limiting of automatic numa balancing
  migration kabi (bnc#1101669 optimise numa balancing for fast
  migrate).
- commit 9eade3a
* Tue Oct  2 2018 mgorman@suse.de
- mm, numa: Migrate pages to local nodes quicker early in the
  lifetime of a task (bnc#1101669 optimise numa balancing for
  fast migrate).
- mm, numa: Remove rate-limiting of automatic numa balancing
  migration (bnc#1101669 optimise numa balancing for fast
  migrate).
- sched/numa: Avoid task migration for small NUMA improvement
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/numa: Reset scan rate whenever task moves across nodes
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/numa: Pass destination CPU as a parameter to
  migrate_task_rq (bnc#1101669 optimise numa balancing for
  fast migrate).
- sched/numa: Stop multiple tasks from moving to the CPU at
  the same time (bnc#1101669 optimise numa balancing for fast
  migrate).
- commit 982ee4b
* Tue Oct  2 2018 ptesarik@suse.cz
- s390/crypto: Fix return code checking in cbc_paes_crypt()
  (bnc#1108323, LTC#171709).
- commit d2a9532
* Tue Oct  2 2018 ptesarik@suse.cz
- s390/qeth: use vzalloc for QUERY OAT buffer (LTC#171527,
  bsc#1106948).
- commit c8a5aea
* Tue Oct  2 2018 ptesarik@suse.cz
- s390/qdio: reset old sbal_state flags (LTC#171525, bsc#1106948).
- commit 9aa8dbc
* Tue Oct  2 2018 ptesarik@suse.cz
- s390/pci: fix out of bounds access during irq setup
  (bnc#1108323, LTC#171068).
- commit 02e74a9
* Mon Oct  1 2018 msuchanek@suse.de
- powerpc/numa: Use associativity if VPHN hcall is successful
  (bsc#1110363).
- commit 1f954f8
* Mon Oct  1 2018 jthumshirn@suse.de
- scsi: hisi_sas: Add SATA FIS check for v3 hw (FATE#326253).
- scsi: hisi_sas: add memory barrier in task delivery function
  (FATE#326253).
- scsi: hisi_sas: Tidy hisi_sas_task_prep() (FATE#326253).
- scsi: hisi_sas: Implement handlers of PCIe FLR for v3 hw
  (FATE#326253).
- scsi: hisi_sas: relocate some common code for v3 hw
  (FATE#326253).
- scsi: hisi_sas: tidy host controller reset function a bit
  (FATE#326253).
- scsi: hisi_sas: Fix the failure of recovering PHY from STP
  link timeout (FATE#326253).
- scsi: hisi_sas: tidy channel interrupt handler for v3 hw
  (FATE#326253).
- scsi: hisi_sas: Drop hisi_sas_slot_abort() (FATE#326253).
- scsi: hisi_sas: Update a couple of register settings for v3 hw
  (FATE#326253).
- scsi: hisi_sas: Add missing PHY spinlock init (FATE#326253).
- scsi: hisi_sas: Pre-allocate slot DMA buffers (FATE#326253).
- scsi: hisi_sas: Release all remaining resources in clear nexus
  ha (FATE#326253).
- scsi: hisi_sas: Add a flag to filter PHY events during reset
  (FATE#326253).
- scsi: hisi_sas: Adjust task reject period during host reset
  (FATE#326253).
- scsi: hisi_sas: Fix the conflict between dev gone and host reset
  (FATE#326253).
- scsi: hisi_sas: Only process broadcast change in
  phy_bcast_v3_hw() (FATE#326253).
- scsi: hisi_sas: Use dmam_alloc_coherent() (FATE#326253).
- commit 5ef2301
* Mon Oct  1 2018 jthumshirn@suse.de
- Refresh
  patches.arch/powerpc-Avoid-code-patching-freed-init-sections.patch.
- Refresh
  patches.arch/powerpc-pkeys-Fix-reading-of-ibm-processor-storage-k.patch.
- Refresh
  patches.arch/powerpc-tm-Avoid-possible-userspace-r1-corruption-on.patch.
- Refresh
  patches.arch/powerpc-tm-Fix-userspace-r13-corruption.patch.
- Refresh
  patches.drivers/scsi-ipr-System-hung-while-dlpar-adding-primary-ipr-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-appropriate-debug-info-for-invalid-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-logic-to-detect-ABTS-hang-and-respo.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-mode-control-for-each-physical-port.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-support-for-ZIO6-interrupt-threshol.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-FC-NVMe-underrun-to-be-handled-by.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Check-for-Register-disconnect.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Decrement-login-retry-count-for-only-pl.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Defer-chip-reset-until-target-mode-is-e.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-Remote-port-registration.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-deadlock-between-ATIO-and-HW-lock.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-increment-of-switch-scan-ret.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-dropped-srb-resource.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-duplicate-switch-s-Nport-ID-entries.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-early-srb-free-on-abort.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-iIDMA-error.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-port-speed-being-set-for-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-out-of-order-Termination-and-ABTS-r.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-port-speed-display-on-chip-reset.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-premature-command-free.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-process-response-queue-for-ISP26XX-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-race-condition-for-resource-cleanup.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-stuck-session-in-PLOGI-state.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Force-fw-cleanup-on-ADISC-error.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Increase-abort-timeout-value.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Move-ABTS-code-behind-qpair.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Move-get-rel-_sp-to-base_qpair-struct.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Move-rport-registration-out-of-internal.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reduce-holding-sess_lock-to-prevent-CPU.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reject-bsg-request-if-chip-is-down.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-ASYNC-GIDPN-switch-command.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-all-rports-if-fabric-scan-retry-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-redundant-check-for-fcport-delet.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-stale-ADISC_DONE-event.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-stale-debug-trace-message-from-t.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Serialize-mailbox-request.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Terminate-Plogi-PRLI-if-WWN-is-0.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Turn-off-IOCB-timeout-timer-on-IOCB-com.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-to-version-10.00.00.09-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.10-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.11-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-rscn_rcvd-field-to-more-meaningf.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-correct-qpair-for-ABTS-CMD.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-shutdown-chip-if-reset-fail.patch.
- Refresh
  patches.fixes/nvme_fc-add-nvme_discovery-sysfs-attribute-to-fc-tra.patch.
- commit 4ee7cfe
* Mon Oct  1 2018 bp@suse.de
- x86: msr-index.h: Correct SNB_C1/C3_AUTO_UNDEMOTE defines
  (bsc#1110301).
- commit 6bed327
* Mon Oct  1 2018 bp@suse.de
- x86/mce: Improve error message when kernel cannot recover
  (bsc#1110301).
- commit cfcbe8b
* Mon Oct  1 2018 bp@suse.de
- blacklist.conf:
- commit b302752
* Mon Oct  1 2018 bp@suse.de
- x86/vdso: Fix lsl operand order (bsc#1110301).
- commit e4cb840
* Mon Oct  1 2018 msuchanek@suse.de
- rpm/mkspec: fix ppc64 kernel-source build.
- commit 85c9272
* Mon Oct  1 2018 bp@suse.de
- blacklist.conf: ff924c5a1ec7
  ff924c5a1ec7 ("x86/pti: Fix section mismatch warning/error")'s Fixes tag is
  wrong. It should point to:
  16a3fe634f6a ("x86/mm/pti: Clone kernel-image on PTE level for 32 bit")
  which introduced the section mismatch by using pti_user_pagetable_walk_pte()
  in pti_clone_pgtable().
- commit 7832955
* Mon Oct  1 2018 bp@suse.de
- x86/boot: Fix kexec booting failure in the SEV bit detection
  code (bsc#1110301).
- commit c221d90
* Mon Oct  1 2018 jroedel@suse.de
- KVM: x86: Do not re-{try,execute} after failed emulation in L2
  (bsc#1106240).
- KVM: x86: Default to not allowing emulation retry in
  kvm_mmu_page_fault (bsc#1106240).
- KVM: x86: Merge EMULTYPE_RETRY and EMULTYPE_ALLOW_REEXECUTE
  (bsc#1106240).
- KVM: x86: Invert emulation re-execute behavior to make it opt-in
  (bsc#1106240).
- KVM: VMX: Do not allow reexecute_instruction() when skipping
  MMIO instr (bsc#1106240).
- commit 3193e58
* Mon Oct  1 2018 nborisov@suse.com
- Stop building F2FS (boo#1109665)
  As per the information in the bugzilla issue f2fs is no longer supported
  on opensuse distributions.
- commit 7d12b0b
* Sat Sep 29 2018 lduncan@suse.com
- scsi: target: iscsi: Use bin2hex instead of a re-implementation
  (bsc#1107829 CVE-2018-14633).
- scsi: target: iscsi: Use hex2bin instead of a re-implementation
  (bsc#1107829 CVE-2018-14633).
- commit 3a95174
* Fri Sep 28 2018 jthumshirn@suse.de
- block: pass inclusive 'lend' parameter to
  truncate_inode_pages_range (bsc#1109992).
- commit d8666d7
* Fri Sep 28 2018 jthumshirn@suse.de
- block: Invalidate cache on discard v2 (bsc#1109992).
- commit f6569f1
* Fri Sep 28 2018 jthumshirn@suse.de
- block: properly protect the 'queue' kobj in blk_unregister_queue
  (bsc#1109979).
- commit 0b9704d
* Fri Sep 28 2018 jthumshirn@suse.de
- block: fix warning when I/O elevator is changed as request_queue
  is being removed (bsc#1109979).
- commit ab9dc17
* Fri Sep 28 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-numa-remove-unused-nr_running-field.patch.
- Delete
  patches.suse/sched-numa-Do-not-move-imbalanced-load-purely-on-the-basis-of-an-idle-CPU.patch.
- Delete
  patches.suse/sched-numa-Stop-comparing-tasks-for-NUMA-placement-after-selecting-an-idle-core.patch.
- commit 838792b
* Fri Sep 28 2018 jthumshirn@suse.de
- sr: get/drop reference to device in revalidate and check_events
  (bsc#1109979).
- commit c375621
* Thu Sep 27 2018 msuchanek@suse.de
- rpm/mkspec: build dtbs for architectures marked -!needs_updating
- commit 2d47640
* Thu Sep 27 2018 msuchanek@suse.de
- Limit kernel-source build to architectures for which we build binaries
  (bsc#1108281).
- commit d643512
* Thu Sep 27 2018 jroedel@suse.de
- x86/mm: Add TLB purge to free pmd/pte page interfaces
  (bsc#1110006).
- ioremap: Update pgtable free interfaces with addr (bsc#1110006).
- x86/mm: Disable ioremap free page handling on x86-PAE
  (bsc#1110006).
- commit 417fdc9
* Thu Sep 27 2018 jroedel@suse.de
- x86/mm: Expand static page table for fixmap space (bsc#1110006).
- x86/process: Don't mix user/kernel regs in 64bit __show_regs()
  (bsc#1110006).
- x86/vdso: Fix lsl operand order (bsc#1110006).
- x86/entry/64: Wipe KASAN stack shadow before
  rewind_stack_do_exit() (bsc#1110006).
- x86/process: Re-export start_thread() (bsc#1110006).
- Fix kexec forbidding kernels signed with keys in the secondary
  keyring to boot (bsc#1110006).
- x86/mce: Improve error message when kernel cannot recover
  (bsc#1110006).
- x86: msr-index.h: Correct SNB_C1/C3_AUTO_UNDEMOTE defines
  (bsc#1110006).
- x86/dumpstack: Save first regs set for the executive summary
  (bsc#1110006).
- x86/mm: Drop TS_COMPAT on 64-bit exec() syscall (bsc#1110006).
- x86/pkeys: Do not special case protection key 0 (bsc#1110006).
- x86/pkeys: Override pkey when moving away from PROT_EXEC
  (bsc#1110006).
- x86/kexec: Avoid double free_page() upon do_kexec_load()
  failure (bsc#1110006).
- commit 1c613b4
* Thu Sep 27 2018 jroedel@suse.de
- x86/dumpstack: Unify show_regs() (bsc#1110006).
- x86/apic: Fix restoring boot IRQ mode in reboot and kexec/kdump
  (bsc#1110006).
- x86/apic: Split disable_IO_APIC() into two functions to fix
  CONFIG_KEXEC_JUMP=y (bsc#1110006).
- x86/apic: Split out restore_boot_irq_mode() from
  disable_IO_APIC() (bsc#1110006).
- x86/mm: implement free pmd/pte page interfaces (bsc#1110006).
- mm/vmalloc: add interfaces to free unmapped page table
  (bsc#1110006).
- x86/apic/vector: Fix off by one in error path (bsc#1110006).
- x86/espfix/64: Fix espfix double-fault handling on 5-level
  systems (bsc#1110006).
- x86/PCI: Make broadcom_postcore_init() check acpi_disabled
  (bsc#1110006).
- x86/idt: Load idt early in start_secondary (bsc#1110006).
- x86/mm: Fix ELF_ET_DYN_BASE for 5-level paging (bsc#1110006).
- x86/mpx: Do not allow MPX if we have mappings above 47-bit
  (bsc#1110006).
- kprobes/x86: Release insn_slot in failure path (bsc#1110006).
- commit 9a3ac30
* Thu Sep 27 2018 jroedel@suse.de
- blacklist.conf: Add 3 fixes for x86 that we don't need
- commit ddd7d7f
* Thu Sep 27 2018 jroedel@suse.de
- blacklist.conf: Blacklist x86 devicetree code
  We don't support devicetree on x86.
- commit b4b3181
* Thu Sep 27 2018 jkosina@suse.cz
- blacklist.conf: fix after mismerge
- commit 1aee746
* Thu Sep 27 2018 ohering@suse.de
- rename/renumber hv patches to simplify upcoming upstream merges
  No code changes.
- commit 0699480
* Thu Sep 27 2018 jroedel@suse.de
- iommu/amd: Return devid as alias for ACPI HID devices
  (bsc#1106105).
- commit d37e986
* Thu Sep 27 2018 jroedel@suse.de
- blacklist.conf: Blacklist one PCI fix
  83c75ddd816e PCI: rcar: Handle rcar_pcie_parse_request_of_pci_ranges() failures
  The driver patches is not compiled on any config.
- commit f0f2bee
* Thu Sep 27 2018 jroedel@suse.de
- PCI: aardvark: Size bridges before resources allocation
  (bsc#1109806).
- commit ae7ab95
* Thu Sep 27 2018 jroedel@suse.de
- PCI: faraday: Fix I/O space page leak (bsc#1109806).
- PCI: designware: Fix I/O space page leak (bsc#1109806).
- PCI: versatile: Fix I/O space page leak (bsc#1109806).
- PCI: xgene: Fix I/O space page leak (bsc#1109806).
- PCI: faraday: Add missing of_node_put() (bsc#1109806).
- PCI: xilinx-nwl: Add missing of_node_put() (bsc#1109806).
- PCI: xilinx: Add missing of_node_put() (bsc#1109806).
- PCI/portdrv: Compute MSI/MSI-X IRQ vectors after final
  allocation (bsc#1109806).
- PCI/portdrv: Factor out Interrupt Message Number lookup
  (bsc#1109806).
- commit d1f8a0e
* Thu Sep 27 2018 vliaskovitis@suse.com
- xen: issue warning message when out of grant maptrack entries
  (bsc#1105795).
- commit 46751db
* Thu Sep 27 2018 neilb@suse.com
- NFS: Use an appropriate work queue for direct-write completion
  (bsc#1082519).
- commit e010715
* Thu Sep 27 2018 neilb@suse.com
- sort series.conf
  I didn't want to, but he made me do it.
- commit 255215b
* Wed Sep 26 2018 dbueso@suse.de
- Revert "mm,vmacache: optimize overflow system-wide flushing" (bsc#1108399 CVE-2018-17182).
- commit 85bf27e
* Wed Sep 26 2018 jeffm@suse.com
- btrfs: fix missing error return in btrfs_drop_snapshot
  (Git-fixes bsc#1109919).
- commit 86c0bd9
* Wed Sep 26 2018 jeffm@suse.com
- btrfs: handle errors while updating refcounts in
  update_ref_for_cow (Git-fixes bsc#1109915).
- commit 602171e
* Wed Sep 26 2018 jeffm@suse.com
- mm: /proc/pid/pagemap: hide swap entries from unprivileged users
  (Git-fixes bsc#1109907).
- commit 32c80e6
* Wed Sep 26 2018 jack@suse.cz
- Fix buggy backport in
  patches.fixes/dax-check-for-queue_flag_dax-in-bdev_dax_supported.patch
  (bsc#1109859)
- commit 6d44295
* Wed Sep 26 2018 msuchanek@suse.de
- powerpc/tm: Avoid possible userspace r1 corruption on reclaim
  (bsc#1109333).
- powerpc/tm: Fix userspace r13 corruption (bsc#1109333).
- commit a98497c
* Wed Sep 26 2018 jack@suse.cz
- Update config files.
- commit 2a4f668
* Wed Sep 26 2018 jack@suse.cz
- blacklist.conf: Blacklist aa28de275a248
- commit 7850c06
* Wed Sep 26 2018 jack@suse.cz
- device-dax: Add missing address_space_operations (bsc#1107783).
- commit 860c238
* Wed Sep 26 2018 jack@suse.cz
- ext4, dax: set ext4_dax_aops for dax files (bsc#1104888).
- commit d17e656
* Wed Sep 26 2018 jack@suse.cz
- ext4, dax: add ext4_bmap to ext4_dax_aops (bsc#1104888).
- commit 2de8851
* Wed Sep 26 2018 wqu@suse.com
- btrfs: delayed-inode: Remove wrong qgroup meta  reservation
  calls (bsc#1031392).
- commit a3d6aee
* Wed Sep 26 2018 jack@suse.cz
- Sort series.conf
- commit 75ce2fa
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Use independent and accurate per inode  qgroup
  rsv (bsc#1031392).
- commit 689ef17
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Commit transaction in advance to reduce  early
  EDQUOT (bsc#1031392).
- commit c51f977
* Wed Sep 26 2018 wqu@suse.com
- Revert "btrfs: qgroups: Retry after commit on getting  EDQUOT"
  (bsc#1031392).
- commit 6fa454e
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Update trace events for metadata  reservation
  (bsc#1031392).
- commit 039a3e9
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Use root::qgroup_meta_rsv_* to record  qgroup
  meta reserved space (bsc#1031392).
- commit c1e3309
* Wed Sep 26 2018 wqu@suse.com
- btrfs: delayed-inode: Use new qgroup meta rsv for  delayed
  inode and item (bsc#1031392).
- commit be686d5
* Wed Sep 26 2018 wqu@suse.com
- btrfs: Fix wrong btrfs_delalloc_release_extents parameter
  (bsc#1031392).
- commit f60cf53
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Use separate meta reservation type for  delalloc
  (bsc#1031392).
- commit dd0023b
* Wed Sep 26 2018 msuchanek@suse.de
- KABI: move the new handler to end of machdep_calls and hide
  it from genksyms (bsc#1094244).
- commit 06a6f3c
* Wed Sep 26 2018 msuchanek@suse.de
- powernv/pseries: consolidate code for mce early handling
  (bsc#1094244).
- powerpc/pseries: Dump the SLB contents on SLB MCE errors
  (bsc#1094244).
  - Refresh patches.kabi/KABI-move-mce_data_buf-into-paca_aux.patch
- powerpc/pseries: Display machine check error details
  (bsc#1094244).
- powerpc/pseries: Flush SLB contents on SLB MCE errors
  (bsc#1094244).
- powerpc/pseries: Define MCE error event section (bsc#1094244).
- commit 4b0cc92
* Wed Sep 26 2018 msuchanek@suse.de
- Sort patches.
- commit ee18a99
* Wed Sep 26 2018 wqu@suse.com
- btrfs: add a comp_refs() helper (dependency for bsc#1031392).
- commit 2b7e949
* Wed Sep 26 2018 wqu@suse.com
- btrfs: switch args for comp_*_refs (dependency for bsc#1031392).
- commit 028ef68
* Wed Sep 26 2018 wqu@suse.com
- btrfs: remove type argument from comp_tree_refs (dependency
  for bsc#1031392).
- commit 6d12157
* Wed Sep 26 2018 wqu@suse.com
- btrfs: make the delalloc block rsv per inode (dependency for
  bsc#1031392).
- commit d6a4960
* Wed Sep 26 2018 wqu@suse.com
- btrfs: add tracepoints for outstanding extents mods (dependency
  for bsc#1031392).
- commit 520ec44
* Wed Sep 26 2018 wqu@suse.com
- Btrfs: rework outstanding_extents (dependency for bsc#1031392).
- commit a390567
* Wed Sep 26 2018 wqu@suse.com
- btrfs: cleanup extent locking sequence (dependency for
  bsc#1031392).
- commit c9c7165
* Wed Sep 26 2018 bpoirier@suse.com
- Fix sorted section
  Merge commits 862a718e83 and 8aa4d41564 had conflicts with (apparently) bad
  resolution which introduced disorder in the sorted section.
- commit 06a8929
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Introduce function to convert  META_PREALLOC
  into META_PERTRANS (bsc#1031392).
- commit 66a2044
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Don't use root->qgroup_meta_rsv for  qgroup
  (bsc#1031392).
- commit 9377718
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Split meta rsv type into meta_prealloc  and
  meta_pertrans (bsc#1031392).
- commit 48f771c
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Cleanup the remaining old reservation  counters
  (bsc#1031392).
- commit ebe4a51
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Update trace events to use new separate  rsv
  types (bsc#1031392).
- commit 28b94d4
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Fix wrong qgroup reservation update for
  relationship modification (bsc#1031392).
- commit 017a285
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Make qgroup_reserve and its callers to  use
  separate reservation type (bsc#1031392).
- commit 28ba57c
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Introduce helpers to update and access  new
  qgroup rsv (bsc#1031392).
- commit 10f14a4
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Skeleton to support separate qgroup  reservation
  type (bsc#1031392).
- commit ca174f6
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Fix qgroup reserved space underflow by  only
  freeing reserved ranges (dependency for bsc#1031392).
- commit 84d52be
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Introduce extent changeset for qgroup  reserve
  functions (dependency for bsc#1031392).
- commit 8ef1999
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Fix qgroup reserved space underflow caused
  by buffered write and quotas being enabled (dependency for
  bsc#1031392).
- commit 25d3c72
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Return actually freed bytes for qgroup  release
  or free data (dependency for bsc#1031392).
- commit 852d7ed
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Cleanup  btrfs_qgroup_prepare_account_extents
  function (dependency for bsc#1031392).
- commit 18dd54a
* Wed Sep 26 2018 wqu@suse.com
- btrfs: qgroup: Add quick exit for non-fs extents (dependency
  for bsc#1031392).
- commit 91f12cc
* Tue Sep 25 2018 jeffm@suse.com
- userfaultfd: hugetlbfs: fix userfaultfd_huge_must_wait()
  pte access (bsc#1109739).
- commit a9faf52
* Tue Sep 25 2018 dbueso@suse.de
- ipc/shm: fix shmat() nil address after round-down when remapping
  (bsc#1090078).
- Revert "ipc/shm: Fix shmat mmap nil-page protection"
  (bsc#1090078).
- commit d8968d8
* Tue Sep 25 2018 dbueso@suse.de
- update series.conf
- commit 9754b53
* Tue Sep 25 2018 jack@suse.cz
- dax: Make extension of dax_operations transparent (bsc#1098782).
- commit eb2986e
* Tue Sep 25 2018 jack@suse.cz
- x86/asm/memcpy_mcsafe: Provide original memcpy_mcsafe_unrolled
  (bsc#1098782).
- commit ad97292
* Tue Sep 25 2018 hare@suse.de
- nvme: register ns_id attributes as default sysfs groups
  (bsc#1105247).
- commit 22aeb65
* Tue Sep 25 2018 hare@suse.de
- PCI: Match Root Port's MPS to endpoint's MPSS as necessary
  (bsc#1109269).
- commit b312a43
* Tue Sep 25 2018 mwilck@suse.com
- x86/build/64: Force the linker to use 2MB page size
  (bsc#1109603).
- commit 03b0ea6
* Tue Sep 25 2018 mgalbraith@suse.de
- sched/fair: Fix bandwidth timer clock drift condition (Git-fixes).
- commit ad03360
* Tue Sep 25 2018 hare@suse.de
- kabi fix for check_disk_size_change() (bsc#1098459).
- commit 0835551
* Tue Sep 25 2018 ptesarik@suse.cz
- Update config files.
  Turn off CONFIG_DYNAMIC_STACK on s390x, because it brings more
  confusiion by reporting false positives.
- commit 6e2def2
* Tue Sep 25 2018 bpoirier@suse.com
- net: ena: fix incorrect usage of memory barriers (bsc#1108093).
- net: ena: fix missing calls to READ_ONCE (bsc#1108093).
- net: ena: fix missing lock during device destruction
  (bsc#1108093).
- net: ena: fix potential double ena_destroy_device()
  (bsc#1108093).
- net: ena: fix device destruction to gracefully free resources
  (bsc#1108093).
- net: ena: fix driver when PAGE_SIZE == 64kB (bsc#1108093).
- net: ena: fix surprise unplug NULL dereference kernel crash
  (bsc#1108093).
- net: ena: Eliminate duplicate barriers on weakly-ordered archs
  (bsc#1108093).
- commit a7d98e3
* Mon Sep 24 2018 jeffm@suse.com
- xfs: Fix per-inode DAX flag inheritance (Git-fixes bsc#1109511).
- commit 30796e4
* Mon Sep 24 2018 brogers@suse.com
- Revert "vhost: cache used event for better performance"
  (bsc#1090528).
- commit 7ed7638
* Mon Sep 24 2018 jroedel@suse.de
- x86/platform/UV: Mark memblock related init code and data
  correctly (bsc#1108243).
- commit 1500ffe
* Mon Sep 24 2018 msuchanek@suse.de
- powerpc/pseries: Disable CPU hotplug across migrations
  (bsc#1065729).
- commit 09057d9
* Mon Sep 24 2018 hare@suse.de
- scsi: qla2xxx: Update driver version to 10.00.00.11-k (bsc#1108870).
- scsi: qla2xxx: Fix double increment of switch scan retry count (bsc#1108870).
- scsi: qla2xxx: Fix duplicate switch's Nport ID entries (bsc#1108870).
- scsi: qla2xxx: Remove stale debug trace message from tcm_qla2xxx (bsc#1108870).
- scsi: qla2xxx: Fix premature command free (bsc#1108870).
- scsi: qla2xxx: Reject bsg request if chip is down (bsc#1108870).
- scsi: qla2xxx: shutdown chip if reset fail (bsc#1108870).
- scsi: qla2xxx: Fix stuck session in PLOGI state (bsc#1108870).
- scsi: qla2xxx: Fix early srb free on abort (bsc#1108870).
- scsi: qla2xxx: Add mode control for each physical port (bsc#1108870).
- scsi: qla2xxx: Fix race condition for resource cleanup (bsc#1108870).
- scsi: qla2xxx: Fix dropped srb resource (bsc#1108870).
- scsi: qla2xxx: Fix port speed display on chip reset (bsc#1108870).
- scsi: qla2xxx: Check for Register disconnect (bsc#1108870).
- scsi: qla2xxx: Increase abort timeout value (bsc#1108870).
- scsi: qla2xxx: Allow FC-NVMe underrun to be handled by transport (bsc#1108870).
- scsi: qla2xxx: Update driver version to 10.00.00.10-k (bsc#1108870).
- scsi: qla2xxx: Move ABTS code behind qpair (bsc#1108870).
- scsi: qla2xxx: Remove stale ADISC_DONE event (bsc#1108870).
- scsi: qla2xxx: Fix Remote port registration (bsc#1108870).
- scsi: qla2xxx: Remove ASYNC GIDPN switch command (bsc#1108870).
- scsi: qla2xxx: Reduce holding sess_lock to prevent CPU lock-up (bsc#1108870).
- scsi: qla2xxx: Move {get|rel}_sp to base_qpair struct (bsc#1108870).
- scsi: qla2xxx: Add support for ZIO6 interrupt threshold (bsc#1108870).
- scsi: qla2xxx: Fix out of order Termination and ABTS response (bsc#1108870).
- scsi: qla2xxx: Add logic to detect ABTS hang and response completion (bsc#1108870).
- scsi: qla2xxx: Add appropriate debug info for invalid RX_ID (bsc#1108870).
- scsi: qla2xxx: Fix deadlock between ATIO and HW lock (bsc#1108870).
- scsi: qla2xxx: Serialize mailbox request (bsc#1108870).
- scsi: qla2xxx: Update driver to version 10.00.00.09-k (bsc#1108870).
- scsi: qla2xxx: Terminate Plogi/PRLI if WWN is 0 (bsc#1108870).
- scsi: qla2xxx: Defer chip reset until target mode is enabled (bsc#1108870).
- scsi: qla2xxx: Fix iIDMA error (bsc#1108870).
- scsi: qla2xxx: Remove all rports if fabric scan retry fails (bsc#1108870).
- scsi: qla2xxx: Force fw cleanup on ADISC error (bsc#1108870).
- scsi: qla2xxx: Turn off IOCB timeout timer on IOCB completion (bsc#1108870).
- scsi: qla2xxx: Decrement login retry count for only plogi (bsc#1108870).
- scsi: qla2xxx: Move rport registration out of internal work_list (bsc#1108870).
- scsi: qla2xxx: Remove redundant check for fcport deletion (bsc#1108870).
- scsi: qla2xxx: Update rscn_rcvd field to more meaningful scan_needed (bsc#1108870).
- scsi: qla2xxx: Use correct qpair for ABTS/CMD (bsc#1108870).
- scsi: qla2xxx: Fix incorrect port speed being set for FC adapters (bsc#1108870).
- scsi: qla2xxx: Fix process response queue for ISP26XX and above (bsc#1108870).
- commit 63477a2
* Mon Sep 24 2018 hare@suse.de
- scripts/git_sort/git_sort.py: add mkp 4.20/scsi-queue
- commit 3284d56
* Mon Sep 24 2018 msuchanek@suse.de
- powerpc/pkeys: Fix reading of ibm, processor-storage-keys
  property (bsc#1109244).
- commit 918a8df
* Mon Sep 24 2018 hare@suse.de
- scsi: mpt3sas: Fix calltrace observed while running IO & reset (bsc#1077989).
- scsi: fcoe: hold disc_mutex when traversing rport lists (bsc#1077989).
- scsi: libfc: hold disc_mutex in fc_disc_stop_rports() (bsc#1077989).
- scsi: libfc: fixup lockdep annotations (bsc#1077989).
- scsi: libfc: fixup 'sleeping function called from invalid context' (bsc#1077989).
- scsi: libfc: Add lockdep annotations (bsc#1077989).
- blk-mq: avoid to synchronize rcu inside blk_cleanup_queue() (bsc#1077989).
- commit 527998e
* Mon Sep 24 2018 jroedel@suse.de
- Refresh
  patches.arch/0003-x86-l1tf-Handle-EPT-disabled-state-proper.patch.
- commit 43d6857
* Mon Sep 24 2018 hare@suse.de
- nvme_fc: add 'nvme_discovery' sysfs attribute to fc transport device (bsc#1044189). - scripts/git_sort/git_sort.py: Update NVMe repo URL
- commit 64467ca
* Mon Sep 24 2018 jroedel@suse.de
- x86/platform/UV: Add kernel parameter to set memory block size
  (bsc#1108243).
- x86/platform/UV: Use new set memory block size function
  (bsc#1108243).
- x86/platform/UV: Add adjustable set memory block size function
  (bsc#1108243).
- x86/mm/memory_hotplug: determine block size based on the end
  of boot memory (bsc#1108243).
- commit eb8e3fa
* Mon Sep 24 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/amdgpu:add VCN booting with firmware loaded by PSP'
- commit 4d1aa08
* Mon Sep 24 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/amdgpu:add VCN support in PSP driver'
- commit 9459a54
* Mon Sep 24 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Use correct pagesize in kvm_unmap_radix()
  (bsc#1061840, git-fixes).
- commit 3763099
* Mon Sep 24 2018 tzimmermann@suse.de
- drm/amdgpu: update tmr mc address (bsc#1100132).
- commit b26d124
* Mon Sep 24 2018 msuchanek@suse.de
- powerpc/pseries: Remove unneeded uses of dlpar work queue
  (bsc#1102495, bsc#1109337).
- Refresh patches.arch/hotplug-cpu-Add-operation-queuing-function.patch.
- powerpc/pseries: Remove prrn_work workqueue (bsc#1102495,
  bsc#1109337).
- commit 7328f0a
* Mon Sep 24 2018 yousaf.kaukab@suse.com
- arm64: Ignore hardware dirty bit updates in ptep_set_wrprotect()
  (bsc#1108010).
- kvm: arm64: Convert kvm_set_s2pte_readonly() from inline asm
  to cmpxchg() (bsc#1108010).
- commit 96eac08
* Mon Sep 24 2018 msuchanek@suse.de
- scsi: ipr: System hung while dlpar adding primary ipr adapter
  back (bsc#1109336).
- commit c86eecc
* Fri Sep 21 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-Avoid-code-patching-freed-init-sections.patch.
- commit 6d7fc83
* Fri Sep 21 2018 mfleming@suse.de
- sched/fair: Fix vruntime_normalized() for remote non-migration
  wakeup (git-fixes).
- commit 87a53f0
* Fri Sep 21 2018 jslaby@suse.cz
- net: rtnl_configure_link: fix dev flags changes arg to
  __dev_notify_flags (git-fixes).
- commit 52cf998
* Fri Sep 21 2018 jroedel@suse.de
- x86/CPU/AMD: Derive CPU topology from CPUID function 0xB when
  available (fate#324376).
- x86/CPU: Modify detect_extended_topology() to return result
  (fate#324376).
- x86: irq_remapping: Move irq remapping mode enum (fate#324376).
- iommu/amd: Add support for higher 64-bit IOMMU Control Register
  (fate#324376).
- iommu/amd: Add support for IOMMU XT mode (fate#324376).
- Refresh
  patches.arch/08-x86-cpu-remove-the-pointless-cpu-printout.patch.
- Refresh
  patches.arch/11-x86-cpu-topology-provide-detect_extended_topology_early.patch.
- Refresh
  patches.arch/13-x86-cpu-amd-do-not-check-cpuid-max-ext-level-before-parsing-smp-info.patch.
- commit 64d6ec7
* Fri Sep 21 2018 tbogendoerfer@suse.de
- bnxt_re: Fix couple of memory leaks that could lead to IOMMU
  call traces (bsc#1050244 FATE#322915).
- IB/ipoib: Avoid a race condition between start_xmit and
  cm_rep_handler (bsc#1046307 FATE#322941).
- IB/hfi1: Invalid NUMA node information can cause a divide by
  zero (bsc#1060463 FATE#323043).
- IB/mlx4: Use 4K pages for kernel QP's WQE buffer (bsc#1046302
  FATE#322945).
- IB/ipoib: Fix error return code in ipoib_dev_init() (bsc#1046307
  FATE#322941).
- RDMA/bnxt_re: Fix a bunch of off by one bugs in qplib_fp.c
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Fix a couple off by one bugs (bsc#1050244
  FATE#322915).
- IB/core: type promotion bug in rdma_rw_init_one_mr()
  (bsc#1046306 FATE#322942).
- RDMA/i40w: Hold read semaphore while looking after VMA
  (bsc#1058659 FATE#322535).
- IB/mlx4: Test port number before querying type (bsc#1046302
  FATE#322945).
- IB/hfi1: Remove incorrect call to do_interrupt callback
  (bsc#1060463 FATE#323043).
- IB/hfi1: Set in_use_ctxts bits for user ctxts only (bsc#1060463
  FATE#323043).
- ib_srpt: Fix a use-after-free in srpt_close_ch() (bsc#1046306
  FATE#322942).
- iw_cxgb4: remove duplicate memcpy() in c4iw_create_listen()
  (bsc#1046543 FATE#322927).
- commit a63f7f6
* Fri Sep 21 2018 tbogendoerfer@suse.de
- bnxt_en: Fix VF mac address regression (bsc#1086282
  FATE#324873).
- bnxt_en: Do not adjust max_cp_rings by the ones used by RDMA
  (bsc#1086282 FATE#324873).
- bnxt_en: Clean up unused functions (bsc#1086282 FATE#324873).
- commit ef196fc
* Fri Sep 21 2018 tiwai@suse.de
- scripts: modpost: check memory allocation results (bsc#1051510).
- PCI: mvebu: Fix I/O space end address calculation (bsc#1051510).
- rsi: Fix 'invalid vdd' warning in mmc (bsc#1051510).
- commit 829fae7
* Fri Sep 21 2018 tiwai@suse.de
- userns: move user access out of the mutex (bsc#1051510).
- commit cac141e
* Fri Sep 21 2018 tiwai@suse.de
- wlcore: Set rx_status boottime_ns field on rx (bsc#1051510).
- commit ac56e08
* Fri Sep 21 2018 tiwai@suse.de
- drm/i915/gvt: clear ggtt entries when destroy vgpu
  (bsc#1051510).
- drm/i915/gvt: request srcu_read_lock before checking if one
  gfn is valid (bsc#1051510).
- drm/vc4: Fix the "no scaling" case on multi-planar YUV formats
  (bsc#1051510).
- commit b59ab11
* Fri Sep 21 2018 nborisov@suse.com
- block: don't warn for flush on read-only device (bsc#1107756).
- commit e361527
* Fri Sep 21 2018 nborisov@suse.com
- series.conf: Sort it
- commit 54dc76e
* Thu Sep 20 2018 jthumshirn@suse.de
- nvme-pci: add a memory barrier to
  nvme_dbbuf_update_and_check_event (git-fixes).
- commit f59adb7
* Thu Sep 20 2018 tiwai@suse.de
- ata: libahci: Allow reconfigure of DEVSLP register
  (bsc#1051510).
- ata: libahci: Correct setting of DEVSLP register (bsc#1051510).
- commit ee6224d
* Thu Sep 20 2018 tiwai@suse.de
- blacklist.conf: Add an ASoC rt5677 entry
- commit 7e9345a
* Thu Sep 20 2018 tiwai@suse.de
- ASoC: rsnd: fixup not to call clk_get/set under non-atomic
  (bsc#1051510).
- ASoC: rsnd: move rsnd_ssi_config_init() execute condition into
  it (bsc#1051510).
- ASoC: rsnd: update pointer more accurate (bsc#1051510).
- commit 5639646
* Thu Sep 20 2018 tiwai@suse.de
- ALSA: oxfw: fix memory leak of discovered stream formats at
  error path (bsc#1051510).
- ALSA: oxfw: fix memory leak for model-dependent data at error
  path (bsc#1051510).
- ALSA: oxfw: fix memory leak of private data (bsc#1051510).
- ALSA: firewire-tascam: fix memory leak of private data
  (bsc#1051510).
- ALSA: firewire-digi00x: fix memory leak of private data
  (bsc#1051510).
- ALSA: fireface: fix memory leak in ff400_switch_fetching_mode()
  (bsc#1051510).
- commit 1f786bc
* Thu Sep 20 2018 tiwai@suse.de
- 9p/virtio: fix off-by-one error in sg list bounds check
  (bsc#1051510).
- 9p: fix multiple NULL-pointer-dereferences (bsc#1051510).
- fs/9p/xattr.c: catch the error of p9_client_clunk when setting
  xattr failed (bsc#1051510).
- net/9p/trans_fd.c: fix race by holding the lock (bsc#1051510).
- net/9p/trans_fd.c: fix race-condition by flushing workqueue
  before the kfree() (bsc#1051510).
- 9p/net: Fix zero-copy path in the 9p virtio transport
  (bsc#1051510).
- net/9p/client.c: version pointer uninitialized (bsc#1051510).
- net/9p: fix error path of p9_virtio_probe (bsc#1051510).
- net/9p: Switch to wait_event_killable() (bsc#1051510).
- commit 2a92430
* Thu Sep 20 2018 tiwai@suse.de
- pstore: Fix incorrect persistent ram buffer mapping
  (bsc#1051510).
- i2c: xiic: Make the start and the byte count write atomic
  (bsc#1051510).
- ALSA: hda - Fix cancel_work_sync() stall from jackpoll work
  (bsc#1051510).
- i2c: core: ACPI: Properly set status byte to 0 for multi-byte
  writes (bsc#1051510).
- Input: atmel_mxt_ts - only use first T9 instance (bsc#1051510).
- staging: comedi: ni_mio_common: fix subdevice flags for PFI
  subdevice (bsc#1051510).
- drm/i915: set DP Main Stream Attribute for color range on DDI
  platforms (bsc#1051510).
- Replace magic for trusting the secondary keyring with #define
  (bsc#1051510).
- gpio: ml-ioh: Fix buffer underwrite on probe error path
  (bsc#1051510).
- gpu: ipu-v3: default to id 0 on missing OF alias (bsc#1051510).
- ath9k_hw: fix channel maximum power level test (bsc#1051510).
- ath9k: report tx status on EOSP (bsc#1051510).
- ath10k: disable bundle mgmt tx completion event support
  (bsc#1051510).
- Bluetooth: h5: Fix missing dependency on BT_HCIUART_SERDEV
  (bsc#1051510).
- Bluetooth: hidp: Fix handling of strncpy for hid->name
  information (bsc#1051510).
- gpio: tegra: Move driver registration to subsys_init level
  (bsc#1051510).
- pinctrl/amd: only handle irq if it is pending and unmasked
  (bsc#1051510).
- rhashtable: add schedule points (bsc#1051510).
- commit e362007
* Thu Sep 20 2018 jthumshirn@suse.de
- libnvdimm: Use max contiguous area for namespace size
  (git-fixes).
- commit 3536ffe
* Wed Sep 19 2018 jack@suse.cz
- x86/asm/memcpy_mcsafe: Fix copy_to_user_mcsafe() exception
  handling (bsc#1098782).
- commit 3410c6d
* Wed Sep 19 2018 jack@suse.cz
- lib/iov_iter: Fix pipe handling in _copy_to_iter_mcsafe()
  (bsc#1098782).
- commit 6d84c3d
* Wed Sep 19 2018 jack@suse.cz
- libnvdimm, pmem: Fix memcpy_mcsafe() return code handling in
  nsio_rw_bytes() (bsc#1098782).
- commit a9dde76
* Wed Sep 19 2018 msuchanek@suse.de
- powerpc/powernv/npu: Do a PID GPU TLB flush when invalidating
  a large address range (bsc#1055120).
- commit 0b87042
* Wed Sep 19 2018 msuchanek@suse.de
- powerpc: Fix size calculation using resource_size()
  (bnc#1012382).
- commit dfbb395
* Wed Sep 19 2018 jgross@suse.com
- patches.fixes/xen-netfront-dont-bug-in-case-of-too-many-frags.patch:
  (bnc#1104824).
- commit ef15470
* Wed Sep 19 2018 jgross@suse.com
- xenbus: track caller request id (bnc#1065600).
- commit 6feb718
* Wed Sep 19 2018 tiwai@suse.de
- mmc: omap_hsmmc: fix wakeirq handling on removal (bsc#1051510).
- commit f256ed6
* Wed Sep 19 2018 tiwai@suse.de
- HID: add quirk for another PIXART OEM mouse used by HP
  (bsc#1051510).
- commit 033f342
* Wed Sep 19 2018 tiwai@suse.de
- fb: fix lost console when the user unplugs a USB adapter
  (bsc#1051510).
- commit df657a2
* Wed Sep 19 2018 jgross@suse.com
- xen: xenbus_dev_frontend: Really return response string
  (bnc#1065600).
- commit d2abf65
* Wed Sep 19 2018 jgross@suse.com
- xen: xenbus_dev_frontend: Fix XS_TRANSACTION_END handling
  (bnc#1065600).
- commit 6849cde
* Wed Sep 19 2018 msuchanek@suse.de
- powerpc/xive: Fix trying to "push" an already active pool VP
  (FATE#322438, bsc#1085030, git-fixes).
- commit 95df48c
* Wed Sep 19 2018 jthumshirn@suse.de
- Refresh
  patches.arch/powerpc-topology-Get-topology-for-shared-processors-.patch.
- Refresh
  patches.drivers/scsi-hpsa-limit-transfer-length-to-1mb-not-512kb.patch.
- Refresh
  patches.fixes/libnvdimm-fix-ars_status-output-length-calculation.patch.
- Refresh
  patches.fixes/scsi-lpfc-Correct-MDS-diag-and-nvmet-configuration.patch.
- Refresh
  patches.suse/0001-md-cluster-release-RESYNC-lock-after-the-last-resync.patch.
  Re-sort series and update upstream tags.
- commit a74430e
* Wed Sep 19 2018 msuchanek@suse.de
- powerpc/fadump: cleanup crash memory ranges support
  (bsc#1103269).
- commit a315a15
* Tue Sep 18 2018 msuchanek@suse.de
- powerpc/fadump: re-register firmware-assisted dump if already
  registered (bsc#1108170, bsc#1108823).
- commit 2677edc
* Tue Sep 18 2018 tiwai@suse.de
- platform/x86: asus-nb-wmi: Add keymap entry for lid flip action
  on UX360 (bsc#1051510).
- commit 1fcd136
* Mon Sep 17 2018 msuchanek@suse.de
- crypto: clarify licensing of OpenSSL asm code (FATE#321642).
- commit 857bee1
* Mon Sep 17 2018 tiwai@suse.de
- usb: gadget: udc: renesas_usb3: fix maxpacket size of ep0
  (bsc#1051510).
- USB: net2280: Fix erroneous synchronization change
  (bsc#1051510).
- USB: serial: ti_usb_3410_5052: fix array underflow in completion
  handler (bsc#1051510).
- USB: serial: io_ti: fix array underflow in completion handler
  (bsc#1051510).
- usb: Don't die twice if PCI xhci host is not responding in
  resume (bsc#1051510).
- drm/i915/overlay: Allocate physical registers from stolen
  (bsc#1051510).
- drm/i915/gvt: Fix the incorrect length of child_device_config
  issue (bsc#1051510).
- r8169: add support for NCube 8168 network card (bsc#1051510).
- drm/edid: Add 6 bpc quirk for SDC panel in Lenovo B50-80
  (bsc#1051510).
- drm/amdgpu:add new firmware id for VCN (bsc#1051510).
- drm/amdgpu:add tmr mc address into amdgpu_firmware_info
  (bsc#1051510).
- drm/i915/lpe: Mark LPE audio runtime pm as "no callbacks"
  (bsc#1051510).
- drm/amd/pp/Polaris12: Fix a chunk of registers missed to program
  (bsc#1051510).
- drm/amdgpu: Fix RLC safe mode test in
  gfx_v9_0_enter_rlc_safe_mode (bsc#1051510).
- ASoC: wm8994: Fix missing break in switch (bsc#1051510).
- ACPI / scan: Initialize status to ACPI_STA_DEFAULT
  (bsc#1051510).
- commit 4f06665
* Fri Sep 14 2018 tonyj@suse.de
- Netperf performance issue due to AppArmor net mediation (bsc#1108520)
  Refresh patches.apparmor/apparmor-check-all-net-profiles.patch
- commit cbd0695
* Fri Sep 14 2018 msuchanek@suse.de
- powerpc: KABI: move mce_data_buf into paca_aux (bsc#1094244).
- commit 1d4ef4d
* Fri Sep 14 2018 msuchanek@suse.de
- powerpc/pseries: Defer the logging of rtas error to irq work
  queue (bsc#1094244).
- commit 90db3c5
* Fri Sep 14 2018 msuchanek@suse.de
- powerpc: KABI add aux_ptr to hole in paca_struct to extend it
  with additional members (bsc#1094244).
- commit 7ba875c
* Fri Sep 14 2018 msuchanek@suse.de
- doc/README.SUSE: Remove mentions of cloneconfig (bsc#1103636).
- commit 3371adc
* Fri Sep 14 2018 tbogendoerfer@suse.de
- kabi protect hnae_ae_ops (bsc#1107924).
- commit 5ac54e8
* Fri Sep 14 2018 tbogendoerfer@suse.de
- net: hns: add netif_carrier_off before change speed and duplex
  (bsc#1107924).
- net: hns: add the code for cleaning pkt in chip (bsc#1107924).
- commit 16541cc
* Thu Sep 13 2018 tiwai@suse.de
- vhost: correctly check the iova range when waking virtqueue
  (bsc#1051510).
- vfio/type1: Fix task tracking for QEMU vCPU hotplug
  (bsc#1051510).
- ti: ethernet: cpdma: Use correct format for genpool_*
  (bsc#1051510).
- tracepoint: Do not warn on ENOMEM (bsc#1051510).
- vhost: do not try to access device IOTLB when not initialized
  (bsc#1051510).
- vhost: use mutex_lock_nested() in vhost_dev_lock_vqs()
  (bsc#1051510).
- fix a page leak in vhost_scsi_iov_to_sgl() error recovery
  (bsc#1051510).
- vfio/pci: Virtualize Maximum Read Request Size (bsc#1051510).
- vfio/pci: Virtualize Maximum Payload Size (bsc#1051510).
- commit 63d1cac
* Thu Sep 13 2018 tiwai@suse.de
- Revert "PCI: Add ACS quirk for Intel 300 series" (bsc#1051510).
- commit e6b51b9
* Thu Sep 13 2018 nborisov@suse.com
- hfsplus: fix NULL dereference in hfsplus_lookup() (bsc#1102870, CVE-2018-14617).
- commit 3810954
* Thu Sep 13 2018 jack@suse.cz
- dax: remove default copy_from_iter fallback (bsc#1098782).
  patches.drivers/dax-remove-the-pmem_dax_ops-flush-abstraction.patch:
  Refresh
- commit 3c3db4d
* Thu Sep 13 2018 jack@suse.cz
- pmem: Switch to copy_to_iter_mcsafe() (bsc#1098782).
- commit 9a8267b
* Thu Sep 13 2018 jack@suse.cz
- dax: Report bytes remaining in dax_iomap_actor() (bsc#1098782).
- commit e7253c5
* Thu Sep 13 2018 jack@suse.cz
- dax: Introduce a ->copy_to_iter dax operation (bsc#1098782).
- commit dd19686
* Thu Sep 13 2018 jack@suse.cz
- uio, lib: Fix CONFIG_ARCH_HAS_UACCESS_MCSAFE compilation
  (bsc#1098782).
- commit 37b2dab
* Thu Sep 13 2018 jack@suse.cz
- x86/asm/memcpy_mcsafe: Define copy_to_iter_mcsafe()
  (bsc#1098782).
- commit 45e6aa4
* Thu Sep 13 2018 jack@suse.cz
- x86/asm/memcpy_mcsafe: Add write-protection-fault handling
  (bsc#1098782).
- commit 88f00bb
* Thu Sep 13 2018 jack@suse.cz
- x86/asm/memcpy_mcsafe: Return bytes remaining (bsc#1098782).
- commit a845711
* Thu Sep 13 2018 jack@suse.cz
- x86/asm/memcpy_mcsafe: Add labels for __memcpy_mcsafe() write
  fault handling (bsc#1098782).
- commit d185440
* Thu Sep 13 2018 jack@suse.cz
- x86/asm/memcpy_mcsafe: Remove loop unrolling (bsc#1098782).
- commit 6aa2974
* Thu Sep 13 2018 jack@suse.cz
- x86/mce: Fix set_mce_nospec() to avoid #GP fault (bsc#1107783).
- commit 7f8d2a1
* Thu Sep 13 2018 bp@suse.de
- x86/mcelog: Get rid of RCU remnants (git-fixes 5de97c9f6d85).
- commit dbcfc68
* Thu Sep 13 2018 tiwai@suse.de
- drm/nouveau/drm/nouveau: Fix bogus drm_kms_helper_poll_enable()
  placement (bsc#1051510).
- commit e4036a9
* Thu Sep 13 2018 glin@suse.com
- bpf: fix uninitialized variable in bpf tools (bsc#1083647).
- commit cee2bee
* Wed Sep 12 2018 jgross@suse.com
- x86/xen/efi: Initialize only the EFI struct members used by Xen
  (bnc#1107945).
- commit cc07f9e
* Wed Sep 12 2018 jgross@suse.com
- resort series.conf
- commit da3426b
* Wed Sep 12 2018 jack@suse.cz
- libnvdimm, pmem: Restore page attributes when clearing errors
  (bsc#1107783).
- commit c8cb253
* Wed Sep 12 2018 jack@suse.cz
- filesystem-dax: Introduce dax_lock_mapping_entry()
  (bsc#1107783).
  patches.kabi/kabi-fixup-bdev_dax_supported.patch: Refresh
- commit 16c290c
* Wed Sep 12 2018 jack@suse.cz
- mm, memory_failure: Collect mapping size in collect_procs()
  (bsc#1107783).
- commit a912b4a
* Wed Sep 12 2018 jack@suse.cz
- mm, madvise_inject_error: Disable MADV_SOFT_OFFLINE for
  ZONE_DEVICE pages (bsc#1107783).
- commit a07de12
* Wed Sep 12 2018 jack@suse.cz
- filesystem-dax: Set page->index (bsc#1107783).
- commit c7ba339
* Wed Sep 12 2018 jack@suse.cz
- mm, memory_failure: Teach memory_failure() about dev_pagemap
  pages (bsc#1107783).
- commit e03913e
* Wed Sep 12 2018 jack@suse.cz
- x86/mm/pat: Prepare {reserve, free}_memtype() for "decoy"
  addresses (bsc#1107783).
- commit 9bffeaa
* Wed Sep 12 2018 jack@suse.cz
- device-dax: Set page->index (bsc#1107783).
- commit 087ebb1
* Wed Sep 12 2018 jack@suse.cz
- x86/memory_failure: Introduce {set, clear}_mce_nospec()
  (bsc#1107783).
- commit 7879886
* Wed Sep 12 2018 jack@suse.cz
- mm, madvise_inject_error: Let memory_failure() optionally take
  a page reference (bsc#1107783).
- commit 37f04d6
* Wed Sep 12 2018 jack@suse.cz
- device-dax: Enable page_mapping() (bsc#1107783).
- commit d7bd7c1
* Wed Sep 12 2018 wqu@suse.com
- btrfs: Introduce mount time chunk <-> dev extent mapping
  check (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit 7f6f993
* Wed Sep 12 2018 wqu@suse.com
- btrfs: Verify that every chunk has corresponding block  group at
  mount time (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit 1253638
* Wed Sep 12 2018 wqu@suse.com
- btrfs: Check that each block group has corresponding  chunk at
  mount time (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit aca95a2
* Wed Sep 12 2018 wqu@suse.com
- btrfs: tree-checker: Detect invalid and empty essential
  trees (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- btrfs: tree-checker: Verify block_group_item (bsc#1102882,
  bsc#1102896, bsc#1102879, bsc#1102877, bsc#1102875,).
- commit 99d8299
* Wed Sep 12 2018 wqu@suse.com
- btrfs: tree-checker: Replace root parameter with fs_info
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit d7954ed
* Wed Sep 12 2018 wqu@suse.com
- btrfs: tree-checker: use %%zu format string for size_t
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit 910d229
* Wed Sep 12 2018 wqu@suse.com
- btrfs: tree-checker: Add checker for dir item (bsc#1102882,
  bsc#1102896, bsc#1102879, bsc#1102877, bsc#1102875,).
- commit 4d74bd3
* Wed Sep 12 2018 wqu@suse.com
- btrfs: tree-checker: Fix false panic for sanity test
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit 78dd7ab
* Wed Sep 12 2018 wqu@suse.com
- btrfs: tree-checker: use %%zu format string for size_t
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit aeec025
* Wed Sep 12 2018 wqu@suse.com
- btrfs: tree-checker: Enhance output for  check_extent_data_item
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- btrfs: tree-checker: Enhance output for check_csum_item
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- btrfs: tree-checker: Enhance output for btrfs_check_leaf
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- btrfs: tree-checker: Enhance btrfs_check_node output
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- btrfs: Move leaf and node validation checker to  tree-checker.c
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- commit f8584a3
* Wed Sep 12 2018 wqu@suse.com
- btrfs: Add checker for EXTENT_CSUM (bsc#1102882, bsc#1102896,
  bsc#1102879, bsc#1102877, bsc#1102875,).
- btrfs: Add sanity check for EXTENT_DATA when reading out
  leaf (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- btrfs: Check if item pointer overlaps with the item  itself
  (bsc#1102882, bsc#1102896, bsc#1102879, bsc#1102877,
  bsc#1102875,).
- btrfs: Refactor check_leaf function for later expansion
  (bsc#1102896, CVE-2018-14613).
- commit 9b8a387
* Tue Sep 11 2018 bp@suse.de
- blacklist.conf:
  Blacklist
  3d95b89e573b ("x86/ACPI/cstate: Make APCI C1 FFH MWAIT C-state description vendor-neutral")
- commit 89bf8f2
* Tue Sep 11 2018 bp@suse.de
- x86/spectre: Add missing family 6 check to microcode check
  (git-fixes a5b296636453).
- commit 5cb13eb
* Tue Sep 11 2018 bp@suse.de
- x86/events/intel/ds: Fix bts_interrupt_threshold alignment
  (git-fixes c1961a4631da).
- commit 81d0f0a
* Tue Sep 11 2018 msuchanek@suse.de
- ibmvnic: Include missing return code checks in reset function
  (bnc#1107966).
- commit 556ed81
* Tue Sep 11 2018 mwilck@suse.com
- Update
  patches.drivers/cdrom-information-leak-in-cdrom_ioctl_media_changed
  (bsc#1051510,bsc#1092903,CVE-2018-10940).
- commit 0f469f0
* Tue Sep 11 2018 ohering@suse.de
- xen: avoid crash in disable_hotplug_cpu (bsc#1106594).
- commit 3563072
* Mon Sep 10 2018 msuchanek@suse.de
- macros.kernel-source: pass -b properly in kernel module package
  (bsc#1107870).
- commit 66709cd
* Mon Sep 10 2018 msuchanek@suse.de
- powerpc: Avoid code patching freed init sections (bnc#1107735).
- commit 0db159b
* Mon Sep 10 2018 mhocko@suse.com
- Refresh
  patches.arch/0001-x86-speculation-l1tf-Increase-l1tf-memory-limit-for-.patch.
- Refresh
  patches.kabi/0001-x86-kabi-speculation-l1tf-Increase-l1tf-memory-limit-for-.patch.
- commit 96ecd28
* Mon Sep 10 2018 nborisov@suse.com
- xfs: validate cached inodes are free when allocated (bsc#1100001, CVE-2018-13093).
- commit 49b81b5
* Mon Sep 10 2018 nborisov@suse.com
- xfs: don't call xfs_da_shrink_inode with NULL bp (bsc#1100000, CVE-2018-13094).
- commit 2124c37
* Mon Sep 10 2018 nborisov@suse.com
- patches.suse/xfs-fix-a-null-pointer-dereference-in-xfs_bmap_exten.patch: (bsc#1099999, CVE-2018-13095).
- commit 00092ab
* Mon Sep 10 2018 tiwai@suse.de
- Update patch tag / sort the upstreamed alarmtimer fix
- commit a0d9531
* Mon Sep 10 2018 tiwai@suse.de
- kABI workaround for posix-timers it_overrun 64bit changes
  (CVE-2018-12896,bsc#1099922).
- posix-timers: Sanitize overrun handling
  (CVE-2018-12896,bsc#1099922).
- commit 4d6309b
* Mon Sep 10 2018 jslaby@suse.cz
- x86/kasan/64: Teach KASAN about the cpu_entry_area (kasan).
- x86/mm/kasan: Don't use vmemmap_populate() to initialize shadow
  (kasan).
- Refresh
  patches.arch/22-x86-cpu_entry_area-move-it-out-of-the-fixmap.patch.
  Make KASAN build.
- commit 3ef9063
* Mon Sep 10 2018 tiwai@suse.de
- tools/power turbostat: Read extended processor family from CPUID
  (bsc#1051510).
- tools/power turbostat: fix -S on UP systems (bsc#1051510).
- tools: usb: ffs-test: Fix build on big endian systems
  (bsc#1051510).
- commit 88fdc8e
* Mon Sep 10 2018 tiwai@suse.de
- usb/phy: fix PPC64 build errors in phy-fsl-usb.c (bsc#1051510).
- commit 63486c9
* Mon Sep 10 2018 tiwai@suse.de
- udlfb: set optimal write delay (bsc#1051510).
- commit 9d6b4d5
* Mon Sep 10 2018 tiwai@suse.de
- uart: fix race between uart_put_char() and uart_shutdown()
  (bsc#1051510).
- commit 0cb3532
* Mon Sep 10 2018 tiwai@suse.de
- sunxi-rsb: Include OF based modalias in device uevent
  (bsc#1051510).
- commit 9eecba6
* Mon Sep 10 2018 tiwai@suse.de
- memory: tegra: Apply interrupts mask per SoC (bsc#1051510).
- memory: tegra: Do not handle spurious interrupts (bsc#1051510).
- commit 0590d27
* Mon Sep 10 2018 tiwai@suse.de
- media: Revert "[media] tvp5150: fix pad format frame height"
  (bsc#1051510).
- commit a131b55
* Mon Sep 10 2018 tiwai@suse.de
- ipmi:bt: Set the timeout before doing a capabilities check
  (bsc#1051510).
- commit bd1ddb1
* Mon Sep 10 2018 tiwai@suse.de
- Revert "UBIFS: Fix potential integer overflow in allocation"
  (bsc#1051510).
- commit 5739a28
* Mon Sep 10 2018 tiwai@suse.de
- i2c: i801: fix DNV's SMBCTRL register offset (bsc#1051510).
- i2c: uniphier-f: issue STOP only for last message or I2C_M_STOP
  (bsc#1051510).
- i2c: uniphier: issue STOP only for last message or I2C_M_STOP
  (bsc#1051510).
- commit d5290f6
* Mon Sep 10 2018 tiwai@suse.de
- spi: davinci: fix a NULL pointer dereference (bsc#1051510).
- spi: cadence: Change usleep_range() to udelay(), for atomic
  context (bsc#1051510).
- commit 9981a86
* Mon Sep 10 2018 tiwai@suse.de
- Update patch tag of dmi fix (bsc#1105597)
  Also moved to the sorted section.
- commit 30bc396
* Mon Sep 10 2018 mgorman@suse.de
- sched/numa: Do not move imbalanced load purely on the basis
  of an idle CPU (bnc#1101669 optimise numa balancing for fast
  migrate).
- sched/numa: Stop comparing tasks for NUMA placement after
  selecting an idle core (bnc#1101669 optimise numa balancing
  for fast migrate).
- sched/numa: remove unused nr_running field (bnc#1101669 optimise
  numa balancing for fast migrate).
- sched/numa: remove unused code from update_numa_stats()
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/numa: Remove numa_has_capacity() (bnc#1101669 optimise
  numa balancing for fast migrate).
- sched/numa: Remove unused task_capacity from 'struct numa_stats'
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/numa: Evaluate move once per node (bnc#1101669 optimise
  numa balancing for fast migrate).
- commit 168092b
* Mon Sep 10 2018 bpoirier@suse.com
- Refresh
  patches.fixes/qlge-Fix-netdev-features-configuration.patch.
- commit 74255c9
* Fri Sep  7 2018 msuchanek@suse.de
- powerpc/mce: Fix SLB rebolting during MCE recovery path
  (bsc#1094244).
- powerpc/64s: move machine check SLB flushing to mm/slb.c
  (bsc#1094244).
- powerpc/pseries: Fix endianness while restoring of r3 in MCE
  handler (bsc#1094244).
- powerpc/pseries: Avoid using the size greater than
  RTAS_ERROR_LOG_MAX (bsc#1094244).
- commit 3cdea6e
* Fri Sep  7 2018 msuchanek@suse.de
- powerpc/pseries: fix EEH recovery of some IOV devices
  (FATE#324970, bsc#1078720, git-fixes).
- commit 0ece9ad
* Fri Sep  7 2018 vliaskovitis@suse.com
- xen/blkback: remove unused pers_gnts_lock from struct
  (bsc#1085042).
- xen/blkfront: reorder tests in xlblk_init() (bsc#1085042).
- xen/blkfront: cleanup stale persistent grants (bsc#1085042).
- xen/blkback: move persistent grants flags to bool (bsc#1085042).
- xen/blkback: don't keep persistent grants too long
  (bsc#1085042).
- commit 31abf82
* Fri Sep  7 2018 tiwai@suse.de
- Update patch tag (CVE-2018-16658,bsc#1107689).
- commit c1fe790
* Fri Sep  7 2018 tbogendoerfer@suse.de
- i40e: fix condition of WARN_ONCE for stat strings (bsc#1107522).
- commit 58237b6
* Fri Sep  7 2018 tiwai@suse.de
- ipmi: Move BT capabilities detection to the detect call
  (bsc#1106779).
- commit f804445
* Fri Sep  7 2018 ptesarik@suse.cz
- Update references (bsc#1064232):
  patches.suse/0227-bcache-simplify-the-calculation-of-the-total-amount-.patch
  patches.suse/0228-bcache-finish-incremental-GC.patch
  patches.suse/0229-bcache-calculate-the-number-of-incremental-GC-nodes-.patch
  patches.suse/0230-bcache-fix-I-O-significant-decline-while-backend-dev.patch
  patches.suse/0231-bcache-free-heap-cache_set-flush_btree-in-bch_journa.patch
  patches.suse/0232-bcache-do-not-check-return-value-of-debugfs_create_d.patch
  patches.suse/0233-bcache-display-rate-debug-parameters-to-0-when-write.patch
  patches.suse/0234-bcache-avoid-unncessary-cache-prefetch-bch_btree_nod.patch
  patches.suse/0235-bcache-set-max-writeback-rate-when-I-O-request-is-id.patch
  patches.suse/0236-bcache-fix-error-setting-writeback_rate-through-sysf.patch
  patches.suse/0237-bcache-make-the-pr_err-statement-used-for-ENOENT-onl.patch
  patches.suse/0238-bcache-release-dc-writeback_lock-properly-in-bch_wri.patch
- commit 8cbdec7
* Fri Sep  7 2018 mkubecek@suse.cz
- irda: Only insert new objects into the global database via
  setsockopt (CVE-2018-6555 bsc#1106511).
- irda: Fix memory leak caused by repeated binds of irda socket
  (CVE-2018-6554 bsc#1106509).
- commit 9ab3d1d
* Fri Sep  7 2018 mhocko@suse.com
- mm/hugetlb: filter out hugetlb pages if HUGEPAGE migration is
  not supported (bnc#1106697).
- commit 1d9bc2e
* Thu Sep  6 2018 jeffm@suse.com
- Update headers for file system patches.
- commit 451e265
* Thu Sep  6 2018 jeffm@suse.com
- btrfs: fix error handling in btrfs_dev_replace_start
  (bsc#1107535).
- commit 4e881dc
* Thu Sep  6 2018 jslaby@suse.cz
- PCI: OF: Fix I/O space page leak (git-fixes).
- PCI: hv: Make sure the bus domain is really unique (git-fixes).
- commit 8945aab
* Thu Sep  6 2018 tiwai@suse.de
- Update patch tags of upstreamed patches; not moved to sorted section yet
- commit 94311a8
* Thu Sep  6 2018 jslaby@suse.cz
- PCI: aardvark: Fix I/O space page leak (git-fixes).
- /dev/mem: Avoid overwriting "err" in read_mem() (git-fixes).
- commit 43758f4
* Thu Sep  6 2018 jslaby@suse.cz
- /dev/mem: Add bounce buffer for copy-out (git-fixes).
- ipmi/powernv: Fix error return code in ipmi_powernv_probe()
  (git-fixes).
- commit d0767ac
* Thu Sep  6 2018 tiwai@suse.de
- Update patch tags of recent security fixes (bsc#1106426)
- commit 47c1bca
* Thu Sep  6 2018 glin@suse.com
- bpf: use GFP_ATOMIC instead of GFP_KERNEL in bpf_parse_prog()
  (bsc#1083647).
- bpf: hash map: decrement counter on error (bsc#1083647).
- bpf, s390: fix potential memleak when later bpf_jit_prog fails
  (bsc#1083647).
- commit 50a2ab4
* Thu Sep  6 2018 tiwai@suse.de
- gpiolib: acpi: Switch to cansleep version of GPIO library call
  (bsc#1051510).
- commit bc3eb16
* Thu Sep  6 2018 tiwai@suse.de
- Workaround kABI breakage by __must_check drop of strscpy()
  (bsc#1051510).
- commit 9066acc
* Thu Sep  6 2018 tiwai@suse.de
- string: drop __must_check from strscpy() and restore strscpy()
  usages in cgroup (bsc#1051510).
- cgroup: avoid copying strings longer than the buffers
  (bsc#1051510).
- commit 6f17138
* Wed Sep  5 2018 tiwai@suse.de
- usb: gadget: r8a66597: Fix a possible sleep-in-atomic-context
  bugs in r8a66597_queue() (bsc#1051510).
- usb: gadget: r8a66597: Fix two possible sleep-in-atomic-context
  bugs in init_controller() (bsc#1051510).
- commit 647cd5a
* Wed Sep  5 2018 tiwai@suse.de
- mei: don't update offset in write (bsc#1051510).
- commit 157d749
* Wed Sep  5 2018 tiwai@suse.de
- libahci: Fix possible Spectre-v1 pmp indexing in
  ahci_led_store() (bsc#1051510).
- commit 555fb22
* Wed Sep  5 2018 tiwai@suse.de
- i2c: davinci: Avoid zero value of CLKH (bsc#1051510).
- commit 25360bc
* Wed Sep  5 2018 tiwai@suse.de
- gpiolib-acpi: make sure we trigger edge events at least once
  on boot (bsc#1051510).
- commit b312d67
* Wed Sep  5 2018 tiwai@suse.de
- drm/bridge: adv7511: Reset registers on hotplug (bsc#1051510).
- drm/imx: imx-ldb: check if channel is enabled before printing
  warning (bsc#1051510).
- drm/imx: imx-ldb: disable LDB on driver bind (bsc#1051510).
- commit 294968d
* Wed Sep  5 2018 tiwai@suse.de
- cdrom: Fix info leak/OOB read in cdrom_ioctl_drive_status
  (bsc#1051510).
- commit 4524c3a
* Wed Sep  5 2018 tiwai@suse.de
- b43legacy/leds: Ensure NUL-termination of LED name string
  (bsc#1051510).
- b43/leds: Ensure NUL-termination of LED name string
  (bsc#1051510).
- commit e4b4203
* Wed Sep  5 2018 tiwai@suse.de
- nl80211: Add a missing break in parse_station_flags
  (bsc#1051510).
- mac80211: add stations tied to AP_VLANs during hw reconfig
  (bsc#1051510).
- commit db4daaa
* Wed Sep  5 2018 tiwai@suse.de
- udl-kms: avoid division (bsc#1051510).
- udl-kms: fix crash due to uninitialized memory (bsc#1051510).
- udl-kms: handle allocation failure (bsc#1051510).
- udl-kms: change down_interruptible to down (bsc#1051510).
- commit 161b133
* Wed Sep  5 2018 tiwai@suse.de
- Refresh patches.drivers/platform-x86-ideapad-laptop-Apply-no_hw_rfkill-to-Y2
  Updated patch tags and moved to sorted section
- commit 74c158d
* Wed Sep  5 2018 lhenriques@suse.com
- ceph: return errors from posix_acl_equiv_mode() correctly
  (bsc#1107320).
- ceph: fix incorrect use of strncpy (bsc#1107319).
- commit 899eb9e
* Wed Sep  5 2018 tiwai@suse.de
- crypto: vmx - Fix sleep-in-atomic bugs (bsc#1051510).
- commit d3a49ba
* Wed Sep  5 2018 yousaf.kaukab@suse.com
- Update
  patches.drivers/0016-arm64-vgic-v2-Fix-proxying-of-cpuif-access.patch
  (bsc#1106901, bsc#1107265).
- commit 1deae2a
* Wed Sep  5 2018 tiwai@suse.de
- mac80211: fix an off-by-one issue in A-MSDU max_subframe
  computation (bsc#1051510).
- mac80211: always account for A-MSDU header changes
  (bsc#1051510).
- cfg80211: nl80211_update_ft_ies() to validate NL80211_ATTR_IE
  (bsc#1051510).
- mac80211: avoid kernel panic when building AMSDU from non-linear
  SKB (bsc#1051510).
- commit f688a83
* Wed Sep  5 2018 tiwai@suse.de
- Update config files: disable useless pinctrl-intel on arm64
- commit e138d79
* Wed Sep  5 2018 tiwai@suse.de
- mfd: intel-lpss: Add Ice Lake PCI IDs (bsc#1051510).
- commit 31dc7a0
* Wed Sep  5 2018 tiwai@suse.de
- i2c: i801: Add support for Intel Ice Lake (bsc#1051510).
- i2c: i801: Consolidate chipset names in documentation and
  Kconfig (bsc#1051510).
- spi: pxa2xx: Add support for Intel Ice Lake (bsc#1051510).
- ahci: Add Intel Ice Lake LP PCI ID (bsc#1051510).
- i2c: i801: Add missing documentation entries for Braswell and
  Kaby Lake (bsc#1051510).
- i2c: i801: Add support for Intel Cedar Fork (bsc#1051510).
- commit 61acf60
* Wed Sep  5 2018 mhocko@suse.com
- blacklist.conf: a6f572084fbe mm/tlb: Remove tlb_remove_table() non-concurrent condition
- commit 9917b05
* Wed Sep  5 2018 jthumshirn@suse.de
- mm: fix devmem_is_allowed() for sub-page System RAM
  intersections (bsc#1106800).
- commit 8872b9e
* Wed Sep  5 2018 tbogendoerfer@suse.de
- net: hns3: fix page_offset overflow when CONFIG_ARM64_64K_PAGES
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for waterline not setting correctly (bsc#1104353
  FATE#326415).
  Refresh
  patches.drivers/net-hns3-Standardize-the-handle-of-return-value.patch.
- commit 945fd24
* Wed Sep  5 2018 hare@suse.de
- block: don't print a message when the device went away (bsc#1098459).
- commit 1899101
* Wed Sep  5 2018 bpoirier@suse.com
- Fix Patch-mainline tag in some patches
  These fixes are along the same lines as the fixes done in
  8ee956fca2e5 ("Fix invalid Patch-mainline tags ("next-release")")
  ..
  3525f6717bc4 ("Update Patch-mainline tags to start with "v"")
- commit cdc2b81
* Wed Sep  5 2018 jthumshirn@suse.de
- kabi protect struct kvm_sync_regs (bsc#1106948).
- commit 6de71f5
* Wed Sep  5 2018 jthumshirn@suse.de
- KVM: s390: add etoken support for guests (bsc#1106948,
  LTC#171029).
- KVM: s390: implement CPU model only facilities (bsc#1106948,
  LTC#171029).
- commit 6308e19
* Wed Sep  5 2018 tiwai@suse.de
- blacklist.conf: Add a blacklist entry for the reverted patch (bsc#1106743)
- commit ed4fb91
* Tue Sep  4 2018 colyli@suse.de
- bcache: release dc->writeback_lock properly in
  bch_writeback_thread().
- bcache: fix error setting writeback_rate through sysfs
  interface.
- bcache: make the pr_err statement used for ENOENT only in
  sysfs_attatch section.
- bcache: set max writeback rate when I/O request is idle.
- bcache: avoid unncessary cache prefetch bch_btree_node_get().
- bcache: display rate debug parameters to 0 when writeback is
  not running.
- bcache: do not check return value of debugfs_create_dir().
- bcache: free heap cache_set->flush_btree in bch_journal_free.
- bcache: fix I/O significant decline while backend devices
  registering.
- bcache: calculate the number of incremental GC nodes according
  to the total of btree nodes.
- bcache: finish incremental GC.
- bcache: simplify the calculation of the total amount of flash
  dirty data.
- commit 13a08de
* Tue Sep  4 2018 lhenriques@suse.com
- kabi/severities: Whitelist libceph, rbd, and ceph (bsc#1096748).
- commit 9628dcb
* Tue Sep  4 2018 jslaby@suse.cz
- netfilter: ip6t_rpfilter: set F_IFACE for linklocal addresses
  (git-fixes).
- commit 12ce0a3
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: 5df63c2a149a hugetlbfs: fix bug in pgoff overflow checking
- commit 993b56a
* Tue Sep  4 2018 mhocko@suse.com
- memcg, thp: do not invoke oom killer on thp charges
  (bnc#1089663).
- commit 753b076
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: 698d0831ba87 vmalloc: fix __GFP_HIGHMEM usage for vmalloc_32 on 32b systems
- commit 4579ce2
* Tue Sep  4 2018 jgross@suse.com
- xen-netfront: fix warn message as irq device name has '/'
  (bnc#1065600).
- xen-netfront: fix queue name setting (bnc#1065600).
- commit 70b555b
* Tue Sep  4 2018 tiwai@suse.de
- Delete patches.drivers/driver-core-Partially-revert-driver-core-correct-dev
  The patch causes errors at reboot, revert it for the time being (bsc#1093389)
- commit ed60106
* Tue Sep  4 2018 mhocko@suse.com
- Revert "mm: page_alloc: skip over regions of invalid pfns
  where possible" (bnc#1107078).
- commit d6d850e
* Tue Sep  4 2018 mhocko@suse.com
- mm/huge_memory.c: fix data loss when splitting a file pmd
  (bnc#1107074).
- commit 1955309
* Tue Sep  4 2018 mgorman@suse.de
- Delete
  patches.suse/sched-numa-Evaluate-move-once-per-node.patch.
- Delete
  patches.suse/sched-numa-Remove-unused-task_capacity-from-struct-numa_stats.patch.
- commit db82b9f
* Tue Sep  4 2018 mhocko@suse.com
- Revert "vmalloc: back off when the current task is killed"
  (bnc#1107073).
- commit e8d477c
* Tue Sep  4 2018 mhocko@suse.com
- mm: memcg: fix use after free in mem_cgroup_iter()
  (bnc#1107065).
- commit 4cee20a
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: 78bb920344b8 mm: hwpoison: dissolve in-use hugepage in unrecoverable memory error
- commit 8b28382
* Tue Sep  4 2018 mhocko@suse.com
- mm/vmscan: wake up flushers for legacy cgroups too
  (bnc#1107061).
- commit 98c3af9
* Tue Sep  4 2018 mhocko@suse.com
- slab: __GFP_ZERO is incompatible with a constructor
  (bnc#1107060).
- commit de0a673
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: f113e64121ba ("mm/vmstat.c: fix wrong comment")
- commit ad74a8e
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: 955c97f0859a ("mm/swapfile.c: fix swap_count comment about nonexistent SWAP_HAS_CONT")
- commit 25b7eb6
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: blacklist 6cc22dc08a24 ("revert "mm/memblock: add missing include <linux/bootmem.h>"")
- commit d5d76ad
* Tue Sep  4 2018 mhocko@suse.com
- blacklist.conf: blacklist a7bed27af194 ("bug: fix "cut here" location for __WARN_TAINT architectures")
- commit b1ea131
* Tue Sep  4 2018 glin@suse.com
- selftests/bpf: fix a typo in map in map test (bsc#1083647).
- selftests/bpf/test_maps: exit child process without error in
  ENOMEM case (bsc#1083647).
- libbpf: Makefile set specified permission mode (bsc#1083647).
- samples/bpf: adjust rlimit RLIMIT_MEMLOCK for xdp1
  (bsc#1083647).
- commit 6dbb87a
* Tue Sep  4 2018 nborisov@suse.com
- btrfs: Handle error from btrfs_uuid_tree_rem call in _btrfs_ioctl_set_received_subvol (bsc#1097105).
- commit bac7ef9
* Tue Sep  4 2018 mhocko@suse.com
- sys: don't hold uts_sem while accessing userspace memory
  (bnc#1106995).
- commit 45c02c7
* Tue Sep  4 2018 jack@suse.cz
- errseq: Add to documentation tree (bsc#1107008).
- commit c5caa9a
* Tue Sep  4 2018 jack@suse.cz
- Documentation: add some docs for errseq_t (bsc#1107008).
- commit 4fe4598
* Tue Sep  4 2018 jack@suse.cz
- errseq: Always report a writeback error once (bsc#1107008).
- commit 59f66ac
* Tue Sep  4 2018 nborisov@suse.com
- btrfs: Fix use-after-free when cleaning up fs_devs with a single  stale device (bsc#1097105).
- commit 915f064
* Tue Sep  4 2018 nborisov@suse.com
- btrfs: round down size diff when shrinking/growing device (bsc#1097105).
- btrfs: Manually implement device_total_bytes getter/setter (bsc#1043912).
- btrfs: Round down values which are written for total_bytes_size (bsc#1043912).
- commit bd2cec0
* Mon Sep  3 2018 tiwai@suse.de
- staging: bcm2835-audio: Don't leak workqueue if open fails
  (FATE#324827).
- staging: bcm2835-audio: Check if workqueue allocation failed
  (FATE#324827).
- staging: bcm2835-audio: Disconnect and free vchi_instance on
  module_exit() (FATE#324827).
- staging: vc04_services: bcm2835-audio: Change to unsigned int *
  (FATE#324827).
- staging: vc04_services: bcm2835-audio Format multiline comment
  (FATE#324827).
- staging: vc04_services: bcm2835-audio: Add blank line after
  declaration (FATE#324827).
- staging: vc04_services: bcm2835-audio: remove redundant license
  text (FATE#324827).
- staging: vc04_services: bcm2835-audio: add SPDX identifiers
  (FATE#324827).
- staging: vc04_services: Fix platform_no_drv_owner.cocci warnings
  (FATE#324827).
- Staging: vc04_services: remove unused variables (FATE#324827).
- staging: vc04_services: please do not use multiple blank lines
  (FATE#324827).
- staging: bcm2835-audio: make snd_pcm_hardware const
  (FATE#324827).
- staging: bcm2835-audio: constify snd_pcm_ops structures
  (FATE#324827).
- commit adc465a
* Mon Sep  3 2018 colyli@suse.de
- Rebase for SLE15 kernel
  patches.suse/md-display-timeout-error.patch.
- Delete obsoleted patches:
  patches.suse/0001-bcache-force-trigger-gc.patch
  patches.suse/0001-bcache-only-recovery-I-O-error-for-writethrough-mode.patch
  patches.suse/0002-bcache-fix-calling-ida_simple_remove-with-incorrect-minor.patch
- commit 9783d14
* Mon Sep  3 2018 mwilck@suse.com
- scsi_debug: call resp_XXX function after setting host_scribble
  (bsc#1069138).
  git-fixes patch.
- commit 3109972
* Mon Sep  3 2018 mwilck@suse.com
- scsi_debug: reset injection flags for every_nth > 0
  (bsc#1069138).
- commit 1f1a785
* Mon Sep  3 2018 jack@suse.cz
- Fix buggy backport of
  patches.drivers/libnvdimm-btt-fix-an-incompatibility-in-the-log-layout.patch
  (bsc#1103961).
- commit 54a0405
* Mon Sep  3 2018 jdelvare@suse.de
- ACPI / bus: Only call dmi_check_system on X86 (bsc#1105597,
  bsc#1106178).
- commit 1b1a47e
* Mon Sep  3 2018 bp@suse.de
- KVM: x86: SVM: Call x86_spec_ctrl_set_guest/host() with
  interrupts disabled (git-fixes 1f50ddb4f418).
- Refresh
  patches.arch/36-x86-bugs-kvm-extend-speculation-control-for-virt_spec_ctrl.patch.
- Refresh
  patches.suse/05-x86-bugs-kvm-support-the-combination-of-guest-and-host-ibrs.patch.
- commit d04f336
* Mon Sep  3 2018 yousaf.kaukab@suse.com
- arm64: mm: check for upper PAGE_SHIFT bits in pfn_valid()
  (bsc#1106893).
- arm64: export memblock_reserve()d regions via /proc/iomem
  (bsc#1106892).
- arm64: numa: rework ACPI NUMA initialization (bsc#1106905).
- arm64: fix vmemmap BUILD_BUG_ON() triggering on !vmemmap setups
  (bsc#1106896).
- arm64: mm: Ensure writes to swapper are ordered wrt subsequent
  cache maintenance (bsc#1106906).
- arm64: dma-mapping: clear buffers allocated with
  FORCE_CONTIGUOUS flag (bsc#1106902).
- arm64: fpsimd: Avoid FPSIMD context leakage for the init task
  (bsc#1106894).
- arm64/acpi: Create arch specific cpu to acpi id helper
  (bsc#1106903).
- arm64: Make sure permission updates happen for pmd/pud
  (bsc#1106891).
- arm64: vgic-v2: Fix proxying of cpuif access (bsc#1106901).
- arm64: kasan: avoid pfn_to_nid() before page array is
  initialized (bsc#1106899).
- arm64: fix unwind_frame() for filtered out fn for function
  graph tracing (bsc#1106900).
- arm64/mm/kasan: don't use vmemmap_populate() to initialize
  shadow (bsc#1106898).
- arm64/kasan: don't allocate extra shadow memory (bsc#1106897).
- commit 4e3b581
* Mon Sep  3 2018 mgorman@suse.de
- blacklist.conf: cosmetic fix of a comment
- commit 399b823
* Mon Sep  3 2018 mgorman@suse.de
- blacklist.conf: backport did not add the problematic include
- commit 33794a5
* Mon Sep  3 2018 yousaf.kaukab@suse.com
- arm64: Enforce BBM for huge IO/VMAP mappings (bsc#1106890).
- commit 8c23103
* Mon Sep  3 2018 yousaf.kaukab@suse.com
- i2c: xlp9xx: Fix case where SSIF read transaction completes
  early (bsc#1105907).
- i2c: xlp9xx: Make sure the transfer size is not more than
  I2C_SMBUS_BLOCK_SIZE (bsc#1105907).
- i2c: xlp9xx: Fix issue seen when updating receive length
  (bsc#1105907).
- ipmi: Fix some counter issues (bsc#1105907).
- ipmi: Remove ACPI SPMI probing from the SSIF (I2C) driver
  (bsc#1105907).
- commit 108b29e
* Mon Sep  3 2018 jroedel@suse.de
- KVM: VMX: Work around kABI breakage in 'enum vmx_l1d_flush_state' (bsc#1106369).
- commit f357e65
* Mon Sep  3 2018 gqjiang@suse.com
- md-cluster: release RESYNC lock after the last resync message
  (bsc#1106688).
- commit f74db00
* Mon Sep  3 2018 jroedel@suse.de
- KVM: VMX: fixes for vmentry_l1d_flush module parameter
  (bsc#1106369).
- x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on
  vmentry (bsc#1106369).
- commit 4183b24
* Mon Sep  3 2018 jslaby@suse.cz
- rpm/kernel-binary.spec.in: fix call of split-modules
  split-modules is called with some parameters depending on config
  options. But since we do not use backslash consistelny, the call to
  split-modules might be evaluated so that also the following cat
  command is appended. Avoid this behaviour by using backslashes
  everywhere and add %%nil to the end.
  This perhaps never happens, but stay on the safe side.
- commit 32df888
* Sat Sep  1 2018 ddiss@suse.de
- target_core_rbd: break up free_device callback (bsc#1105524).
- target_core_rbd: use RCU in free_device (bsc#1105524).
- commit c86ea53
* Fri Aug 31 2018 tiwai@suse.de
- ALSA: pcm: Workaround for weird PulseAudio behavior on rewind
  error (FATE#324827).
- ALSA: pcm: Fix possible inconsistent appl_ptr update via mmap
  (FATE#324827).
- ALSA: pcm: Skip ack callback without actual appl_ptr update
  (FATE#324827).
- ALSA: pcm: Call ack() whenever appl_ptr is updated
  (FATE#324827).
- staging: bcm2835-audio: Deliver indirect-PCM transfer error
  (FATE#324827).
- ALSA: rme32: Deliver indirect-PCM transfer error (FATE#324827).
- ALSA: emu10k1: Deliver indirect-PCM transfer error
  (FATE#324827).
- ALSA: cs46xx: Deliver indirect-PCM transfer error (FATE#324827).
- ALSA: mips: Deliver indirect-PCM transfer error (FATE#324827).
- ALSA: pcm: Fix negative appl_ptr handling in pcm-indirect
  helpers (FATE#324827).
- ALSA: pcm: Simplify forward/rewind codes (FATE#324827).
- ALSA: pcm: Use a common helper for PCM state check and hwsync
  (FATE#324827).
- commit bb024f5
* Fri Aug 31 2018 palcantara@suse.de
- cifs: check kmalloc before use (bsc#1051510).
- commit bebab77
* Fri Aug 31 2018 palcantara@suse.de
- cifs: Fix stack out-of-bounds in smb{2,3}_create_lease_buf()
  (bsc#1051510).
- commit 9edbb40
* Fri Aug 31 2018 palcantara@suse.de
- cifs: store the leaseKey in the fid on SMB2_open (bsc#1051510).
- commit 6540d4c
* Fri Aug 31 2018 mwilck@suse.com
- block: bio_iov_iter_get_pages: pin more pages for multi-segment
  IOs (bsc#1083663).
- commit cc2b437
* Fri Aug 31 2018 mwilck@suse.com
- blkdev: __blkdev_direct_IO_simple: fix leak in error case
  (bsc#1083663).
- commit f46b7e1
* Fri Aug 31 2018 mwilck@suse.com
- block: bio_iov_iter_get_pages: fix size of last iovec
  (bsc#1083663).
- commit 0c71f39
* Fri Aug 31 2018 lhenriques@suse.com
- libceph: weaken sizeof check in ceph_x_verify_authorizer_reply()
  (bsc#1096748).
- libceph: check authorizer reply/challenge length before reading
  (bsc#1096748).
- libceph: implement CEPHX_V2 calculation mode (bsc#1096748
  CVE-2018-1129).
- libceph: add authorizer challenge (bsc#1096748 CVE-2018-1128).
- libceph: factor out encrypt_authorizer() (bsc#1096748).
- libceph: factor out __ceph_x_decrypt() (bsc#1096748).
- libceph: factor out __prepare_write_connect() (bsc#1096748).
- libceph: store ceph_auth_handshake pointer in ceph_connection
  (bsc#1096748).
- commit 9961671
* Fri Aug 31 2018 tiwai@suse.de
- blacklist.conf: Add i915 blacklist commit
- commit 75ba08e
* Fri Aug 31 2018 tiwai@suse.de
- drm/i915: Increase LSPCON timeout (bsc#1051510).
- commit f6a2c2e
* Fri Aug 31 2018 tiwai@suse.de
- PM / clk: signedness bug in of_pm_clk_add_clks() (bsc#1051510).
- commit 8771052
* Fri Aug 31 2018 mwilck@suse.com
- scsi: hpsa: limit transfer length to 1MB, not 512kB
  (bsc#1102346).
- commit 8fe3be6
* Fri Aug 31 2018 jthumshirn@suse.de
- libnvdimm, nfit: move the check on nd_reserved2 to the endpoint
  (bsc#1103961).
- commit 2a0dfd3
* Fri Aug 31 2018 jthumshirn@suse.de
- scsi: lpfc: Correct MDS diag and nvmet configuration
  (bsc#1106636).
- commit 24436b8
* Fri Aug 31 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: Add fixes branch from mkp/scsi.git.
- commit a5cf63e
* Fri Aug 31 2018 jthumshirn@suse.de
- Update config files, make CRYPTO_CRCT10DIF_PCLMUL built-in
  (bsc#1105603).
- commit e11db61
* Fri Aug 31 2018 bpoirier@suse.com
- Update Patch-mainline tags to start with "v"
  Mainline release tags begin with a "v". Some Patch-mainline tags do and
  other don't. For consistency, use the same format as upstream. This makes
  parsing easier if some people want to grep through those tags.
- Refresh
  patches.arch/powerpc-64s-Use-emergency-stack-for-kernel-TM-Bad-Thing-program-checks.patch.
- Refresh
  patches.arch/x86-boot-KASLR-Prefer-mirrored-memory-regions-for-th.patch.
- Refresh
  patches.arch/x86-mm-Unbreak-modules-that-use-the-DMA-API.patch.
- Refresh patches.arch/x86-mm-Use-pr_cont-in-dump_pagetable.
- Refresh
  patches.drivers/0001-scsi-hpsa-limit-transfer-length-to-1MB.patch.
- Refresh
  patches.drivers/ACPI-scan-Initialize-watchdog-before-PNP.patch.
- Refresh
  patches.drivers/ACPI-x86-Add-KIOX000A-accelerometer-on-GPD-win-to-al.
- Refresh
  patches.drivers/ACPI-x86-Allow-matching-always_present_id-array-entr.
- Refresh
  patches.drivers/ACPI-x86-Extend-KIOX000A-quirk-to-cover-all-affected.
- Refresh
  patches.drivers/ALSA-caiaq-Fix-stray-URB-at-probe-error-path.
- Refresh patches.drivers/ALSA-compress-Remove-unused-variable.
- Refresh
  patches.drivers/ALSA-hda-Add-AZX_DRIVER_SKL-for-simplification.
- Refresh patches.drivers/ALSA-hda-Add-Cannonlake-PCI-ID.
- Refresh
  patches.drivers/ALSA-hda-Add-MIC_NO_PRESENCE-fixup-for-2-HP-machines.
- Refresh patches.drivers/ALSA-hda-Add-Raven-PCI-ID.
- Refresh
  patches.drivers/ALSA-hda-Add-hdmi-id-for-a-Geminilake-variant.
- Refresh
  patches.drivers/ALSA-hda-Add-vendor-id-for-Cannonlake-HDMI-codec.
- Refresh patches.drivers/ALSA-hda-Drop-useless-WARN_ON.
- Refresh
  patches.drivers/ALSA-hda-Fix-forget-to-free-resource-in-error-handli.
- Refresh
  patches.drivers/ALSA-hda-Fix-missing-COEF-init-for-ALC225-295-299.
- Refresh
  patches.drivers/ALSA-hda-Fix-regression-of-hdmi-eld-control-created-.
- Refresh
  patches.drivers/ALSA-hda-Fix-too-short-HDMI-DP-chmap-reporting.
- Refresh
  patches.drivers/ALSA-hda-Remove-superfluous-added-by-printk-conversi.
- Refresh
  patches.drivers/ALSA-hda-ca0132-Fix-memory-leak-at-error-path.
- Refresh
  patches.drivers/ALSA-hda-change-the-location-for-one-mic-on-a-Lenovo.
- Refresh
  patches.drivers/ALSA-hda-fix-headset-mic-detection-issue-on-a-Dell-m.
- Refresh
  patches.drivers/ALSA-hda-fix-headset-mic-problem-for-Dell-machines-alc274.
- Refresh
  patches.drivers/ALSA-hda-fix-headset-mic-problem-for-Dell-machines-w.
- Refresh
  patches.drivers/ALSA-hda-program-ICT-bits-to-support-HBR-audio.
- Refresh
  patches.drivers/ALSA-hda-realtek-Add-ALC256-HP-depop-function.
- Refresh
  patches.drivers/ALSA-hda-realtek-Add-default-procedure-for-suspend-a.
- Refresh
  patches.drivers/ALSA-hda-realtek-Add-headset-mic-support-for-Intel-N.
- Refresh
  patches.drivers/ALSA-hda-realtek-Add-support-for-ALC1220.
- Refresh
  patches.drivers/ALSA-hda-realtek-Add-support-for-ALC236-ALC3204.
- Refresh
  patches.drivers/ALSA-hda-realtek-Enable-jack-detection-function-for-.
- Refresh
  patches.drivers/ALSA-hda-realtek-Fix-ALC275-no-sound-issue.
- Refresh
  patches.drivers/ALSA-hda-realtek-Fix-ALC700-family-no-sound-issue.
- Refresh
  patches.drivers/ALSA-hda-realtek-Fix-Dell-AIO-LineOut-issue.
- Refresh
  patches.drivers/ALSA-hda-realtek-Fix-pincfg-for-Dell-XPS-13-9370.
- Refresh
  patches.drivers/ALSA-hda-realtek-Fix-typo-of-pincfg-for-Dell-quirk.
- Refresh
  patches.drivers/ALSA-hda-realtek-New-codec-device-ID-for-ALC1220.
- Refresh
  patches.drivers/ALSA-hda-realtek-New-codec-support-for-ALC257.
- Refresh
  patches.drivers/ALSA-hda-realtek-New-codecs-support-for-ALC215-ALC28.
- Refresh
  patches.drivers/ALSA-hda-realtek-No-loopback-on-ALC225-ALC295-codec.
- Refresh
  patches.drivers/ALSA-hda-realtek-Remove-ALC285-device-ID.
- Refresh
  patches.drivers/ALSA-hda-realtek-Support-Dell-headset-mode-for-ALC32.
- Refresh
  patches.drivers/ALSA-hda-realtek-Support-headset-mode-for-ALC234-ALC.
- Refresh
  patches.drivers/ALSA-hda-realtek-There-is-no-loopback-mixer-in-the-A.
- Refresh
  patches.drivers/ALSA-hda-realtek-Update-headset-mode-for-ALC225.
- Refresh
  patches.drivers/ALSA-hda-realtek-Update-headset-mode-for-ALC298.
- Refresh
  patches.drivers/ALSA-line6-Fix-NULL-dereference-at-podhd_disconnect.
- Refresh
  patches.drivers/ALSA-line6-Fix-leftover-URB-at-error-path-during-pro.
- Refresh
  patches.drivers/ALSA-line6-Fix-missing-initialization-before-error-p.
- Refresh patches.drivers/ALSA-pcm-prevent-UAF-in-snd_pcm_info.
- Refresh
  patches.drivers/ALSA-pcm-update-tstamp-only-if-audio_tstamp-changed.
- Refresh
  patches.drivers/ALSA-rawmidi-Avoid-racy-info-ioctl-via-ctl-device.
- Refresh
  patches.drivers/ALSA-seq-Avoid-invalid-lockdep-class-warning.
- Refresh
  patches.drivers/ALSA-seq-Cancel-pending-autoload-work-at-unbinding-d.
- Refresh
  patches.drivers/ALSA-seq-Enable-use-locking-in-all-configurations.
- Refresh
  patches.drivers/ALSA-seq-Fix-OSS-sysex-delivery-in-OSS-emulation.
- Refresh
  patches.drivers/ALSA-seq-Fix-copy_from_user-call-inside-lock.
- Refresh
  patches.drivers/ALSA-seq-Fix-nested-rwsem-annotation-for-lockdep-spl.
- Refresh
  patches.drivers/ALSA-seq-Remove-spurious-WARN_ON-at-timer-check.
- Refresh
  patches.drivers/ALSA-timer-Add-missing-mutex-lock-for-compat-ioctls.
- Refresh
  patches.drivers/ALSA-timer-Limit-max-instances-per-timer.
- Refresh
  patches.drivers/ALSA-timer-Remove-kernel-warning-at-compat-ioctl-err.
- Refresh
  patches.drivers/ALSA-usb-audio-Add-check-return-value-for-usb_string.
- Refresh
  patches.drivers/ALSA-usb-audio-Add-native-DSD-support-for-Esoteric-D.
- Refresh
  patches.drivers/ALSA-usb-audio-Add-native-DSD-support-for-Pro-Ject-P.
- Refresh
  patches.drivers/ALSA-usb-audio-Add-sanity-checks-in-v2-clock-parsers.
- Refresh
  patches.drivers/ALSA-usb-audio-Add-sanity-checks-to-FE-parser.
- Refresh
  patches.drivers/ALSA-usb-audio-Check-out-of-bounds-access-by-corrupt.
- Refresh patches.drivers/ALSA-usb-audio-Fix-out-of-bound-error.
- Refresh
  patches.drivers/ALSA-usb-audio-Fix-potential-out-of-bound-access-at-.
- Refresh
  patches.drivers/ALSA-usb-audio-Fix-the-missing-ctl-name-suffix-at-pa.
- Refresh
  patches.drivers/ALSA-usb-audio-Kill-stray-URB-at-exiting.
- Refresh
  patches.drivers/ALSA-usb-audio-support-new-Amanero-Combo384-firmware.
- Refresh
  patches.drivers/ALSA-usb-audio-uac1-Invalidate-ctl-on-interrupt.
- Refresh
  patches.drivers/ALSA-usx2y-Suppress-kernel-warning-at-page-allocatio.
- Refresh
  patches.drivers/ASoC-adau17x1-Workaround-for-noise-bug-in-ADC.
- Refresh
  patches.drivers/ASoC-atmel-classd-select-correct-Kconfig-symbol.
- Refresh
  patches.drivers/ASoC-codecs-msm8916-fix-invalid-cast-to-bool-type.
- Refresh
  patches.drivers/ASoC-codecs-msm8916-wcd-Fix-supported-formats.
- Refresh
  patches.drivers/ASoC-cs42l56-Fix-reset-GPIO-name-in-example-DT-bindi.
- Refresh patches.drivers/ASoC-da7218-fix-fix-child-node-lookup.
- Refresh
  patches.drivers/ASoC-davinci-mcasp-Fix-an-error-handling-path-in-dav.
- Refresh
  patches.drivers/ASoC-fsl_ssi-AC-97-ops-need-regmap-clock-and-cleanin.
- Refresh
  patches.drivers/ASoC-intel-include-linux-module.h-as-needed.
- Refresh
  patches.drivers/ASoC-mediatek-Fix-an-error-checking-code.
- Refresh
  patches.drivers/ASoC-rockchip-Correct-dmic-delay-property-name.
- Refresh patches.drivers/ASoC-rockchip-disable-clock-on-error.
- Refresh patches.drivers/ASoC-rsnd-avoid-duplicate-free_irq.
- Refresh
  patches.drivers/ASoC-rsnd-ssiu-clear-SSI_MODE-for-non-TDM-Extended-m.
- Refresh patches.drivers/ASoC-rt5514-fix-gcc-7-warning.
- Refresh
  patches.drivers/ASoC-rt5645-Add-jack-detection-workaround-for-GPD-Wi.
- Refresh patches.drivers/ASoC-rt5645-add-inv_jd1_1-flag.
- Refresh
  patches.drivers/ASoC-rt5645-read-jd1_1-status-for-jd-detection.
- Refresh
  patches.drivers/ASoC-rt5645-rename-jd_invert-flag-in-platform-data.
- Refresh
  patches.drivers/ASoC-rt5665-Fix-uninitialized-warning-in-rt5665_i2s_.
- Refresh patches.drivers/ASoC-rt5665-fix-gcc-7-warning.
- Refresh
  patches.drivers/ASoC-samsung-Fix-invalid-argument-when-devm_gpiod_ge.
- Refresh
  patches.drivers/ASoC-samsung-Fix-possible-double-iounmap-on-s3c24xx-.
- Refresh
  patches.drivers/ASoC-sun8i-codec-Fix-left-and-right-channels-inversi.
- Refresh
  patches.drivers/ASoC-sun8i-codec-Invert-Master-Slave-condition.
- Refresh patches.drivers/ASoC-sun8i-codec-Set-the-BCLK-divider.
- Refresh
  patches.drivers/ASoC-tlv320aic31xx-Fix-GPIO1-register-definition.
- Refresh
  patches.drivers/ASoC-topology-Fix-a-potential-NULL-pointer-dereferen.
- Refresh
  patches.drivers/ASoC-topology-Fix-a-potential-memory-leak-in-soc_tpl.
- Refresh patches.drivers/ASoC-twl4030-fix-child-node-lookup.
- Refresh
  patches.drivers/ASoC-wm_adsp-Fix-validation-of-firmware-and-coeff-le.
- Refresh
  patches.drivers/Bluetooth-Add-support-for-Intel-Bluetooth-device-946.patch.
- Refresh
  patches.drivers/Bluetooth-hci_bcm-Add-support-for-BCM2E7E.
- Refresh
  patches.drivers/Fix-serial-console-on-SNI-RM400-machines.patch.
- Refresh
  patches.drivers/Input-ims-psu-check-if-CDC-union-descriptor-is-sane.
- Refresh
  patches.drivers/Input-ti_am335x_tsc-fix-incorrect-step-config-for-5-.patch.
- Refresh
  patches.drivers/Input-ucb1400_ts-fix-suspend-and-resume-handling.patch.
- Refresh
  patches.drivers/Input-uinput-avoid-crash-when-sending-FF-request-to-.
- Refresh
  patches.drivers/PM-devfreq-Fix-memory-leak-when-fail-to-register-dev.
- Refresh
  patches.drivers/Revert-ALSA-echoaudio-purge-contradictions-between-d.
- Refresh
  patches.drivers/Revert-drm-i915-bxt-Disable-device-ready-before-shut.
- Refresh
  patches.drivers/Revert-net-bcmgenet-Remove-init-parameter-from-bcmge.patch.
- Refresh
  patches.drivers/ath10k-fix-reported-HT-MCS-rates-with-NSS-1.
- Refresh patches.drivers/b43-Add-missing-MODULE_FIRMWARE.
- Refresh
  patches.drivers/brcmfmac-Use-separate-firmware-for-revision-0-of-the.
- Refresh
  patches.drivers/brcmfmac-fix-double-free-upon-register_netdevice-fai.
- Refresh
  patches.drivers/cfg80211-honor-NL80211_RRF_NO_HT40-MINUS-PLUS.patch.
- Refresh
  patches.drivers/crypto-hmac-require-that-the-underlying-hash-algorit.
- Refresh
  patches.drivers/crypto-salsa20-fix-blkcipher_walk-API-usage.
- Refresh
  patches.drivers/drm-Add-driver-private-objects-to-atomic-state.
- Refresh patches.drivers/drm-Drop-drm_get_link_status_name.
- Refresh
  patches.drivers/drm-amd-powerplay-initialize-a-variable-before-using.
- Refresh
  patches.drivers/drm-amdgpu-Throttle-visible-VRAM-moves-separately.
- Refresh
  patches.drivers/drm-atomic-helper-Realign-function-parameters.
- Refresh
  patches.drivers/drm-bridge-sii8620-Fix-memory-corruption.
- Refresh
  patches.drivers/drm-crc-Only-open-CRC-on-atomic-drivers-when-the-CRT.
- Refresh patches.drivers/drm-doc-Fix-missing-ctx-documentation.
- Refresh
  patches.drivers/drm-dp-Add-DP-MST-helpers-to-atomically-find-and-rel.
- Refresh
  patches.drivers/drm-dp-Introduce-MST-topology-state-to-track-availab.
- Refresh
  patches.drivers/drm-dp-mst-Handle-errors-from-drm_atomic_get_private.
- Refresh
  patches.drivers/drm-edid-Don-t-send-non-zero-YQ-in-AVI-infoframe-for.
- Refresh
  patches.drivers/drm-exynos-mark-pm-functions-as-__maybe_unused.
- Refresh
  patches.drivers/drm-fsl-dcu-avoid-disabling-pixel-clock-twice-on-sus.
- Refresh patches.drivers/drm-gma500-fix-logic-error.
- Refresh
  patches.drivers/drm-handle-HDMI-2.0-VICs-in-AVI-info-frames.
- Refresh patches.drivers/drm-imx-fix-typo-in-ipu_plane_formats.
- Refresh
  patches.drivers/drm-kirin-Checking-for-IS_ERR-instead-of-NULL.
- Refresh
  patches.drivers/drm-mediatek-separate-color-module-to-fixup-error-me.
- Refresh
  patches.drivers/drm-msm-dsi-Calculate-link-clock-rates-with-updated-.
- Refresh
  patches.drivers/drm-msm-hdmi-Use-bitwise-operators-when-building-reg.
- Refresh
  patches.drivers/drm-nouveau-kms-nv50-perform-null-check-on-msto-i-ra.
- Refresh
  patches.drivers/drm-nouveau-use-proper-prototype-in-nouveau_pmops_ru.
- Refresh
  patches.drivers/drm-omap-Fix-error-handling-path-in-omap_dmm_probe.
- Refresh
  patches.drivers/drm-omap-displays-panel-dpi-add-backlight-dependency.
- Refresh
  patches.drivers/drm-omapdrm-Take-GEM-object-reference-when-exporting.
- Refresh patches.drivers/drm-panel-S6E3HA2-needs-backlight-code.
- Refresh
  patches.drivers/drm-panel-add-backlight-dependency-for-sitronix-st77.
- Refresh
  patches.drivers/drm-panel-simple-Add-missing-panel_simple_unprepare-.
- Refresh
  patches.drivers/drm-panel-simple-Fix-width-and-height-for-Olimex-LCD.
- Refresh
  patches.drivers/drm-qxl-replace-QXL_INFO-with-DRM_DEBUG_DRIVER.
- Refresh
  patches.drivers/drm-radeon-disable-hard-reset-in-hibernate-for-APUs.
- Refresh
  patches.drivers/drm-rcar-du-Use-the-VBK-interrupt-for-vblank-events.patch.
- Refresh patches.drivers/drm-rockchip-fix-Kconfig-dependencies.
- Refresh
  patches.drivers/drm-sun4i-backend-Offset-layer-buffer-address-by-DRA.
- Refresh
  patches.drivers/drm-sun4i-tcon-Unconditionally-reset-the-TCON.
- Refresh
  patches.drivers/drm-tegra-Set-MODULE_FIRMWARE-for-the-VIC.
- Refresh
  patches.drivers/drm-tegra-dc-Avoid-reset-asserts-on-Tegra20.
- Refresh
  patches.drivers/drm-tilcdc-Precalculate-total-frametime-in-tilcdc_cr.
- Refresh
  patches.drivers/drm-vc4-Account-for-interrupts-in-flight.
- Refresh
  patches.drivers/drm-vc4-Don-t-disable-DSI-clocks-on-component-unload.
- Refresh patches.drivers/drm-vc4-Fix-leak-of-HDMI-EDID.
- Refresh
  patches.drivers/gpu-host1x-Don-t-fail-on-NULL-bo-physical-address.patch.
- Refresh
  patches.drivers/gpu-host1x-Free-the-IOMMU-domain-when-there-is-no-de.patch.
- Refresh patches.drivers/gpu-ipu-v3-add-DRM-dependency.patch.
- Refresh
  patches.drivers/i2c-cadance-fix-ctrl-addr-reg-write-order.patch.
- Refresh
  patches.drivers/iio-dummy-events-Add-missing-break.patch.
- Refresh patches.drivers/iio-inkern-fix-a-static-checker-error.
- Refresh
  patches.drivers/iio-trigger-stm32-timer-fix-a-corner-case-to-write-p.
- Refresh
  patches.drivers/ipmi-Prefer-ACPI-system-interfaces-over-SMBIOS-ones.
- Refresh patches.drivers/ipmi_ssif-unlock-on-allocation-failure.
- Refresh
  patches.drivers/iwlwifi-add-new-cards-for-8260-series.patch.
- Refresh
  patches.drivers/iwlwifi-add-new-cards-for-8265-series.patch.
- Refresh
  patches.drivers/iwlwifi-add-new-cards-for-a000-series.patch.
- Refresh
  patches.drivers/iwlwifi-fix-PCI-IDs-and-configuration-mapping-for-90.patch.
- Refresh
  patches.drivers/iwlwifi-fix-TX-tracing-for-non-linear-SKBs.
- Refresh
  patches.drivers/iwlwifi-fix-firmware-names-for-9000-and-A000-series-.patch.
- Refresh
  patches.drivers/iwlwifi-fix-tracing-when-tx-only-is-enabled.
- Refresh
  patches.drivers/iwlwifi-missing-error-code-in-iwl_trans_pcie_alloc.
- Refresh patches.drivers/iwlwifi-mvm-add-missing-lq_color.patch.
- Refresh patches.drivers/iwlwifi-mvm-change-sta_id-to-u8.
- Refresh
  patches.drivers/iwlwifi-mvm-don-t-mess-the-SNAP-header-in-TSO-for-no.
- Refresh
  patches.drivers/iwlwifi-mvm-don-t-send-fetch-the-TID-from-a-non-QoS-.
- Refresh
  patches.drivers/iwlwifi-mvm-fix-TCP-CSUM-offload-with-WEP-and-A000-s.
- Refresh
  patches.drivers/iwlwifi-mvm-fix-a-NULL-pointer-dereference-of-error-.
- Refresh
  patches.drivers/iwlwifi-mvm-fix-deduplication-start-logic.
- Refresh patches.drivers/iwlwifi-mvm-fix-mac80211-queue-tracking.
- Refresh
  patches.drivers/iwlwifi-mvm-fix-reorder-buffer-for-9000-devices.patch.
- Refresh
  patches.drivers/iwlwifi-mvm-handle-IBSS-probe_queue-in-a-few-missing.
- Refresh
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-assoc-response-fr.
- Refresh
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-disassoc-frames.
- Refresh
  patches.drivers/iwlwifi-mvm-reset-seq-num-after-restart.patch.
- Refresh
  patches.drivers/iwlwifi-mvm-set-the-RTS_MIMO_PROT-bit-in-flag-mask-w.
- Refresh
  patches.drivers/iwlwifi-mvm-unconditionally-stop-device-after-init.
- Refresh
  patches.drivers/iwlwifi-mvm-use-IWL_HCMD_NOCOPY-for-MCAST_FILTER_CMD.patch.
- Refresh
  patches.drivers/iwlwifi-pcie-fix-TVQM-queue-ID-range-check.
- Refresh
  patches.drivers/iwlwifi-pcie-fix-command-completion-name-debug.
- Refresh
  patches.drivers/iwlwifi-pcie-reconfigure-MSI-X-HW-on-resume.
- Refresh
  patches.drivers/iwlwifi-pcie-sort-IDs-for-the-9000-series-for-easier.patch.
- Refresh
  patches.drivers/libertas-Fix-lbs_prb_rsp_limit_set.patch.
- Refresh
  patches.drivers/mac80211-agg-tx-call-drv_wake_tx_queue-in-proper-con.patch.
- Refresh
  patches.drivers/mac80211-validate-user-rate-mask-before-configuring-.patch.
- Refresh
  patches.drivers/mac80211_hwsim-Fix-memory-leak-in-hwsim_new_radio_nl.
- Refresh
  patches.drivers/media-Revert-media-et8ek8-Export-OF-device-ID-as-mod.patch.
- Refresh
  patches.drivers/media-au0828-fix-RC_CORE-dependency.patch.
- Refresh
  patches.drivers/media-devnode-Rename-mdev-argument-as-devnode.patch.
- Refresh
  patches.drivers/media-em28xx-calculate-left-volume-level-correctly.patch.
- Refresh
  patches.drivers/media-mceusb-fix-memory-leaks-in-error-path.patch.
- Refresh
  patches.drivers/media-omap_vout-Fix-a-possible-null-pointer-derefere.
- Refresh
  patches.drivers/media-rainshadow-cec-avoid-Wmaybe-uninitialized-warn.patch.
- Refresh
  patches.drivers/media-rainshadow-cec-avoid-Wmaybe-uninitialized-warn2.patch.
- Refresh
  patches.drivers/media-rainshadow-cec-use-strlcat-instead-of-strncat.patch.
- Refresh
  patches.drivers/media-usbtv-fix-brightness-and-contrast-controls.
- Refresh
  patches.drivers/media-v4l2-compat-ioctl32-Fix-timespec-conversion.patch.
- Refresh
  patches.drivers/mfd-intel_soc_pmic-Differentiate-between-Bay-and-Che.
- Refresh
  patches.drivers/mfd-intel_soc_pmic-Export-separate-mfd-cell-configs-.
- Refresh
  patches.drivers/mfd-intel_soc_pmic-Select-designware-i2c-bus-driver.
- Refresh
  patches.drivers/mfd-lpc_ich-Do-not-touch-SPI-NOR-write-protection-bi.
- Refresh patches.drivers/mfd-omap-usb-tll-Fix-register-offsets.
- Refresh
  patches.drivers/mfd-rn5t618-Unregister-restart-handler-on-remove.
- Refresh
  patches.drivers/mmc-core-prepend-0x-to-OCR-entry-in-sysfs.
- Refresh
  patches.drivers/mmc-core-prepend-0x-to-pre_eol_info-entry-in-sysfs.
- Refresh
  patches.drivers/mmc-mediatek-Fixed-size-in-dma_free_coherent.patch.
- Refresh
  patches.drivers/mmc-sdhci-acpi-Workaround-conflict-with-PCI-wifi-on-.
- Refresh
  patches.drivers/mmc-sdhci-pci-Fix-default-d3_retune-for-Intel-host-c.
- Refresh
  patches.drivers/mmc-sdhci-pci-remove-outdated-declaration.
- Refresh
  patches.drivers/mwifiex-do-not-update-MCS-set-from-hostapd.
- Refresh
  patches.drivers/mwifiex-replace-netif_carrier_on-off-by-netif_device.patch.
- Refresh
  patches.drivers/net-mlx5e-Fix-fixpoint-divide-exception-in-mlx5e_am_.patch.
- Refresh
  patches.drivers/net-usb-asix-fill-null-ptr-deref-in-asix_suspend.patch.
- Refresh
  patches.drivers/nl80211-fix-null-ptr-dereference-on-invalid-mesh-con.patch.
- Refresh
  patches.drivers/nl80211-look-for-HT-VHT-capabilities-in-beacon-s-tai.patch.
- Refresh
  patches.drivers/platform-x86-Add-driver-for-ACPI-INT0002-Virtual-GPI.
- Refresh
  patches.drivers/platform-x86-fujitsu-laptop-Fix-radio-LED-detection.
- Refresh
  patches.drivers/platform-x86-hp-wmi-Fix-tablet-mode-detection-for-co.
- Refresh
  patches.drivers/platform-x86-ideapad-laptop-Add-IdeaPad-V510-15IKB-t.
- Refresh
  patches.drivers/platform-x86-ideapad-laptop-Add-Y520-15IKBN-to-no_hw.
- Refresh
  patches.drivers/platform-x86-ideapad-laptop-Add-Y720-15IKBN-to-no_hw.
- Refresh
  patches.drivers/platform-x86-ideapad-laptop-Add-several-models-to-no.
- Refresh
  patches.drivers/platform-x86-sony-laptop-Fix-error-handling-in-sony_.
- Refresh patches.drivers/qxl-alloc-use-shadow-for-dumb-buffers.
- Refresh patches.drivers/qxl-fix-pinning.patch.
- Refresh patches.drivers/qxl-fix-primary-surface-handling.patch.
- Refresh
  patches.drivers/r8169-Do-not-increment-tx_dropped-in-TX-ring-cleanin.
- Refresh
  patches.drivers/rtc-rtc-nuc900-fix-loop-timeout-test.patch.
- Refresh
  patches.drivers/rtc-sa1100-fix-unbalanced-clk_prepare_enable-clk_dis.patch.
- Refresh
  patches.drivers/rtlwifi-rtl8821ae-Fix-HW_VAR_NAV_UPPER-operation.
- Refresh
  patches.drivers/rtlwifi-rtl8821ae-Fix-connection-lost-problem.
- Refresh
  patches.drivers/serial-8250_fintek-Fix-rs485-disablement-on-invalid-.
- Refresh
  patches.drivers/serial-8250_pci-Add-Amazon-PCI-serial-device-ID.
- Refresh
  patches.drivers/serial-8250_uniphier-fix-serial-port-index-in-privat.patch.
- Refresh
  patches.drivers/serial-pch_uart-Make-port-type-explicit.patch.
- Refresh
  patches.drivers/staging-rtl8723bs-avoid-null-pointer-dereference-on-.
- Refresh
  patches.drivers/video-console-Add-dmi-quirk-table-for-x86-systems-wh.
- Refresh
  patches.drivers/video-console-Add-new-BIOS-date-for-GPD-pocket-to-dm.
- Refresh
  patches.drivers/video-console-Update-BIOS-dates-list-for-GPD-win-con.
- Refresh patches.drivers/video-udlfb-Fix-read-EDID-timeout.
- Refresh
  patches.drivers/x86-gpu-CNL-uses-the-same-GMS-values-as-SKL.
- Refresh
  patches.drivers/xhci-Fix-perceived-dead-host-due-to-runtime-s.patch.
- Refresh
  patches.fixes/0001-CIFS-dump-IPC-tcon-in-debug-proc-file.patch.
- Refresh patches.fixes/0001-CIFS-make-IPC-a-regular-tcon.patch.
- Refresh
  patches.fixes/0001-CIFS-use-tcon_ipc-instead-of-use_ipc-parameter-of-SM.patch.
- Refresh
  patches.fixes/0001-CIFS-zero-sensitive-data-when-freeing.patch.
- Refresh
  patches.fixes/0001-cifs-Fix-autonegotiate-security-settings-mismatch.patch.
- Refresh
  patches.fixes/0001-cifs-Fix-missing-put_xid-in-cifs_file_strict_mmap.patch.
- Refresh
  patches.fixes/0001-fs-fcntl-f_setown-allow-returning-error.patch.
- Refresh
  patches.fixes/0001-ipc-shm-fix-use-after-free-of-shm-file-via-remap_fil.patch.
- Refresh
  patches.fixes/0001-kernel-exit.c-avoid-undefined-behaviour-when-calling.patch.
- Refresh
  patches.fixes/0001-kernel-signal.c-avoid-undefined-behaviour-in-kill_so.patch.
- Refresh
  patches.fixes/0001-mm-distinguish-CMA-and-MOVABLE-isolation-in-has_unmo.patch.
- Refresh
  patches.fixes/0001-mm-drop-migrate-type-checks-from-has_unmovable_pages.patch.
- Refresh
  patches.fixes/0001-mm-memory_hotplug-add-scheduling-point-to-__add_page.patch.
- Refresh
  patches.fixes/0001-mm-memory_hotplug-simplify-empty-node-mask-handling-.patch.
- Refresh
  patches.fixes/0001-mm-oom-fix-concurrent-munlock-and-oom-reaper-unmap-v.patch.
- Refresh
  patches.fixes/0001-mm-shmem-do-not-wait-for-lock_page-in-shmem_unused_h.patch.
- Refresh
  patches.fixes/0001-mm-thp-do-not-cause-memcg-oom-for-thp.patch.
- Refresh
  patches.fixes/0001-smartpqi-limit-transfer-length-to-1MB.patch.
- Refresh
  patches.fixes/0002-fs-fcntl-f_setown-avoid-undefined-behaviour.patch.
- Refresh
  patches.fixes/0002-hugetlb-memory_hotplug-prefer-to-use-reserved-pages-.patch.
- Refresh
  patches.fixes/0002-mm-page_alloc-add-scheduling-point-to-memmap_init_zo.patch.
- Refresh
  patches.fixes/0002-mm-page_alloc-fail-has_unmovable_pages-when-seeing-r.patch.
- Refresh
  patches.fixes/0003-memremap-add-scheduling-point-to-devm_memremap_pages.patch.
- Refresh
  patches.fixes/0003-mm-memory_hotplug-do-not-fail-offlining-too-early.patch.
- Refresh
  patches.fixes/0003-mm-unify-new_node_page-and-alloc_migrate_target.patch.
- Refresh
  patches.fixes/0004-mm-memory_hotplug-remove-timeout-from-__offline_memo.patch.
- Refresh
  patches.fixes/ACPI-NUMA-ia64-Parse-all-entries-of-SRAT-memory-affi.patch.
- Refresh
  patches.fixes/KEYS-don-t-revoke-uninstantiated-key-in-request_key_.
- Refresh
  patches.fixes/KEYS-fix-cred-refcount-leak-in-request_key_auth_new.
- Refresh
  patches.fixes/KEYS-fix-key-refcount-leak-in-keyctl_assume_authorit.
- Refresh
  patches.fixes/KEYS-fix-key-refcount-leak-in-keyctl_read_key.
- Refresh patches.fixes/PKCS-7-fix-certificate-blacklisting.
- Refresh patches.fixes/PKCS-7-fix-certificate-chain-verification.
- Refresh
  patches.fixes/PKCS-7-fix-direct-verification-of-SignerInfo-signatu.
- Refresh
  patches.fixes/assoc_array-Fix-a-buggy-node-splitting-case.
- Refresh patches.fixes/cfg80211-fix-cfg80211_beacon_dup.
- Refresh
  patches.fixes/drm-Handle-unexpected-holes-in-color-eviction.
- Refresh
  patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch.
- Refresh
  patches.fixes/drm-atomic-Fix-memleak-on-ERESTARTSYS-during-non-blo.
- Refresh patches.fixes/drm-cirrus-Load-lut-in-crtc_commit.
- Refresh
  patches.fixes/drm-edid-Add-6-bpc-quirk-for-CPT-panel-in-Asus-UX303.
- Refresh
  patches.fixes/fuse-fix-READDIRPLUS-skipping-an-entry.patch.
- Refresh patches.fixes/i2c-designware-must-wait-for-enable.
- Refresh
  patches.fixes/mac80211-fix-a-possible-leak-of-station-stats.
- Refresh
  patches.fixes/mac80211-fix-calling-sleeping-function-in-atomic-con.
- Refresh patches.fixes/mm-adaptive-hash-table-scaling.patch.
- Refresh
  patches.fixes/mm-backing-dev.c-fix-an-error-handling-path-in-cgwb_.patch.
- Refresh
  patches.fixes/mm-cma-fix-alloc_contig_range-ret-code-potential-lea.patch.
- Refresh
  patches.fixes/mm-hugetlb-fix-NULL-pointer-dereference-on-5-level-p.patch.
- Refresh
  patches.fixes/mm-madvise.c-fix-madvise-infinite-loop-under-special.patch.
- Refresh
  patches.fixes/mm-make-PR_SET_THP_DISABLE-immediately-active.patch.
- Refresh
  patches.fixes/mm-meminit-mark-init_reserved_page-as-__meminit.patch.
- Refresh
  patches.fixes/mm-memory_hotplug-change-pfn_to_section_nr-section_n.patch.
- Refresh
  patches.fixes/mm-memory_hotplug-define-find_-smallest-biggest-_sec.patch.
- Refresh
  patches.fixes/mm-memory_hotplug-do-not-back-off-draining-pcp-free-.patch.
- Refresh
  patches.fixes/mm-mmap.c-do-not-blow-on-PROT_NONE-MAP_FIXED-holes-i.patch.
- Refresh
  patches.fixes/mm-mprotect-add-a-cond_resched-inside-change_pmd_ran.patch.
- Refresh
  patches.fixes/mm-oom-fix-potential-data-corruption-when-oom_reaper.patch.
- Refresh patches.fixes/mm-oom_reaper-fix-memory-corruption.patch.
- Refresh
  patches.fixes/mm-oom_reaper-gather-each-vma-to-prevent-leaking-TLB.patch.
- Refresh
  patches.fixes/mm-page_alloc.c-broken-deferred-calculation.patch.
- Refresh
  patches.fixes/mm-page_ext.c-check-if-page_ext-is-not-prepared.patch.
- Refresh
  patches.fixes/mm-page_vma_mapped-ensure-pmd-is-loaded-with-READ_ON.patch.
- Refresh
  patches.fixes/mm-pagewalk.c-report-holes-in-hugetlb-ranges.patch.
- Refresh
  patches.fixes/mm-sparse-do-not-swamp-log-with-huge-vmemmap-allocat.patch.
- Refresh
  patches.fixes/printk-Add-console-owner-and-waiter-logic-to-load-ba.patch.
- Refresh
  patches.fixes/printk-Hide-console-waiter-logic-into-helpers.patch.
- Refresh
  patches.fixes/printk-Never-set-console_may_schedule-in-console_try.patch.
- Refresh
  patches.fixes/userfaultfd-hugetlbfs-prevent-UFFDIO_COPY-to-fill-be.patch.
- Refresh
  patches.fixes/userfaultfd-hugetlbfs-remove-superfluous-page-unlock.patch.
- Refresh
  patches.fixes/x86-paravirt-fix-spectre-v2-mitigations-for-paravirt-guests.patch.
- Refresh patches.fixes/xen-add-sysfs-node-for-guest-type.patch.
- Refresh
  patches.fixes/xen-allocate-page-for-shared-info-page-from-low-mem.patch.
- Refresh
  patches.fixes/xen-balloon-don-t-online-new-memory-initially.patch.
- Refresh patches.fixes/xen-mce-dont-issue-error-message.patch.
- Refresh patches.fixes/xen-netfront-dont-cache-skb_shinfo.patch.
- Refresh
  patches.suse/0001-futex-futex_wake_op-do-not-fail-on-invalid-op.patch.
- Refresh
  patches.suse/0001-mm-memory_hotplug-support-movable_node-for-hotplugab.patch.
- Refresh
  patches.suse/0001-mm-remove-return-value-from-init_currently_empty_zon.patch.
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0001-objtool-Move-checking-code-to-check.c.patch.
- Refresh
  patches.suse/0001-x86-KASLR-Parse-all-memmap-boot-option-entries.patch.
- Refresh
  patches.suse/0001-x86-boot-KASLR-Wrap-e820-entries-walking-code-into-n.patch.
- Refresh
  patches.suse/0002-mm-memory_hotplug-use-node-instead-of-zone-in-can_on.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0002-x86-KASLR-Handle-the-memory-limit-specified-by-the-m.patch.
- Refresh
  patches.suse/0002-x86-boot-KASLR-Switch-to-pass-struct-mem_vector-to-p.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-Documentation-kernel-parameters.txt-Update-memmap-bo.patch.
- Refresh
  patches.suse/0003-mm-drop-page_initialized-check-from-get_nid_for_pfn.patch.
- Refresh
  patches.suse/0003-x86-boot-KASLR-Rename-process_e820_entry-into-proces.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-mm-memory_hotplug-get-rid-of-is_zone_device_section.patch.
- Refresh
  patches.suse/0004-objtool-Silence-warnings-for-functions-which-use-IRE.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-mm-memory_hotplug-split-up-register_one_node.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-mm-memory_hotplug-consider-offline-memblocks-removab.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-mm-consider-zone-which-is-not-fully-populated-to-hav.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-mm-compaction-skip-over-holes-in-__reset_isolation_s.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0009-mm-__first_valid_page-skip-over-offline-pages.patch.
- Refresh
  patches.suse/0010-mm-vmstat-skip-reporting-offline-pages-in-pagetypein.patch.
- Refresh
  patches.suse/0011-mm-memory_hotplug-do-not-associate-hotadded-memory-t.patch.
- Refresh
  patches.suse/0012-mm-memory_hotplug-fix-MMOP_ONLINE_KEEP-behavior.patch.
- Refresh
  patches.suse/0013-mm-memory_hotplug-do-not-assume-ZONE_NORMAL-is-defau.patch.
- Refresh
  patches.suse/0014-mm-memory_hotplug-replace-for_device-by-want_membloc.patch.
- Refresh
  patches.suse/0015-mm-memory_hotplug-fix-the-section-mismatch-warning.patch.
- Refresh
  patches.suse/0016-mm-memory_hotplug-remove-unused-cruft-after-memory-h.patch.
- Refresh
  patches.suse/btrfs-add-support-for-fallocate-s-zero-range-operati.patch.
- Refresh
  patches.suse/btrfs-fix-missing-inode-i_size-update-after-zero-ran.patch.
- Refresh
  patches.suse/btrfs-fix-reported-number-of-inode-blocks-after-buff.patch.
- Refresh
  patches.suse/btrfs-fix-space-leak-after-fallocate-and-zero-range-.patch.
- Refresh
  patches.suse/btrfs-move-definition-of-the-function-btrfs_find_new.patch.
- Refresh
  patches.suse/btrfs-remove-spurious-WARN_ON-ref-count-0-in-find_pa.patch.
- Refresh
  patches.suse/efi-Introduce-efi_early_memdesc_ptr-to-get-pointer-t.patch.
- Refresh
  patches.suse/objtool-Print-top-level-commands-on-incorrect-usage.patch.
- Refresh
  patches.suse/x86-stacktrace-Avoid-recording-save_stack_trace-wrap.patch.
- Refresh
  patches.suse/x86-unwind-Make-CONFIG_UNWINDER_ORC-y-the-default-in.patch.
- Refresh
  patches.suse/x86-unwind-Rename-unwinder-config-options-to-CONFIG_.patch.
- Refresh
  patches.suse/x86-unwinder-Make-CONFIG_UNWINDER_ORC-y-the-default-.patch.
- commit 3525f67
* Fri Aug 31 2018 bpoirier@suse.com
- Update Patch-mainline tags to include rc information
  Some Patch-mainline tags include the release candidate (rc) while others do
  not. Because of that inconsistency it is impossible to know from a
  Patch-mainline tag with no rc if it describes a commit that was added
  between the last rc and the release of a development cycle or if the rc
  part was not included in the tag. Update Patch-mainline tags of patches in
  the sorted section to include rc information consistently.
- commit 2528c74
* Fri Aug 31 2018 bpoirier@suse.com
- Fix invalid Patch-mainline tags
  Some patches have a Patch-mainline tag which does not correspond with the
  first mainline version to contain the commit mentioned in the Git-commit
  tag. Fix those Patch-mainline tags.
- Refresh
  patches.arch/kvm-fix-stack-out-of-bounds-read-in-write_mmio.
- Refresh
  patches.drivers/0001-drm-mali-dp-Uninitialized-variable-in-malidp_se_chec.patch.
- Refresh
  patches.drivers/0001-drm-msm-don-t-deref-error-pointer-in-the-msm_fbdev_c.patch.
- Refresh
  patches.drivers/0001-drm-nouveau-drm-nouveau-Fix-runtime-PM-leak-in-nv50_.patch.
- Refresh
  patches.drivers/0001-drm-rcar-du-Remove-zpos-field-from-rcar_du_vsp_plane.patch.
- Refresh
  patches.drivers/0001-drm-rcar-du-lvds-Fix-LVDCR1-for-R-Car-gen3.patch.
- Refresh
  patches.drivers/0001-drm-rockchip-Fix-build-warning-in-analogix_dp-rockch.patch.
- Refresh
  patches.drivers/0001-drm-rockchip-analogix_dp-Remove-unnecessary-init-cod.patch.
- Refresh
  patches.drivers/0001-drm-rockchip-dw_hdmi-Move-HDMI-vpll-clock-enable-to-.patch.
- Refresh
  patches.drivers/0001-drm-rockchip-inno_hdmi-Fix-error-handling-path.patch.
- Refresh
  patches.drivers/0001-drm-rockchip-inno_hdmi-reorder-clk_disable_unprepare.patch.
- Refresh
  patches.drivers/0001-drm-tegra-Acquire-a-reference-to-the-IOVA-cache.patch.
- Refresh
  patches.drivers/0001-drm-udl-fix-display-corruption-of-the-last-line.patch.
- Refresh
  patches.drivers/0001-gpu-host1x-Acquire-a-reference-to-the-IOVA-cache.patch.
- Refresh
  patches.drivers/0001-vfb-fix-video-mode-and-line_length-being-set-when-lo.patch.
- Refresh
  patches.drivers/0001-video-omap-add-module-license-tags.patch.
- Refresh
  patches.drivers/0001-video-remove-unused-kconfig-SH_LCD_MIPI_DSI.patch.
- Refresh
  patches.drivers/0001-virtio-gpu-fix-ioctl-and-expose-the-fixed-status-to-.patch.
- Refresh
  patches.drivers/0004-test_firmware-add-test-case-for-SIGCHLD-on-sync-fall.patch.
- Refresh
  patches.drivers/0005-test_firmware-add-batched-firmware-tests.patch.
- Refresh
  patches.drivers/0019-usb-hcd-constify-attribute_group-structures.patch.
- Refresh
  patches.drivers/0020-xhci-rename-temp-and-temp1-variables.patch.
- Refresh
  patches.drivers/0021-usb-Increase-root-hub-reset-signaling-time-to-preven.patch.
- Refresh
  patches.drivers/0022-xhci-rework-bus_resume-and-check-ports-are-suspended.patch.
- Refresh patches.drivers/0023-usb-make-device_type-const.patch.
- Refresh
  patches.drivers/0024-USB-core-constify-vm_operations_struct.patch.
- Refresh
  patches.drivers/0025-usb-xhci-Support-enabling-of-compliance-mode-for-xhc.patch.
- Refresh
  patches.drivers/0026-usb-misc-lvstest-add-entry-to-place-port-in-complian.patch.
- Refresh
  patches.drivers/Documentation-DMA-API-fix-a-typo-in-a-function-name.patch.
- Refresh
  patches.drivers/KVM-s390-Fix-KVM_S390_GET_CMMA_BITS-ioctl-definition.patch.
- Refresh
  patches.drivers/KVM-s390-add-proper-locking-for-CMMA-migration-bitma.patch.
- Refresh
  patches.drivers/KVM-s390-fix-cmma-migration-for-multiple-memory-slot.patch.
- Refresh
  patches.drivers/KVM-s390-prevent-buffer-overrun-on-memory-hotplug-du.patch.
- Refresh
  patches.drivers/aacraid-Fix-controller-initialization-failure.patch.
- Refresh
  patches.drivers/ahci-Add-PCI-ids-for-Intel-Bay-Trail-Cherry-Trail-an.patch.
- Refresh
  patches.drivers/ahci-Annotate-PCI-ids-for-mobile-Intel-chipsets-as-s.patch.
- Refresh
  patches.drivers/ata-pata_artop-remove-redundant-initialization-of-pi.patch.
- Refresh
  patches.drivers/blk-mq-attempt-to-fix-atomic-flag-memory-ordering.patch.
- Refresh
  patches.drivers/block-Relax-a-check-in-blk_start_queue.patch.
- Refresh
  patches.drivers/drm-amdkfd-NULL-dereference-involving-create_process.
- Refresh
  patches.drivers/ixgbe-Refactor-queue-disable-logic-to-take-completio.patch.
- Refresh
  patches.drivers/ixgbe-Reorder-Tx-Rx-shutdown-to-reduce-time-needed-t.patch.
- Refresh
  patches.drivers/kernel-doc-describe-the-literal-syntax.patch.
- Refresh
  patches.drivers/libata-sata_down_spd_limit-should-return-if-driver-h.patch.
- Refresh
  patches.drivers/s390-guarded-storage-fix-possible-memory-corruption.patch.
- Refresh
  patches.drivers/s390-mm-make-pmdp_invalidate-do-invalidation-only.patch.
- Refresh
  patches.drivers/s390-perf-fix-bug-when-creating-per-thread-event.patch.
- Refresh
  patches.drivers/s390-runtime-instrumention-fix-possible-memory-corru.patch.
- Refresh
  patches.drivers/scsi-bnx2fc-Simplify-CPU-hotplug-code.patch.
- Refresh
  patches.drivers/scsi-bnx2i-prevent-recursive-cpuhotplug-locking.
- Refresh patches.drivers/scsi-bnx2i-simplify-cpu-hotplug-code.
- Refresh
  patches.drivers/scsi-csiostor-fail-probe-if-fw-does-not-support-FCoE.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Replace-PCI-pool-old-API-1.patch.
- Refresh
  patches.drivers/scsi-mq-Always-unprepare-before-requeuing-a-req.patch.
- Refresh
  patches.drivers/scsi-qedi-fix-kernel-crash-during-port-toggle.
- Refresh
  patches.drivers/sun_esp-fix-device-reference-leaks.patch.
- Refresh
  patches.drivers/zfcp-add-handling-for-FCP_RESID_OVER-to-the-fcp.patch.
- Refresh
  patches.fixes/0001-PCMCIA-PM-Avoid-noirq-suspend-aborts-during-suspend-.patch.
- Refresh
  patches.fixes/0001-USB-serial-io_edgeport-fix-possible-sleep-in-atomic.patch.
- Refresh
  patches.fixes/0001-drm-Use-kvzalloc-for-allocating-blob-property-memory.patch.
- Refresh
  patches.fixes/0001-drm-i915-Restore-user-forcewake-domains-across-suspe.patch.
- Refresh
  patches.fixes/0001-video-uvesafb-Fix-integer-overflow-in-allocation.patch.
- Refresh
  patches.fixes/0004-iomap-report-collisions-between-directio-and-buffere.patch.
- Refresh
  patches.fixes/crypto-pcrypt-fix-freeing-pcrypt-instances.
- Refresh
  patches.fixes/scsi-isci-fix-typo-in-function-names.patch.
- Refresh
  patches.fixes/scsi-libiscsi-fix-shifting-of-did_requeue-host-byte.
- Refresh patches.fixes/st-fix-blk_get_queue-usage.patch.
- Refresh
  patches.suse/0001-firmware-send-EINTR-on-signal-abort-on-fallback-mech.patch.
- Refresh
  patches.suse/0001-locking-pvqspinlock-Relax-cmpxchg-s-to-improve-perfo.patch.
- Refresh
  patches.suse/0001-locking-refcount-Create-unchecked-atomic_t-implement.patch.
- Refresh
  patches.suse/0001-locking-rtmutex-Remove-unnecessary-priority-adjustme.patch.
- Refresh
  patches.suse/0001-smp-Avoid-sending-needless-IPI-in-smp_call_function_.patch.
- Refresh
  patches.suse/0001-smp-cpumask-Use-non-atomic-cpumask_-set-clear-_cpu.patch.
- Refresh patches.suse/0002-firmware-define-pr_fmt.patch.
- Refresh
  patches.suse/0003-firmware-enable-a-debug-print-for-batched-requests.patch.
- Refresh
  patches.suse/09-crypto-ccp-use-devres-interface-to-allocate-pci-iomap-and-cleanup.patch.
- Refresh patches.suse/block-add-a-__disk_get_part-helper.patch.
- Refresh
  patches.suse/block-cache-the-partition-index-in-struct-block_devi.patch.
- Refresh
  patches.suse/block-reject-attempts-to-allocate-more-than-DISK_MAX.patch.
- Refresh
  patches.suse/block-replace-bi_bdev-with-a-gendisk-pointer-and-par.patch.
- Refresh patches.suse/block-tolerate-tracing-of-NULL-bio.patch.
- Refresh
  patches.suse/btrfs-Take-trans-lock-before-access-running-trans-in.patch.
- Refresh
  patches.suse/btrfs-account-for-pinned-bytes-in-should_alloc_chunk.patch.
- Refresh
  patches.suse/btrfs-avoid-losing-data-raid-profile-when-deleting-a-device.patch.
- Refresh
  patches.suse/btrfs-fix-crash-due-to-not-cleaning-up-tree-log-block-s-dirty-bits.patch.
- Refresh
  patches.suse/btrfs-fix-deadlock-in-run_delalloc_nocow.patch.
- Refresh
  patches.suse/btrfs-fix-extent-state-leak-from-tree-log.patch.
- Refresh
  patches.suse/btrfs-fix-readdir-deadlock-with-pagefault.patch.
- Refresh
  patches.suse/btrfs-fix-unexpected-eexist-when-creating-new-inode.patch.
- Refresh
  patches.suse/btrfs-incremental-send-fix-emission-of-invalid-clone-operations.patch.
- Refresh
  patches.suse/btrfs-incremental-send-fix-wrong-unlink-path-after-renaming-file.patch.
- Refresh
  patches.suse/btrfs-index-check-integrity-state-hash-by-a-dev_t.patch.
- Refresh
  patches.suse/btrfs-preserve-i_mode-if-_btrfs_set_acl-fails.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Add-Skylake-servers-support.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Clean-up-after-performance-governor-changes.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Drop-get-from-intel_pstate-structure.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Fix-ratio-setting-for-min_perf_pct.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Improve-IO-performance-with-per-core-P-states.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Remove-max-min-fractions-to-limit-performance.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Replace-bxt_funcs-with-core_funcs.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-constify-attribute_group-structures.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-report-correct-CPU-frequencies-during-trace.patch.
- Refresh
  patches.suse/cpufreq-schedutil-Fix-sugov_start-versus-sugov_update_shared-race.patch.
- Refresh
  patches.suse/cpuidle-menu-allow-state-0-to-be-disabled.patch.
- Refresh
  patches.suse/intel_pstate-delete-scheduler-hook-in-HWP-mode.patch.
- Refresh
  patches.suse/intel_pstate-skip-scheduler-hook-when-in-performance-mode.patch.
- Refresh
  patches.suse/intel_pstate-use-updated-msr-index.h-HWP.EPP-values.patch.
- Refresh
  patches.suse/mm-fix-the-NULL-mapping-case-in-__isolate_lru_page.patch.
- Refresh
  patches.suse/raid5-remove-a-call-to-get_start_sect.patch.
- Refresh
  patches.suse/suse-hv-hv_netvsc-enable-multicast-if-necessary.patch.
- Refresh
  patches.suse/x86-msr-index.h-define-EPB-mid-points.patch.
- Refresh
  patches.suse/x86-msr-index.h-define-HWP.EPP-values.patch.
- Refresh
  patches.suse/x86-msr-index.h-fix-shifts-to-ULL-results-in-HWP-macros.patch.
- commit 2767cf1
* Fri Aug 31 2018 bpoirier@suse.com
- Update outdated Patch-mainline tags ("next release")
- Refresh
  patches.arch/powerpc-eeh-Fix-crashes-in-eeh_report_resume.patch.
- Refresh
  patches.drivers/ACPI-watchdog-Fix-off-by-one-error-at-resource-assig.
- Refresh
  patches.drivers/ALSA-hda-Revert-power_save-option-default-value.
- Refresh
  patches.drivers/ALSA-seq-Clear-client-entry-before-deleting-else-at-.
- Refresh
  patches.drivers/ALSA-seq-Fix-possible-UAF-in-snd_seq_check_queue.
- Refresh
  patches.drivers/Bluetooth-btusb-Fix-quirk-for-Atheros-1525-QCA6174.
- Refresh
  patches.drivers/HID-debug-check-length-before-copy_to_user.
- Refresh
  patches.drivers/Partial-revert-e1000e-Avoid-receiver-overrun-interru.patch.
- Refresh
  patches.drivers/Revert-e1000e-Separate-signaling-for-link-check-link.patch.
- Refresh
  patches.drivers/drm-i915-Specify-which-engines-to-reset-following-se.
- Refresh
  patches.drivers/e1000e-Avoid-missed-interrupts-following-ICR-read.patch.
- Refresh
  patches.drivers/e1000e-Fix-check_for_link-return-value-with-autoneg-.patch.
- Refresh
  patches.drivers/e1000e-Fix-link-check-race-condition.patch.
- Refresh
  patches.drivers/e1000e-Fix-queue-interrupt-re-raising-in-Other-inter.patch.
- Refresh patches.drivers/e1000e-Remove-Other-from-EIAC.patch.
- Refresh
  patches.drivers/e1000e-allocate-ring-descriptors-with-dma_zalloc_coh.patch.
- Refresh
  patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh
  patches.drivers/ibmvnic-Clear-pending-interrupt-after-device-reset.patch.
- Refresh
  patches.drivers/ibmvnic-Define-vnic_login_client_data-name-field-as-.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-notify-peers-on-parameter-change-rese.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-non-fatal-firmware-error-reset.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-pending-MAC-address-changes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-statistics-buffers-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh
  patches.drivers/ibmvnic-Free-coherent-DMA-memory-if-FW-map-failed.patch.
- Refresh
  patches.drivers/ibmvnic-Handle-all-login-error-conditions.patch.
- Refresh
  patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- Refresh patches.drivers/net-hns-Fix-ethtool-private-flags.patch.
- Refresh
  patches.drivers/nvme-pci-take-sglist-coalescing-in-dma_map_sg-into-a.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-crashes-in-qla2x00_probe_one-on-pro.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-FC_NO_LOOP_ID-for-FCP-and-FC-NVM.patch.
- Refresh
  patches.fixes/ipc-shm.c-add-split-function-to-shm_vm_ops.patch.
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-ppp-session-destroy.patch.
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-tunnel-destroy.patch.
- Refresh
  patches.fixes/l2tp-fix-race-in-pppol2tp_release-with-session-objec.patch.
- Refresh
  patches.fixes/l2tp-fix-races-with-tunnel-socket-close.patch.
- Refresh
  patches.fixes/l2tp-fix-tunnel-lookup-use-after-free-race.patch.
- Refresh
  patches.suse/bpf-array-fix-overflow-in-max_entries-and-undefined-.patch.
- commit 69f0e65
* Fri Aug 31 2018 bpoirier@suse.com
- Fix invalid Patch-mainline tags (stable)
  Some patches in the sorted section have a Patch-mainline tag indicating
  that they are backports of a stable tree commit but have a Git-commit tag
  pointing to the original mainline commit. Fix this mismatch by updating the
  Patch-mainline tag so that it corresponds with the Git-commit.
- Refresh
  patches.fixes/4.4.129-040-powerpc-powernv-Handle-unknown-OPAL-errors-in.patch.
- Refresh
  patches.fixes/4.4.129-041-powerpc-64-Fix-smp_wmb-barrier-definition-use.patch.
- Refresh
  patches.fixes/4.4.129-042-powerpc-powernv-define-a-standard-delay-for-O.patch.
- Refresh
  patches.fixes/4.4.129-043-powerpc-powernv-Fix-OPAL-NVRAM-driver-OPAL_BU.patch.
- Refresh
  patches.fixes/4.4.129-086-powerpc-eeh-Fix-enabling-bridge-MMIO-windows.patch.
- Refresh
  patches.fixes/4.4.133-056-powerpc-powernv-Fix-NVRAM-sleep-in-invalid-co.patch.
- Refresh
  patches.fixes/4.4.134-183-powerpc-mpic-Check-if-cpu_possible-in-mpic_ph.patch.
- Refresh
  patches.fixes/4.4.134-214-powerpc-Add-missing-prototype-for-arch_irq_wo.patch.
- Refresh
  patches.fixes/4.4.136-002-powerpc-64s-Clear-PCR-on-boot.patch.
- Refresh
  patches.fixes/4.4.139-043-powerpc-mm-hash-Add-missing-isync-prior-to-ke.patch.
- Refresh
  patches.fixes/4.4.139-044-powerpc-ptrace-Fix-setting-512B-aligned-break.patch.
- Refresh
  patches.fixes/4.4.139-047-powerpc-fadump-Unregister-fadump-on-kexec-dow.patch.
- Refresh
  patches.fixes/xfs-fix-incorrect-extent-state-in-xfs_bmap_ad.patch.
- Refresh
  patches.fixes/xfs-fix-log-block-underflow-during-recovery-c.patch.
- Refresh
  patches.fixes/xfs-quota-check-result-of-register_shrinker.patch.
- Refresh
  patches.fixes/xfs-quota-fix-missed-destroy-of-qi_tree_lock.patch.
- Refresh patches.fixes/xfs-ubsan-fixes.patch.
- commit 899fef6
* Fri Aug 31 2018 bpoirier@suse.com
- Fix invalid Patch-mainline tags ("next-release")
  Some patches are tagged with something of the form
  "v4.14 or v4.13-rc6 (next release)"
  When properly used, the two kernel versions in this tag should be the same.
  Additionally, in some cases, the actual tagged version is neither of the
  two listed alternatives.
  Update these patches. In all cases, enough time has passed that the
  ambiguity is lifted.
- Refresh
  patches.arch/01-x86-cpu-amd-document-amd-secure-memory-encryption-sme.patch.
- Refresh
  patches.arch/01-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
- Refresh
  patches.arch/02-x86-mm-pat-set-write-protect-cache-mode-for-full-pat-support.patch.
- Refresh
  patches.arch/02-x86-retpoline-add-lfence-to-the-retpoline-rsb-filling-rsb-macros.patch.
- Refresh
  patches.arch/03-x86-mpparse-x86-acpi-x86-pci-x86-dmi-sfi-use-memremap-for-ram-mappings.patch.
- Refresh
  patches.arch/04-x86-cpu-amd-add-the-secure-memory-encryption-cpu-feature.patch.
- Refresh
  patches.arch/05-x86-cpu-amd-handle-sme-reduction-in-physical-address-size.patch.
- Refresh
  patches.arch/05-x86-cpufeature-move-processor-tracing-out-of-scattered-features.patch.
- Refresh
  patches.arch/06-module-add-retpoline-tag-to-vermagic.patch.
- Refresh
  patches.arch/06-x86-mm-add-secure-memory-encryption-sme-support.patch.
- Refresh
  patches.arch/07-x86-mm-remove-phys_to_virt-usage-in-ioremap.patch.
- Refresh
  patches.arch/08-x86-mm-add-support-to-enable-sme-in-early-boot-processing.patch.
- Refresh patches.arch/09-x86-mm-simplify-pd_page-macros.patch.
- Refresh
  patches.arch/10-x86-mm-provide-general-kernel-support-for-memory-encryption.patch.
- Refresh
  patches.arch/11-x86-mm-add-sme-support-for-read_cr3_pa.patch.
- Refresh
  patches.arch/12-x86-mm-extend-early_memremap-support-with-additional-attrs.patch.
- Refresh
  patches.arch/13-x86-mm-add-support-for-early-encryption-decryption-of-memory.patch.
- Refresh
  patches.arch/14-x86-mm-insure-that-boot-memory-areas-are-mapped-properly.patch.
- Refresh
  patches.arch/15-x86-boot-e820-add-support-to-determine-the-e820-type-of-an-address.patch.
- Refresh
  patches.arch/16-efi-add-an-efi-table-address-match-function.patch.
- Refresh
  patches.arch/17-efi-update-efi_mem_type-to-return-an-error-rather-than-0.patch.
- Refresh
  patches.arch/18-x86-efi-update-efi-pagetable-creation-to-work-with-sme.patch.
- Refresh
  patches.arch/19-x86-mm-add-support-to-access-boot-related-data-in-the-clear.patch.
- Refresh
  patches.arch/20-x86-boot-use-memremap-to-map-the-mpf-and-mpc-data.patch.
- Refresh
  patches.arch/21-x86-mm-add-support-to-access-persistent-memory-in-the-clear.patch.
- Refresh
  patches.arch/22-x86-mm-add-support-for-changing-the-memory-encryption-attribute.patch.
- Refresh
  patches.arch/23-x86-realmode-decrypt-trampoline-area-if-memory-encryption-is-active.patch.
- Refresh
  patches.arch/24-x86-swiotlb-add-memory-encryption-support.patch.
- Refresh
  patches.arch/25-swiotlb-add-warnings-for-use-of-bounce-buffers-with-sme.patch.
- Refresh
  patches.arch/26-x86-cpu-amd-make-the-microcode-level-available-earlier-in-the-boot.patch.
- Refresh
  patches.arch/27-iommu-amd-allow-the-amd-iommu-to-work-with-memory-encryption.patch.
- Refresh
  patches.arch/28-x86-boot-realmode-check-for-memory-encryption-on-the-aps.patch.
- Refresh
  patches.arch/29-x86-drm-fbdev-do-not-specify-encrypted-memory-for-video-mappings.patch.
- Refresh
  patches.arch/30-kvm-x86-svm-support-secure-memory-encryption-within-kvm.patch.
- Refresh
  patches.arch/31-x86-mm-kexec-allow-kexec-to-be-used-with-sme.patch.
- Refresh
  patches.arch/32-xen-x86-remove-sme-feature-in-pv-guests.patch.
- Refresh
  patches.arch/33-x86-mm-use-proper-encryption-attributes-with-dev-mem.patch.
- Refresh
  patches.arch/34-x86-mm-create-native_make_p4d-for-pgtable_levels-4.patch.
- Refresh
  patches.arch/35-x86-mm-add-support-to-encrypt-the-kernel-in-place.patch.
- Refresh
  patches.arch/36-x86-boot-add-early-cmdline-parsing-for-options-with-arguments.patch.
- Refresh
  patches.arch/37-compiler-gcc-h-introduce-_nostackprotector-function-attribute.patch.
- Refresh
  patches.arch/38-x86-mm-add-support-to-make-use-of-secure-memory-encryption.patch.
- Refresh
  patches.arch/39-x86-boot-fix-memremap-related-build-failure.patch.
- Refresh
  patches.arch/40-x86-mm-kexec-fix-memory-corruption-with-sme-on-successive-kexecs.patch.
- Refresh
  patches.arch/41-acpi-x86-mm-remove-encryption-mask-from-acpi-page-protection-type.patch.
- Refresh
  patches.arch/42-x86-mm-fix-sme-encryption-stack-ptr-handling.patch.
- Refresh
  patches.drivers/0033-scsi-libsas-align-sata_device-s-rps_resp-on-a-cachel.patch.
- Refresh
  patches.drivers/bnxt_en-Fix-population-of-flow_type-in-bnxt_hwrm_cfa.patch.
- Refresh
  patches.drivers/bnxt_en-Fix-the-Invalid-VF-id-check-in-bnxt_vf_ndo_p.patch.
- Refresh
  patches.drivers/nvme-fc-remove-double-put-reference-if-admin-connect.patch.
- Refresh
  patches.fixes/jfs-fix-inconsistency-between-memory-allocation-and-ea_buf-max_size.patch.
- Refresh
  patches.fixes/keys-return-full-count-in-keyring_read-if-buffer-is-too-small.
- Refresh
  patches.fixes/kvm-x86-fix-device-passthrough-when-sme-is-active.patch.
- Refresh
  patches.suse/btrfs-add-missing-initialization-in-btrfs_check_shared.patch.
- Refresh
  patches.suse/include-psp-sev-capitalize-invalid-length-enum.patch.
- Refresh
  patches.suse/kvm-svm-fix-sev-launch_secret-command.patch.
- Refresh
  patches.suse/kvm-svm-no-need-to-call-access_ok-in-launch_measure-command.patch.
- Refresh
  patches.suse/kvm-x86-remove-indirect-msr-op-calls-from-spec_ctrl.patch.
- commit 8ee956f
* Fri Aug 31 2018 bpoirier@suse.com
- Update outdated Patch-mainline and Git-repo tags
  Some patches which backport commits part of a mainline release are still
  tagged as "Queued ...". Update them for accuracy.
- Refresh
  patches.arch/44-x86-mm-Unbreak-modules-that-rely-on-external-PAGE_KERNEL-availability.patch.
- Refresh
  patches.drivers/IB-core-Fix-qp_sec-use-after-free-access.patch.
- Refresh
  patches.drivers/IB-core-Fix-typo-in-the-name-of-the-tag-matching-cap.patch.
- Refresh
  patches.drivers/IB-hfi1-Check-eeprom-config-partition-validity.patch.
- Refresh
  patches.drivers/IB-hfi1-Unsuccessful-PCIe-caps-tuning-should-not-fai.patch.
- Refresh
  patches.drivers/IB-ipoib-Fix-sysfs-Pkey-create-remove-possible-deadl.patch.
- Refresh
  patches.drivers/IB-mlx5-Fix-NULL-deference-on-mlx5_ib_update_xlt-fai.patch.
- Refresh
  patches.drivers/qed-Fix-reading-stale-configuration-information.patch.
- Refresh
  patches.fixes/Fix-up-non-directory-creation-in-SGID-directories.patch.
- Refresh
  patches.fixes/test_bpf-Fix-testing-with-CONFIG_BPF_JIT_ALWAYS_ON-y.patch.
- Refresh
  patches.suse/cpufreq-intel_pstate-Limit-the-scope-of-HWP-dynamic-.patch.
- commit 56146a0
* Thu Aug 30 2018 oneukum@suse.com
- blacklist.conf: only reduces memory consumption
- commit 2fe52b4
* Thu Aug 30 2018 oneukum@suse.com
- PM / runtime: Drop usage count for suppliers at device link
  removal (bsc#1100132).
- commit f99e8a2
* Thu Aug 30 2018 oneukum@suse.com
- blacklist.conf: changes semantics and profiles for PM
- commit 4cb9d15
* Thu Aug 30 2018 oneukum@suse.com
- blacklist.conf: changes semantics of PM calls
- commit e02278a
* Thu Aug 30 2018 oneukum@suse.com
- blacklist.conf: breaks sysfs users
- commit 658f5b6
* Thu Aug 30 2018 oneukum@suse.com
- blacklist.conf: breaks sysfs users
- commit 3a30808
* Thu Aug 30 2018 ykaukab@suse.de
- arm64: move patches to sorted section
- Refresh
  patches.arch/0003-arm-arm64-smccc-Add-SMCCC-specific-return-codes.patch.
- Refresh
  patches.arch/0004-arm64-Call-ARCH_WORKAROUND_2-on-transitions-between-.patch.
- Refresh
  patches.arch/0005-arm64-Add-per-cpu-infrastructure-to-call-ARCH_WORKAR.patch.
- Refresh
  patches.arch/0006-arm64-Add-ARCH_WORKAROUND_2-probing.patch.
- Refresh
  patches.arch/0007-arm64-Add-ssbd-command-line-option.patch.
- Refresh
  patches.arch/0008-arm64-ssbd-Add-global-mitigation-state-accessor.patch.
- Refresh
  patches.arch/0009-arm64-ssbd-Skip-apply_ssbd-if-not-using-dynamic-miti.patch.
- Refresh
  patches.arch/0010-arm64-ssbd-Restore-mitigation-status-on-CPU-resume.patch.
- Refresh
  patches.arch/0011-arm64-ssbd-Introduce-thread-flag-to-control-userspac.patch.
- Refresh
  patches.arch/0012-arm64-ssbd-Add-prctl-interface-for-per-thread-mitiga.patch.
- Refresh
  patches.drivers/0001-crypto-cavium-Fix-fallout-from-CONFIG_VMAP_STACK.patch.
- Refresh
  patches.drivers/0002-crypto-cavium-Limit-result-reading-attempts.patch.
- Refresh
  patches.drivers/0002-i2c-xlp9xx-return-ENXIO-on-slave-address-NACK.patch.
- Refresh
  patches.drivers/0002-phy-qcom-ufs-add-MODULE_LICENSE-tag.patch.
- Refresh
  patches.drivers/0003-crypto-cavium-Prevent-division-by-zero.patch.
- Refresh
  patches.drivers/0003-i2c-xlp9xx-Handle-transactions-with-I2C_M_RECV_LEN-p.patch.
- Refresh
  patches.drivers/0004-crypto-cavium-Fix-statistics-pending-request-value.patch.
- Refresh
  patches.drivers/0005-crypto-cavium-Fix-smp_processor_id-warnings.patch.
- Refresh
  patches.drivers/0012-PCI-Probe-for-device-reset-support-during-enumeratio.patch.
- Refresh
  patches.drivers/0013-PCI-Remove-redundant-probes-for-device-reset-support.patch.
- Refresh
  patches.drivers/0016-ACPI-IORT-Add-msi-address-regions-reservation-helper.patch.
- commit d5ee297
* Thu Aug 30 2018 tiwai@suse.de
- PCI: pciehp: Fix use-after-free on unplug (bsc#1051510).
- PCI: hotplug: Don't leak pci_slot on registration failure
  (bsc#1051510).
- commit 25eff09
* Thu Aug 30 2018 tiwai@suse.de
- lib/test_hexdump.c: fix failure on big endian cpu (bsc#1051510).
- commit 931b8a5
* Thu Aug 30 2018 tiwai@suse.de
- crypto: caam/qi - fix error path in xts setkey (bsc#1051510).
- crypto: caam/jr - fix descriptor DMA unmapping (bsc#1051510).
- commit fb8ae18
* Wed Aug 29 2018 pvorel@suse.cz
- Apply e666d4e9ceec crypto: vmx - Use skcipher for ctr fallback
  to SLE12-SP4 (bsc#1106464).
- Refresh
  patches.drivers/crypto-vmx-Remove-overly-verbose-printk-from-AES-ini.
- commit c922d6f
* Wed Aug 29 2018 rgoldwyn@suse.com
- Apparmor fixes from git-fixes
- apparmor: ensure that undecidable profile attachments fail (bsc#1106427).
- apparmor: fix an error code in __aa_create_ns() (bsc#1106427).
- apparmor: remove no-op permission check in policy_unpack
  (bsc#1106427).
- apparmor: Fix regression in profile conflict logic
  (bsc#1106427)
- Refreshed
  patches.apparmor/0001-apparmor-fix-profile-attachment-for-special-unconfin.patch
- commit ce5df95
* Wed Aug 29 2018 tiwai@suse.de
- thermal_hwmon: Pass the originating device down to
  hwmon_device_register_with_info (bsc#1103363).
- thermal_hwmon: Sanitize attribute name passed to hwmon
  (bsc#1103363).
- thermal: thermal_hwmon: Convert to
  hwmon_device_register_with_info() (bsc#1103363).
- commit f41fe4d
* Wed Aug 29 2018 mhocko@suse.com
- x86/init: fix build with CONFIG_SWAP=n (bnc#1106121).
- commit 15c1cf0
* Wed Aug 29 2018 mkubecek@suse.cz
- Cipso: cipso_v4_optptr enter infinite loop (CVE-2018-10938
  bsc#1106016).
- commit 4af59dd
* Wed Aug 29 2018 gqjiang@suse.com
- md-cluster: don't send msg if array is closing (bsc#1106333).
- md-cluster: show array's status more accurate (bsc#1106333).
- md-cluster: clear another node's suspend_area after the copy
  is finished (bsc#1106333).
- commit 99939e9
* Tue Aug 28 2018 rgoldwyn@suse.com
- Filesystem and FUSE fixes from upstream
- f2fs: remove unneeded memory footprint accounting (bsc#1106297).
- f2fs: validate before set/clear free nat bitmap (bsc#1106297).
- fix __legitimize_mnt()/mntput() race (bsc#1106297).
- fix mntput/mntput race (bsc#1106297).
- fs/proc/proc_sysctl.c: fix potential page fault while
  unregistering sysctl table (bsc#1106297).
- fuse: Add missed unlock_page() to fuse_readpages_fill()
  (bsc#1106291).
- fuse: Fix oops at process_init_reply() (bsc#1106291).
- fuse: fix double request_end() (bsc#1106291).
- fuse: fix initial parallel dirops (bsc#1106291).
- fuse: fix unlocked access to processing queue (bsc#1106291).
- fuse: umount should wait for all requests (bsc#1106291).
- getxattr: use correct xattr length (bsc#1106297).
- pipe: actually allow root to exceed the pipe buffer limits
  (bsc#1106297).
- root dentries need RCU-delayed freeing (bsc#1106297).
- Refresh
  patches.fixes/pipe-fix-off-by-one-error-when-checking-buffer-limit.patch.
- commit 2fb5115
* Tue Aug 28 2018 jroedel@suse.de
- x86/kvm: fix LAPIC timer drift when guest uses periodic mode (bsc#1106240).
- commit ad93d53
* Tue Aug 28 2018 jroedel@suse.de
- KVM: x86: fix APIC page invalidation (bsc#1106240).
- commit c5ec8b3
* Tue Aug 28 2018 tiwai@suse.de
- lan78xx: Lan7801 Support for Fixed PHY (bsc#1085262).
- commit 8e83fff
* Tue Aug 28 2018 jroedel@suse.de
- KVM: nVMX: Fix injection to L2 when L1 don't intercept
  external-interrupts (bsc#1106240).
- KVM: nVMX: Re-evaluate L1 pending events when running L2 and
  L1 got posted-interrupt (bsc#1106240).
- KVM: x86: Change __kvm_apic_update_irr() to also return if
  max IRR updated (bsc#1106240).
- commit d6a7729
* Tue Aug 28 2018 tiwai@suse.de
- lan78xx: remove redundant initialization of pointer 'phydev'
  (bsc#1085262).
- commit 0d9dc95
* Tue Aug 28 2018 tiwai@suse.de
- lan78xx: Set ASD in MAC_CR when EEE is enabled (bsc#1085262).
- Refresh
  patches.suse/bsc1084332-0003-lan78xx-Enable-LEDs-and-auto-negotiation.patch.
- commit 730e995
* Tue Aug 28 2018 tiwai@suse.de
- Refresh with the upstream patches for lan78xx fixes (bsc#1085262)
  Also moved to sorted section
- commit 345b729
* Tue Aug 28 2018 jroedel@suse.de
- KVM: Enforce error in ioctl for compat tasks when !KVM_COMPAT (bsc#1106240).
- commit 630d41f
* Tue Aug 28 2018 jroedel@suse.de
- KVM: nVMX: Don't flush TLB when vmcs12 uses VPID (bsc#1106240).
- commit 652ae7c
* Tue Aug 28 2018 jroedel@suse.de
- KVM: nVMX: Fix races when sending nested PI while dest enters/leaves L2 (bsc#1106240).
- commit 8141888
* Tue Aug 28 2018 msuchanek@suse.de
- KABI: tpm: do keep the cmd_ready and go_idle as pm ops
  (bsc#1082555).
- KABI: tpm: change relinquish_locality return value back to void
  (bsc#1082555).
- commit cfc9ac9
* Tue Aug 28 2018 msuchanek@suse.de
- tpm: separate cmd_ready/go_idle from runtime_pm (bsc#1082555).
- tpm: tpm_crb: relinquish locality on error path (bsc#1082555).
- tpm: cmd_ready command can be issued only after granting
  locality (bsc#1082555).
- tpm: vtpm_proxy: Implement request_locality function
  (bsc#1082555).
- tpm: Introduce flag TPM_TRANSMIT_RAW (bsc#1082555).
- commit 55c64dd
* Tue Aug 28 2018 bp@suse.de
- x86/vdso: Fix vDSO build if a retpoline is emitted (git-fixes
  76b043848fd2).
- commit b796688
* Tue Aug 28 2018 jroedel@suse.de
- kvm: x86: vmx: fix vpid leak (bsc#1106240).
- kvm: nVMX: Use nested_run_pending rather than from_vmentry
  (bsc#1106240).
- KVM/x86: remove WARN_ON() for when vm_munmap() fails
  (bsc#1106240).
- commit e9778df
* Tue Aug 28 2018 jthumshirn@suse.de
- libnvdimm, btt: fix uninitialized err_lock (bsc#1103961).
- libnvdimm: rename nd_sector_size_{show,store} to
  nd_size_select_{show,store} (bsc#1103961).
- libnvdimm, nfit: enable support for volatile ranges
  (bsc#1103961).
- commit 5166982
* Tue Aug 28 2018 jroedel@suse.de
- iommu/arm-smmu-v3: Don't free page table ops twice (bsc#1106237).
- commit b284a77
* Tue Aug 28 2018 jack@suse.cz
- block, bfq: return nbytes and not zero from struct cftype
  .write() method (bsc#1106238).
- commit bcb0c5f
* Tue Aug 28 2018 jack@suse.cz
- reiserfs: fix broken xattr handling (heap corruption, bad
  retval) (bsc#1106236).
- commit 8cb0131
* Tue Aug 28 2018 jack@suse.cz
- getxattr: use correct xattr length (bsc#1106235).
- commit 3823b92
* Tue Aug 28 2018 jack@suse.cz
- f2fs: remove unneeded memory footprint accounting (bsc#1106233).
- commit 4e0cd5b
* Tue Aug 28 2018 jack@suse.cz
- f2fs: validate before set/clear free nat bitmap (bsc#1106231).
- commit 720d1f7
* Tue Aug 28 2018 jack@suse.cz
- ubifs: Fix directory size calculation for symlinks
  (bsc#1106230).
- commit 8e56a6f
* Tue Aug 28 2018 jack@suse.cz
- ext4: sysfs: print ext4_super_block fields as little-endian
  (bsc#1106229).
- commit 3ae063e
* Tue Aug 28 2018 tiwai@suse.de
- video: fbdev: pxafb: clear allocated memory for video modes
  (bsc#1051510).
- commit e46a180
* Tue Aug 28 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm: add missing ctx argument to plane transitional helpers'
- commit 084be65
* Tue Aug 28 2018 jack@suse.cz
- blacklist.conf: Blacklist c10f778ddfc1
- commit 65e7761
* Tue Aug 28 2018 tzimmermann@suse.de
- drm/tegra: Fix comparison operator for buffer size (bsc#1100132).
- commit 120cf74
* Mon Aug 27 2018 msuchanek@suse.de
- powerpc/kprobes: Fix call trace due to incorrect preempt count
  (bsc#1065729).
- commit d9f2095
* Mon Aug 27 2018 msuchanek@suse.de
- KVM: PPC: Book3S: Fix guest DMA when guest partially backed
  by THP pages (bsc#1077761, git-fixes, bsc#1103948, bsc#1103949).
- commit f8b5434
* Mon Aug 27 2018 ohering@suse.de
- Tools: hv: vss: fix loop device detection (fate#323887).
- commit adec91f
* Mon Aug 27 2018 jroedel@suse.de
- kvm: nVMX: Fix fault vector for VMX operation at CPL > 0
  (bsc#1106105).
- iommu/amd: Finish TLB flush in amd_iommu_unmap() (bsc#1106105).
- iommu/amd: make sure TLB to be flushed before IOVA freed
  (bsc#1106105).
- iommu/vt-d: Fix a potential memory leak (bsc#1106105).
- iommu/vt-d: Ratelimit each dmar fault printing (bsc#1106105).
- blacklist.conf:
- Refresh
  patches.arch/x86-sched-allow-topologies-where-numa-nodes-share-an-llc.patch.
- commit 0278c0c
* Mon Aug 27 2018 tiwai@suse.de
- drm/armada: fix irq handling (bsc#1051510).
- drm/armada: fix colorkey mode property (bsc#1051510).
- drm/exynos: decon5433: Fix WINCONx reset value (bsc#1051510).
- drm/exynos: decon5433: Fix per-plane global alpha for XRGB modes
  (bsc#1051510).
- drm/exynos: gsc: Fix support for NV16/61, YUV420/YVU420 and
  YUV422 modes (bsc#1051510).
- drm/bridge/sii8620: Fix display of packed pixel modes
  (bsc#1051510).
- drm/arm/malidp: Preserve LAYER_FORMAT contents when setting
  format (bsc#1051510).
- drm: mali-dp: Enable Global SE interrupts mask for DP500
  (bsc#1051510).
- drm/bridge/sii8620: fix display of packed pixel modes in MHL2
  (bsc#1051510).
- drm/bridge/sii8620: fix loops in EDID fetch logic (bsc#1051510).
- commit 2fb9f1b
* Mon Aug 27 2018 tzimmermann@suse.de
- drm/tegra: Check for malformed offsets and sizes in the 'submit' IOCTL (bsc#1106170).
- commit e00a923
* Mon Aug 27 2018 tiwai@suse.de
- ARM: imx: flag failure of of_iomap (bsc#1051510).
- ARM: hisi: handle of_iomap and fix missing of_node_put
  (bsc#1051510).
- ARM: hisi: fix error handling and missing of_node_put
  (bsc#1051510).
- ARM: DRA7/OMAP5: Enable ACTLR[0] (Enable invalidates of BTB)
  for secondary cores (bsc#1051510).
- ARM: pxa: irq: fix handling of ICMR registers in suspend/resume
  (bsc#1051510).
- ARM: 8780/1: ftrace: Only set kernel memory back to read-only
  after boot (bsc#1051510).
- ARM: imx_v4_v5_defconfig: Select ULPI support (bsc#1051510).
- ARM: imx_v6_v7_defconfig: Select ULPI support (bsc#1051510).
- commit 0e3c5de
* Mon Aug 27 2018 tiwai@suse.de
- ACPI / EC: Add another entry for Thinkpad X1 Carbon 6th
  (bsc#1051510).
- ACPI / EC: Use ec_no_wakeup on ThinkPad X1 Yoga 3rd
  (bsc#1051510).
- ACPI / EC: Use ec_no_wakeup on more Thinkpad X1 Carbon 6th
  systems (bsc#1051510).
- ACPI / EC: Use ec_no_wakeup on Thinkpad X1 Carbon 6th
  (bsc#1051510).
- ACPI / EC: Add parameter to force disable the GPE on suspend
  (bsc#1051510).
- commit 1138c0c
* Mon Aug 27 2018 tiwai@suse.de
- fat: fix memory allocation failure handling of match_strdup()
  (bsc#1051510).
- commit f52e3e9
* Mon Aug 27 2018 tiwai@suse.de
- Input: edt-ft5x06 - fix error handling for factory mode on
  non-M06 (bsc#1051510).
- Input: edt-ft5x06 - implement support for the EDT-M12 series
  (bsc#1051510).
- Input: edt-ft5x06 - make distinction between m06/m09/generic
  more clear (bsc#1051510).
- commit c90db2d
* Mon Aug 27 2018 tiwai@suse.de
- irqchip/bcm7038-l1: Hide cpu offline callback when building
  for !SMP (bsc#1051510).
- commit 828545b
* Mon Aug 27 2018 tiwai@suse.de
- PM / Domains: Fix error path during attach in genpd
  (bsc#1051510).
- commit 652af00
* Mon Aug 27 2018 mbenes@suse.cz
- module: exclude SHN_UNDEF symbols from kallsyms api
  (bsc#1071995).
- commit e106f34
* Mon Aug 27 2018 tiwai@suse.de
- pwm: tiehrpwm: Fix disabling of output of PWMs (bsc#1051510).
- commit 1bfb3de
* Mon Aug 27 2018 tiwai@suse.de
- ubifs: Check data node size before truncate (bsc#1051510).
- ubifs: xattr: Don't operate on deleted inodes (bsc#1051510).
- ubifs: Fix memory leak in lprobs self-check (bsc#1051510).
- ubifs: Fix synced_i_size calculation for xattr inodes
  (bsc#1051510).
- commit 32af19d
* Mon Aug 27 2018 tiwai@suse.de
- usb: xhci: increase CRS timeout value (bsc#1051510).
- usb: gadget: dwc2: fix memory leak in gadget_init()
  (bsc#1051510).
- usb: gadget: composite: fix delayed_status race condition when
  set_interface (bsc#1051510).
- usb: dwc2: fix isoc split in transfer with no data
  (bsc#1051510).
- usb: dwc2: gadget: Fix issue in dwc2_gadget_start_isoc()
  (bsc#1051510).
- usb: dwc3: pci: add support for Intel IceLake (bsc#1051510).
- commit 615b8ac
* Mon Aug 27 2018 mhocko@suse.com
- kabi: x86/speculation/l1tf: Increase l1tf memory limit for
  Nehalem+ (bnc#1105536).
- x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+
  (bnc#1105536).
- x86/speculation/l1tf: Suggest what to do on systems with too
  much RAM (bnc#1105536).
- x86/speculation/l1tf: Fix off-by-one error when warning that
  system has too much RAM (bnc#1105536).
- commit ed48a55
* Mon Aug 27 2018 mgorman@suse.de
- Delete patches.suse/x86-mm-tlb-Always-use-lazy-TLB-mode.patch.
- Delete patches.suse/x86-mm-tlb-Leave-lazy-TLB-mode-at-page-table-free-time.patch.
- Delete patches.suse/x86-mm-tlb-Make-lazy-TLB-mode-lazier.patch.
- Delete patches.suse/x86-mm-tlb-Only-send-page-table-free-TLB-flush-to-lazy-TLB-CPUs.patch.
- Delete patches.suse/x86-mm-tlb-Restructure-switch_mm_irqs_off.patch.
- Delete patches.suse/x86-mm-tlb-Skip-atomic-operations-for-init_mm-in-switch_mm_irqs_off.patch.
- commit 68ab5c6
* Mon Aug 27 2018 mbenes@suse.cz
- livepatch: Remove reliable stacktrace check in
  klp_try_switch_task() (bsc#1071995).
- commit 4e520b0
* Mon Aug 27 2018 mbenes@suse.cz
- livepatch: Validate module/old func name length (bsc#1071995).
- Refresh patches.suse/livepatch-add-atomic-replace.patch.
- commit 3dddc66
* Mon Aug 27 2018 jthumshirn@suse.de
- dax: remove VM_MIXEDMAP for fsdax and device dax (bsc#1106007).
- commit d533b73
* Mon Aug 27 2018 jslaby@suse.cz
- cls_matchall: fix tcf_unbind_filter missing
  (networking-stable-18_08_21).
- net: mvneta: fix mvneta_config_rss on armada 3700
  (networking-stable-18_08_21).
- net: ethernet: mvneta: Fix napi structure mixup on armada 3700
  (networking-stable-18_08_21).
- commit 9d95eb5
* Mon Aug 27 2018 jslaby@suse.cz
- net: stmmac: mark PM functions as __maybe_unused (git-fixes).
- netlink: Don't shift on 64 for ngroups (git-fixes).
- commit fc97ca9
* Mon Aug 27 2018 tiwai@suse.de
- staging: lustre: Use 'kvfree()' for memory allocated by
  'kvzalloc()' (bsc#1051510).
- staging: lustre: o2iblnd: Fix crash in kiblnd_handle_early_rxs()
  (bsc#1051510).
- staging: lustre: o2iblnd: fix race at kiblnd_connect_peer
  (bsc#1051510).
- staging: lustre: o2iblnd: Fix FastReg map/unmap for MLX5
  (bsc#1051510).
- staging: lustre: llite: correct removexattr detection
  (bsc#1051510).
- staging: lustre: llite: initialize xattr->xe_namelen
  (bsc#1051510).
- staging: lustre: ldlm: free resource when ldlm_lock_create()
  fails (bsc#1051510).
- staging: lustre: remove invariant in cl_io_read_ahead()
  (bsc#1051510).
- staging: lustre: statahead: remove incorrect test on
  agl_list_empty() (bsc#1051510).
- staging: lustre: fix bug in osc_enter_cache_try (bsc#1051510).
- staging: lustre: obd_mount: use correct niduuid suffix
  (bsc#1051510).
- staging: lustre: lmv: correctly iput lmo_root (bsc#1051510).
- staging: lustre: lov: use correct env in
  lov_io_data_version_end() (bsc#1051510).
- staging: lustre: libcfs: Prevent harmless read underflow
  (bsc#1051510).
- staging: lustre: disable preempt while sampling processor id
  (bsc#1051510).
- staging: lustre: ptlrpc: kfree used instead of kvfree
  (bsc#1051510).
- staging: lustre: obdclass: return -EFAULT if copy_from_user()
  fails (bsc#1051510).
- staging: lustre: libcfs: fix test for libcfs_ioctl_hdr minimum
  size (bsc#1051510).
- commit c1ade13
* Mon Aug 27 2018 neilb@suse.com
- NFSv4: Fix a sleep in atomic context in nfs4_callback_sequence()
  (git-fixes).
- NFSv4 client live hangs after live data migration recovery
  (git-fixes).
- pnfs/blocklayout: off by one in bl_map_stripe() (git-fixes).
- NFSv4: Fix possible 1-byte stack overflow in
  nfs_idmap_read_and_verify_message (git-fixes).
- nfsd: remove blocked locks on client teardown (git-fixes).
- nfs41: do not return ENOMEM on LAYOUTUNAVAILABLE (git-fixes).
- nfs/pnfs: fix nfs_direct_req ref leak when i/o falls back to
  the mds (git-fixes).
- commit b16787b
* Mon Aug 27 2018 neilb@suse.com
- blacklist.conf: blacklist lustre
- commit 8d0eb93
* Mon Aug 27 2018 ptesarik@suse.cz
- s390: fix br_r1_trampoline for machines without exrl (git-fixes,
  bsc#1103421).
- commit 7592773
* Sun Aug 26 2018 jslaby@suse.cz
- net_sched: Fix missing res info when create new tc_index filter
  (netfilter-stable-18_08_17).
- net_sched: fix NULL pointer dereference when delete tcindex
  filter (netfilter-stable-18_08_17).
- commit 26110bb
* Sun Aug 26 2018 jslaby@suse.cz
- l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache
  (netfilter-stable-18_08_17).
- commit d4e62c8
* Sun Aug 26 2018 jslaby@suse.cz
- vhost: reset metadata cache when initializing new IOTLB
  (netfilter-stable-18_08_17).
- llc: use refcount_inc_not_zero() for llc_sap_find()
  (netfilter-stable-18_08_17).
- dccp: fix undefined behavior with 'cwnd' shift in
  ccid2_cwnd_restart() (netfilter-stable-18_08_17).
- vsock: split dwork to avoid reinitializations
  (netfilter-stable-18_08_17).
- kABI: protect struct vsock_sock (kabi).
- kABI: reexport vsock_pending_work (kabi).
- mlxsw: core_acl_flex_actions: Return error for conflicting
  actions (netfilter-stable-18_08_17).
- commit 9eed15d
* Sun Aug 26 2018 jslaby@suse.cz
- rxrpc: Fix user call ID check in rxrpc_service_prealloc_one
  (netfilter-stable-18_08_04).
- net: dsa: Do not suspend/resume closed slave_dev
  (netfilter-stable-18_08_04).
- netlink: Fix spectre v1 gadget in netlink_create()
  (netfilter-stable-18_08_04).
- net: stmmac: Fix WoL for PCI-based setups
  (netfilter-stable-18_08_04).
- bonding: avoid lockdep confusion in bond_get_stats()
  (netfilter-stable-18_08_04).
- commit e43380e
* Fri Aug 24 2018 ykaukab@suse.de
- serial: make sc16is7xx driver supported
  References: bsc#1105672
- commit 2e01fee
* Fri Aug 24 2018 msuchanek@suse.de
- tpm: fix race condition in tpm_common_write() (bsc#1082555).
- commit 23bd66e
* Fri Aug 24 2018 msuchanek@suse.de
- tpm: fix use after free in tpm2_load_context() (bsc#1082555).
- commit 934d5ee
* Fri Aug 24 2018 ptesarik@suse.cz
- s390: use expoline thunks for all branches generated by the
  BPF JIT (bsc#1103421).
- commit 4690229
* Fri Aug 24 2018 msuchanek@suse.de
- cxl: Fix wrong comparison in cxl_adapter_context_get()
  (bsc#1055014, git-fixes).
- cxl: Configure PSL to not use APC virtual machines (bsc#1055014,
  git-fixes).
- commit 43f92b3
* Fri Aug 24 2018 ptesarik@suse.cz
- kabi: move s390 mm_context_t lock to mm_struct and ignore the
  change (bsc#1103421).
- s390/mm: fix race on mm->context.flush_mm (bsc#1103421).
- commit 1da3fff
* Fri Aug 24 2018 msuchanek@suse.de
- powerpc/lib: Fix the feature fixup tests to actually work
  (bsc#1065729).
- powerpc: make feature-fixup tests fortify-safe (bsc#1065729).
- commit 93d5bbb
* Fri Aug 24 2018 ptesarik@suse.cz
- s390/mm: fix local TLB flushing vs. detach of an mm address
  space (bsc#1103421).
- commit 209b523
* Fri Aug 24 2018 msuchanek@suse.de
- powerpc/64s: Default l1d_size to 64K in RFI fallback flush
  (bsc#1068032, git-fixes).
- commit 691bb4c
* Fri Aug 24 2018 ptesarik@suse.cz
- s390: fix compat system call table (bsc#1103421).
- commit da13d32
* Fri Aug 24 2018 ptesarik@suse.cz
- s390: always save and restore all registers on context switch
  (bsc#1103421).
- commit 45679c7
* Fri Aug 24 2018 tiwai@suse.de
- Fix kABI breakage due to enum addition for ath10k (bsc#1051510).
- commit 680c7d7
* Fri Aug 24 2018 ptesarik@suse.cz
- s390/runtime instrumentation: simplify task exit handling
  (bsc#1103421).
- commit ff79708
* Fri Aug 24 2018 ptesarik@suse.cz
- s390: fix handling of -1 in set{,fs}id16 syscalls (bsc#1103421).
- commit c15f7ae
* Fri Aug 24 2018 ptesarik@suse.cz
- s390: detect etoken facility (bsc#1103421).
- commit 2a2f8e4
* Fri Aug 24 2018 ptesarik@suse.cz
- s390/entry.S: use assembler alternatives (bsc#1103421).
- Refresh
  patches.arch/s390-move-expoline-assembler-macros-to-a-header.patch.
- commit ff761b9
* Fri Aug 24 2018 tiwai@suse.de
- fbdev: omapfb: off by one in omapfb_register_client()
  (bsc#1051510).
- i2c: imx: Fix race condition in dma read (bsc#1051510).
- drm/i915/kvmgt: Fix potential Spectre v1 (bsc#1051510).
- ath10k: update the phymode along with bandwidth change request
  (bsc#1051510).
- brcmfmac: stop watchdog before detach and free everything
  (bsc#1051510).
- gpu: host1x: Check whether size of unpin isn't 0 (bsc#1051510).
- drm/amdgpu: fix swapped emit_ib_size in vce3 (bsc#1051510).
- nl80211: check nla_parse_nested() return values (bsc#1051510).
- dwc2: gadget: Fix ISOC IN DDMA PID bitfield value calculation
  (bsc#1051510).
- Input: synaptics-rmi4 - fix axis-swap behavior (bsc#1051510).
- commit 74c7c7d
* Fri Aug 24 2018 msuchanek@suse.de
- powerpc/64s: Fix DT CPU features Power9 DD2.1 logic
  (bsc#1055117).
- commit 44ff2dd
* Fri Aug 24 2018 ptesarik@suse.cz
- KVM: s390: force bp isolation for VSIE (bsc#1103421).
- commit 549f198
* Fri Aug 24 2018 ptesarik@suse.cz
- s390/lib: use expoline for all bcr instructions (git-fixes,
  bsc#1103421).
- commit 93ede07
* Fri Aug 24 2018 msuchanek@suse.de
- powerpc64s: Show ori31 availability in spectre_v1 sysfs file
  not v2 (bsc#1068032, bsc#1080157, git-fixes).
- commit 36ff604
* Fri Aug 24 2018 jslaby@suse.cz
- netlink: Don't shift with UB on nlk->ngroups
  (netfilter-stable-18_08_01).
- netlink: Do not subscribe to non-existent groups
  (netfilter-stable-18_08_01).
- NET: stmmac: align DMA stuff to largest cache line length
  (netfilter-stable-18_08_01).
- tcp_bbr: fix bw probing to raise in-flight data for very small
  BDPs (netfilter-stable-18_08_01).
- net: mdio-mux: bcm-iproc: fix wrong getter and setter pair
  (netfilter-stable-18_08_01).
- ipv4: remove BUG_ON() from fib_compute_spec_dst
  (netfilter-stable-18_08_01).
- net: ena: Fix use of uninitialized DMA address bits field
  (netfilter-stable-18_08_01).
- net: fix amd-xgbe flow-control issue
  (netfilter-stable-18_08_01).
- tcp: add one more quick ack after after ECN events
  (netfilter-stable-18_08_01).
- tcp: refactor tcp_ecn_check_ce to remove sk type cast
  (netfilter-stable-18_08_01).
- tcp: do not aggressively quick ack after ECN events
  (netfilter-stable-18_08_01).
- tcp: add max_quickacks param to tcp_incr_quickack and
  tcp_enter_quickack_mode (netfilter-stable-18_08_01).
- Refresh
  patches.suse/tcp-do-not-delay-ACK-in-DCTCP-upon-CE-status-change.patch.
- tcp: do not force quickack when receiving out-of-order packets
  (netfilter-stable-18_08_01).
- commit 6635520
* Fri Aug 24 2018 tiwai@suse.de
- Fix kABI breakage due to additional fields in drm structs
  (FATE#325208).
- drm: Add and handle new aspect ratios in DRM layer
  (FATE#325208).
- drm: Add aspect ratio parsing in DRM layer (FATE#325208).
- drm: Expose modes with aspect ratio, only if requested
  (FATE#325208).
- drm: Handle aspect ratio info in legacy modeset path
  (FATE#325208).
- drm: Add DRM client cap for aspect-ratio (FATE#325208).
- drm/modes: Introduce drm_mode_match() (FATE#325208).
- commit f0895e2
* Fri Aug 24 2018 tbogendoerfer@suse.de
- ixgbe: Refactor queue disable logic to take completion time
  into account (bsc#1101557).
- ixgbe: Reorder Tx/Rx shutdown to reduce time needed to stop
  device (bsc#1101557).
- commit e2ad5f8
* Fri Aug 24 2018 glin@suse.com
- bpf: powerpc64: pad function address loads with NOPs
  (bsc#1083647).
- bpf: fix references to free_bpf_prog_info() in comments
  (bsc#1083647).
- commit 7dcea1d
* Fri Aug 24 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915: Pass hpd_pin to long_pulse_detect()'
- commit f415342
* Fri Aug 24 2018 jack@suse.cz
- ext2: auto disable dax instead of failing mount (bsc#1104888 fate#325574).
  patches.fixes/fs-allow-per-device-dax-status-checking-for-filesystems.patch:
  Refresh
  patches.kabi/kabi-fixup-bdev_dax_supported.patch: Refresh
- commit 98273dd
* Fri Aug 24 2018 jack@suse.cz
- ext4: auto disable dax instead of failing mount (bsc#1104888
  fate#325574).
  patches.fixes/fs-allow-per-device-dax-status-checking-for-filesystems.patch:
  Refresh
  patches.kabi/kabi-fixup-bdev_dax_supported.patch: Refresh
- commit 6720deb
* Fri Aug 24 2018 bpoirier@suse.com
- qlge: Fix netdev features configuration (bsc#1098822).
- commit 952d194
* Fri Aug 24 2018 bpoirier@suse.com
- Cleanup out-of-tree subsection
- commit ae7126b
* Thu Aug 23 2018 jack@suse.cz
- mm, dax: introduce pfn_t_special() (bsc#1104888).
- commit 1544708
* Thu Aug 23 2018 msuchanek@suse.de
- powerpc/perf: Remove sched_task function defined for thread-imc
  (bsc#1054914).
- commit fbbc745
* Thu Aug 23 2018 msuchanek@suse.de
- powerpc/perf: Fix memory allocation for core-imc based on
  num_possible_cpus() (bsc#1054914).
- powerpc/perf: Fix IMC allocation routine (bsc#1054914).
- commit 20c6b1f
* Thu Aug 23 2018 msuchanek@suse.de
- Update
  patches.fixes/4.4.139-043-powerpc-mm-hash-Add-missing-isync-prior-to-ke.patch
  (bnc#1012382, bsc#1094244).
- commit fb6d49a
* Thu Aug 23 2018 msuchanek@suse.de
- powerpc/64s: Fix compiler store ordering to SLB shadow area
  (bsc#1094244).
- commit b08b43e
* Thu Aug 23 2018 jack@suse.cz
- fs, dax: use page->mapping to warn if truncate collides with
  a busy page (bsc#1104888).
- commit c117b75
* Thu Aug 23 2018 jack@suse.cz
- ext2, dax: introduce ext2_dax_aops (bsc#1104888).
- commit 0f61c7b
* Thu Aug 23 2018 jack@suse.cz
- ext4, dax: introduce ext4_dax_aops (bsc#1104888).
- commit d354926
* Thu Aug 23 2018 jack@suse.cz
- xfs, dax: introduce xfs_dax_aops (bsc#1104888).
- commit c02ab50
* Thu Aug 23 2018 jack@suse.cz
- block, dax: remove dead code in blkdev_writepages()
  (bsc#1104888).
- commit 48887a7
* Thu Aug 23 2018 jack@suse.cz
- fs, dax: prepare for dax-specific address_space_operations
  (bsc#1104888).
  patches.fixes/fs-allow-per-device-dax-status-checking-for-filesystems.patch:
  Refresh
  patches.kabi/kabi-fixup-bdev_dax_supported.patch: Refresh
- commit 9ba44a9
* Thu Aug 23 2018 ykaukab@suse.de
- serial: enable spi in sc16is7xx driver
  References: bsc#1105672
- commit 3a6d5cd
* Thu Aug 23 2018 tiwai@suse.de
- mfd: lpc_ich: Do not touch SPI-NOR write protection bit on
  Apollo Lake (FATE#326580,bsc#1051510).
- spi-nor: intel-spi: Fix number of protected range registers
  for BYT/LPT (FATE#326580).
- commit abe590f
* Thu Aug 23 2018 tiwai@suse.de
- mei: me: enable asynchronous probing (FATE#326580).
- commit 87c1d7e
* Thu Aug 23 2018 tiwai@suse.de
- HID: i2c-hid: Add no-irq-after-reset quirk for 0911:5288 device
  (FATE#326580).
- commit de8b56e
* Thu Aug 23 2018 tiwai@suse.de
- drm/i915/audio: Fix audio enumeration issue on BXT
  (FATE#326580).
- commit dd947f6
* Thu Aug 23 2018 tiwai@suse.de
- Fix kABI breakage with ath9k MSI support (FATE#326580).
- commit ebcb9bb
* Thu Aug 23 2018 tiwai@suse.de
- ath9k: add MSI support (FATE#326580).
- commit f299a2d
* Thu Aug 23 2018 mbrugger@suse.com
- ACPI/IORT: Remove temporary iort_get_id_mapping_index() ACPICA
  guard (bsc#1103387).
- ACPICA: iasl: Add SMMUv3 device ID mapping index support
  (bsc#1103387).
- commit 05d48cc
* Thu Aug 23 2018 jthumshirn@suse.de
- s390: Prevent hotplug rwsem recursion (bsc#1105731).
- commit 2ccd2c2
* Thu Aug 23 2018 tzimmermann@suse.de
- drm/i915: Restore user forcewake domains across suspend (bsc#1100132).
- commit a5893c4
* Thu Aug 23 2018 tiwai@suse.de
- drm/i915/cfl: Add a new CFL PCI ID (FATE#322643).
- commit 28443b3
* Thu Aug 23 2018 tiwai@suse.de
- drm/i915/aml: Introducing Amber Lake platform (FATE#322643).
- drm/i915/whl: Introducing Whiskey Lake platform (FATE#322643).
- commit 0dfa448
* Thu Aug 23 2018 tiwai@suse.de
- ppp: Destroy the mutex when cleanup (bsc#1051510).
- ppp: fix __percpu annotation (bsc#1051510).
- commit 57fcad2
* Thu Aug 23 2018 tiwai@suse.de
- PM / sleep: wakeup: Fix build error caused by missing SRCU
  support (bsc#1051510).
- commit 64103cb
* Thu Aug 23 2018 tiwai@suse.de
- platform/x86: thinkpad_acpi: Proper model/release matching
  (bsc#1051510).
- commit 0d9c3c2
* Thu Aug 23 2018 tiwai@suse.de
- mfd: sm501: Set coherent_dma_mask when creating subdevices
  (bsc#1051510).
- mfd: arizona: Don't use regmap_read_poll_timeout (bsc#1051510).
- commit 963690c
* Wed Aug 22 2018 jack@suse.cz
- dax: store pfns in the radix (bsc#1104888).
  patches.fixes/fs-allow-per-device-dax-status-checking-for-filesystems.patch:
  Refresh
- commit 416e9d2
* Wed Aug 22 2018 jack@suse.cz
- dax: require 'struct page' by default for filesystem dax
  (bsc#1104888 fate#325574).
  patches.fixes/fs-allow-per-device-dax-status-checking-for-filesystems.patch:
  Refresh
- commit 046aa0a
* Wed Aug 22 2018 ykaukab@suse.de
- irqdomain: Prevent potential NULL pointer dereference in
  irq_domain_push_irq() (bsc#1105378).
- commit 7f46718
* Wed Aug 22 2018 ykaukab@suse.de
- arm64: enable thunderx gpio driver
- Update config files
- supported.conf
- commit ed452df
* Wed Aug 22 2018 tiwai@suse.de
- isdn: Disable IIOCDBGVAR (bsc#1051510).
- commit f26546f
* Wed Aug 22 2018 tiwai@suse.de
- Fix kABI breakage with removing field addition to power_supply
  (bsc#1051510).
- commit c24883f
* Wed Aug 22 2018 ykaukab@suse.de
- gpio: thunderx: fix error return code in thunderx_gpio_probe()
  (bsc#1105378).
- gpio: thunderx: remove unused .map() hook from irq_domain_ops
  (bsc#1105378).
- gpio: Add gpio driver support for ThunderX and OCTEON-TX
  (bsc#1105378).
- irqdomain: Add irq_domain_{push,pop}_irq() functions
  (bsc#1105378).
- irqdomain: Check for NULL function pointer in
  irq_domain_free_irqs_hierarchy() (bsc#1105378).
- irqdomain: Factor out code to add and remove items to and from
  the revmap (bsc#1105378).
- genirq: Add handle_fasteoi_{level,edge}_irq flow handlers
  (bsc#1105378).
- genirq: Export more irq_chip_*_parent() functions (bsc#1105378).
- commit 548ef80
* Wed Aug 22 2018 tiwai@suse.de
- power: supply: max77693_charger: fix unintentional fall-through
  (bsc#1051510).
- power: generic-adc-battery: check for duplicate properties
  copied from iio channels (bsc#1051510).
- power: generic-adc-battery: fix out-of-bounds write when
  copying channel properties (bsc#1051510).
- power: supply: axp288_charger: Fix initial
  constant_charge_current value (bsc#1051510).
- power: gemini-poweroff: Avoid more spurious poweroffs
  (bsc#1051510).
- power: vexpress: fix corruption in notifier registration
  (bsc#1051510).
- power: remove possible deadlock when unregistering power_supply
  (bsc#1051510).
- commit 67e1cf7
* Wed Aug 22 2018 tiwai@suse.de
- serial: 8250: Don't service RX FIFO if interrupts are disabled
  (bsc#1051510).
- serial: core: mark port as initialized after successful IRQ
  change (bsc#1051510).
- commit ac2f7bc
* Wed Aug 22 2018 tiwai@suse.de
- serial: 8250_dw: Add ACPI support for uart on Broadcom SoC
  (bsc#1051510).
- serial: 8250_dw: always set baud rate in dw8250_set_termios
  (bsc#1051510).
- serial: sh-sci: Stop RX FIFO timer during port shutdown
  (bsc#1051510).
- serial: xuartps: fix typo in cdns_uart_startup (bsc#1051510).
- serial: pxa: Fix an error handling path in 'serial_pxa_probe()'
  (bsc#1051510).
- commit 9666db8
* Wed Aug 22 2018 tiwai@suse.de
- uprobes: Use synchronize_rcu() not synchronize_sched()
  (bsc#1051510).
- uprobes/x86: Remove incorrect WARN_ON() in uprobe_init_insn()
  (bsc#1051510).
- commit 813f7ff
* Wed Aug 22 2018 tiwai@suse.de
- iwlwifi: pcie: don't access periphery registers when not
  available (bsc#1051510).
- commit 4f7ad44
* Wed Aug 22 2018 tiwai@suse.de
- Bluetooth: avoid killing an already killed socket (bsc#1051510).
- commit 28dc173
* Wed Aug 22 2018 jslaby@suse.cz
- ip: in cmsg IP(V6)_ORIGDSTADDR call pskb_may_pull
  (netfilter-stable-18_07_27).
- ip: hash fragments consistently (netfilter-stable-18_07_27).
- vxlan: fix default fdb entry netlink notify ordering during
  netdev create (netfilter-stable-18_07_27).
- vxlan: make netlink notify in vxlan_fdb_destroy optional
  (netfilter-stable-18_07_27).
- vxlan: add new fdb alloc and create helpers
  (netfilter-stable-18_07_27).
- rtnetlink: add rtnl_link_state check in rtnl_configure_link
  (netfilter-stable-18_07_27).
- net: skb_segment() should not return NULL
  (netfilter-stable-18_07_27).
- net: phy: consider PHY_IGNORE_INTERRUPT in phy_start_aneg_priv
  (netfilter-stable-18_07_27).
- tcp: do not delay ACK in DCTCP upon CE status change
  (netfilter-stable-18_07_27).
- tcp: do not cancel delay-AcK on DCTCP special ACK
  (netfilter-stable-18_07_27).
- kABI: reexport tcp_send_ack (kabi).
- tcp: helpers to send special DCTCP ack
  (netfilter-stable-18_07_27).
- tcp: fix dctcp delayed ACK schedule (netfilter-stable-18_07_27).
- commit 9c52876
* Wed Aug 22 2018 tiwai@suse.de
- USB: serial: pl2303: add a new device id for ATEN (bsc#1051510).
- USB: option: add support for DW5821e (bsc#1051510).
- commit 87d48f9
* Wed Aug 22 2018 tiwai@suse.de
- ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry
  (bsc#1051510).
- ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs
  (bsc#1051510).
- ALSA: hda - Turn CX8200 into D3 as well upon reboot
  (bsc#1051510).
- ALSA: virmidi: Fix too long output trigger loop (bsc#1051510).
- ALSA: cs5535audio: Fix invalid endian conversion (bsc#1051510).
- ALSA: vxpocket: Fix invalid endian conversions (bsc#1051510).
- ALSA: vx222: Fix invalid endian conversions (bsc#1051510).
- ALSA: memalloc: Don't exceed over the requested size
  (bsc#1051510).
- commit 7b0ea28
* Wed Aug 22 2018 tiwai@suse.de
- ACPI / PM: save NVS memory for ASUS 1025C laptop (bsc#1051510).
- commit d252d99
* Wed Aug 22 2018 msuchanek@suse.de
- powerpc/topology: Get topology for shared processors at boot
  (bsc#1104683).
  - Refresh patches.arch/mobility-numa-Ensure-numa-update-does-not-overlap.patch.
- commit 420c8a6
* Tue Aug 21 2018 jeffm@suse.com
- xfs: repair malformed inode items during log recovery
  (bsc#1105396).
- xfs: Remove dead code from inode recover function (bsc#1105396).
- commit 6563853
* Tue Aug 21 2018 tiwai@suse.de
- Update patch tag of the upstreamed EDAC fix and move to sorted section
- commit bb0f656
* Tue Aug 21 2018 tiwai@suse.de
- random: fix possible sleeping allocation from irq context
  (bsc#1051510).
- commit 406c790
* Tue Aug 21 2018 tiwai@suse.de
- random: set up the NUMA crng instances after the CRNG is fully
  initialized (bsc#1051510).
- Refresh
  patches.drivers/random-crng_reseed-should-lock-the-crng-instance-tha.
- commit 73bf385
* Tue Aug 21 2018 mhocko@suse.com
- x86/speculation: Protect against userspace-userspace spectreRSB
  (bnc#1102517, CVE-2018-15572).
- commit 06220b2
* Tue Aug 21 2018 tiwai@suse.de
- random: mix rdrand with entropy sent in from userspace
  (bsc#1051510).
- random: add new ioctl RNDRESEEDCRNG (bsc#1051510).
- commit 47f1ea7
* Tue Aug 21 2018 jgross@suse.com
- x86/xen: Add call of speculative_store_bypass_ht_init() to PV
  paths (bnc#1065600).
- commit ca8ca94
* Tue Aug 21 2018 jgross@suse.com
- sorted series.conf
- commit ea30488
* Tue Aug 21 2018 mgorman@suse.de
- readahead: stricter check for bdi io_pages (VM Functionality,
  git fixes).
- commit 65cf459
* Tue Aug 21 2018 mgorman@suse.de
- arm/asm/tlb.h: Fix build error implicit func declaration
  (bnc#1105467 Reduce IPIs and atomic ops with improved lazy TLB).
- commit e415706
* Tue Aug 21 2018 tiwai@suse.de
- ata: Fix ZBC_OUT all bit handling (bsc#1051510).
- ata: Fix ZBC_OUT command block check (bsc#1051510).
- libata: Fix command retry decision (bsc#1051510).
- driver core: add __printf verification to __ata_ehi_pushv_desc
  (bsc#1051510).
- libata: Fix compile warning with ATA_DEBUG enabled
  (bsc#1051510).
- commit 3ebc0bd
* Tue Aug 21 2018 jthumshirn@suse.de
- kabi/severities: add qeth inter-module symbols to ignore list.
- commit 351744c
* Tue Aug 21 2018 mgorman@suse.de
- mm, page_alloc: double zone's batchsize (bnc#971975 VM
  performance -- page allocator).
- commit 8c952d8
* Tue Aug 21 2018 mgorman@suse.de
- x86/mm/tlb: Skip atomic operations for 'init_mm' in
  switch_mm_irqs_off() (bnc#1105467 Reduce IPIs and atomic ops
  with improved lazy TLB).
- x86/mm/tlb: Always use lazy TLB mode (bnc#1105467 Reduce IPIs
  and atomic ops with improved lazy TLB).
- x86/mm/tlb: Only send page table free TLB flush to lazy TLB CPUs
  (bnc#1105467 Reduce IPIs and atomic ops with improved lazy TLB).
- x86/mm/tlb: Make lazy TLB mode lazier (bnc#1105467 Reduce IPIs
  and atomic ops with improved lazy TLB).
- x86/mm/tlb: Restructure switch_mm_irqs_off() (bnc#1105467
  Reduce IPIs and atomic ops with improved lazy TLB).
- x86/mm/tlb: Leave lazy TLB mode at page table free time
  (bnc#1105467 Reduce IPIs and atomic ops with improved lazy TLB).
- commit 02a3275
* Tue Aug 21 2018 jthumshirn@suse.de
- s390/qeth: consistently re-enable device features (bsc#1104482,
  LTC#170340).
- s390/qeth: don't clobber buffer on async TX completion
  (bsc#1104482, LTC#170340).
- commit 60a7748
* Tue Aug 21 2018 jthumshirn@suse.de
- s390/qeth: rely on kernel for feature recovery (bsc#1104482,
  LTC#170340).
- Refresh
  patches.drivers/s390-qeth-fix-GSO-throughput-regression.patch.
- commit 76f7bee
* Tue Aug 21 2018 jslaby@suse.cz
- ipv6: fix useless rol32 call on hash
  (netfilter-stable-18_07_23).
- ipv6: ila: select CONFIG_DST_CACHE (netfilter-stable-18_07_23).
- tg3: Add higher cpu clock for 5762 (netfilter-stable-18_07_23).
- ipv6: make DAD fail with enhanced DAD when nonce length differs
  (netfilter-stable-18_07_23).
- net: systemport: Fix CRC forwarding check for SYSTEMPORT Lite
  (netfilter-stable-18_07_23).
- net: diag: Don't double-free TCP_NEW_SYN_RECV sockets in
  tcp_abort (netfilter-stable-18_07_23).
- net/ipv4: Set oif in fib_compute_spec_dst
  (netfilter-stable-18_07_23).
- ipv4: Return EINVAL when ping_group_range sysctl doesn't map
  to user ns (netfilter-stable-18_07_23).
- net: phy: fix flag masking in __set_phy_supported
  (netfilter-stable-18_07_23).
- gen_stats: Fix netlink stats dumping in the presence of padding
  (netfilter-stable-18_07_23).
- commit b94b51f
* Tue Aug 21 2018 jthumshirn@suse.de
- libnvdimm: fix ars_status output length calculation
  (bsc#1104890).
- commit 773d3ad
* Tue Aug 21 2018 tiwai@suse.de
- Update patch tag for rawmidi security fix (CVE-2018-10902,bsc#1105322).
- commit 88ecd0e
* Mon Aug 20 2018 tiwai@suse.de
- clk: mvebu: armada-38x: add support for missing clocks
  (bsc#1105355).
- clk: mvebu: armada-38x: add support for 1866MHz variants
  (bsc#1105355).
- commit 833d9a5
* Mon Aug 20 2018 tiwai@suse.de
- atm: zatm: fix memcmp casting (bsc#1105355).
- atm: horizon: Fix irq release error (bsc#1105355).
- commit d8acb4f
* Mon Aug 20 2018 tiwai@suse.de
- affs_lookup(): close a race with affs_remove_link()
  (bsc#1105355).
- commit e222b99
* Mon Aug 20 2018 tiwai@suse.de
- ptr_ring: prevent integer overflow when calculating size
  (bsc#1105355).
- ptr_ring: fail early if queue occupies more than
  KMALLOC_MAX_SIZE (bsc#1105355).
- ptr_ring: fix up after recent ptr_ring changes (bsc#1105355).
- commit 07c7e29
* Mon Aug 20 2018 tiwai@suse.de
- ptp: fix missing break in switch (bsc#1105355).
- commit 9a17d18
* Mon Aug 20 2018 tiwai@suse.de
- vmci: type promotion bug in qp_host_get_user_memory()
  (bsc#1105355).
- zram: fix null dereference of handle (bsc#1105355).
- commit 97aca4e
* Mon Aug 20 2018 tiwai@suse.de
- PCI: pciehp: Fix unprotected list iteration in IRQ handler
  (bsc#1051510).
- PCI: Skip MPS logic for Virtual Functions (VFs) (bsc#1051510).
- commit 3af88fd
* Mon Aug 20 2018 tiwai@suse.de
- partitions/aix: append null character to print data from disk
  (bsc#1051510).
- partitions/aix: fix usage of uninitialized lv_info and lvname
  structures (bsc#1051510).
- commit d25dc16
* Mon Aug 20 2018 tiwai@suse.de
- lib/rhashtable: consider param->min_size when setting initial
  table size (bsc#1051510).
- commit e170309
* Mon Aug 20 2018 ykaukab@suse.de
- cpufreq / CPPC: Set platform specific transition_delay_us
  (bsc#1101480).
- commit 4deee00
* Mon Aug 20 2018 tiwai@suse.de
- lib/vsprintf: Remove atomic-unsafe support for %%pCr
  (bsc#1051510).
- commit c64cd94
* Mon Aug 20 2018 tiwai@suse.de
- ima: based on policy verify firmware signatures (pre-allocated
  buffer) (bsc#1051510).
- commit 8010634
* Mon Aug 20 2018 tiwai@suse.de
- iio: adc: sun4i-gpadc: select REGMAP_IRQ (bsc#1051510).
- commit c213990
* Mon Aug 20 2018 tiwai@suse.de
- ieee802154: ca8210: fix uninitialised data read (bsc#1051510).
- ieee802154: mrf24j40: fix incorrect mask in mrf24j40_stop
  (bsc#1051510).
- ieee802154: fix gcc-4.9 warnings (bsc#1051510).
- commit ef527f0
* Mon Aug 20 2018 tiwai@suse.de
- PCI: Cleanup PCI_REBAR_CTRL_BAR_SHIFT handling (bsc#1105355).
- PCI: Restore resized BAR state on resume (bsc#1105355).
- PCI: Allow release of resources that were never assigned
  (bsc#1105355).
- PCI: Add pci_resize_resource() for resizing BARs (bsc#1105355).
- PCI: Add resizable BAR infrastructure (bsc#1105355).
- PCI: Add PCI resource type mask #define (bsc#1105355).
- commit 7bb8e6d
* Mon Aug 20 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add libnvdimm-for-next branch
- commit 2a73ff8
* Mon Aug 20 2018 tiwai@suse.de
- dma-buf: remove redundant initialization of sg_table
  (bsc#1051510).
- commit 8537e5b
* Mon Aug 20 2018 tiwai@suse.de
- devicectree: bindings: fix location of leds common file
  (bsc#1051510).
- commit 2648baf
* Mon Aug 20 2018 tiwai@suse.de
- net: bcmgenet: Fix sparse warnings in bcmgenet_put_tx_csum()
  (bsc#1051510).
- net: bcmgenet: enable loopback during UniMAC sw_reset
  (bsc#1051510).
- net: bcmgenet: prevent duplicate calls of bcmgenet_dma_teardown
  (bsc#1051510).
- net: bcmgenet: correct bad merge (bsc#1051510).
- net: bcmgenet: Fix unmapping of fragments in bcmgenet_xmit()
  (bsc#1051510).
- commit f1c0f2d
* Mon Aug 20 2018 tiwai@suse.de
- audit: Fix extended comparison of GID/EGID (bsc#1051510).
- audit: allow not equal op for audit by executable (bsc#1051510).
- commit cc3b8b1
* Mon Aug 20 2018 tiwai@suse.de
- ASoC: Intel: cht_bsw_max98090: remove useless code, align with
  ChromeOS driver (bsc#1051510).
- commit f1ce77b
* Mon Aug 20 2018 ykaukab@suse.de
- cpufreq: CPPC: Don't set transition_latency (bsc#1101480).
- commit df1a5c4
* Mon Aug 20 2018 tbogendoerfer@suse.de
- IB/IPoIB: Set ah valid flag in multicast send flow (bsc#1046307
  FATE#322941).
- IB/mlx5: fix uaccess beyond "count" in debugfs read/write
  handlers (bsc#1046305 FATE#322943).
- include/rdma/opa_addr.h: Fix an endianness issue (bsc#1046306
  FATE#322942).
- net: hns3: Fix desc num set to default when setting channel
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for phy link issue when using marvell phy driver
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for information of phydev lost problem when
  down/up (bsc#1104353 FATE#326415).
- net: hns3: Fix for command format parsing error in
  hclge_is_all_function_id_zero (bsc#1104353 FATE#326415).
- net: hns3: Fix MSIX allocation issue for VF (bsc#1104353
  FATE#326415).
- net: hns3: fix return value error while hclge_cmd_csq_clean
  failed (bsc#1104353 FATE#326415).
- net: hns3: Standardize the handle of return value (bsc#1104353
  FATE#326415).
- net: hns3: Fix comments for hclge_get_ring_chain_from_mbx
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for using wrong mask and shift in
  hclge_get_ring_chain_from_mbx (bsc#1104353 FATE#326415).
- net: hns3: Fix for reset_level default assignment probelm
  (bsc#1104353 FATE#326415).
- net: hns3: remove unnecessary ring configuration operation
  while resetting (bsc#1104353 FATE#326415).
- net: hns3: Fix return value error in hns3_reset_notify_down_enet
  (bsc#1104353 FATE#326415).
- net: hns3: Prevent sending command during global or core reset
  (bsc#1104353 FATE#326415).
- net: hns3: Fix get_vector ops in hclgevf_main module
  (bsc#1104353 FATE#326415).
- net: hns3: Fix warning bug when doing lp selftest (bsc#1104353
  FATE#326415).
- net: hns3: Fix for mailbox message truncated problem
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for l4 checksum offload bug (bsc#1104353
  FATE#326415).
- net: hns3: Fix for mac pause not disable in pfc mode
  (bsc#1104353 FATE#326415).
- cxgb4: Fix the condition to check if the card is T5 (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- net: hns3: modify hnae_ to hnae3_ (bsc#1104353 FATE#326415).
- net: hns3: simplify hclge_cmd_csq_clean (bsc#1104353
  FATE#326415).
- net: hns3: remove some redundant assignments (bsc#1104353
  FATE#326415).
- net: hns3: add unlikely for error check (bsc#1104353
  FATE#326415).
- RDMA/uverbs: Expand primary and alt AV port checks (bsc#1046306
  FATE#322942).
- commit 2935983
* Mon Aug 20 2018 tiwai@suse.de
- Update patch tag for BT security issue (CVE-2018-9363,bsc#1105292)
- commit 359753e
* Mon Aug 20 2018 nborisov@suse.com
- xfs: preserve i_rdev when recycling a reclaimable inode (bsc#1095344).
- commit 15a0237
* Sun Aug 19 2018 tiwai@suse.de
- wan/fsl_ucc_hdlc: use IS_ERR_VALUE() to check return value of
  qe_muram_alloc (bsc#1051510).
- commit e88aabf
* Sun Aug 19 2018 tiwai@suse.de
- vmw_balloon: remove inflation rate limiting (bsc#1051510).
- vmw_balloon: fix VMCI use when balloon built into kernel
  (bsc#1051510).
- vmw_balloon: VMCI_DOORBELL_SET does not check status
  (bsc#1051510).
- vmw_balloon: do not use 2MB without batching (bsc#1051510).
- vmw_balloon: fix inflation of 64-bit GFNs (bsc#1051510).
- commit 3d67ae9
* Sun Aug 19 2018 tiwai@suse.de
- usb: dwc3: change stream event enable bit back to 13
  (bsc#1051510).
- USB: serial: kobil_sct: fix modem-status error handling
  (bsc#1051510).
- USB: serial: sierra: fix potential deadlock at close
  (bsc#1051510).
- USB: cdc-wdm: don't enable interrupts in USB-giveback
  (bsc#1051510).
- commit 7ef5397
* Sun Aug 19 2018 tiwai@suse.de
- uio: potential double frees if __uio_register_device() fails
  (bsc#1051510).
- commit ad06b4b
* Sun Aug 19 2018 tiwai@suse.de
- tty: serial: 8250: Revert NXP SC16C2552 workaround
  (bsc#1051510).
- tty: fix termios input-speed encoding when using BOTHER
  (bsc#1051510).
- tty: fix termios input-speed encoding (bsc#1051510).
- commit 94a3d40
* Sun Aug 19 2018 tiwai@suse.de
- security: check for kstrdup() failure in lsm_append()
  (bsc#1051510).
- commit a6ac173
* Sun Aug 19 2018 tiwai@suse.de
- staging: rts5208: fix missing error check on call to
  rtsx_write_register (bsc#1051510).
- commit b1d7e41
* Sun Aug 19 2018 tiwai@suse.de
- rndis_wlan: potential buffer overflow in
  rndis_wlan_auth_indication() (bsc#1051510).
- commit ffbc66c
* Sun Aug 19 2018 tiwai@suse.de
- mmc: tegra: prevent HS200 on Tegra 3 (bsc#1051510).
- commit 42d2798
* Sun Aug 19 2018 tiwai@suse.de
- media: v4l2-mem2mem: Fix missing v4l2_m2m_try_run call
  (bsc#1051510).
- commit a4c03c3
* Sun Aug 19 2018 tiwai@suse.de
- mailbox: xgene-slimpro: Fix potential NULL pointer dereference
  (bsc#1051510).
- commit 2da014a
* Sun Aug 19 2018 tiwai@suse.de
- irqdomain: Update the comments of fwnode field of irq_domain
  structure (bsc#1051510).
- commit 2157cb9
* Sun Aug 19 2018 tiwai@suse.de
- iio: ad9523: Fix return value for ad952x_store() (bsc#1051510).
- iio: sca3000: Fix missing return in switch (bsc#1051510).
- iio: ad9523: Fix displayed phase (bsc#1051510).
- iio: adc: ina2xx: avoid kthread_stop() with stale task_struct
  (bsc#1051510).
- iio: 104-quad-8: Fix off-by-one error in register selection
  (bsc#1051510).
- iio: sca3000: Fix an error handling path in 'sca3000_probe()'
  (bsc#1051510).
- commit f178243
* Sun Aug 19 2018 tiwai@suse.de
- Drivers: hv: vmbus: Fix the offer_in_progress in
  vmbus_process_offer() (bsc#1051510).
- Drivers: hv: vmbus: do not mark HV_PCIE as perf_device
  (bsc#1051510).
- commit af4783c
* Sun Aug 19 2018 tiwai@suse.de
- extcon: Release locking when sending the notification of
  connector state (bsc#1051510).
- gpio: Fix wrong rounding in gpio-menz127 (bsc#1051510).
- commit 1d28212
* Sun Aug 19 2018 tiwai@suse.de
- drm/i915/gvt: Off by one in intel_vgpu_write_fence()
  (bsc#1051510).
- drm/i915: Unmask user interrupts writes into HWSP on
  snb/ivb/vlv/hsw (bsc#1051510).
- commit d5ae2d9
* Sun Aug 19 2018 tiwai@suse.de
- dmaengine: mv_xor_v2: kill the tasklets upon exit (bsc#1051510).
- dmaengine: idma64: Support dmaengine_terminate_sync()
  (bsc#1051510).
- dmaengine: hsu: Support dmaengine_terminate_sync()
  (bsc#1051510).
- commit a14499a
* Sun Aug 19 2018 tiwai@suse.de
- crypto: ablkcipher - fix crash flushing dcache in error path
  (bsc#1051510).
- commit f5d4a5e
* Sun Aug 19 2018 tiwai@suse.de
- coresight: tpiu: Fix disabling timeouts (bsc#1051510).
- commit 113fb5e
* Sun Aug 19 2018 tiwai@suse.de
- binfmt_elf: Respect error return from `regset->active'
  (bsc#1051510).
- commit a1a1140
* Sun Aug 19 2018 tiwai@suse.de
- staging: bcm2835-camera: fix timeout handling in
  wait_for_completion_timeout (bsc#1051510).
- staging: bcm2835-camera: handle wait_for_completion_timeout
  return properly (bsc#1051510).
- commit 69c48bf
* Sun Aug 19 2018 tiwai@suse.de
- ASoC: Intel: cht_bsw_max98090_ti: Fix jack initialization
  (bsc#1051510).
- ASoC: msm8916-wcd-digital: fix RX2 MIX1 and RX3 MIX1
  (bsc#1051510).
- commit fa657bb
* Sun Aug 19 2018 tiwai@suse.de
- ACPI / APEI: Remove ghes_ioremap_area (bsc#1051510).
- commit cc4f7a3
* Sun Aug 19 2018 tiwai@suse.de
- blacklist.conf: Add a cherry-picked entry
- commit ddcf485
* Sat Aug 18 2018 tiwai@suse.de
- Update upstreamed patches
- commit 22ff2f4
* Fri Aug 17 2018 jgross@suse.com
- x86/paravirt: Fix spectre-v2 mitigations for paravirt guests
  (bnc#1065600).
- x86/entry/64: Remove %%ebx handling from error_entry/exit
  (bnc#1102715).
- commit a7024a7
* Fri Aug 17 2018 ykaukab@suse.de
- cpufreq: CPPC: Use transition_delay_us depending transition_latency (bsc#1101480).
- cpufreq: remove setting of policy->cpu in policy->cpus during init (bsc#1101480).
- commit 4fdd416
* Fri Aug 17 2018 msuchanek@suse.de
- Re-sort 4.4 stable patches.
- commit ef1a0c4
* Fri Aug 17 2018 hare@suse.de
- scsi: qla2xxx: Fix issue reported by static checker for
  qla2x00_els_dcmd2_sp_done() (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Update driver version to 10.00.00.08-k
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Migrate NVME N2N handling into state machine
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Save frame payload size from ICB
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix stalled relogin (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix race between switch cmd completion and
  timeout (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix Management Server NPort handle reservation
  logic (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Flush mailbox commands on chip reset
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix unintended Logout (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix session state stuck in Get Port DB
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix redundant fc_rport registration
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Silent erroneous message
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Prevent sysfs access when chip is down
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Add longer window for chip reset
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix login retry count (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix N2N link re-connect
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Cleanup for N2N code (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix ISP recovery on unload
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Spinlock recursion in qla_target
  (bsc#1086327,FATE#324903).
- commit 6be5935
* Fri Aug 17 2018 jslaby@suse.cz
- ipv6: sr: fix passing wrong flags to crypto_alloc_shash()
  (networking-stable-18_07_19).
- net: fix use-after-free in GRO with ESP
  (networking-stable-18_07_19).
- tcp: prevent bogus FRTO undos with non-SACK flows
  (networking-stable-18_07_19).
- atm: zatm: Fix potential Spectre v1
  (networking-stable-18_07_19).
- tcp: fix Fast Open key endianness (networking-stable-18_07_19).
- strparser: Remove early eaten to fix full tcp receive buffer
  stall (networking-stable-18_07_19).
- net/mlx5e: Avoid dealing with vport representors if not being
  e-switch manager (networking-stable-18_07_19).
- net/mlx5: E-Switch, Avoid setup attempt if not being e-switch
  manager (networking-stable-18_07_19).
- kABI: protect eswitch.h include (kabi).
- net: dccp: switch rx_tstamp_last_feedback to monotonic clock
  (networking-stable-18_07_19).
- net: dccp: avoid crash in ccid3_hc_rx_send_feedback()
  (networking-stable-18_07_19).
- net: mvneta: fix the Rx desc DMA address in the Rx path
  (networking-stable-18_07_19).
- vhost_net: validate sock before trying to put its fd
  (networking-stable-18_07_19).
- VSOCK: fix loopback on big-endian systems
  (networking-stable-18_07_19).
- net/packet: fix use-after-free (networking-stable-18_07_19).
- ipvlan: fix IFLA_MTU ignored on NEWLINK
  (networking-stable-18_07_19).
- stmmac: fix DMA channel hang in half-duplex mode
  (networking-stable-18_07_19).
- net: sungem: fix rx checksum support
  (networking-stable-18_07_19).
- net_sched: blackhole: tell upper qdisc about dropped packets
  (networking-stable-18_07_19).
- atm: Preserve value of skb->truesize when accounting to vcc
  (networking-stable-18_07_19).
- commit af535df
* Fri Aug 17 2018 tbogendoerfer@suse.de
- Refresh patches.kabi/kabi-protect_fwnode_handle.patch.
- commit 8a927a7
* Thu Aug 16 2018 tiwai@suse.de
- Fix kABI breakage with libertas dev field addition
  (bsc#1051510).
- libertas: fix suspend and resume for SDIO connected cards
  (bsc#1051510).
- commit 3158a60
* Thu Aug 16 2018 tiwai@suse.de
- media: rtl28xxu: be sure that it won't go past the array size
  (bsc#1051510).
- media: tw686x: Fix oops on buffer alloc failure (bsc#1051510).
- media: exynos4-is: Prevent NULL pointer dereference in
  __isp_video_try_fmt() (bsc#1051510).
- media: omap3isp: zero-initialize the isp cam_xclk{a,b} initial
  data (bsc#1051510).
- media: mem2mem: Remove excessive try_run call (bsc#1051510).
- commit f296c63
* Thu Aug 16 2018 tiwai@suse.de
- crypto: ccp - Check for NULL PSP pointer at module unload
  (bsc#1051510).
- crypto: blkcipher - fix crash flushing dcache in error path
  (bsc#1051510).
- crypto: skcipher - fix crash flushing dcache in error path
  (bsc#1051510).
- crypto: skcipher - fix aligning block size in skcipher_copy_iv()
  (bsc#1051510).
- crypto: ccp - Fix command completion detection race
  (bsc#1051510).
- crypto: x86/sha256-mb - fix digest copy in
  sha256_mb_mgr_get_comp_job_avx2() (bsc#1051510).
- crypto: vmac - separate tfm and request context (bsc#1051510).
- crypto: vmac - require a block cipher with 128-bit block size
  (bsc#1051510).
- commit c553787
* Thu Aug 16 2018 tiwai@suse.de
- MAINTAINERS: fix location of ina2xx.txt device tree file
  (bsc#1051510).
- commit 79ba775
* Thu Aug 16 2018 tiwai@suse.de
- clk: imx6ul: fix missing of_node_put() (bsc#1051510).
- clk: core: Potentially free connection id (bsc#1051510).
- clk: rockchip: fix clk_i2sout parent selection bits on rk3399
  (bsc#1051510).
- clk: meson: gxbb: remove HHI_GEN_CLK_CTNL duplicate definition
  (bsc#1051510).
- commit da07cce
* Thu Aug 16 2018 tiwai@suse.de
- leds: max8997: use mode when calling max8997_led_set_mode
  (bsc#1051510).
- commit be431b3
* Thu Aug 16 2018 tiwai@suse.de
- drm/i915: Nuke the LVDS lid notifier (bsc#1051510).
- drm/panel: type promotion bug in s6e8aa0_read_mtp_id()
  (bsc#1051510).
- drm/i915: Only show debug for state changes when banning
  (bsc#1051510).
- drm/rockchip: lvds: add missing of_node_put (bsc#1051510).
- drm/fb-helper: Fix typo on kerneldoc (bsc#1051510).
- commit caa8e3b
* Thu Aug 16 2018 tiwai@suse.de
- brcmsmac: fix wrap around in conversion from constant to s16
  (bsc#1051510).
- commit fdcc372
* Thu Aug 16 2018 tiwai@suse.de
- Documentation: ip-sysctl.txt: document addr_gen_mode
  (bsc#1051510).
- commit 08e984b
* Thu Aug 16 2018 tiwai@suse.de
- EDAC, i7core: Fix memleaks and use-after-free on probe and
  remove (bsc#1051510).
- EDAC: Fix memleak in module init error path (bsc#1051510).
- commit 0c40b5b
* Thu Aug 16 2018 tiwai@suse.de
- Bluetooth: hidp: buffer overflow in hidp_process_report
  (bsc#1051510).
- commit 01e6c28
* Thu Aug 16 2018 tiwai@suse.de
- ath10k: prevent active scans on potential unusable channels
  (bsc#1051510).
- commit a6e8225
* Thu Aug 16 2018 tiwai@suse.de
- Move the previous hv netvsc fix to the sorted section (bsc#1104708)
  Patch tags update, too
- commit 50ea871
* Wed Aug 15 2018 msuchanek@suse.de
- Move kabi patches into patches.kabi
  Some scrfipts depend on this to remove these patches automatically on
  configs without KABI tracking.
- commit 99e1e6d
* Wed Aug 15 2018 jslaby@suse.cz
- netfilter: nf_tables: disable preemption in
  nft_update_chain_stats() (netfilter-stable-18_06_27).
- netfilter: nft_meta: fix wrong value dereference in
  nft_meta_set_eval (netfilter-stable-18_06_27).
- netfilter: nf_tables: fix memory leak on error exit return
  (netfilter-stable-18_06_27).
- netfilter: nft_compat: fix handling of large matchinfo size
  (netfilter-stable-18_06_27).
- netfilter: nft_compat: prepare for indirect info storage
  (netfilter-stable-18_06_27).
- netfilter: nf_tables: don't assume chain stats are set when
  jumplabel is set (netfilter-stable-18_06_27).
- netfilter: nf_tables: nft_compat: fix refcount leak on xt module
  (netfilter-stable-18_06_27).
- netfilter: nf_tables: add missing netlink attrs to policies
  (netfilter-stable-18_06_27).
- commit 3bc4a5b
* Wed Aug 15 2018 tzimmermann@suse.de
- drm/cirrus: Use drm_framebuffer_put to avoid kernel oops in clean-up (bsc#1101822).
- commit 48dbb6a
* Wed Aug 15 2018 tiwai@suse.de
- spi: spi-fsl-dspi: Fix imprecise abort on VF500 during probe
  (bsc#1051510).
- rtc: ensure rtc_set_alarm fails when alarms are not supported
  (bsc#1051510).
- commit a5f6ce9
* Wed Aug 15 2018 tiwai@suse.de
- PM / devfreq: rk3399_dmc: Fix duplicated opp table on reload
  (bsc#1051510).
- commit bf1544a
* Wed Aug 15 2018 tiwai@suse.de
- pinctrl: freescale: off by one in imx1_pinconf_group_dbg_show()
  (bsc#1051510).
- pinctrl: cannonlake: Fix community ordering for H variant
  (bsc#1051510).
- pinctrl: imx: off by one in imx_pinconf_group_dbg_show()
  (bsc#1051510).
- pinctrl: single: Fix group and function selector use
  (bsc#1051510).
- pinctrl: pinmux: Return selector to the pinctrl driver
  (bsc#1051510).
- pinctrl: core: Return selector to the pinctrl driver
  (bsc#1051510).
- pinctrl: qcom: spmi-gpio: Fix pmic_gpio_config_get() to be
  compliant (bsc#1051510).
- commit f8e2baa
* Wed Aug 15 2018 pmladek@suse.com
- kthread, tracing: Don't expose half-written comm when creating
  kthreads (bsc#1104897).
- commit bc336f5
* Wed Aug 15 2018 tiwai@suse.de
- gtp: Initialize 64-bit per-cpu stats correctly (bsc#1051510).
- commit 654f242
* Wed Aug 15 2018 tiwai@suse.de
- i2c: imx: Fix reinit_completion() use (bsc#1051510).
- geneve: update skb dst pmtu on tx path (bsc#1051510).
- commit b14055a
* Wed Aug 15 2018 tiwai@suse.de
- docs: zh_CN: fix location of oops-tracing.txt (bsc#1051510).
- commit 2fe224f
* Wed Aug 15 2018 tiwai@suse.de
- genirq: Fix editing error in a comment (bsc#1051510).
- genirq: Make force irq threading setup more robust
  (bsc#1051510).
- commit a8d21bd
* Wed Aug 15 2018 tiwai@suse.de
- Update tags upstreamed patches, move to upstream section
- commit 1c6a87b
* Wed Aug 15 2018 tiwai@suse.de
- ASoC: sirf: Fix potential NULL pointer dereference
  (bsc#1051510).
- ASoC: zte: Fix incorrect PCM format bit usages (bsc#1051510).
- ASoC: rsnd: cmd: Add missing newline to debug message
  (bsc#1051510).
- ASoC: es7134: remove 64kHz rate from the supported rates
  (bsc#1051510).
- ASoC: dpcm: don't merge format from invalid codec dai
  (bsc#1051510).
- ALSA: snd-aoa: add of_node_put() in error path (bsc#1051510).
- commit a36ee64
* Wed Aug 15 2018 jslaby@suse.cz
- netfilter: nf_tables: use WARN_ON_ONCE instead of BUG_ON in
  nft_do_chain() (netfilter-stable-18_06_25).
- netfilter: ip6t_rpfilter: provide input interface for route
  lookup (netfilter-stable-18_06_25).
- netfilter: don't set F_IFACE on ipv6 fib lookups
  (netfilter-stable-18_06_25).
- netfilter: nat: Revert "netfilter: nat: convert nat bysrc hash
  to rhashtable" (netfilter-stable-17_11_16).
- kABI: protect struct nf_conn (kabi).
- commit d2096e3
* Tue Aug 14 2018 tiwai@suse.de
- init: rename and re-order boot_cpu_state_init() (bsc#1104365).
- Refresh
  patches.arch/17-cpu-hotplug-Boot-HT-siblings-at-least-once.patch.
- Refresh
  patches.suse/Fix-arm64-breakage-with-this_cpu_write.patch.
- commit 070598e
* Tue Aug 14 2018 tiwai@suse.de
- Delete patches.suse/Fix-arm64-breakage-with-this_cpu_write.patch
  It's no longer needed after the upstream fix.
- commit d44e7e2
* Tue Aug 14 2018 tiwai@suse.de
- hv/netvsc: Fix NULL dereference at single queue mode fallback
  (bsc#1104708).
- commit 947aa51
* Tue Aug 14 2018 tiwai@suse.de
- media: videobuf2-core: don't call memop 'finish' when queueing
  (bsc#1051510).
- media: omap3isp: fix unbalanced dma_iommu_mapping (bsc#1051510).
- commit 3bd1bae
* Tue Aug 14 2018 tiwai@suse.de
- EDAC, altera: Fix ARM64 build warning (bsc#1051510).
- EDAC, mv64x60: Fix an error handling path (bsc#1051510).
- EDAC, octeon: Fix an uninitialized variable warning
  (bsc#1051510).
- EDAC, sb_edac: Fix missing break in switch (bsc#1051510).
- commit 9f77e18
* Tue Aug 14 2018 tiwai@suse.de
- ACPI / PCI: Bail early in acpi_pci_add_bus() if there is no
  ACPI handle (bsc#1051510).
- commit 31c51d2
* Tue Aug 14 2018 tiwai@suse.de
- xhci: Fix perceived dead host due to runtime suspend race with
  event handler (bsc#1051510).
- commit 861687b
* Tue Aug 14 2018 tiwai@suse.de
- Fix kABI breakage of kvm_x86_ops due to L1TF patches
  (bsc#1089343 CVE-2018-3646).
- commit 8a4775d
* Tue Aug 14 2018 tiwai@suse.de
- kabi/severities: Relax kvm_vcpu_* kABI breakage
- commit 1763549
* Tue Aug 14 2018 mgorman@suse.de
- sched/numa: Move task_numa_placement() closer to
  numa_migrate_preferred() (bnc#1101669 optimise numa balancing
  for fast migrate).
- sched/numa: Use group_weights to identify if migration degrades
  locality (bnc#1101669 optimise numa balancing for fast migrate).
- sched/numa: Update the scan period without holding the
  numa_group lock (bnc#1101669 optimise numa balancing for
  fast migrate).
- sched/numa: Modify migrate_swap() to accept additional
  parameters (bnc#1101669 optimise numa balancing for fast
  migrate).
- sched/numa: Remove unused task_capacity from 'struct numa_stats'
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/numa: Skip nodes that are at 'hoplimit' (bnc#1101669
  optimise numa balancing for fast migrate).
- sched/debug: Reverse the order of printing faults (bnc#1101669
  optimise numa balancing for fast migrate).
- sched/numa: Use task faults only if numa_group is not yet set up
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/numa: Set preferred_node based on best_cpu (bnc#1101669
  optimise numa balancing for fast migrate).
- sched/numa: Simplify load_too_imbalanced() (bnc#1101669 optimise
  numa balancing for fast migrate).
- sched/numa: Evaluate move once per node (bnc#1101669 optimise
  numa balancing for fast migrate).
- sched/numa: Remove redundant field -kabi (bnc#1101669 optimise
  numa balancing for fast migrate).
- sched/numa: Remove redundant field (bnc#1101669 optimise numa
  balancing for fast migrate).
- commit 718fbcc
* Tue Aug 14 2018 mgorman@suse.de
- series.conf: Sort automatic NUMA balancing related patch
- commit 78160e1
* Tue Aug 14 2018 jgross@suse.com
- xen/netfront: don't cache skb_shinfo() (bnc#1065600).
- x86/xen: init %%gs very early to avoid page faults with stack
  protector (bnc#1104777).
- commit 7fdcb3b
* Tue Aug 14 2018 oneukum@suse.com
- typec: tcpm: fusb302: Resolve out of order messaging events
  (bsc#1087092).
- commit 2640a76
* Mon Aug 13 2018 ohering@suse.de
- hv_netvsc: Fix napi reschedule while receive completion is busy
  (fate#323887).
- commit e458677
* Mon Aug 13 2018 agraf@suse.de
- supported.conf: Enable HiSi v3 SAS adapter (FATE#326253)
- commit 760b46a
* Mon Aug 13 2018 msuchanek@suse.de
- powerpc/fadump: merge adjacent memory ranges to reduce PT_LOAD
  segements (bsc#1103269).
- powerpc/fadump: handle crash memory ranges array index overflow
  (bsc#1103269).
- commit 0d8b4a2
* Mon Aug 13 2018 oneukum@suse.com
- net: qmi_wwan: Add Netgear Aircard 779S (bsc#1090888).
- commit 8783b64
* Mon Aug 13 2018 oneukum@suse.com
- net: lan78xx: fix rx handling before first packet is send
  (bsc#1100132).
- commit d201338
* Mon Aug 13 2018 oneukum@suse.com
- net: usb: asix: replace mii_nway_restart in resume path
  (bsc#1100132).
- commit 3df7ed3
* Mon Aug 13 2018 oneukum@suse.com
- net: lan78xx: Fix race in tx pending skb size calculation
  (bsc#1100132).
- commit 748c48c
* Mon Aug 13 2018 oneukum@suse.com
- net: qmi_wwan: add BroadMobi BM806U 2020:2033 (bsc#1087092).
- commit f2aab4f
* Mon Aug 13 2018 oneukum@suse.com
- net-usb: add qmi_wwan if on lte modem wistron neweb d18q1
  (bsc#1087092).
- commit ec40a3b
* Mon Aug 13 2018 nborisov@suse.com
- xfs: move xfs_iext_insert tracepoint to report useful
  information (bsc#1095344).
- xfs: fix memory leak in xfs_iext_free_last_leaf (bsc#1095344).
- xfs: fix type usage (bsc#1095344).
- xfs: handle zero entries case in xfs_iext_rebalance_leaf
  (bsc#1095344).
- xfs: add comments documenting the rebalance algorithm
  (bsc#1095344).
- xfs: trivial indentation fixup for xfs_iext_remove_node
  (bsc#1095344).
- xfs: remove a superflous assignment in xfs_iext_remove_node
  (bsc#1095344).
- xfs: add some comments to xfs_iext_insert/xfs_iext_insert_node
  (bsc#1095344).
- xfs: fix number of records handling in xfs_iext_split_leaf
  (bsc#1095344).
- xfs: move xfs_bmbt_irec and xfs_exntst_t to xfs_types.h
  (bsc#1095344).
- xfs: pass struct xfs_bmbt_irec to  xfs_bmbt_validate_extent
  (bsc#1095344).
- xfs: remove the nr_extents argument to xfs_iext_remove
  (bsc#1095344).
- xfs: remove the nr_extents argument to xfs_iext_insert
  (bsc#1095344).
- xfs: use a b+tree for the in-core extent list (bsc#1095344).
- xfs: allow unaligned extent records in  xfs_bmbt_disk_set_all
  (bsc#1095344).
- xfs: remove support for inlining data/extents into the  inode
  fork (bsc#1095344).
- xfs: simplify xfs_reflink_convert_cow (bsc#1095344).
- xfs: iterate backwards in xfs_reflink_cancel_cow_blocks
  (bsc#1095344).
- xfs: introduce the xfs_iext_cursor abstraction (bsc#1095344).
- xfs: iterate over extents in xfs_bmap_extents_to_btree
  (bsc#1095344).
- xfs: iterate over extents in xfs_iextents_copy (bsc#1095344).
- xfs: pass an on-disk extent to xfs_bmbt_validate_extent
  (bsc#1095344).
- xfs: treat idx as a cursor in xfs_bmap_collapse_extents
  (bsc#1095344).
- xfs: treat idx as a cursor in xfs_bmap_del_extent_*
  (bsc#1095344).
- xfs: treat idx as a cursor in
  xfs_bmap_add_extent_unwritten_real (bsc#1095344).
- xfs: treat idx as a cursor in  xfs_bmap_add_extent_hole_real
  (bsc#1095344).
- xfs: treat idx as a cursor in  xfs_bmap_add_extent_hole_delay
  (bsc#1095344).
- xfs: treat idx as a cursor in  xfs_bmap_add_extent_delay_real
  (bsc#1095344).
- xfs: remove a duplicate assignment in
  xfs_bmap_add_extent_delay_real (bsc#1095344).
- xfs: don't create overlapping extents in
  xfs_bmap_add_extent_delay_real (bsc#1095344).
- xfs: add a new xfs_iext_lookup_extent_before helper
  (bsc#1095344).
- xfs: merge xfs_bmap_read_extents into xfs_iread_extents
  (bsc#1095344).
- xfs: add asserts for the mmap lock in
  xfs_{insert,collapse}_file_space (bsc#1095344).
- xfs: rewrite xfs_bmap_first_unused to make better use  of
  xfs_iext_get_extent (bsc#1095344).
- xfs: don't rely on extent indices in  xfs_bmap_insert_extents
  (bsc#1095344).
- xfs: don't rely on extent indices in  xfs_bmap_collapse_extents
  (bsc#1095344).
- xfs: update got in xfs_bmap_shift_update_extent (bsc#1095344).
- xfs: remove xfs_bmse_shift_one (bsc#1095344).
- xfs: split xfs_bmap_shift_extents (bsc#1095344).
- xfs: remove XFS_BMAP_MAX_SHIFT_EXTENTS (bsc#1095344).
- xfs: inline xfs_shift_file_space into callers (bsc#1095344).
- xfs: remove if_rdev (bsc#1095344).
- xfs: remove the never fully implemented UUID fork  format
  (bsc#1095344).
- xfs: remove XFS_BMAP_TRACE_EXLIST (bsc#1095344).
- xfs: move pre/post-bmap tracing into  xfs_iext_update_extent
  (bsc#1095344).
- xfs: remove post-bmap tracing in  xfs_bmap_local_to_extents
  (bsc#1095344).
- xfs: make better use of the 'state' variable in
  xfs_bmap_del_extent_real (bsc#1095344).
- xfs: add a xfs_bmap_fork_to_state helper (bsc#1095344).
- xfs: remove xfs_bmbt_get_state (bsc#1095344).
- xfs: remove all xfs_bmbt_set_* helpers except for
  xfs_bmbt_set_all (bsc#1095344).
- xfs: replace xfs_bmbt_lookup_ge with  xfs_bmbt_lookup_first
  (bsc#1095344).
- xfs: pass a struct xfs_bmbt_irec to xfs_bmbt_lookup_eq
  (bsc#1095344).
- xfs: pass a struct xfs_bmbt_irec to xfs_bmbt_update
  (bsc#1095344).
- xfs: refactor xfs_bmap_add_extent_unwritten_real (bsc#1095344).
- xfs: refactor delalloc accounting in
  xfs_bmap_add_extent_delay_real (bsc#1095344).
- xfs: refactor xfs_bmap_add_extent_delay_real (bsc#1095344).
- xfs: refactor xfs_bmap_add_extent_hole_real (bsc#1095344).
- xfs: refactor xfs_bmap_add_extent_hole_delay (bsc#1095344).
- xfs: refactor xfs_del_extent_real (bsc#1095344).
- xfs: use the state defines in xfs_bmap_del_extent_real
  (bsc#1095344).
- xfs: use correct state defines in
  xfs_bmap_del_extent_{cow,delay} (bsc#1095344).
- commit 2783d07
* Mon Aug 13 2018 nborisov@suse.com
- xfs: move some more code into xfs_bmap_del_extent_real
  (bsc#1095344).
- xfs: use xfs_bmap_del_extent_delay for the data fork as  well
  (bsc#1095344).
- xfs: rename bno to end in __xfs_bunmapi (bsc#1095344).
- xfs: don't set XFS_BTCUR_BPRV_WASDEL in xfs_bunmapi
  (bsc#1095344).
- xfs: use xfs_iext_get_extent instead of open coding it
  (bsc#1095344).
- xfs: simplify the xfs_getbmap interface (bsc#1095344).
- xfs: rewrite getbmap using the xfs_iext_* helpers (bsc#1095344).
- xfs: replace xfs_qm_get_rtblks with a direct call to
  xfs_bmap_count_leaves (bsc#1095344).
- xfs: rewrite xfs_bmap_count_leaves using  xfs_iext_get_extent
  (bsc#1095344).
- xfs: use xfs_iext_*_extent helpers in  xfs_bmap_split_extent_at
  (bsc#1095344).
- xfs: use xfs_iext_*_extent helpers in  xfs_bmap_shift_extents
  (bsc#1095344).
- xfs: move some code around inside  xfs_bmap_shift_extents
  (bsc#1095344).
- xfs: use xfs_iext_get_extent in xfs_bmap_first_unused
  (bsc#1095344).
- xfs: switch xfs_bmap_local_to_extents to use  xfs_iext_insert
  (bsc#1095344).
- xfs: add a xfs_iext_update_extent helper (bsc#1095344).
- xfs: refactor dir2 leaf readahead shadow buffer  cleverness
  (bsc#1095344).
- commit 24b4ed0
* Mon Aug 13 2018 jroedel@suse.de
- x86/kvm: kABI workaround for CVE-2018-10853 fix (CVE-2018-10853
  bsc#1097104).
- kvm: x86: use correct privilege level for
  sgdt/sidt/fxsave/fxrstor access (CVE-2018-10853 bsc#1097104).
- KVM: x86: pass kvm_vcpu to kvm_read_guest_virt and
  kvm_write_guest_virt_system (CVE-2018-10853 bsc#1097104).
- KVM: x86: introduce linear_{read,write}_system (CVE-2018-10853
  bsc#1097104).
- commit 65006cb
* Mon Aug 13 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915/pmu: Fix PMU enable vs execlists tasklet race' #2
- commit bb04587
* Mon Aug 13 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/i915/pmu: Fix PMU enable vs execlists tasklet race'
- commit 777d4c9
* Mon Aug 13 2018 jgross@suse.com
- xen-netback: fix input validation in xenvif_set_hash_mapping()
  (bnc#1103277).
- commit 6d2d327
* Fri Aug 10 2018 tiwai@suse.de
- hwmon: (asus_atk0110) Replace deprecated device register call
  (bsc#1103363).
- commit d786db1
* Fri Aug 10 2018 jack@suse.cz
- ext4: check for allocation block validity with block group
  locked (bsc#1104495).
- commit 687b42e
* Fri Aug 10 2018 jack@suse.cz
- ext4: fix inline data updates with checksums enabled
  (bsc#1104494).
- commit 8bd5d82
* Fri Aug 10 2018 jack@suse.cz
- ext4: fix false negatives *and* false positives in
  ext4_check_descriptors() (bsc#1103445).
- commit aae2736
* Fri Aug 10 2018 hare@suse.de
- s390/dasd: configurable IFCC handling (bsc#1097808).
- commit fa71ad6
* Fri Aug 10 2018 tbogendoerfer@suse.de
- be2net: Update the driver version to 12.0.0.0 (bsc#1086288
  FATE#324877).
- be2net: gather debug info and reset adapter (only for Lancer)
  on a tx-timeout (bsc#1086288 FATE#324877).
- commit c3595f8
* Fri Aug 10 2018 jdelvare@suse.de
- ACPI / PCI: pci_link: Allow the absence of _PRS and change
  log level (bsc#1104172).
- ACPI/PCI: pci_link: reduce verbosity when IRQ is enabled
  (bsc#1104172).
- commit d5d5a1d
* Fri Aug 10 2018 tiwai@suse.de
- EDAC: Drop duplicated array of strings for memory type names
  (bsc#1103886).
- commit 06bf79d
* Fri Aug 10 2018 ohering@suse.de
- TCM_RBD depends on BLK_DEV_RBD (fate#318836).
- commit 9847077
* Fri Aug 10 2018 lduncan@suse.com
- scsi: qedi: Send driver state to MFW (bsc#1086315).
- qedi: Add get_generic_tlv_data handler (bsc#1086315).
- qedi: Add support for populating ethernet TLVs (bsc#1086315).
- scsi: qedi: fix build regression (bsc#1086315).
- scsi: qedi: fix building with LTO (bsc#1086315).
- scsi: qedi: Fix kernel crash during port toggle (bsc#1086315).
- commit 76cd28a
* Fri Aug 10 2018 tbogendoerfer@suse.de
- Update config files.
- supported.conf: added hns-roce-hw-v1 and hns-roce-hw-v2
- commit e68ebe7
* Fri Aug 10 2018 tbogendoerfer@suse.de
- IB/hns: Use zeroing memory allocator instead of allocator/memset
  (bsc#1104427 FATE#326416).
- RDMA/hns_roce: Don't check return value of zap_vma_ptes()
  (bsc#1104427 FATE#326416).
- RDMA/hns: Implement the disassociate_ucontext API (bsc#1104427
  FATE#326416).
- RDMA/hns: Fix the illegal memory operation when cross page
  (bsc#1104427 FATE#326416).
- RDMA/hns: Add reset process for RoCE in hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Increase checking CMQ status timeout value
  (bsc#1104427 FATE#326416).
- RDMA/hns: Modify uar allocation algorithm to avoid bitmap
  exhaust (bsc#1104427 FATE#326416).
- RDMA/hns: Rename the idx field of db (bsc#1104427 FATE#326416).
- RDMA/hns: Add 64KB page size support for hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Drop local zgid in favor of core defined variable
  (bsc#1104427 FATE#326416).
- RDMA/hns: Move the location for initializing tmp_len
  (bsc#1104427 FATE#326416).
- RDMA/hns: Bugfix for cq record db for kernel (bsc#1104427
  FATE#326416).
- RDMA/hns: Fix the bug with NULL pointer (bsc#1104427
  FATE#326416).
- RDMA/hns: Set NULL for __internal_mr (bsc#1104427 FATE#326416).
- RDMA/hns: Enable inner_pa_vld filed of mpt (bsc#1104427
  FATE#326416).
- RDMA/hns: Set desc_dma_addr for zero when free cmq desc
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix the bug with rq sge (bsc#1104427 FATE#326416).
- RDMA/hns: Not support qp transition from reset to reset for
  hip06 (bsc#1104427 FATE#326416).
- RDMA/hns: Add return operation when configured global param fail
  (bsc#1104427 FATE#326416).
- RDMA/hns: Update convert function of endian format (bsc#1104427
  FATE#326416).
- RDMA/hns: Load the RoCE dirver automatically (bsc#1104427
  FATE#326416).
- RDMA/hns: Bugfix for rq record db for kernel (bsc#1104427
  FATE#326416).
- RDMA/hns: Add rq inline flags judgement (bsc#1104427
  FATE#326416).
- RDMA/hns: Fix a couple misspellings (bsc#1104427 FATE#326416).
- RDMA/hns: Submit bad wr (bsc#1104427 FATE#326416).
- RDMA/hns: Update assignment method for owner field of send wqe
  (bsc#1104427 FATE#326416).
- RDMA/hns: Adjust the order of cleanup hem table (bsc#1104427
  FATE#326416).
- RDMA/hns: Only assign dqpn if IB_QP_PATH_DEST_QPN bit is set
  (bsc#1104427 FATE#326416).
- RDMA/hns: Remove some unnecessary attr_mask judgement
  (bsc#1104427 FATE#326416).
- RDMA/hns: Only assign mtu if IB_QP_PATH_MTU bit is set
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix the qp context state diagram (bsc#1104427
  FATE#326416).
- RDMA/hns: Intercept illegal RDMA operation when use inline data
  (bsc#1104427 FATE#326416).
- RDMA/hns: Bugfix for init hem table (bsc#1104427 FATE#326416).
- RDMA/hns: Fix cq record doorbell enable in kernel (bsc#1104427
  FATE#326416).
- RDMA/hns: Fix init resp when alloc ucontext (bsc#1104427
  FATE#326416).
- RDMA/hns: Use structs to describe the uABI instead of opencoding
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix cqn type and init resp (bsc#1104427 FATE#326416).
- RDMA/hns: Support cq record doorbell for kernel space
  (bsc#1104427 FATE#326416).
- RDMA/hns: Support rq record doorbell for kernel space
  (bsc#1104427 FATE#326416).
- RDMA/hns: Support cq record doorbell for the user space
  (bsc#1104427 FATE#326416).
- RDMA/hns: Support rq record doorbell for the user space
  (bsc#1104427 FATE#326416).
- RDMA/hns: Replace __raw_write*(cpu_to_le*()) with LE write*()
  (bsc#1104427 FATE#326416).
- RDMA/hns: Use free_pages function instead of free_page
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix QP state judgement before receiving work requests
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix a bug with modifying mac address (bsc#1104427
  FATE#326416).
- RDMA/hns: ensure for-loop actually iterates and free's buffers
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix the endian problem for hns (bsc#1104427
  FATE#326416).
- RDMA/hns: Fix misplaced call to hns_roce_cleanup_hem_table
  (bsc#1104427 FATE#326416).
- RDMA/hns: Add names to function arguments in function pointers
  (bsc#1104427 FATE#326416).
- RDMA/hns: Remove unnecessary operator (bsc#1104427 FATE#326416).
- RDMA/hns: Remove unnecessary platform_get_resource() error check
  (bsc#1104427 FATE#326416).
- RDMA/hns: Set the guid for hip08 RoCE device (bsc#1104427
  FATE#326416).
- RDMA/hns: Update the verbs of polling for completion
  (bsc#1104427 FATE#326416).
- RDMA/hns: Assign zero for pkey_index of wc in hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Fill sq wqe context of ud type in hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Add gsi qp support for modifying qp in hip08
  (bsc#1104427 FATE#326416).
- RDMA/hns: Create gsi qp in hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: Assign the correct value for tx_cqn (bsc#1104427
  FATE#326416).
- RDMA/hns: Fix endian problems around imm_data and rkey
  (bsc#1104427 FATE#326416).
- RDMA/hns: Assign dest_qp when deregistering mr (bsc#1104427
  FATE#326416).
- RDMA/hns: Fix QP state judgement before sending work requests
  (bsc#1104427 FATE#326416).
- RDMA/hns: Filter for zero length of sge in hip08 kernel mode
  (bsc#1104427 FATE#326416).
- RDMA/hns: Set access flags of hip08 RoCE (bsc#1104427
  FATE#326416).
- RDMA/hns: Update the usage of sr_max and rr_max field
  (bsc#1104427 FATE#326416).
- RDMA/hns: Add rq inline data support for hip08 RoCE (bsc#1104427
  FATE#326416).
- RDMA/hns: Add detailed comments for mb() call (bsc#1104427
  FATE#326416).
- RDMA/hns: Add eq support of hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: Refactor eq code for hip06 (bsc#1104427 FATE#326416).
- RDMA/hns: Get rid of page operation after dma_alloc_coherent
  (bsc#1104427 FATE#326416).
- RDMA/hns: Get rid of virt_to_page and vmap calls after
  dma_alloc_coherent (bsc#1104427 FATE#326416).
- RDMA/hns: Fix the issue of IOVA not page continuous in hip08
  (bsc#1104427 FATE#326416).
- RDMA/hns: Modify the usage of cmd_sn in hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Unify the calculation for hem index in hip08
  (bsc#1104427 FATE#326416).
- RDMA/hns: Set the owner field of SQWQE in hip08 RoCE
  (bsc#1104427 FATE#326416).
- RDMA/hns: Add sq_invld_flg field in QP context (bsc#1104427
  FATE#326416).
- RDMA/hns: Update the usage of ack timeout in hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Set sq_cur_sge_blk_addr field in QPC in hip08
  (bsc#1104427 FATE#326416).
- RDMA/hns: Enable the cqe field of sqwqe of RC (bsc#1104427
  FATE#326416).
- RDMA/hns: Set se attribute of sqwqe in hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Configure fence attribute in hip08 RoCE (bsc#1104427
  FATE#326416).
- RDMA/hns: Configure TRRL field in hip08 RoCE device (bsc#1104427
  FATE#326416).
- RDMA/hns: Update calculation of irrl_ba field for hip08
  (bsc#1104427 FATE#326416).
- RDMA/hns: Configure sgid type for hip08 RoCE (bsc#1104427
  FATE#326416).
- RDMA/hns: Generate gid type of RoCEv2 (bsc#1104427 FATE#326416).
- RDMA/hns: Add rereg mr support for hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Add modify CQ support for hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Update the PD&CQE&MTT specification in hip08
  (bsc#1104427 FATE#326416).
- RDMA/hns: Update the IRRL table chunk size in hip08 (bsc#1104427
  FATE#326416).
- RDMA/hns: Support WQE/CQE/PBL page size configurable feature
  in hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: fix spelling mistake: "Reseved" -> "Reserved"
  (bsc#1104427 FATE#326416).
- IB/hns: Declare local functions 'static' (bsc#1104427
  FATE#326416).
- IB/hns: Annotate iomem pointers correctly (bsc#1104427
  FATE#326416).
- RDMA/hns: return 0 rather than return a garbage status value
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix calltrace for sleeping in atomic (bsc#1104427
  FATE#326416).
- RDMA/hns: Don't unregister a callback we didn't register
  (bsc#1104427 FATE#326416).
- RDMA/hns: Avoid NULL pointer exception (bsc#1104427
  FATE#326416).
- RDMA/hns: Set rdma_ah_attr type for querying qp (bsc#1104427
  FATE#326416).
- RDMA/hns: Only assign dest_qp if IB_QP_DEST_QPN bit is set
  (bsc#1104427 FATE#326416).
- RDMA/hns: Check return value of kzalloc (bsc#1104427
  FATE#326416).
- RDMA/hns: Refactor code for readability (bsc#1104427
  FATE#326416).
- RDMA/hns: Modify the value with rd&dest_rd of qp_attr
  (bsc#1104427 FATE#326416).
- RDMA/hns: remove redundant assignment to variable j (bsc#1104427
  FATE#326416).
- RDMA/hns: make various function static, fixes warnings
  (bsc#1104427 FATE#326416).
- RDMA/hns: Delete the unnecessary initializing enum to zero
  (bsc#1104427 FATE#326416).
- RDMA/hns: Fix inconsistent warning (bsc#1104427 FATE#326416).
- RDMA/hns: Replace condition statement using hardware version
  information (bsc#1104427 FATE#326416).
- RDMA/hns: Add releasing resource operation in error branch
  (bsc#1104427 FATE#326416).
- RDMA/hns: Configure the MTPT in hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: Add support for processing send wr and receive wr
  (bsc#1104427 FATE#326416).
- RDMA/hns: Add QP operations support for hip08 SoC (bsc#1104427
  FATE#326416).
- RDMA/hns: Add CQ operations support for hip08 RoCE driver
  (bsc#1104427 FATE#326416).
- RDMA/hns: Configure mac&gid and user access region for hip08
  RoCE driver (bsc#1104427 FATE#326416).
- RDMA/hns: Support multi hop addressing for PBL in hip08
  (bsc#1104427 FATE#326416).
- RDMA/hns: Split CQE from MTT in hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: Update the interfaces for MTT/CQE multi hop addressing
  in hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: Configure BT BA and BT attribute for the contexts
  in hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: Add the interfaces to support multi hop addressing
  for the contexts in hip08 (bsc#1104427 FATE#326416).
- RDMA/hns: Add mailbox's implementation for hip08 RoCE driver
  (bsc#1104427 FATE#326416).
- RDMA/hns: Add profile support for hip08 driver (bsc#1104427
  FATE#326416).
- RDMA/hns: Add command queue support for hip08 RoCE driver
  (bsc#1104427 FATE#326416).
- RDMA/hns: Modify assignment device variable to support both
  PCI device and platform device (bsc#1104427 FATE#326416).
- RDMA/hns: Initialize the PCI device for hip08 RoCE (bsc#1104427
  FATE#326416).
- RDMA/hns: Move priv in order to add multiple hns_roce support
  (bsc#1104427 FATE#326416).
- RDMA/hns: Split hw v1 driver from hns roce driver (bsc#1104427
  FATE#326416).
- IB/hns: Avoid compile test under non 64bit environments
  (bsc#1104427 FATE#326416).
- IB/hns: include linux/interrupt.h (bsc#1104427 FATE#326416).
- IB/hns: fix semicolon.cocci warnings (bsc#1104427 FATE#326416).
- IB/hns: fix returnvar.cocci warnings (bsc#1104427 FATE#326416).
- IB/hns: fix boolreturn.cocci warnings (bsc#1104427 FATE#326416).
- IB/hns: Support compile test for hns RoCE driver (bsc#1104427
  FATE#326416).
- IB/hns: fix memory leak on ah on error return path (bsc#1104427
  FATE#326416).
- IB/hns: Fix for checkpatch.pl comment style warnings
  (bsc#1104427 FATE#326416).
- IB/hns: Fix the bug with modifying the MAC address without
  removing the driver (bsc#1104427 FATE#326416).
- IB/hns: Fix the bug with rdma operation (bsc#1104427
  FATE#326416).
- IB/hns: Fix the bug with wild pointer when destroy rc qp
  (bsc#1104427 FATE#326416).
- IB/hns: Fix the bug of polling cq failed for loopback Qps
  (bsc#1104427 FATE#326416).
  Refresh
  patches.suse/0001-IB-hns-checking-for-IS_ERR-instead-of-NULL.patch.
- commit 869c294
* Thu Aug  9 2018 tbogendoerfer@suse.de
- supported.conf: added hns3 modules
- commit 7f097bf
* Thu Aug  9 2018 lduncan@suse.com
- scsi: qla4xxx: Use dma_pool_zalloc() (bsc#1086331).
- scsi: qla4xxx: Move an array from a .h into a .c file
  (bsc#1086331).
- scsi: qla4xxx: Remove unused symbols (bsc#1086331).
- scsi: qla4xxx: skip error recovery in case of register
  disconnect (bsc#1086331).
- scsi: qla4xxx: Use zeroing allocator rather than
  allocator/memset (bsc#1086331).
- commit fc896bf
* Thu Aug  9 2018 lduncan@suse.com
- scsi: qedf: Send the driver state to MFW (bsc#1086317).
- scsi: qedf: Update version number to 8.33.16.20 (bsc#1086317).
- scsi: qedf: Update copyright for 2018 (bsc#1086317).
- scsi: qedf: Add more defensive checks for concurrent error
  conditions (bsc#1086317).
- scsi: qedf: Set the UNLOADING flag when removing a vport
  (bsc#1086317).
- scsi: qedf: Add additional checks when restarting an rport
  due to ABTS timeout (bsc#1086317).
- scsi: qedf: If qed fails to enable MSI-X fail PCI probe
  (bsc#1086317).
- scsi: qedf: Honor default_prio module parameter even if DCBX
  does not converge (bsc#1086317).
- scsi: qedf: Improve firmware debug dump handling (bsc#1086317).
- scsi: qedf: Remove setting DCBX pending during soft context
  reset (bsc#1086317).
- scsi: qedf: Add task id to kref_get_unless_zero() debug messages
  when flushing requests (bsc#1086317).
- scsi: qedf: Check if link is already up when receiving a link
  up event from qed (bsc#1086317).
- scsi: qedf: Return request as DID_NO_CONNECT if MSI-X is not
  enabled (bsc#1086317).
- scsi: qedf: Release RRQ reference correctly when RRQ command
  times out (bsc#1086317).
- scsi: qedf: Honor priority from DCBX FCoE App tag (bsc#1086317).
- scsi: qedf: Add dcbx_not_wait module parameter so we won't
  wait for DCBX convergence to start discovery (bsc#1086317).
- scsi: qedf: Sanity check FCoE/FIP priority value to make sure
  it's between 0 and 7 (bsc#1086317).
- scsi: qedf: Add check for offload before flushing I/Os for
  target (bsc#1086317).
- scsi: qedf: Fix VLAN display when printing sent FIP frames
  (bsc#1086317).
- scsi: qedf: Add missing skb frees in error path (bsc#1086317).
- scsi: qedf: Increase the number of default FIP VLAN request
  retries to 60 (bsc#1086317).
- scsi: qedf: Synchronize rport restarts when multiple ELS
  commands time out (bsc#1086317).
- qedf: Add get_generic_tlv_data handler (bsc#1086317).
- qedf: Add support for populating ethernet TLVs (bsc#1086317).
- scsi: qedf: use correct strncpy() size (bsc#1086317).
- scsi: qedf: fix LTO-enabled build (bsc#1086317).
- scsi: qedf: remove redundant initialization of 'fcport'
  (bsc#1086317).
- commit be37185
* Thu Aug  9 2018 jroedel@suse.de
- kabi/severities: Allow kABI changes for kvm/x86 (except for kvm_x86_ops)
- commit 66e926d
* Thu Aug  9 2018 tbogendoerfer@suse.de
- Update config files.
  Enabled HNS3 ethernet drivers
- commit 5759ff3
* Thu Aug  9 2018 tbogendoerfer@suse.de
- net: hns3: Optimize PF CMDQ interrupt switching process
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for VF mailbox receiving unknown message
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for VF mailbox cannot receiving PF response
  (bsc#1104353 FATE#326415).
- net: hns3: remove unused hclgevf_cfg_func_mta_filter
  (bsc#1104353 FATE#326415).
- net: hns3: Optimize the VF's process of updating multicast MAC
  (bsc#1104353 FATE#326415).
- net: hns3: Optimize the PF's process of updating multicast MAC
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for vxlan tx checksum bug (bsc#1104353
  FATE#326415).
- net: hns3: Add missing break in misc_irq_handle (bsc#1104353
  FATE#326415).
- net: hns3: Fix for phy not link up problem after resetting
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for hclge_reset running repeatly problem
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for service_task not running problem after
  resetting (bsc#1104353 FATE#326415).
- net: hns3: Fix setting mac address error (bsc#1104353
  FATE#326415).
- net: hns3: Add repeat address checking for setting mac address
  (bsc#1104353 FATE#326415).
- net: hns3: Add support for IFF_ALLMULTI flag (bsc#1104353
  FATE#326415).
- net: hns3: Disable vf vlan filter when vf vlan table is full
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes initalization of RoCE handle and makes it
  conditional (bsc#1104353 FATE#326415).
- net: hns3: Adds support for led locate command for copper port
  (bsc#1104353 FATE#326415).
- net: hns3: Remove unused led control code (bsc#1104353
  FATE#326415).
- net: hns3: Clear TX/RX rings when stopping port &
  un-initializing client (bsc#1104353 FATE#326415).
- net: hns3: Removes unnecessary check when clearing TX/RX rings
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the init of the VALID BD info in the descriptor
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the state to indicate client-type
  initialization (bsc#1104353 FATE#326415).
- net: hns3: Fix for PF mailbox receving unknown message
  (bsc#1104353 FATE#326415).
- net: hns3: Add support to enable TX/RX promisc mode for H/W
  rev(0x21) (bsc#1104353 FATE#326415).
- net: hns3: Add STRP_TAGP field support for hardware revision
  0x21 (bsc#1104353 FATE#326415).
- net: hns3: Add support for tx_accept_tag2 and tx_accept_untag2
  config (bsc#1104353 FATE#326415).
- net: hns3: Updates RX packet info fetch in case of multi BD
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for CMDQ and Misc. interrupt init order problem
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes kernel panic issue during rmmod hns3 driver
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for netdev not running problem after calling
  net_stop and net_open (bsc#1104353 FATE#326415).
- net: hns3: Use enums instead of magic number in
  hclge_is_special_opcode (bsc#1104353 FATE#326415).
- net: hns3: Fix for hns3 module is loaded multiple times problem
  (bsc#1104353 FATE#326415).
- net: hns3: Fix the missing client list node initialization
  (bsc#1104353 FATE#326415).
- net: hns3: cleanup of return values in
  hclge_init_client_instance() (bsc#1104353 FATE#326415).
- net: hns3: Fixes API to fetch ethernet header length with
  kernel default (bsc#1104353 FATE#326415).
- net: hns3: Fixes error reported by Kbuild and internal review
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the missing PCI iounmap for various legs
  (bsc#1104353 FATE#326415).
- net: hns3: Add support of .sriov_configure in HNS3 driver
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for fiber link up problem (bsc#1104353
  FATE#326415).
- net: hns3: Fixes the back pressure setting when sriov is enabled
  (bsc#1104353 FATE#326415).
- net: hns3: Change return value in hnae3_register_client
  (bsc#1104353 FATE#326415).
- net: hns3: Change return type of hnae3_register_ae_algo
  (bsc#1104353 FATE#326415).
- net: hns3: Change return type of hnae3_register_ae_dev
  (bsc#1104353 FATE#326415).
- net: hns3: Add a check for client instance init state
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for the null pointer problem occurring when
  initializing ae_dev failed (bsc#1104353 FATE#326415).
- net: hns3: Fix for deadlock problem occurring when unregistering
  ae_algo (bsc#1104353 FATE#326415).
- net: hns3: refactor the loopback related function (bsc#1104353
  FATE#326415).
- net: hns3: fix for cleaning ring problem (bsc#1104353
  FATE#326415).
- net: hns3: remove add/del_tunnel_udp in hns3_enet module
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for setting mac address when resetting
  (bsc#1104353 FATE#326415).
- net: hns3: Add support of hardware rx-vlan-offload to HNS3 VF
  driver (bsc#1104353 FATE#326415).
- net: hns3: Remove packet statistics in the range of 8192~12287
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for packet loss due wrong filter config in VLAN
  tbls (bsc#1104353 FATE#326415).
- net: hns3: fix a dead loop in hclge_cmd_csq_clean (bsc#1104353
  FATE#326415).
- net: hns3: Fix to support autoneg only for port attached with
  phy (bsc#1104353 FATE#326415).
- net: hns3: fix for phy_addr error in hclge_mac_mdio_config
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the error legs in hclge_init_ae_dev function
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the out of bounds access in hclge_map_tqp
  (bsc#1104353 FATE#326415).
- net: hns3: fix to correctly fetch l4 protocol outer header
  (bsc#1104353 FATE#326415).
- net: hns3: Remove error log when getting pfc stats fails
  (bsc#1104353 FATE#326415).
- net: hns3: fix length overflow when CONFIG_ARM64_64K_PAGES
  (bsc#1104353 FATE#326415).
- net: hns3: remove unnecessary pci_set_drvdata() and devm_kfree()
  (bsc#1104353 FATE#326415).
- net: hns3: never send command queue message to IMP when reset
  (bsc#1104353 FATE#326415).
- net: hns3: fix for not initializing VF rss_hash_key problem
  (bsc#1104353 FATE#326415).
- net: hns3: fix for the wrong shift problem in
  hns3_set_txbd_baseinfo (bsc#1104353 FATE#326415).
- net: hns3: fix for returning wrong value problem in
  hns3_get_rss_indir_size (bsc#1104353 FATE#326415).
- net: hns3: fix for returning wrong value problem in
  hns3_get_rss_key_size (bsc#1104353 FATE#326415).
- net: hns3: hclge_inform_reset_assert_to_vf() can be static
  (bsc#1104353 FATE#326415).
- net: hns3: Changes required in PF mailbox to support VF reset
  (bsc#1104353 FATE#326415).
- net: hns3: Add *Asserting Reset* mailbox message & handling
  in VF (bsc#1104353 FATE#326415).
- net: hns3: Changes to support ARQ(Asynchronous Receive Queue)
  (bsc#1104353 FATE#326415).
- net: hns3: Add support to re-initialize the hclge device
  (bsc#1104353 FATE#326415).
- net: hns3: Add support to reset the enet/ring mgmt layer
  (bsc#1104353 FATE#326415).
- net: hns3: Add support to request VF Reset to PF (bsc#1104353
  FATE#326415).
- net: hns3: Add VF Reset device state and its handling
  (bsc#1104353 FATE#326415).
- net: hns3: Add VF Reset Service Task to support event handling
  (bsc#1104353 FATE#326415).
- net: hns3: Changes to make enet watchdog timeout func common
  for PF/VF (bsc#1104353 FATE#326415).
- net: hns3: fix for not returning problem in get_link_ksettings
  when phy exists (bsc#1104353 FATE#326415).
- net: hns3: add querying speed and duplex support to VF
  (bsc#1104353 FATE#326415).
- net: hns3: add get_link support to VF (bsc#1104353 FATE#326415).
- net: hns3: fix for getting wrong link mode problem (bsc#1104353
  FATE#326415).
- net: hns3: change the time interval of int_gl calculating
  (bsc#1104353 FATE#326415).
- net: hns3: change GL update rate (bsc#1104353 FATE#326415).
- net: hns3: increase the max time for IMP handle command
  (bsc#1104353 FATE#326415).
- net: hns3: export pci table of hclge and hclgevf to userspace
  (bsc#1104353 FATE#326415).
- net: hns3: fix for vlan table lost problem when resetting
  (bsc#1104353 FATE#326415).
- net: hns3: fix the VF queue reset flow error (bsc#1104353
  FATE#326415).
- net: hns3: reallocate tx/rx buffer after changing mtu
  (bsc#1104353 FATE#326415).
- net: hns3: add result checking for VF when modify unicast mac
  address (bsc#1104353 FATE#326415).
- net: hns3: add existence checking before adding unicast mac
  address (bsc#1104353 FATE#326415).
- net: hns3: fix return value error of
  hclge_get_mac_vlan_cmd_status() (bsc#1104353 FATE#326415).
- net: hns3: fix error type definition of return value
  (bsc#1104353 FATE#326415).
- net: hns3: fix for buffer overflow smatch warning (bsc#1104353
  FATE#326415).
- net: hns3: fix for loopback failure when vlan filter is enable
  (bsc#1104353 FATE#326415).
- net: hns3: add support for querying pfc puase packets statistic
  (bsc#1104353 FATE#326415).
- net: hns3: fix rx path skb->truesize reporting bug (bsc#1104353
  FATE#326415).
- net: hns3: unify the pause params setup function (bsc#1104353
  FATE#326415).
- net: hns3: fix for ipv6 address loss problem after setting
  channels (bsc#1104353 FATE#326415).
- net: hns3: fix for netdev not running problem after calling
  net_stop and net_open (bsc#1104353 FATE#326415).
- net: hns3: add existence check when remove old uc mac address
  (bsc#1104353 FATE#326415).
- net: hns3: fix for coal configuation lost when setting the
  channel (bsc#1104353 FATE#326415).
- net: hns3: refactor the coalesce related struct (bsc#1104353
  FATE#326415).
- net: hns3: fix for coalesce configuration lost during reset
  (bsc#1104353 FATE#326415).
- net: hns3: refactor the get/put_vector function (bsc#1104353
  FATE#326415).
- net: hns3: fix for use-after-free when setting ring parameter
  (bsc#1104353 FATE#326415).
- net: hns3: fix for pause configuration lost during reset
  (bsc#1104353 FATE#326415).
- net: hns3: fix for RSS configuration loss problem during reset
  (bsc#1104353 FATE#326415).
- net: hns3: refactor the hclge_get/set_rss_tuple function
  (bsc#1104353 FATE#326415).
- net: hns3: refactor the hclge_get/set_rss function (bsc#1104353
  FATE#326415).
- net: hns3: add support for VF driver inner interface
  hclgevf_ops.get_tqps_and_rss_info (bsc#1104353 FATE#326415).
- net: hns3: set the max ring num when alloc netdev (bsc#1104353
  FATE#326415).
- net: hns3: fix the queue id for tqp enable&&reset (bsc#1104353
  FATE#326415).
- net: hns3: fix endian issue when PF get mbx message flag
  (bsc#1104353 FATE#326415).
- net: hns3: set the cmdq out_vld bit to 0 after used (bsc#1104353
  FATE#326415).
- net: hns3: VF should get the real rss_size instead of
  rss_size_max (bsc#1104353 FATE#326415).
- net: hns3: add int_gl_idx setup for VF (bsc#1104353
  FATE#326415).
- net: hns3: add get/set_coalesce support to VF (bsc#1104353
  FATE#326415).
- net: hns3: converting spaces into tabs to avoid checkpatch.pl
  warning (bsc#1104353 FATE#326415).
- net: hns3: add net status led support for fiber port
  (bsc#1104353 FATE#326415).
- net: hns3: add ethtool -p support for fiber port (bsc#1104353
  FATE#326415).
- net: hns3: add manager table initialization for hardware
  (bsc#1104353 FATE#326415).
- net: hns3: add support for get_regs (bsc#1104353 FATE#326415).
- net: hns3: check for NULL function pointer in
  hns3_nic_set_features (bsc#1104353 FATE#326415).
- net: hns3: add feature check when feature changed (bsc#1104353
  FATE#326415).
- net: hns3: add int_gl_idx setup for TX and RX queues
  (bsc#1104353 FATE#326415).
- net: hns3: change the unit of GL value macro (bsc#1104353
  FATE#326415).
- net: hns3: remove unused GL setup function (bsc#1104353
  FATE#326415).
- net: hns3: refactor GL update function (bsc#1104353
  FATE#326415).
- net: hns3: refactor interrupt coalescing init function
  (bsc#1104353 FATE#326415).
- net: hns3: add ethtool_ops.set_coalesce support to PF
  (bsc#1104353 FATE#326415).
- net: hns3: add ethtool_ops.get_coalesce support to PF
  (bsc#1104353 FATE#326415).
- net: hns3: remove TSO config command from VF driver (bsc#1104353
  FATE#326415).
- net: hns3: add ethtool_ops.get_channels support for VF
  (bsc#1104353 FATE#326415).
- net: hns3: report the function type the same line with
  hns3_nic_get_stats64 (bsc#1104353 FATE#326415).
- net: hns3: Add more packet size statisctics (bsc#1104353
  FATE#326415).
- net: hns3: remove redundant semicolon (bsc#1104353 FATE#326415).
- net: hns3: fix for not setting pause parameters (bsc#1104353
  FATE#326415).
- net: hns3: add MTU initialization for hardware (bsc#1104353
  FATE#326415).
- net: hns3: fix for changing MTU (bsc#1104353 FATE#326415).
- net: hns3: fix for setting MTU (bsc#1104353 FATE#326415).
- net: hns3: fix for updating fc_mode_last_time (bsc#1104353
  FATE#326415).
- net: hns3: Fix a response data read error of tqp statistics
  query (bsc#1104353 FATE#326415).
- net: hns3: Remove a useless member of struct hns3_stats
  (bsc#1104353 FATE#326415).
- net: hns3: Fix an error macro definition of HNS3_TQP_STAT
  (bsc#1104353 FATE#326415).
- net: hns3: Fix a loop index error of tqp statistics query
  (bsc#1104353 FATE#326415).
- net: hns3: Fix an error of total drop packet statistics
  (bsc#1104353 FATE#326415).
- net: hns3: Mask the packet statistics query when NIC is down
  (bsc#1104353 FATE#326415).
- net: hns3: Modify the update period of packet statistics
  (bsc#1104353 FATE#326415).
- net: hns3: Remove repeat statistic of rx_errors (bsc#1104353
  FATE#326415).
- net: hns3: Fix spelling errors (bsc#1104353 FATE#326415).
- net: hns3: Unify the strings display of packet statistics
  (bsc#1104353 FATE#326415).
- net: hns3: Disable VFs change rxvlan offload status (bsc#1104353
  FATE#326415).
- net: hns3: Add ethtool interface for vlan filter (bsc#1104353
  FATE#326415).
- net: hns3: hns3_get_channels() can be static (bsc#1104353
  FATE#326415).
- net: hns3: change TM sched mode to TC-based mode when SRIOV
  enabled (bsc#1104353 FATE#326415).
- net: hns3: Increase the default depth of bucket for TM shaper
  (bsc#1104353 FATE#326415).
- net: hns3: add support for querying advertised pause frame by
  ethtool ethx (bsc#1104353 FATE#326415).
- net: hns3: add Asym Pause support to phy default features
  (bsc#1104353 FATE#326415).
- net: hns3: add support to update flow control settings after
  autoneg (bsc#1104353 FATE#326415).
- net: hns3: add support for set_pauseparam (bsc#1104353
  FATE#326415).
- net: hns3: fix for getting auto-negotiation state in
  hclge_get_autoneg (bsc#1104353 FATE#326415).
- net: hns3: cleanup mac auto-negotiation state query (bsc#1104353
  FATE#326415).
- net: hns3: add handling vlan tag offload in bd (bsc#1104353
  FATE#326415).
- net: hns3: add ethtool related offload command (bsc#1104353
  FATE#326415).
- net: hns3: add vlan offload config command (bsc#1104353
  FATE#326415).
- net: hns3: add a mask initialization for mac_vlan table
  (bsc#1104353 FATE#326415).
- net: hns3: get rss_size_max from configuration but not hardcode
  (bsc#1104353 FATE#326415).
- net: hns3: free the ring_data structrue when change tqps
  (bsc#1104353 FATE#326415).
- net: hns3: change the returned tqp number by ethtool -x
  (bsc#1104353 FATE#326415).
- net: hns3: add support to modify tqps number (bsc#1104353
  FATE#326415).
- net: hns3: add support to query tqps number (bsc#1104353
  FATE#326415).
- net: hns3: Add mailbox interrupt handling to PF driver
  (bsc#1104353 FATE#326415).
- net: hns3: Change PF to add ring-vect binding & resetQ to
  mailbox (bsc#1104353 FATE#326415).
- net: hns3: Add mailbox support to PF driver (bsc#1104353
  FATE#326415).
- net: hns3: Unified HNS3 {VF|PF} Ethernet Driver for hip08 SoC
  (bsc#1104353 FATE#326415).
- net: hns3: Add HNS3 VF driver to kernel build framework
  (bsc#1104353 FATE#326415).
- net: hns3: Add HNS3 VF HCL(Hardware Compatibility Layer)
  Support (bsc#1104353 FATE#326415).
- net: hns3: Add mailbox support to VF driver (bsc#1104353
  FATE#326415).
- net: hns3: Add HNS3 VF IMP(Integrated Management Proc) cmd
  interface (bsc#1104353 FATE#326415).
- net: hns3: Refactors the requested reset & pending reset
  handling code (bsc#1104353 FATE#326415).
- net: hns3: Add reset service task for handling reset requests
  (bsc#1104353 FATE#326415).
- net: hns3: Refactor of the reset interrupt handling logic
  (bsc#1104353 FATE#326415).
- net: hns3: Updates MSI/MSI-X alloc/free APIs(depricated)
  to new APIs (bsc#1104353 FATE#326415).
- net: hns3: cleanup mac auto-negotiation state query in
  hclge_update_speed_duplex (bsc#1104353 FATE#326415).
- net: hns3: fix a bug when getting phy address from NCL_config
  file (bsc#1104353 FATE#326415).
- net: hns3: fix a bug for phy supported feature initialization
  (bsc#1104353 FATE#326415).
- net: hns3: add support for nway_reset (bsc#1104353 FATE#326415).
- net: hns3: add support for set_link_ksettings (bsc#1104353
  FATE#326415).
- net: hns3: fix a bug in hns3_driv_to_eth_caps (bsc#1104353
  FATE#326415).
- net: hns3: fix for getting advertised_caps in
  hns3_get_link_ksettings (bsc#1104353 FATE#326415).
- net: hns3: fix for getting autoneg in hns3_get_link_ksettings
  (bsc#1104353 FATE#326415).
- net: hns3: hns3:fix a bug about statistic counter in reset
  process (bsc#1104353 FATE#326415).
- net: hns3: Fix a misuse to devm_free_irq (bsc#1104353
  FATE#326415).
- net: hns3: Add reset interface implementation in client
  (bsc#1104353 FATE#326415).
- net: hns3: Add timeout process in hns3_enet (bsc#1104353
  FATE#326415).
- net: hns3: Add reset process in hclge_main (bsc#1104353
  FATE#326415).
- net: hns3: Add support for misc interrupt (bsc#1104353
  FATE#326415).
- net: hns3: Refactor the initialization of command queue
  (bsc#1104353 FATE#326415).
- net: hns3: Refactor mac_init function (bsc#1104353 FATE#326415).
- net: hns3: Refactor the mapping of tqp to vport (bsc#1104353
  FATE#326415).
- net: hns3: remove a couple of redundant assignments (bsc#1104353
  FATE#326415).
- net: hns3: fix the bug when reuse command description in
  hclge_add_mac_vlan_tbl (bsc#1104353 FATE#326415).
- net: hns3: fix a bug in hclge_uninit_client_instance
  (bsc#1104353 FATE#326415).
- net: hns3: add nic_client check when initialize roce base
  information (bsc#1104353 FATE#326415).
- net: hns3: fix the bug of hns3_set_txbd_baseinfo (bsc#1104353
  FATE#326415).
- net: hns3: fix a bug about hns3_clean_tx_ring (bsc#1104353
  FATE#326415).
- net: hns3: remove redundant memset when alloc buffer
  (bsc#1104353 FATE#326415).
- net: hns3: fix the TX/RX ring.queue_index in hns3_ring_get_cfg
  (bsc#1104353 FATE#326415).
- net: hns3: get vf count by pci_sriov_get_totalvfs (bsc#1104353
  FATE#326415).
- net: hns3: fix the ops check in hns3_get_rxnfc (bsc#1104353
  FATE#326415).
- net: hns3: fix the bug when map buffer fail (bsc#1104353
  FATE#326415).
- net: hns3: fix a bug when alloc new buffer (bsc#1104353
  FATE#326415).
- net: hns3: Add mac loopback selftest support in hns3 driver
  (bsc#1104353 FATE#326415).
- net: hns3: Refactor the skb receiving and transmitting function
  (bsc#1104353 FATE#326415).
- net: hns3: make local functions static (bsc#1104353
  FATE#326415).
- net: hns3: fix the ring count for ETHTOOL_GRXRINGS (bsc#1104353
  FATE#326415).
- net: hns3: add support for ETHTOOL_GRXFH (bsc#1104353
  FATE#326415).
- net: hns3: add support for set_rxnfc (bsc#1104353 FATE#326415).
- net: hns3: add support for set_ringparam (bsc#1104353
  FATE#326415).
- net: hns3: fixes the ring index in hns3_fini_ring (bsc#1104353
  FATE#326415).
- net: hns3: Cleanup for non-static function in hns3 driver
  (bsc#1104353 FATE#326415).
- net: hns3: Cleanup for endian issue in hns3 driver (bsc#1104353
  FATE#326415).
- net: hns3: Cleanup for struct that used to send cmd to firmware
  (bsc#1104353 FATE#326415).
- net: hns3: Consistently using GENMASK in hns3 driver
  (bsc#1104353 FATE#326415).
- net: hns3: Cleanup indentation for Kconfig in the the hisilicon
  folder (bsc#1104353 FATE#326415).
- net: hns3: Add hns3_get_handle macro in hns3 driver (bsc#1104353
  FATE#326415).
- net: hns3: Cleanup for shifting true in hns3 driver (bsc#1104353
  FATE#326415).
- net: hns3: fix null pointer dereference before null check
  (bsc#1104353 FATE#326415).
- net: hns3: Add DCB support when interacting with network stack
  (bsc#1104353 FATE#326415).
- net: hns3: Setting for fc_mode and dcb enable flag in TM module
  (bsc#1104353 FATE#326415).
- net: hns3: Add dcb netlink interface for the support of DCB
  feature (bsc#1104353 FATE#326415).
- net: hns3: Add hclge_dcb module for the support of DCB feature
  (bsc#1104353 FATE#326415).
- net: hns3: Add some interface for the support of DCB feature
  (bsc#1104353 FATE#326415).
- net: hns3: Add tc-based TM support for sriov enabled port
  (bsc#1104353 FATE#326415).
- net: hns3: Add support for port shaper setting in TM module
  (bsc#1104353 FATE#326415).
- net: hns3: Add support for PFC setting in TM module (bsc#1104353
  FATE#326415).
- net: hns3: Add support for dynamically buffer reallocation
  (bsc#1104353 FATE#326415).
- net: hns3: Support for dynamically assigning tx buffer to TC
  (bsc#1104353 FATE#326415).
- net: hns3: Fix an error handling path in 'hclge_rss_init_hw()'
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for pri to tc mapping in TM (bsc#1104353
  FATE#326415).
- net: hns3: Fix for setting rss_size incorrectly (bsc#1104353
  FATE#326415).
- net: hns3: Fix typo error for feild in hclge_tm (bsc#1104353
  FATE#326415).
- net: hns3: Fix for rx priv buf allocation when DCB is not
  supported (bsc#1104353 FATE#326415).
- net: hns3: Fix for rx_priv_buf_alloc not setting rx shared
  buffer (bsc#1104353 FATE#326415).
- net: hns3: Fix for not setting rx private buffer size to zero
  (bsc#1104353 FATE#326415).
- net: hns3: Fix for DEFAULT_DV when dev doesn't support DCB
  (bsc#1104353 FATE#326415).
- net: hns3: Fix initialization when cmd is not supported
  (bsc#1104353 FATE#326415).
- net: hns3: Cleanup for ROCE capability flag in ae_dev
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the premature exit of loop when matching
  clients (bsc#1104353 FATE#326415).
- net: hns3: Fixes the default VLAN-id of PF (bsc#1104353
  FATE#326415).
- net: hns3: Fixes the ether address copy with appropriate API
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the initialization of MAC address in hardware
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes ring-to-vector map-and-unmap command
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the command used to unmap ring from vector
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes initialization of phy address from firmware
  (bsc#1104353 FATE#326415).
- net: hns3: Fixes the wrong IS_ERR check on the returned phydev
  value (bsc#1104353 FATE#326415).
- net: hns3: Add support to change MTU in HNS3 hardware
  (bsc#1104353 FATE#326415).
- net: hns3: fix a handful of spelling mistakes (bsc#1104353
  FATE#326415).
- net: hns3: Fixes the static check warning due to missing unsupp
  L3 proto check (bsc#1104353 FATE#326415).
- net: hns3: Fixes the static checker error warning in
  hns3_get_link_ksettings() (bsc#1104353 FATE#326415).
- net: hns3: Fixes the missing u64_stats_fetch_begin_irq in
  64-bit stats fetch (bsc#1104353 FATE#326415).
- net: hns3: ensure media_type is unitialized (bsc#1104353
  FATE#326415).
- hns3pf: Fix some harmless copy and paste bugs (bsc#1104353
  FATE#326415).
- hns3pf: fix hns3_del_tunnel_port() (bsc#1104353 FATE#326415).
- net: hns3: fix spelling mistake: "capabilty" -> "capability"
  (bsc#1104353 FATE#326415).
- hns3: fix unused function warning (bsc#1104353 FATE#326415).
- commit 0a43e3f
* Thu Aug  9 2018 msuchanek@suse.de
- Re-sort powerpc Spectre patches.
- Refresh patches.arch/powerpc-64s-Add-support-for-a-store-forwarding-barri.patch.
- Refresh patches.arch/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch.
- commit 01a5251
* Thu Aug  9 2018 oneukum@suse.com
- media: rc: oops in ir_timer_keyup after device unplug
  (bsc#1090888).
- commit 3663882
* Thu Aug  9 2018 msuchanek@suse.de
- powerpc/64: Add GENERIC_CPU support for little endian (FATE#325836).
- Update config files.
- commit c8b744b
* Thu Aug  9 2018 oneukum@suse.com
- blacklist.conf: the patch changes the API
- commit c6dbfea
* Thu Aug  9 2018 hare@suse.de
- scsi: mpt3sas: Update driver version "26.100.00.00"
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: As per MPI-spec, use combined reply queue for
  SAS3.5 controllers when HBA supports more than 16 MSI-x vectors
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Fix, False timeout prints for ioctl
  and other internal commands during controller reset
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Don't access the structure after decrementing
  it's instance reference count (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Incorrect command status was set/marked as not
  used (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Don't abort I/Os issued to NVMe drives
  while processing Async Broadcast primitive event
  (bsc#1086906,FATE#324923).
- commit 60a6371
* Thu Aug  9 2018 hare@suse.de
- scsi: mpt3sas: Add an I/O barrier (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Update driver version "25.100.00.00"
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: fix possible memory leak
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: For NVME device, issue a protocol level reset
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Update MPI Headers (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Report Firmware Package Version from HBA Driver
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Cache enclosure pages during enclosure add
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Allow processing of events during driver unload
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Increase event log buffer to support 24 port
  HBA's (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Added support for SAS Device Discovery Error
  Event (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Enhanced handling of Sense Buffer
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Optimize I/O memory consumption in driver
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Lockless access for chain buffers
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Pre-allocate RDPQ Array at driver boot time
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Bug fix for big endian systems
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: fix spelling mistake: "disbale" -> "disable"
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: clarify mmio pointer types
  (bsc#1086906,FATE#324923).
- commit 840c968
* Thu Aug  9 2018 hare@suse.de
- scsi: mpt3sas: Introduce Base function for cloning
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Introduce function to clone mpi reply
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Introduce function to clone mpi request
  (bsc#1086906,FATE#324923).
- Refresh
  patches.fixes/scsi-mpt3sas-Do-not-use-32-bit-atomic-request-descri.patch.
- commit 9ba5e2b
* Thu Aug  9 2018 hare@suse.de
- scsi: mpt3sas: Introduce API to get BAR0 mapped buffer address
  (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Configure reply post queue depth, DMA and sgl
  tablesize (bsc#1086906,FATE#324923).
- scsi: mpt3sas: Add PCI device ID for Andromeda
  (bsc#1086906,FATE#324923).
- commit 4557764
* Thu Aug  9 2018 hare@suse.de
- scsi: mpt3sas: Do not mark fw_event workqueue as WQ_MEM_RECLAIM
  (bsc#1086906,FATE#324923).
- commit c0b5a3a
* Thu Aug  9 2018 tiwai@suse.de
- Fix arm64 breakage with this_cput_write() (bsc#1089343
  CVE-2018-3646).
- commit 059d25d
* Thu Aug  9 2018 msuchanek@suse.de
- selftests/powerpc: Fix ptrace-pkey for default execute
  permission change (bsc#1097577).
- selftests/powerpc: Fix core-pkey for default execute permission
  change (bsc#1097577).
- powerpc/pkeys: make protection key 0 less special (bsc#1097577).
- powerpc/pkeys: Preallocate execute-only key (bsc#1097577).
- powerpc/pkeys: Fix calculation of total pkeys (bsc#1097577).
- powerpc/pkeys: Save the pkey registers before fork
  (bsc#1097577).
- powerpc/pkeys: key allocation/deallocation must not change
  pkey registers (bsc#1097577).
- powerpc/pkeys: Deny read/write/execute by default (bsc#1097577).
- powerpc/pkeys: Give all threads control of their key permissions
  (bsc#1097577).
- commit f0b072f
* Thu Aug  9 2018 hare@suse.de
- scsi: mpt3sas: Replace PCI pool old API (bsc#1081917). - Refresh patches.drivers/scsi-mpt3sas-SGL-to-PRP-Translation-for-I-Os-to-NVMe.patch.
- commit 02a8fdb
* Thu Aug  9 2018 hare@suse.de
- scsi: qla2xxx: remove irq save in qla2x00_poll() (bsc#1086327,FATE#324903).
- commit f20c572
* Thu Aug  9 2018 hare@suse.de
- kabi/severities: ignore qla2xxx as all symbols are internal
- commit 1d5e8aa
* Thu Aug  9 2018 tbogendoerfer@suse.de
- Refresh
  patches.drivers/net-sched-get-rid-of-struct-tc_to_netdev.patch.
- commit e72cc42
* Thu Aug  9 2018 tbogendoerfer@suse.de
- Refresh
  patches.drivers/net-sched-change-return-value-of-ndo_setup_tc-for-dr.patch.
- commit 9aa4a5b
* Thu Aug  9 2018 tbogendoerfer@suse.de
- Refresh
  patches.drivers/net-sched-push-cls-related-args-into-cls_common-stru.patch.
- commit a721468
* Thu Aug  9 2018 tbogendoerfer@suse.de
- hns3pf: don't check handle during mqprio offload (bsc#1104353
  FATE#326415).
- commit b715ab5
* Thu Aug  9 2018 tbogendoerfer@suse.de
- Refresh
  patches.drivers/net-sched-make-type-an-argument-for-ndo_setup_tc.patch.
- commit e316e44
* Thu Aug  9 2018 tbogendoerfer@suse.de
- net: hns3: Add HNS3 driver to kernel build framework &
  MAINTAINERS (bsc#1104353 FATE#326415).
- net: hns3: Add Ethtool support to HNS3 driver (bsc#1104353
  FATE#326415).
- net: hns3: Add MDIO support to HNS3 Ethernet driver for hip08
  SoC (bsc#1104353 FATE#326415).
- net: hns3: Add support of TX Scheduler & Shaper to HNS3 driver
  (bsc#1104353 FATE#326415).
- net: hns3: Add HNS3 Acceleration Engine & Compatibility Layer
  Support (bsc#1104353 FATE#326415).
- net: hns3: Add HNS3 IMP(Integrated Mgmt Proc) Cmd Interface
  Support (bsc#1104353 FATE#326415).
- net: hns3: Add support of the HNAE3 framework (bsc#1104353
  FATE#326415).
- net: hns3: Add support of HNS3 Ethernet Driver for hip08 SoC
  (bsc#1104353 FATE#326415).
- commit aacbe50
* Thu Aug  9 2018 jack@suse.cz
- patches.fixes/reiserfs-fix-buffer-overflow-with-long-warning-messa.patch:
  Silence bogus compiler warning about unused result of strscpy().
- commit 7a69014
* Thu Aug  9 2018 hare@suse.de
- scsi: qla2xxx: Fix crash on qla2x00_mailbox_command
  (bsc#1086327,FATE#324903).
- commit b3b8f71
* Thu Aug  9 2018 hare@suse.de
- scsi: qla2xxx: Fix setting lower transfer speed if GPSC fails
  (bsc#1086327,FATE#324903).
- commit 85edfd0
* Thu Aug  9 2018 hare@suse.de
- scsi: qla2xxx: Update driver version to 10.00.00.07-k
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix TMF and Multi-Queue config
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Prevent relogin loop by removing stale code
  (bsc#1086327,FATE#324903).
- commit f6a2423
* Thu Aug  9 2018 hare@suse.de
- scsi: qla2xxx: Remove stale debug value for login_retry flag
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Use predefined get_datalen_for_atio() inline
  function (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix Inquiry command being dropped in Target mode
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Move GPSC and GFPNID out of session management
  (bsc#1086327,FATE#324903).
- commit 209318f
* Thu Aug  9 2018 hare@suse.de
- scsi: qla2xxx: Reduce redundant ADISC command for RSCNs
  (bsc#1086327,FATE#324903).
- commit cfaf492
* Thu Aug  9 2018 hare@suse.de
- Refresh
  patches.drivers/qla2xxx-Fix-Async-GPN_FT-for-FCP-and-FC-NVMe-scan.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
- commit a88ab76
* Thu Aug  9 2018 tbogendoerfer@suse.de
- qed: Make some functions static (bsc#1086314 FATE#324886).
- qed: remove redundant functions qed_get_cm_pq_idx_rl
  (bsc#1086314 FATE#324886).
- qed: remove redundant functions qed_set_gft_event_id_cm_hdr
  (bsc#1086314 FATE#324886).
- qede: Add driver callbacks for eeprom module query (bsc#1086314
  FATE#324886).
- qed: Add qed APIs for PHY module query (bsc#1086314
  FATE#324886).
- qed: remove redundant pointer 'name' (bsc#1086314 FATE#324886).
- qed: fix spelling mistake "successffuly" -> "successfully"
  (bsc#1086314 FATE#324886).
- RDMA/qedr: Fix NULL pointer dereference when running over
  iWARP without RDMA-CM (bsc#1086314 FATE#324886).
- RDMA/qedr: fix spelling mistake: "adrresses" -> "addresses"
  (bsc#1086314 FATE#324886).
- RDMA/qedr: fix spelling mistake: "failes" -> "fails"
  (bsc#1086314 FATE#324886).
- qed*: Utilize FW 8.37.2.0 (bsc#1086314 FATE#324886).
- qed: use dma_zalloc_coherent instead of allocator/memset
  (bsc#1086314 FATE#324886).
- qed: Add srq core support for RoCE and iWARP (bsc#1086314
  FATE#324886).
- qed*: Add link change count value to ethtool statistics display
  (bsc#1086314 FATE#324886).
- commit e41194d
* Thu Aug  9 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-lpfc-Correct-LCB-ACCept-payload.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-ELS-abort-on-SLI-3-adapters.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-driver-crash-when-re-registering-NVME-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-list-corruption-on-the-completion-queu.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-sysfs-Speed-value-on-CNA-ports.patch.
- Refresh
  patches.drivers/scsi-lpfc-Limit-tracking-of-tgt-queue-depth-in-fast-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Remove-lpfc_enable_pbde-as-module-paramete.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.6.patch.
- Refresh patches.fixes/nvme-use-hw-qid-in-trace-events.patch.
  Update seriers sorting
- commit 05b54b9
* Thu Aug  9 2018 jack@suse.cz
- ext4: fix check to prevent initializing reserved inodes
  (bsc#1104319).
- commit 3986094
* Thu Aug  9 2018 hare@suse.de
- scsi: qla2xxx: Fix Rport and session state getting out of sync
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix sending ADISC command for login
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Correct setting of SAM_STAT_CHECK_CONDITION
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: correctly shift host byte
  (bsc#1086327,FATE#324903).
- scsi: qla2xxx: Fix race condition between iocb timeout and
  initialisation (bsc#1086327,FATE#324903).
- commit 426fe6a
* Thu Aug  9 2018 jbohac@suse.cz
- kabi; ip: drop IPSTATS_MIB_REASM_OVERLAPS (bsc#1103097,
  CVE-2018-5391).
- commit 6b61716
* Thu Aug  9 2018 jthumshirn@suse.de
- xfs: catch inode allocation state mismatch corruption
  (bsc#1104211).
- commit 5512909
* Thu Aug  9 2018 glin@suse.com
- bpf, ppc64: fix unexpected r0=0 exit path inside bpf_xadd
  (bsc#1083647).
- commit d914487
* Thu Aug  9 2018 colyli@suse.de
- dm writecache: support optional offset for start of device
  (bsc#1101116,fate#324698).
- dm writecache: use 2-factor allocator arguments
  (bsc#1101116,fate#324698).
- commit 82142d5
* Thu Aug  9 2018 colyli@suse.de
- dm: add writecache target (bsc#1101116,fate#324697).
- Update config files to add CONFIG_DM_WRITECACHE=m
- supported.conf: add drivers/md/dm-writecache
- commit 1d27f06
* Thu Aug  9 2018 colyli@suse.de
- overflow.h: Add allocation size calculation helpers
  (bsc#1101116,fate#324698).
- commit d2ae9ee
* Thu Aug  9 2018 colyli@suse.de
- compiler.h: enable builtin overflow checkers and add fallback
  code (bsc#1101116,fate#324698).
- branch-check: fix long->int truncation when profiling branches
  (bsc#1101116,fate#324698).
- commit 66925e5
* Wed Aug  8 2018 tiwai@suse.de
- EDAC: Add missing MEM_LRDDR4 entry in edac_mem_types[]
  (bsc#1103886).
- commit 05dc898
* Wed Aug  8 2018 msuchanek@suse.de
- hotplug/pmt: Update topology after PMT (FATE#325308).
- mobility/numa: Ensure numa update does not overlap
  (FATE#325308).
- hotplug/cpu: Provide CPU readd operation (FATE#325308).
- hotplug/cpu: Add operation queuing function (FATE#325308).
- hotplug/cpu: Conditionally acquire/release DRC index
  (FATE#325308).
- commit fe4b5e8
* Wed Aug  8 2018 tiwai@suse.de
- clk: at91: fix clk-generated compilation (bsc#1051510).
- commit fe89fab
* Wed Aug  8 2018 msuchanek@suse.de
- ibmvnic: Update firmware error reporting with cause string
  (bsc#1104174).
- ibmvnic: Remove code to request error information (bsc#1104174).
- ibmvnic: Revise RX/TX queue error messages (bsc#1101331).
- commit ad29e0c
* Wed Aug  8 2018 jthumshirn@suse.de
- Delete
  patches.suse/0201-dax-dm-allow-device-mapper-to-operate-without-dax-su.patch (bsc#1103917).
- commit 34be890
* Wed Aug  8 2018 jthumshirn@suse.de
- linvdimm, pmem: Preserve read-only setting for pmem devices
  (git-fixes).
- commit 4caf4e0
* Wed Aug  8 2018 hare@suse.de
- scsi: smartpqi: bump driver version to 1.1.4-130 (bsc#1086274).
- scsi: smartpqi: fix critical ARM issue reading PQI index
  registers (bsc#1086274).
- scsi: smartpqi: add inspur advantech ids (bsc#1086274).
- scsi: smartpqi: improve error checking for sync requests
  (bsc#1086274).
- scsi: smartpqi: improve handling for sync requests
  (bsc#1086274).
- scsi: smartpqi: update driver version (bsc#1086274).
- scsi: smartpqi: workaround fw bug for oq deletion (bsc#1086274).
- scsi: smartpqi: add in new supported controllers (bsc#1086274).
- commit 16b2418
* Wed Aug  8 2018 hare@suse.de
- nvme: use hw qid in trace events (bsc#1102633).
- nvme-fabrics: Ignore nr_io_queues option for discovery
  controllers (bsc#1102633).
- commit 7585e24
* Wed Aug  8 2018 hare@suse.de
- nvme.h: fixup ANA group descriptor format (bsc#1104111).
- commit 8716981
* Wed Aug  8 2018 jthumshirn@suse.de
- libnvdimm, dimm: fix dpa reservation vs uninitialized label area
  (git-fixes).
- commit 19be07d
* Wed Aug  8 2018 hare@suse.de
- scsi: lpfc: update driver version to 12.0.0.6 (bsc#1102658).
- scsi: lpfc: Remove lpfc_enable_pbde as module parameter
  (bsc#1102658).
- scsi: lpfc: Correct LCB ACCept payload (bsc#1102658).
- scsi: lpfc: Limit tracking of tgt queue depth in fast path
  (bsc#1102658).
- scsi: lpfc: Fix driver crash when re-registering NVME rports
  (bsc#1102658).
- scsi: lpfc: Fix list corruption on the completion queue
  (bsc#1102658).
- scsi: lpfc: Fix sysfs Speed value on CNA ports (bsc#1102658).
- scsi: lpfc: Fix ELS abort on SLI-3 adapters (bsc#1102658).
- commit 7874701
* Wed Aug  8 2018 hare@suse.de
- scripts/git_sort/git_sort.py: Update SCSI branches from mkp
- commit 9ef0360
* Wed Aug  8 2018 hare@suse.de
- scsi: lpfc: Revise copyright for new company language
  (bsc#1102658).
- scsi: lpfc: update driver version to 12.0.0.5 (bsc#1102658).
- scsi: lpfc: devloss timeout race condition caused null pointer
  reference (bsc#1102658).
- scsi: lpfc: Fix NVME Target crash in defer rcv logic
  (bsc#1102658).
- scsi: lpfc: Support duration field in Link Cable Beacon V1
  command (bsc#1102658).
- scsi: lpfc: Make PBDE optimizations configurable (bsc#1102658).
- scsi: lpfc: Fix abort error path for NVMET (bsc#1102658).
- scsi: lpfc: Fix panic if driver unloaded when port is offline
  (bsc#1102658).
- scsi: lpfc: Fix driver not setting dpp bits correctly in
  doorbell word (bsc#1102658).
- scsi: lpfc: Add Buffer overflow check, when nvme_info larger
  than PAGE_SIZE (bsc#1102658).
- commit 76d7dc2
* Wed Aug  8 2018 tiwai@suse.de
- Update config files: update vanilla config accordingly, too
- commit 85e24ed
* Wed Aug  8 2018 hare@suse.de
- nvme: fixup crash on failed discovery (bsc#1103920).
- commit 62c671b
* Wed Aug  8 2018 tiwai@suse.de
- Enable / support pinctrl-lewisburg (FATE#325120)
- commit a75e7c4
* Wed Aug  8 2018 tiwai@suse.de
- pinctrl: intel: Add Intel Lewisburg GPIO support (FATE#325120).
- commit 8bbee0b
* Wed Aug  8 2018 jthumshirn@suse.de
- Refresh patches.kabi/kabi-fixup-bdev_dax_supported.patch.
  Fix build with CONFIG_FS_DAX=n
- commit 5e2991a
* Wed Aug  8 2018 jthumshirn@suse.de
- kabi/severities: don't complain on hisi_sas internal changes (FATE#326253).
- commit 1886299
* Wed Aug  8 2018 jthumshirn@suse.de
- scsi: hisi_sas: Mark PHY as in reset for nexus reset
  (FATE#326253).
- scsi: hisi_sas: Fix return value when get_free_slot() failed
  (FATE#326253).
- scsi: hisi_sas: Terminate STP reject quickly for v2 hw
  (FATE#326253).
- scsi: hisi_sas: Add v2 hw force PHY function for internal ATA
  command (FATE#326253).
- scsi: hisi_sas: Include TMF elements in struct hisi_sas_slot
  (FATE#326253).
- scsi: hisi_sas: Try wait commands before before controller reset
  (FATE#326253).
- scsi: hisi_sas: Init disks after controller reset (FATE#326253).
- scsi: hisi_sas: Create a scsi_host_template per HW module
  (FATE#326253).
- scsi: hisi_sas: Reset disks when discovered (FATE#326253).
- scsi: hisi_sas: Add LED feature for v3 hw (FATE#326253).
- scsi: hisi_sas: Change common allocation mode of device id
  (FATE#326253).
- scsi: hisi_sas: change slot index allocation mode (FATE#326253).
- scsi: hisi_sas: Introduce hisi_sas_phy_set_linkrate()
  (FATE#326253).
- scsi: hisi_sas: fix a typo in hisi_sas_task_prep()
  (FATE#326253).
- scsi: hisi_sas: add check of device in hisi_sas_task_exec()
  (FATE#326253).
- scsi: hisi_sas: Use device lock to protect slot alloc/free
  (FATE#326253).
- scsi: hisi_sas: Don't lock DQ for complete task sending
  (FATE#326253).
- scsi: hisi_sas: allocate slot buffer earlier (FATE#326253).
- scsi: hisi_sas: make return type of prep functions void
  (FATE#326253).
- scsi: hisi_sas: relocate smp sg map (FATE#326253).
- scsi: hisi_sas: workaround a v3 hw hilink bug (FATE#326253).
- scsi: hisi_sas: add readl poll timeout helper wrappers
  (FATE#326253).
- scsi: hisi_sas: remove redundant handling to event95 for v3
  (FATE#326253).
- scsi: hisi_sas: config ATA de-reset as an constrained command
  for v3 hw (FATE#326253).
- scsi: hisi_sas: update PHY linkrate after a controller reset
  (FATE#326253).
- scsi: hisi_sas: stop controller timer for reset (FATE#326253).
- scsi: hisi_sas: check sas_dev gone earlier in
  hisi_sas_abort_task() (FATE#326253).
- scsi: hisi_sas: fix PI memory size (FATE#326253).
- scsi: hisi_sas: check host frozen before calling "done" function
  (FATE#326253).
- scsi: hisi_sas: Add some checks to avoid free'ing a sas_task
  twice (FATE#326253).
- scsi: hisi_sas: optimise the usage of DQ locking (FATE#326253).
- scsi: hisi_sas: remove some unneeded structure members
  (FATE#326253).
- scsi: hisi_sas: print device id for errors (FATE#326253).
- scsi: hisi_sas: check IPTT is valid before using it for v3 hw
  (FATE#326253).
- scsi: hisi_sas: consolidate command check in
  hisi_sas_get_ata_protocol() (FATE#326253).
- scsi: hisi_sas: use dma_zalloc_coherent() (FATE#326253).
- scsi: hisi_sas: delete timer when removing hisi_sas driver
  (FATE#326253).
- scsi: hisi_sas: update RAS feature for later revision of v3 HW
  (FATE#326253).
- scsi: hisi_sas: make SAS address of SATA disks unique
  (FATE#326253).
- commit 159d1e6
* Wed Aug  8 2018 neilb@suse.com
- cachefiles: Wait rather than BUG'ing on "Unexpected object
  collision" (bsc#1099858).
- cachefiles: Fix missing clear of the CACHEFILES_OBJECT_ACTIVE
  flag (bsc#1099858).
- fscache: Fix reference overput in fscache_attach_object()
  error handling (bsc#1099858).
- cachefiles: Fix refcounting bug in backing-file read monitoring
  (bsc#1099858).
- fscache: Allow cancelled operations to be enqueued
  (bsc#1099858).
- commit c298ec1
* Tue Aug  7 2018 jthumshirn@suse.de
- scsi: hisi_sas: Remove depends on HAS_DMA in case of platform
  dependency (FATE#326253).
- scsi: hisi_sas: add v3 hw MODULE_DEVICE_TABLE() (FATE#326253).
- scsi: hisi_sas: modify some register config for hip08
  (FATE#326253).
- scsi: hisi_sas: Code cleanup and minor bug fixes (FATE#326253).
- scsi: hisi_sas: fix return value of hisi_sas_task_prep()
  (FATE#326253).
- scsi: hisi_sas: remove unused variable
  hisi_sas_devices.running_req (FATE#326253).
- scsi: hisi_sas: increase timer expire of internal abort task
  (FATE#326253).
- scsi: hisi_sas: fix the issue of setting linkrate register
  (FATE#326253).
- scsi: hisi_sas: fix the issue of link rate inconsistency
  (FATE#326253).
- scsi: hisi_sas: support the property of signal attenuation
  for v2 hw (FATE#326253).
- scsi: hisi_sas: dt-bindings: add an property of signal
  attenuation (FATE#326253).
- commit 7f7691c
* Tue Aug  7 2018 jack@suse.cz
- delayacct: fix crash in delayacct_blkio_end() after delayacct
  init failure (bsc#1104066).
- commit 133b2fe
* Tue Aug  7 2018 jthumshirn@suse.de
- dm: prevent DAX mounts if not supported (bsc#1103917).
- Refresh patches.kabi/kabi-fixup-bdev_dax_supported.patch.
- commit 4a4646d
* Tue Aug  7 2018 jthumshirn@suse.de
- pmem: only set QUEUE_FLAG_DAX for fsdax mode (bsc#1103917).
- commit 9fd6076
* Tue Aug  7 2018 jthumshirn@suse.de
- kabi protect bdev_dax_supported (bsc#1103917).
- commit f675f2c
* Tue Aug  7 2018 msuchanek@suse.de
- Update patches.arch/KVM-PPC-Check-if-IOMMU-page-is-contained-in-the-pinn.patch (bsc#1077761, git-fixes, bsc#1103948, bsc#1103949).
- commit 0c63421
* Tue Aug  7 2018 jthumshirn@suse.de
- fs: allow per-device dax status checking for filesystems
  (bsc#1103917).
- Refresh
  patches.fixes/dax-check-for-queue_flag_dax-in-bdev_dax_supported.patch.
- Refresh patches.suse/xfs-unsupported-features.patch.
- commit d80ad0b
* Tue Aug  7 2018 jthumshirn@suse.de
- scsi: hisi_sas: re-add the lldd_port_deformed() (FATE#326253).
- Refresh
  patches.drivers/scsi-hisi_sas-directly-attached-disk-LED-feature-for.patch.
- commit 196be3a
* Tue Aug  7 2018 jthumshirn@suse.de
- scsi: ata: enhance the definition of SET MAX feature field value
  (FATE#326253).
- commit 44511b6
* Tue Aug  7 2018 jthumshirn@suse.de
- scsi: hisi_sas: fix a bug in hisi_sas_dev_gone() (FATE#326253).
- scsi: hisi_sas: make local symbol host_attrs static
  (FATE#326253).
- scsi: hisi_sas: Change frame type for SET MAX commands
  (FATE#326253).
- scsi: hisi_sas: add v3 hw suspend and resume (FATE#326253).
- scsi: hisi_sas: fix SAS_QUEUE_FULL problem while running IO
  (FATE#326253).
- scsi: hisi_sas: add internal abort dev in some places
  (FATE#326253).
- scsi: hisi_sas: judge result of internal abort (FATE#326253).
- scsi: hisi_sas: do link reset for some CHL_INT2 ints
  (FATE#326253).
- scsi: hisi_sas: use an general way to delay PHY work
  (FATE#326253).
- scsi: hisi_sas: add v2 hw port AXI error handling support
  (FATE#326253).
- scsi: hisi_sas: improve int_chnl_int_v2_hw() consistency with
  v3 hw (FATE#326253).
- scsi: hisi_sas: add some print to enhance debugging
  (FATE#326253).
- scsi: hisi_sas: add RAS feature for v3 hw (FATE#326253).
- scsi: hisi_sas: change ncq process for v3 hw (FATE#326253).
- scsi: hisi_sas: add an mechanism to do reset work synchronously
  (FATE#326253).
- scsi: hisi_sas: modify hisi_sas_dev_gone() for reset
  (FATE#326253).
- scsi: hisi_sas: some optimizations of host controller reset
  (FATE#326253).
- scsi: hisi_sas: optimise port id refresh function (FATE#326253).
- scsi: hisi_sas: relocate clearing ITCT and freeing device
  (FATE#326253).
- scsi: hisi_sas: fix dma_unmap_sg() parameter (FATE#326253).
- scsi: hisi_sas: initialize dq spinlock before use (FATE#326253).
- commit a512149
* Tue Aug  7 2018 tiwai@suse.de
- iwlwifi: add more card IDs for 9000 series (bsc#1051510).
- commit ca74914
* Tue Aug  7 2018 tiwai@suse.de
- mm/kmemleak.c: make cond_resched() rate-limiting more efficient
  (bsc#1051510).
- commit a56377a
* Tue Aug  7 2018 tiwai@suse.de
- misc: pci_endpoint_test: Avoid triggering a BUG() (bsc#1051510).
- commit c061d00
* Tue Aug  7 2018 tiwai@suse.de
- ibmasm: don't write out of bounds in read handler (bsc#1051510).
- commit 7843972
* Tue Aug  7 2018 tiwai@suse.de
- clk: renesas: cpg-mssr: Stop using printk format %%pCr
  (bsc#1051510).
- commit b9a1e6f
* Tue Aug  7 2018 tiwai@suse.de
- irqchip/gic-v3: Ignore disabled ITS nodes (bsc#1051510).
- commit a143ca9
* Tue Aug  7 2018 tiwai@suse.de
- irqchip/qcom: Fix check for spurious interrupts (bsc#1051510).
- irqchip/gic: Take lock when updating irq type (bsc#1051510).
- irqchip/gic-v3: Use wmb() instead of smb_wmb() in
  gic_raise_softirq() (bsc#1051510).
- irqchip/gic-v3: Change pr_debug message to pr_devel
  (bsc#1051510).
- irqchip/gic-v3: Fix the driver probe() fail due to disabled
  GICC entry (bsc#1051510).
- irqchip/qcom: Fix u32 comparison with value less than zero
  (bsc#1051510).
- irqchip: brcmstb-l2: Define an irq_pm_shutdown function
  (bsc#1051510).
- commit 557df2b
* Tue Aug  7 2018 tiwai@suse.de
- can: ems_usb: Fix memory leak on ems_usb_disconnect()
  (bsc#1051510).
- can: dev: increase bus-off message severity (bsc#1051510).
- can: m_can: change comparison to bitshift when dealing with
  a mask (bsc#1051510).
- commit d662b35
* Tue Aug  7 2018 tiwai@suse.de
- kbuild: Handle builtin dtb file names containing hyphens
  (bsc#1051510).
- kconfig: display recursive dependency resolution hint just once
  (bsc#1051510).
- kbuild: add '-fno-stack-check' to kernel build options
  (bsc#1051510).
- kbuild: pkg: use --transform option to prefix paths in tar
  (bsc#1051510).
- coccinelle: fix parallel build with CHECK=scripts/coccicheck
  (bsc#1051510).
- commit b792f1f
* Tue Aug  7 2018 tiwai@suse.de
- audit: fix potential null dereference 'context->module.name'
  (bsc#1051510).
- commit 402d9a9
* Tue Aug  7 2018 tiwai@suse.de
- ARM: davinci: board-omapl138-hawk: fix GPIO numbers for MMC/SD
  lookup (bsc#1051510).
- commit 8e85a14
* Tue Aug  7 2018 tiwai@suse.de
- kmemleak: add scheduling point to kmemleak_scan() (bsc#1051510).
- commit 465515e
* Tue Aug  7 2018 jslaby@suse.cz
- sctp: introduce sctp_dst_mtu (git-fixes).
- commit 2d90b81
* Mon Aug  6 2018 mkubecek@suse.cz
- ipv6: defrag: drop non-last frags smaller than min mtu
  (CVE-2018-5391 bsc#1103097).
- ip: discard IPv4 datagrams with overlapping segments
  (CVE-2018-5391 bsc#1103097).
- ipv4: frags: handle possible skb truesize change (CVE-2018-5391
  bsc#1103097).
- inet: frag: enforce memory limits earlier (CVE-2018-5391
  bsc#1103097).
- commit 232ab4a
* Mon Aug  6 2018 jslaby@suse.cz
- sctp: fix the issue that pathmtu may be set lower than
  MINSEGMENT (git-fixes).
- commit 53fce18
* Mon Aug  6 2018 tiwai@suse.de
- ARM: davinci: board-da850-evm: fix WP pin polarity for MMC/SD
  (bsc#1051510).
- ARM: 8764/1: kgdb: fix NUMREGBYTES so that gdb_regs[] is the
  correct size (bsc#1051510).
- ARM: amba: Fix wrong indentation in driver_override_store()
  (bsc#1051510).
- ARM: 8772/1: kprobes: Prohibit kprobes on get_user functions
  (bsc#1051510).
- ARM: 8771/1: kprobes: Prohibit kprobes on do_undefinstr
  (bsc#1051510).
- ARM: 8770/1: kprobes: Prohibit probing on optimized_callback
  (bsc#1051510).
- ARM: 8769/1: kprobes: Fix to use get_kprobe_ctlblk after
  irq-disabed (bsc#1051510).
- sysrq : fix Show Regs call trace on ARM (bsc#1051510).
- commit 9ceb779
* Mon Aug  6 2018 tiwai@suse.de
- arm: spear13xx: Fix dmas cells (bsc#1051510).
- commit cb84639
* Mon Aug  6 2018 tiwai@suse.de
- ARM: kexec: fix kdump register saving on panic() (bsc#1051510).
- ARM: 8758/1: decompressor: restore r1 and r2 just before
  jumping to the kernel (bsc#1051510).
- ARM: 8753/1: decompressor: add a missing parameter to the
  addruart macro (bsc#1051510).
- ARM: davinci: board-dm646x-evm: set VPIF capture card name
  (bsc#1051510).
- ARM: davinci: board-dm646x-evm: pass correct I2C adapter id
  for VPIF (bsc#1051510).
- ARM: davinci: dm646x: fix timer interrupt generation
  (bsc#1051510).
- ARM: keystone: fix platform_domain_notifier array overrun
  (bsc#1051510).
- ARM: OMAP2+: powerdomain: use raw_smp_processor_id() for trace
  (bsc#1051510).
- ARM: davinci: board-dm355-evm: fix broken networking
  (bsc#1051510).
- ARM: davinci: board-da850-evm: fix GPIO lookup for MMC/SD
  (bsc#1051510).
- ARM: davinci: board-da830-evm: fix GPIO lookup for MMC/SD
  (bsc#1051510).
- ARM: amba: Fix race condition with driver_override
  (bsc#1051510).
- ARM: amba: Make driver_override output consistent with other
  buses (bsc#1051510).
- ARM: socfpga_defconfig: Remove QSPI Sector 4K size force
  (bsc#1051510).
- ARM: OMAP: Fix SRAM W+X mapping (bsc#1051510).
- ARM: OMAP: Fix dmtimer init for omap1 (bsc#1051510).
- ARM: davinci: fix the GPIO lookup for omapl138-hawk
  (bsc#1051510).
- ARM: 8748/1: mm: Define vdso_start, vdso_end as array
  (bsc#1051510).
- ARM: 8746/1: vfp: Go back to clearing vfp_current_hw_state[]
  (bsc#1051510).
- ARM: orion5x: Revert commit 4904dbda41c8 (bsc#1051510).
- ARM: orion: fix orion_ge00_switch_board_info initialization
  (bsc#1051510).
- ARM: OMAP1: clock: Fix debugfs_create_*() usage (bsc#1051510).
- ARM: OMAP3: Fix prm wake interrupt for resume (bsc#1051510).
- ARM: OMAP2+: timer: fix a kmemleak caused in omap_get_timer_dt
  (bsc#1051510).
- ARM: mvebu: Fix broken PL310_ERRATA_753970 selects
  (bsc#1051510).
- ARM: kvm: fix building with gcc-8 (bsc#1051510).
- ARM: 8743/1: bL_switcher: add MODULE_LICENSE tag (bsc#1051510).
- ARM: pxa/tosa-bt: add MODULE_LICENSE tag (bsc#1051510).
- ARM: sunxi_defconfig: Enable CMA (bsc#1051510).
- commit 6f47878
* Mon Aug  6 2018 tiwai@suse.de
- ARM: davinci: fix mmc entries in dm365's dma_slave_map
  (bsc#1051510).
- ARM: davinci: Add dma_mask to dm365's eDMA device (bsc#1051510).
- ARM: davinci: Use platform_device_register_full() to create
  pdev for dm365's eDMA (bsc#1051510).
- ARM: 8731/1: Fix csum_partial_copy_from_user() stack mismatch
  (bsc#1051510).
- ARM: omap2: hide omap3_save_secure_ram on non-OMAP3 builds
  (bsc#1051510).
- ARM: OMAP3: hwmod_data: add missing module_offs for MMC3
  (bsc#1051510).
- ARM: AM33xx: PRM: Remove am33xx_pwrdm_read_prev_pwrst function
  (bsc#1051510).
- ARM: OMAP2+: Fix SRAM virt to phys translation for
  save_secure_ram_context (bsc#1051510).
- ARM: avoid faulting on qemu (bsc#1051510).
- ARM: BUG if jumping to usermode address in kernel mode
  (bsc#1051510).
- ARM: 8722/1: mm: make STRICT_KERNEL_RWX effective for LPAE
  (bsc#1051510).
- ARM: 8721/1: mm: dump: check hardware RO bit for LPAE
  (bsc#1051510).
- ARM: sunxi: fix the core number of V3s in sunxi README
  (bsc#1051510).
- ARM: DRA722: remove redundant definition of 1.0 device
  (bsc#1051510).
- arm-ccn: perf: Prevent module unload while PMU is in use
  (bsc#1051510).
- ARM: 8720/1: ensure dump_instr() checks addr_limit
  (bsc#1051510).
- ARM: 8715/1: add a private asm/unaligned.h (bsc#1051510).
- ARM: multi_v7_defconfig: Replace DRM_RCAR_HDMI by generic
  bridge options (bsc#1051510).
- ARM: multi_v7_defconfig: Replace SND_SOC_RSRC_CARD by
  SND_SIMPLE_SCU_CARD (bsc#1051510).
- ARM: shmobile: defconfig: Replace DRM_RCAR_HDMI by generic
  bridge options (bsc#1051510).
- ARM: shmobile: defconfig: Replace SND_SOC_RSRC_CARD by
  SND_SIMPLE_SCU_CARD (bsc#1051510).
- ARM: shmobile: defconfig: Replace USB_XHCI_RCAR by
  USB_XHCI_PLATFORM (bsc#1051510).
- ARM: shmobile: defconfig: Enable missing PCIE_RCAR dependency
  (bsc#1051510).
- ARM: OMAP4+: PRM: fix of_irq_get() result checks (bsc#1051510).
- ARM: OMAP3+: PRM: fix of_irq_get() result check (bsc#1051510).
- ARM: OMAP2+: omap_device: drop broken RPM status update from
  suspend_noirq (bsc#1051510).
- ARM: s3c24xx: Fix NAND ECC mode for mini2440 board
  (bsc#1051510).
- ARM: at91: don't select CONFIG_ARM_CPU_SUSPEND for old platforms
  (bsc#1051510).
- ARM: shmobile: rcar-gen2: Fix deadlock in regulator quirk
  (bsc#1051510).
- ARM: pxa: select both FB and FB_W100 for eseries (bsc#1051510).
- ARM: kexec: fix failure to boot crash kernel (bsc#1051510).
- arm: remove wrong CONFIG_PROC_SYSCTL ifdef (bsc#1051510).
- arm: fix return value of parse_cpu_capacity (bsc#1051510).
- commit 5d09b7e
* Mon Aug  6 2018 tiwai@suse.de
- agp: uninorth: make two functions static (bsc#1051510).
- commit 48b6c9c
* Mon Aug  6 2018 tiwai@suse.de
- af_key: Always verify length of provided sadb_key (bsc#1051510).
- af_key: fix buffer overread in parse_exthdrs() (bsc#1051510).
- af_key: fix buffer overread in verify_address_len()
  (bsc#1051510).
- commit 02d1d88
* Mon Aug  6 2018 oneukum@suse.com
- typec: tcpm: Fix a msecs vs jiffies bug (bsc#1100132).
- commit 3b8103d
* Mon Aug  6 2018 jthumshirn@suse.de
- scsi: libsas: defer ata device eh commands to libata
  (FATE#326253).
- commit 0921606
* Mon Aug  6 2018 jthumshirn@suse.de
- ata: do not schedule hot plug if it is a sas host (FATE#326253).
- commit 6431177
* Mon Aug  6 2018 jthumshirn@suse.de
- libata: ensure host is free'd on error exit paths (git-fixes).
- commit 97116c3
* Mon Aug  6 2018 jthumshirn@suse.de
- nvme: ensure forward progress during Admin passthru (git-fixes).
- Refresh
  patches.kabi/Revert-nvme-mark-nvme_queue_scan-static.patch.
- commit 7c97e5e
* Mon Aug  6 2018 jroedel@suse.de
- KVM: SVM: Implement pause loop exit logic in SVM (fate#325533).
- KVM: SVM: Add pause filter threshold (fate#325533).
- KVM: VMX: Bring the common code to header file (fate#325533).
- KVM: VMX: Remove ple_window_actual_max (fate#325533).
- KVM: VMX: Fix the module parameters for vmx (fate#325533).
- commit 077b1aa
* Mon Aug  6 2018 jthumshirn@suse.de
- scsi: qla2xxx: Return error when TMF returns (git-fixes).
- scsi: qla2xxx: Fix driver unload by shutting down chip
  (git-fixes).
- scsi: qla2xxx: Fix NPIV deletion by calling
  wait_for_sess_deletion (git-fixes).
- scsi: qla2xxx: Fix unintialized List head crash (git-fixes).
- scsi: qla2xxx: Fix NULL pointer dereference for fcport search
  (git-fixes).
- sr: pass down correctly sized SCSI sense buffer (git-fixes).
- scsi: qla2xxx: Avoid double completion of abort command
  (git-fixes).
- commit 56236cf
* Mon Aug  6 2018 tiwai@suse.de
- staging: speakup: fix wraparound in uaccess length check
  (bsc#1051510).
- pinctrl: nand: meson-gxl: fix missing data pins (bsc#1051510).
- sc16is7xx: Check for an error when the clock is enabled
  (bsc#1051510).
- commit fa6d117
* Mon Aug  6 2018 tiwai@suse.de
- nohz: Fix local_timer_softirq_pending() (bsc#1051510).
- commit 2e06012
* Mon Aug  6 2018 tiwai@suse.de
- crypto: padlock-aes - Fix Nano workaround data corruption
  (bsc#1051510).
- mfd: cros_ec: Fail early if we cannot identify the EC
  (bsc#1051510).
- crypto: authencesn - don't leak pointers to authenc keys
  (bsc#1051510).
- crypto: authenc - don't leak pointers to authenc keys
  (bsc#1051510).
- ACPI / LPSS: Only call pwm_add_table() for Bay Trail PWM if
  PMIC HRV is 2 (bsc#1051510).
- doc: Add vendor prefix for Kieback & Peter GmbH (bsc#1051510).
- staging: ks7010: Use constants from ieee80211_eid instead of
  literal ints (bsc#1051510).
- mfd: fsl-imx25: Clean up irq settings during removal
  (bsc#1051510).
- mfd: mxs-lradc: Fix error handling in mxs_lradc_probe()
  (bsc#1051510).
- MAINTAINERS: review Renesas DT bindings as well (bsc#1051510).
- commit 6529987
* Mon Aug  6 2018 jslaby@suse.cz
- blacklist.conf: add commit for APM
- commit 76c48bc
* Mon Aug  6 2018 jthumshirn@suse.de
- KABI protect structy ata_host (git-fixes).
- libata: add refcounting to ata_host (git-fixes).
- commit aebfd5b
* Mon Aug  6 2018 jslaby@suse.cz
- x86: Treat R_X86_64_PLT32 as R_X86_64_PC32 (binutils_2.31).
- commit 42ed19e
* Mon Aug  6 2018 jthumshirn@suse.de
- Refresh patches.drivers/nvme-add-ANA-support.patch.
- Refresh
  patches.drivers/nvme-move-init-of-keep_alive-work-item-to-controller.patch.
- Refresh
  patches.drivers/nvme-remove-nvme_req_needs_failover.patch.
- Refresh
  patches.drivers/nvme-simplify-the-API-for-getting-log-pages.patch.
- Refresh patches.drivers/nvme.h-add-ANA-definitions.patch.
- Refresh
  patches.drivers/nvme.h-add-support-for-the-log-specific-field.patch.
- Refresh patches.drivers/nvmet-add-minimal-ANA-support.patch.
- Refresh
  patches.drivers/nvmet-keep-a-port-pointer-in-nvmet_ctrl.patch.
- Refresh
  patches.drivers/nvmet-support-configuring-ANA-groups.patch.
- Refresh
  patches.drivers/nvmet-track-and-limit-the-number-of-namespaces-per-s.patch.
- Refresh
  patches.drivers/nvmet-use-Retain-Async-Event-bit-to-clear-AEN.patch.
- Refresh
  patches.fixes/nvmet-fixup-crash-on-NULL-device-path.patch.
- commit 7f68ba6
* Mon Aug  6 2018 ohering@suse.de
- hv/netvsc: fix handling of fallback to single queue mode
  (fate#323887).
- commit bd2b0b7
* Mon Aug  6 2018 ohering@suse.de
- hv_netvsc: split sub-channel setup into async and sync
  (fate#323887).
- hv_netvsc: set master device (fate#323887, bsc#1051979).
- hv_netvsc: Fix net device attach on older Windows hosts
  (fate#323887).
- hv_netvsc: Ensure correct teardown message sequence order
  (fate#323887).
- hv_netvsc: Split netvsc_revoke_buf() and netvsc_teardown_gpadl()
  (fate#323887).
- hv_netvsc: Use Windows version instead of NVSP version on GPAD
  teardown (fate#323887).
- commit af29dba
* Mon Aug  6 2018 tiwai@suse.de
- drm/atomic: Make atomic helper track newly assigned planes
  correctly, v2 (bsc#1051510).
- Refresh
  patches.drivers/drm-atomic-Check-for-busy-planes-connectors-before-s.
- commit d1408d2
* Mon Aug  6 2018 tiwai@suse.de
- drm/atomic: Make atomic iterators less surprising (bsc#1051510).
- commit 3192c02
* Sat Aug  4 2018 tiwai@suse.de
- drm/vc4: Reset ->{x, y}_scaling[1] when dealing with uniplanar
  formats (bsc#1051510).
- drm/atomic: Initialize variables in
  drm_atomic_helper_async_check() to make gcc happy (bsc#1051510).
- drm/atomic: Check old_plane_state->crtc in
  drm_atomic_helper_async_check() (bsc#1051510).
- drm: re-enable error handling (bsc#1051510).
- commit c3cb984
* Sat Aug  4 2018 tiwai@suse.de
- drm/atomic: Make async plane update checks work as intended,
  v2 (bsc#1051510).
- Refresh
  patches.drivers/drm-atomic-Check-for-busy-planes-connectors-before-s.
- commit da93c7a
* Fri Aug  3 2018 ggherdovich@suse.cz
- cpufreq: intel_pstate: Limit the scope of HWP dynamic boost
  platforms (bsc#1066110).
- commit fb964ec
* Fri Aug  3 2018 mbrugger@suse.com
- arm64: perf: correct PMUVer probing (bsc#1103727).
- arm64: Disable unhandled signal log messages by default
  (bsc#1103724).
- arm64: spinlock: Fix theoretical trylock() A-B-A with LSE
  atomics (bsc#1103729).
- arm64: Correct type for PUD macros (bsc#1103723).
- arm64: KVM: fix VTTBR_BADDR_MASK BUG_ON off-by-one
  (bsc#1103725).
- arm64: vdso: fix clock_getres for 4GiB-aligned res
  (bsc#1103730).
- arm64: mm: Fix set_memory_valid() declaration (bsc#1103726).
- arm64: ptrace: Avoid setting compat FPR to garbage if get_user
  fails (bsc#1103728).
- commit e9c9c2d
* Fri Aug  3 2018 tiwai@suse.de
- virtio_balloon: fix another race between migration and
  ballooning (bsc#1051510).
- thermal: exynos: fix setting rising_threshold for Exynos5433
  (bsc#1051510).
- wlcore: sdio: check for valid platform device data before
  suspend (bsc#1051510).
- tty: Fix data race in tty_insert_flip_string_fixed_flag
  (bsc#1051510).
- usbip: usbip_detach: Fix memory, udev context and udev leak
  (bsc#1051510).
- usb: hub: Don't wait for connect state at resume for powered-off
  ports (bsc#1051510).
- commit b882831
* Fri Aug  3 2018 tiwai@suse.de
- spi: pxa2xx: check clk_prepare_enable() return value
  (bsc#1051510).
- spi/bcm63xx-hspi: Enable the clock before calling clk_get_rate()
  (bsc#1051510).
- spi: bcm2835aux: ensure interrupts are enabled for shared
  handler (bsc#1051510).
- spi: bcm-qspi: Always read and set BSPI_MAST_N_BOOT_CTRL
  (bsc#1051510).
- spi: bcm-qspi: Avoid setting MSPI_CDRAM_PCS for spi-nor master
  (bsc#1051510).
- spi: pxa2xx: Allow 64-bit DMA (bsc#1051510).
- spi: cadence: Add usleep_range() for cdns_spi_fill_tx_fifo()
  (bsc#1051510).
- commit 3231b87
* Fri Aug  3 2018 tiwai@suse.de
- soc: imx: gpc: restrict register range for regmap access
  (bsc#1051510).
- soc: imx: gpcv2: correct PGC offset (bsc#1051510).
- soc: imx: gpcv2: Do not pass static memory as platform data
  (bsc#1051510).
- soc: rockchip: power-domain: Fix wrong value when power up pd
  with writemask (bsc#1051510).
- soc: bcm2835: Make !RASPBERRYPI_FIRMWARE dummies return failure
  (bsc#1051510).
- soc: bcm: raspberrypi-power: Fix use of __packed (bsc#1051510).
- soc: qcom: wcnss_ctrl: Fix increment in NV upload (bsc#1051510).
- soc: imx: gpc: de-register power domains only if initialized
  (bsc#1051510).
- soc: mediatek: pwrap: fix compiler errors (bsc#1051510).
- drivers: soc: sunxi: fix error processing on base address when
  claiming (bsc#1051510).
- soc/tegra: Fix bad of_node_put() in powergate init
  (bsc#1051510).
- soc: ti: ti_sci_pm_domains: Populate name for genpd
  (bsc#1051510).
- soc: imx: gpcv2: fix regulator deferred probe (bsc#1051510).
- soc: zte: Restrict SOC_ZTE to ARCH_ZX or COMPILE_TEST
  (bsc#1051510).
- soc/tegra: flowctrl: Fix error handling (bsc#1051510).
- commit 9cb4c4a
* Fri Aug  3 2018 tiwai@suse.de
- regulator: pfuze100: add .is_enable() for
  pfuze100_swb_regulator_ops (bsc#1051510).
- commit 6fcd164
* Fri Aug  3 2018 tiwai@suse.de
- pinctrl: at91-pio4: add missing of_node_put (bsc#1051510).
- commit 88447f1
* Fri Aug  3 2018 tiwai@suse.de
- PCI: pciehp: Request control of native hotplug only if supported
  (bsc#1051510).
- PCI: Prevent sysfs disable of device while driver is attached
  (bsc#1051510).
- PCI: pciehp: Assume NoCompl+ for Thunderbolt ports
  (bsc#1051510).
- commit fd4b739
* Fri Aug  3 2018 tiwai@suse.de
- mwifiex: handle race during mwifiex_usb_disconnect
  (bsc#1051510).
- mwifiex: correct histogram data with appropriate index
  (bsc#1051510).
- commit 213b188
* Fri Aug  3 2018 tiwai@suse.de
- mmc: dw_mmc: update actual clock for mmc debugfs (bsc#1051510).
- mmc: pwrseq: Use kmalloc_array instead of stack VLA
  (bsc#1051510).
- commit 9de6ae2
* Fri Aug  3 2018 tiwai@suse.de
- iwlwifi: pcie: fix race in Rx buffer allocator (bsc#1051510).
- hippi: Fix a Fix a possible sleep-in-atomic bug in rr_close
  (bsc#1051510).
- commit 4d9f523
* Fri Aug  3 2018 tiwai@suse.de
- HID: hid-plantronics: Re-resend Update to map button for PTT
  products (bsc#1051510).
- HID: i2c-hid: check if device is there before really probing
  (bsc#1051510).
- commit 5031b8e
* Fri Aug  3 2018 hare@suse.de
- genirq: Check __free_irq() return value for NULL (bsc#1103517).
- commit 9178bf4
* Fri Aug  3 2018 tiwai@suse.de
- drm/nouveau/fifo/gk104-: poll for runlist update completion
  (bsc#1051510).
- drm/radeon: fix mode_valid's return type (bsc#1051510).
- drm/amdgpu: Remove VRAM from shared bo domains (bsc#1051510).
- drm/atomic: Handling the case when setting old crtc for plane
  (bsc#1051510).
- drm: Add DP PSR2 sink enable bit (bsc#1051510).
- drm/gma500: fix psb_intel_lvds_mode_valid()'s return type
  (bsc#1051510).
- drm/atomic-helper: Drop plane->fb references only for
  drm_atomic_helper_shutdown() (bsc#1051510).
- drm/dp/mst: Fix off-by-one typo when dump payload table
  (bsc#1051510).
- commit 7cea46b
* Fri Aug  3 2018 tiwai@suse.de
- brcmfmac: Add support for bcm43364 wireless chipset
  (bsc#1051510).
- commit 0ffea14
* Fri Aug  3 2018 tiwai@suse.de
- Bluetooth: hci_qca: Fix "Sleep inside atomic section" warning
  (bsc#1051510).
- Bluetooth: btusb: Add a new Realtek 8723DE ID 2ff8:b011
  (bsc#1051510).
- Bluetooth: btusb: add ID for LiteOn 04ca:301a (bsc#1051510).
- commit 1558300
* Fri Aug  3 2018 tiwai@suse.de
- backlight: pwm_bl: Don't use GPIOF_* with gpiod_get_direction
  (bsc#1051510).
- commit b690254
* Fri Aug  3 2018 tiwai@suse.de
- ath: Add regulatory mapping for FCC3_ETSIC (bsc#1051510).
- ath: Add regulatory mapping for ETSI8_WORLD (bsc#1051510).
- ath: Add regulatory mapping for APL13_WORLD (bsc#1051510).
- ath: Add regulatory mapping for APL2_FCCA (bsc#1051510).
- ath: Add regulatory mapping for Uganda (bsc#1051510).
- ath: Add regulatory mapping for Tanzania (bsc#1051510).
- ath: Add regulatory mapping for Serbia (bsc#1051510).
- ath: Add regulatory mapping for Bermuda (bsc#1051510).
- ath: Add regulatory mapping for Bahamas (bsc#1051510).
- commit ef8a588
* Fri Aug  3 2018 tiwai@suse.de
- media: tw686x: Fix incorrect vb2_mem_ops GFP flags
  (bsc#1051510).
- media: rcar_jpu: Add missing clk_disable_unprepare() on error
  in jpu_open() (bsc#1051510).
- media: media-device: fix ioctl function types (bsc#1051510).
- media: saa7164: Fix driver name in debug output (bsc#1051510).
- media: siano: get rid of __le32/__le16 cast warnings
  (bsc#1051510).
- media: si470x: fix __be16 annotations (bsc#1051510).
- commit ed46958
* Fri Aug  3 2018 tiwai@suse.de
- Input: i8042 - add Lenovo LaVie Z to the i8042 reset list
  (bsc#1051510).
- Input: elan_i2c - add another ACPI ID for Lenovo Ideapad
  330-15AST (bsc#1051510).
- Input: elan_i2c - add ACPI ID for lenovo ideapad 330
  (bsc#1051510).
- commit 5f598bb
* Fri Aug  3 2018 tiwai@suse.de
- ALSA: emu10k1: add error handling for snd_ctl_add (bsc#1051510).
- ALSA: fm801: add error handling for snd_ctl_add (bsc#1051510).
- ASoC: dpcm: fix BE dai not hw_free and shutdown (bsc#1051510).
- ASoC: topology: Add missing clock gating parameter when parsing
  hw_configs (bsc#1051510).
- ASoC: topology: Fix bclk and fsync inversion in
  set_link_hw_format() (bsc#1051510).
- ALSA: emu10k1: Rate-limit error messages about page errors
  (bsc#1051510).
- ALSA: usb-audio: Apply rate limit to warning messages in URB
  complete callback (bsc#1051510).
- commit 3e4eb6b
* Fri Aug  3 2018 tiwai@suse.de
- Revert "drm/nouveau/drm/therm/fan: add a fallback if no fan
  control is specified in the vbios" (bsc#1103356).
- commit 23b40ec
* Fri Aug  3 2018 tiwai@suse.de
- rpm/config.sh: Use SUSE:SLE-15:Update project instead of GA
- commit 2813d45
* Fri Aug  3 2018 tonyj@suse.de
- perf/x86/intel/uncore: Add event constraint for BDX PCU
  (bsc#1087202).
- perf intel-pt: Always set no branch for dummy event
  (bsc#1087217).
- perf intel-pt: Set no_aux_samples for the tracking event
  (bsc#1087217).
- perf/x86/intel/uncore: Fix missing marker for
  skx_uncore_cha_extra_regs (bsc#1087233).
- perf/x86/intel/uncore: Fix SKX CHA event extra regs
  (bsc#1087233).
- perf/x86/intel/uncore: Remove invalid Skylake server CHA filter
  field (bsc#1087233).
- perf/x86/intel/uncore: Fix Skylake server CHA LLC_LOOKUP event
  umask (bsc#1087233).
- perf/x86/intel/uncore: Fix Skylake server PCU PMU event format
  (bsc#1087233).
- perf/x86/intel/uncore: Fix Skylake UPI PMU event masks
  (bsc#1087233).
- commit 9fb5cd3
* Thu Aug  2 2018 jthumshirn@suse.de
- kabi protect struct ccw_device_private (bsc#1103421).
- commit 7037da6
* Thu Aug  2 2018 mkubecek@suse.cz
- tcp: add tcp_ooo_try_coalesce() helper (CVE-2018-5390
  bsc#1102340).
- tcp: call tcp_drop() from tcp_data_queue_ofo() (CVE-2018-5390
  bsc#1102340).
- tcp: detect malicious patterns in tcp_collapse_ofo_queue()
  (CVE-2018-5390 bsc#1102340).
- tcp: avoid collapses in tcp_prune_queue() if possible
  (CVE-2018-5390 bsc#1102340).
- tcp: free batches of packets in tcp_prune_ofo_queue()
  (CVE-2018-5390 bsc#1102340).
- net: add rb_to_skb() and other rb tree helpers (bsc#1102340).
- commit b01b19a
* Thu Aug  2 2018 jthumshirn@suse.de
- s390/qdio: don't release memory in qdio_setup_irq()
  (bsc#1103421).
- s390/ipl: ensure loadparm valid flag is set (bsc#1103421).
- s390/cio: clear timer when terminating driver I/O (bsc#1103421).
- s390/cio: fix return code after missing interrupt (bsc#1103421).
- s390/dasd: fix handling of internal requests (bsc#1103421).
- s390/eadm: fix CONFIG_BLOCK include dependency (bsc#1103421).
- s390/dasd: fix wrongly assigned configuration data
  (bsc#1103421).
- s390/dasd: prevent prefix I/O error (bsc#1103421).
- s390/pci: do not require AIS facility (bsc#1103421).
- commit c4de01a
* Thu Aug  2 2018 duwe@suse.de
- powerpc/64s: Clear PCR on boot (bnc#1012382).
- powerpc/64s: Fix section mismatch warnings from
  setup_rfi_flush() (bsc#1068032, bsc#1075087, bsc#1091041).
- powerpc/64: Fix smp_wmb barrier definition use use lwsync
  consistently (bnc#1012382).
- powerpc/fadump: Unregister fadump on kexec down path
  (bnc#1012382).
- powerpc/ptrace: Fix setting 512B aligned breakpoints with
  PTRACE_SET_DEBUGREG (bnc#1012382).
- powerpc/mm/hash: Add missing isync prior to kernel stack SLB
  switch (bnc#1012382).
- powerpc: Add missing prototype for arch_irq_work_raise()
  (bnc#1012382).
- powerpc/mpic: Check if cpu_possible() in mpic_physmask()
  (bnc#1012382).
- powerpc/powernv: Fix NVRAM sleep in invalid context when
  crashing (bnc#1012382).
- powerpc/eeh: Fix enabling bridge MMIO windows (bnc#1012382).
- powerpc/powernv: Fix OPAL NVRAM driver OPAL_BUSY loops
  (bnc#1012382).
- powerpc/powernv: define a standard delay for OPAL_BUSY type
  retry loops (bnc#1012382).
- powerpc/powernv: Handle unknown OPAL errors in
  opal_nvram_write() (bnc#1012382).
- commit 6fb06ed
* Thu Aug  2 2018 ptesarik@suse.cz
- s390: use expoline thunks in the BPF JIT (git-fixes, bsc#1103421).
- commit 79a523e
* Thu Aug  2 2018 ptesarik@suse.cz
- s390: extend expoline to BC instructions (git-fixes, bsc#1103421).
- commit abc1ec1
* Thu Aug  2 2018 ptesarik@suse.cz
- s390: Correct register corruption in critical section cleanup
  (git-fixes 6dd85fbb87).
- commit ff9a3e3
* Thu Aug  2 2018 ptesarik@suse.cz
- s390: add assembler macros for CPU alternatives (git-fixes
  f19fbd5ed6).
- commit 426746b
* Thu Aug  2 2018 tonyj@suse.de
- fix kabi due to perf_event.h uapi field change (FATE#325127).
- perf/x86: Fix data source decoding for Skylake (FATE#325127).
- commit 03e4225
* Wed Aug  1 2018 mgorman@suse.de
- series.conf: Sort rq ordering, load balancing and group search optimisations
- Refresh
  patches.suse/sched-fair-Move-select_task_rq_fair-slow-path-into-its-own-function.patch.
- Refresh
  patches.suse/sched-fair-Restructure-wake_affine-to-return-a-CPU-id.patch.
- Refresh
  patches.suse/sched-fair-Use-a-recently-used-CPU-as-an-idle-candidate-and-the-basis-for-SIS.patch.
- Refresh
  patches.suse/sched-fair-Use-unsigned-long-for-utilization-consistently.patch.
- commit 41b48ae
* Wed Aug  1 2018 mgorman@suse.de
- sched/fair: Remove impossible condition from
  find_idlest_group_cpu() (bnc#1101669 optimise numa balancing
  for fast migrate).
- sched/fair: Consider RT/IRQ pressure in capacity_spare_wake()
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/fair: Use 'unsigned long' for utilization, consistently
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/fair: Fix usage of find_idlest_group() when the local
  group is idlest (bnc#1101669 optimise numa balancing for
  fast migrate).
- sched/fair: Fix usage of find_idlest_group() when no groups are
  allowed (bnc#1101669 optimise numa balancing for fast migrate).
- sched/fair: Fix find_idlest_group() when local group is not
  allowed (bnc#1101669 optimise numa balancing for fast migrate).
- sched/fair: Remove unnecessary comparison with -1 (bnc#1101669
  optimise numa balancing for fast migrate).
- sched/fair: Move select_task_rq_fair() slow-path into its own
  function (bnc#1101669 optimise numa balancing for fast migrate).
- sched/fair: Spare idle load balancing on nohz_full CPUs
  (bnc#1101669 optimise numa balancing for fast migrate).
- commit bbd0329
* Wed Aug  1 2018 ptesarik@suse.cz
- s390/gs: add compat regset for the guarded storage broadcast
  control block (git-fixes e525f8a6e696).
- commit ef8c31e
* Wed Aug  1 2018 tbogendoerfer@suse.de
- enic: do not overwrite error code (bsc#1037697).
- commit 60531ee
* Wed Aug  1 2018 ptesarik@suse.cz
- blacklist.conf: Avoid renaming IBM z13/z14 PMU counters
- commit df7d970
* Wed Aug  1 2018 ptesarik@suse.cz
- s390: remove indirect branch from do_softirq_own_stack
  (git-fixes f19fbd5ed6).
- commit ea90acb
* Wed Aug  1 2018 ptesarik@suse.cz
- s390/kernel: use expoline for indirect branches (git-fixes
  f19fbd5ed6).
- commit b07cbb8
* Wed Aug  1 2018 ptesarik@suse.cz
- s390/ftrace: use expoline for indirect branches (git-fixes
  f19fbd5ed6).
- commit bbd06c7
* Wed Aug  1 2018 ptesarik@suse.cz
- s390/crc32-vx: use expoline for indirect branches (git-fixes
  f19fbd5ed6).
- commit e803442
* Wed Aug  1 2018 ptesarik@suse.cz
- s390: move expoline assembler macros to a header (git-fixes
  f19fbd5ed6).
- commit e782f00
* Wed Aug  1 2018 ptesarik@suse.cz
- s390: correct module section names for expoline code revert
  (git-fixes f19fbd5ed6).
- commit d4b1943
* Wed Aug  1 2018 ptesarik@suse.cz
- s390/lib: use expoline for indirect branches (git-fixes
  f19fbd5ed6).
- commit 3122123
* Wed Aug  1 2018 ptesarik@suse.cz
- s390: optimize memset implementation (git-fixes f19fbd5ed6).
- commit 26a173c
* Wed Aug  1 2018 tbogendoerfer@suse.de
- net: cxgb3_main: fix potential Spectre v1 (bsc#1046533
  FATE#322936).
- IB/hfi1: Fix user context tail allocation for DMA_RTAIL
  (bsc#1060463 FATE#323043).
- IB/isert: Fix for lib/dma_debug check_sync warning (bsc#1046306
  FATE#322942).
- RDMA/cma: Do not query GID during QP state transition to RTR
  (bsc#1046306 FATE#322942).
- IB/core: Make ib_mad_client_id atomic (bsc#1046306 FATE#322942).
- IB/rxe: avoid double kfree_skb (bsc#1046306 FATE#322942).
- IB/rxe: add RXE_START_MASK for rxe_opcode
  IB_OPCODE_RC_SEND_ONLY_INV (bsc#1046306 FATE#322942).
- IB/rxe: Fix for oops in rxe_register_device on ppc64le arch
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Don't allow setting RDMA_OPTION_IB_PATH without an
  RDMA device (bsc#1046306 FATE#322942).
- IB/core: Honor port_num while resolving GID for IB link layer
  (bsc#1046306 FATE#322942).
- RDMA/mlx5: Fix NULL dereference while accessing XRC_TGT QPs
  (bsc#1046305 FATE#322943).
- net/mlx5: Protect from command bit overflow (bsc#1046303
  FATE#322944).
- enic: enable rq before updating rq descriptors (bsc#1037697).
- IB/uverbs: Fix possible oops with duplicate ioctl attributes
  (bsc#1046306 FATE#322942).
- RDMA/uverbs: Use an unambiguous errno for method not supported
  (bsc#1046306 FATE#322942).
- commit ff4da97
* Wed Aug  1 2018 tbogendoerfer@suse.de
- qed*: Advance drivers' version to 8.33.0.20 (bsc#1086314
  FATE#324886).
- Refresh
  patches.suse/qed-bump-drivers-to-version-8.10.10.55.patch.
- commit 8db21aa
* Wed Aug  1 2018 jthumshirn@suse.de
- acpi, nfit: Fix scrub idle detection (bsc#1094119).
- Refresh patches.kabi/kabi-protect-struct-acpi_nfit_desc.patch.
- commit 82e4386
* Wed Aug  1 2018 tbogendoerfer@suse.de
- of: Make of_fwnode_handle() safer (bsc#1098633).
- commit cf24c8d
* Wed Aug  1 2018 wqu@suse.com
- btrfs: Don't remove block group still has pinned down bytes
  (bsc#1086457).
- commit 8838e79
* Tue Jul 31 2018 yousaf.kaukab@suse.com
- arm64: kpti: Use early_param for kpti= command-line option
  (bsc#1103220).
- commit 3380e30
* Tue Jul 31 2018 tbogendoerfer@suse.de
- device property: preserve usecount for node passed to
  of_fwnode_graph_get_port_parent() (bsc#1098633).
- device property: Introduce fwnode_call_bool_op() for ops that
  return bool (bsc#1098633).
- commit bc692e9
* Tue Jul 31 2018 tiwai@suse.de
- Fix kABI breakage for of/device change (bsc#1051510).
- commit eecd28c
* Tue Jul 31 2018 tiwai@suse.de
- spi: sh-msiof: Fix bit field overflow writes to TSCR/RSCR
  (bsc#1051510).
- spi: bcm-qspi: fIX some error handling paths (bsc#1051510).
- spi: pxa2xx: Don't touch CS pin until we have a transfer pending
  (bsc#1051510).
- spi: core: Fix devm_spi_register_master() function name in
  kerneldoc (bsc#1051510).
- commit 9891f7b
* Tue Jul 31 2018 tiwai@suse.de
- tools/power turbostat: Correct SNB_C1/C3_AUTO_UNDEMOTE defines
  (bsc#1051510).
- tools/thermal: tmon: fix for segfault (bsc#1051510).
- tools/libbpf: handle issues with bpf ELF objects containing
  .eh_frames (bsc#1051510).
- tools/usbip: fixes build with musl libc toolchain (bsc#1051510).
- tools lib traceevent: Fix get_field_str() for dynamic strings
  (bsc#1051510).
- tools lib traceevent: Simplify pointer print logic and fix %%pF
  (bsc#1051510).
- tools/lib/lockdep: Define the ARRAY_SIZE() macro (bsc#1051510).
- tools/lib/lockdep: Fix undefined symbol prandom_u32
  (bsc#1051510).
- commit 698d9e9
* Tue Jul 31 2018 mgorman@suse.de
- series.conf: Sort scheduler stats optimisations
- commit d6c308d
* Tue Jul 31 2018 mgorman@suse.de
- jump_label: Add branch hints to static_branch_{un,}likely()
  (bnc#1101669 optimise numa balancing for fast migrate).
- sched/core: Optimize update_stats_*() (bnc#1101669 optimise
  numa balancing for fast migrate).
- sched/core: Optimize ttwu_stat() (bnc#1101669 optimise numa
  balancing for fast migrate).
- commit d188bbf
* Tue Jul 31 2018 hare@suse.de
- nvmet: kABI fixes for ANA support (bsc#1054245).
- nvme: guard additional fields in nvme command structures
  (bsc#1054245).
- commit 0d43d1b
* Tue Jul 31 2018 tiwai@suse.de
- of/pci: Fix theoretical NULL dereference (bsc#1051510).
- of: restrict DMA configuration (bsc#1051510).
- of: fix DMA mask generation (bsc#1051510).
- commit 1a048c8
* Tue Jul 31 2018 tbogendoerfer@suse.de
- kabi protect fwnode_handle (bsc#1098633).
- commit 47e036d
* Tue Jul 31 2018 tiwai@suse.de
- qmi_wwan: fix interface number for DW5821e production firmware
  (bsc#1051510).
- commit 704cd75
* Tue Jul 31 2018 tiwai@suse.de
- mmc: sdhci-xenon: wait 5ms after set 1.8V signal enable
  (bsc#1051510).
- mmc: tmio: remove outdated comment (bsc#1051510).
- commit abfc8b4
* Tue Jul 31 2018 jthumshirn@suse.de
- libnvdimm: add an api to cast a 'struct nd_region' to its
  'struct device' (bsc#1094119).
- nfit, address-range-scrub: add module option to skip initial
  ars (bsc#1094119).
- nfit, address-range-scrub: determine one platform max_ars value
  (bsc#1094119).
- nfit, address-range-scrub: introduce nfit_spa->ars_state
  (bsc#1094119).
- nfit, address-range-scrub: rework and simplify ARS state machine
  (bsc#1094119).
- Refresh patches.kabi/kabi-protect-struct-acpi_nfit_desc.patch.
- commit f654227
* Tue Jul 31 2018 tiwai@suse.de
- mmc: sdhci-of-esdhc: fix the mmc error after sleep on ls1046ardb
  (bsc#1051510).
- mmc: sdhci-of-esdhc: fix eMMC couldn't work after kexec
  (bsc#1051510).
- mmc: sdhci-msm: fix issue with power irq (bsc#1051510).
- mmc: sdhci-of-esdhc: disable SD clock for clock value 0
  (bsc#1051510).
- mmc: sdhci-xenon: Fix clock resource by adding an optional
  bus clock (bsc#1051510).
- commit 52a4751
* Tue Jul 31 2018 mbrugger@suse.com
- arm64: blacklist.conf: add ids
- commit 6cc4ee8
* Tue Jul 31 2018 hare@suse.de
- nvme: kABI fix for ANA support in nvme_ctrl (bsc#1054245).
- nvme: partially revert "nvme: remove nvme_req_needs_failover"
  (bsc#1054245).
- nvme: reintruduce nvme_get_log_ext() (bsc#1054245).
- commit 95a4774
* Tue Jul 31 2018 tbogendoerfer@suse.de
- device property: Introduce fwnode_device_is_available()
  (bsc#1098633).
- device property: Move fwnode graph ops to firmware specific
  locations (bsc#1098633).
- device property: Move FW type specific functionality to FW
  specific files (bsc#1098633).
  Refresh
  patches.drivers/device-property-Track-owner-device-of-device-propert.patch.
- commit 38385a8
* Tue Jul 31 2018 hare@suse.de
- nvme: add ANA support (bsc#1054245).
- nvme: remove nvme_req_needs_failover (bsc#1054245).
- nvme: simplify the API for getting log pages (bsc#1054245).
- nvme.h: add ANA definitions (bsc#1054245).
- nvme.h: add support for the log specific field (bsc#1054245).
- nvmet: add minimal ANA support (bsc#1054245).
- nvmet: keep a port pointer in nvmet_ctrl (bsc#1054245).
- nvmet: support configuring ANA groups (bsc#1054245).
- nvmet: track and limit the number of namespaces per subsystem
  (1054245).
- nvmet: use Retain Async Event bit to clear AEN (bsc#1054245).
- nvmet: fixup crash on NULL device path (bsc#1054245).
- Refresh
  patches.kabi/Revert-nvmet-constify-struct-nvmet_fabrics_ops.patch.
- Refresh patches.kabi/nvme-kABI-fixes-for-nvme_ctrl.patch.
- Refresh patches.kabi/nvme-kABI-fixes-for-nvmet.patch.
- commit 34e8a34
* Tue Jul 31 2018 lhenriques@suse.com
- crash_dump: is_kdump_kernel can be boolean (bsc#1103230).
- commit e5aecef
* Tue Jul 31 2018 lhenriques@suse.com
- rbd: flush rbd_dev->watch_dwork after watch is unregistered
  (bsc#1103216).
- commit 4d76deb
* Tue Jul 31 2018 tiwai@suse.de
- usb: gadget: udc: renesas_usb3: disable the controller's irqs
  for reconnecting (bsc#1051510).
- usbip: Correct maximum value of CONFIG_USBIP_VHCI_HC_PORTS
  (bsc#1051510).
- commit fa44f7b
* Tue Jul 31 2018 tiwai@suse.de
- qmi_wwan: add support for Quectel EG91 (bsc#1051510).
- qmi_wwan: add support for the Dell Wireless 5821e module
  (bsc#1051510).
- qmi_wwan: set FLAG_SEND_ZLP to avoid network initiated
  disconnect (bsc#1051510).
- commit 0ff68bc
* Tue Jul 31 2018 tiwai@suse.de
- Add cherry-picked id for qmi_wwan fix
- commit 5ed8892
* Tue Jul 31 2018 tiwai@suse.de
- PCI: endpoint: Populate func_no before calling pci_epc_add_epf()
  (bsc#1051510).
- Refresh
  patches.drivers/PCI-endpoint-Fix-find_first_zero_bit-usage.
- commit 7ded3de
* Tue Jul 31 2018 hare@suse.de
- kABI fixes for
  nvme-if_ready-checks-fail-io-to-deleting-controll.patch
  (bsc#1077989).
- nvme: if_ready checks to fail io to deleting controller
  (bsc#1077989).
- commit d9c5619
* Tue Jul 31 2018 hare@suse.de
- nvme: don't enable AEN if not supported (bsc#1077989).
- commit 0b65d62
* Tue Jul 31 2018 tiwai@suse.de
- PCI: shpchp: Fix AMD POGO identification (bsc#1051510).
- PCI: ibmphp: Fix use-before-set in get_max_bus_speed()
  (bsc#1051510).
- PCI: endpoint: Fix kernel panic after put_device()
  (bsc#1051510).
- PCI: altera: Fix bool initialization in tlp_read_packet()
  (bsc#1051510).
- PCI: exynos: Fix a potential init_clk_resources NULL pointer
  dereference (bsc#1051510).
- PCI: faraday: Fix of_irq_get() error check (bsc#1051510).
- commit de6cd97
* Tue Jul 31 2018 hare@suse.de
- kABI fixes for qla2xxx-Fix-inconsistent-DMA-mem-alloc-free.patch
  (bsc#1077989).
- scsi: qla2xxx: Fix inconsistent DMA mem alloc/free
  (bsc#1077989).
- commit 7c04ff3
* Tue Jul 31 2018 hare@suse.de
- block: always set partition number to '0' in
  blk_partition_remap() (bsc#1077989).
- scsi: core: clean up generated file scsi_devinfo_tbl.c
  (bsc#1077989).
- scsi: aacraid: Correct hba_send to include iu_type
  (bsc#1077989).
- nvme: Fix sync controller reset return (bsc#1077989).
- blk-mq: fix sysfs inflight counter (bsc#1077989).
- blk-mq: count allocated but not started requests in iostats
  inflight (bsc#1077989).
- scsi: megaraid_sas: Do not log an error if FW successfully
  initializes (bsc#1077989).
- block: bio_check_eod() needs to consider partitions
  (bsc#1077989).
- block: fail op_is_write() requests to read-only partitions
  (bsc#1077989).
- block: pass 'run_queue' to blk_mq_request_bypass_insert
  (bsc#1077989).
- block: set request_list for request (bsc#1077989).
- commit 23b8135
* Tue Jul 31 2018 hare@suse.de
- Delete
  patches.drivers/block-always-set-partition-number-to-0-in-blk_partit.patch.
- commit 60c43ad
* Tue Jul 31 2018 hare@suse.de
- scripts/git_sort/git_sort.py: Add 'nvme-4.18' to the list of repositories
- commit 9c28cfd
* Mon Jul 30 2018 tiwai@suse.de
- usbip: usbip_host: refine probe and disconnect debug msgs to
  be useful (bsc#1051510).
- Refresh
  patches.fixes/0001-usbip-usbip_host-fix-NULL-ptr-deref-and-use-after-fr.patch.
- commit 97b064e
* Mon Jul 30 2018 tiwai@suse.de
- usbip: vhci_sysfs: fix potential Spectre v1 (bsc#1051510).
- usbip: usbip_event: fix to not print kernel pointer address
  (bsc#1051510).
- usbip: vhci_hcd: Fix usb device and sockfd leaks (bsc#1051510).
- commit b4db2d8
* Mon Jul 30 2018 tiwai@suse.de
- usb: core: handle hub C_PORT_OVER_CURRENT condition
  (bsc#1051510).
- usb: gadget: f_fs: Only return delayed status when len is 0
  (bsc#1051510).
- commit 2327a1e
* Mon Jul 30 2018 tiwai@suse.de
- usb: gadget: f_uac2: fix endianness of 'struct cntrl_*_lay3'
  (bsc#1051510).
- usb: dwc2: Fix DMA alignment to start at allocated boundary
  (bsc#1051510).
- usb: gadget: f_uac2: fix error handling in afunc_bind (again)
  (bsc#1051510).
- usb: cdc_acm: Add quirk for Castles VEGA3000 (bsc#1051510).
- usb: quirks: add delay quirks for Corsair Strafe (bsc#1051510).
- commit 20fffbc
* Mon Jul 30 2018 tiwai@suse.de
- USB: serial: mos7840: fix status-register error handling
  (bsc#1051510).
- USB: serial: cp210x: add another USB ID for Qivicon ZigBee stick
  (bsc#1051510).
- USB: serial: ch341: fix type promotion bug in ch341_control_in()
  (bsc#1051510).
- USB: serial: cp210x: add CESINEL device ids (bsc#1051510).
- USB: serial: cp210x: add Silicon Labs IDs for Windows Update
  (bsc#1051510).
- usb: cdc_acm: Add quirk for Uniden UBC125 scanner (bsc#1051510).
- usb: dwc2: fix the incorrect bitmaps for the ports of multi_tt
  hub (bsc#1051510).
- usb: dwc3: of-simple: fix use-after-free on remove
  (bsc#1051510).
- usb-storage: Add compatibility quirk flags for G-Technologies
  G-Drive (bsc#1051510).
- usb-storage: Add support for FL_ALWAYS_SYNC flag in the UAS
  driver (bsc#1051510).
- commit e67d0c5
* Mon Jul 30 2018 tiwai@suse.de
- Add cherry-pick commit for dwc3 gadget fix
- commit d52d858
* Mon Jul 30 2018 tiwai@suse.de
- usb: dwc2: debugfs: Don't touch RX FIFO during register dump
  (bsc#1051510).
- usb: do not reset if a low-speed or full-speed device timed out
  (bsc#1051510).
- usb: audio-v2: Correct the comment for struct
  uac_clock_selector_descriptor (bsc#1051510).
- usb: musb: fix remote wakeup racing with suspend (bsc#1051510).
- USB: serial: visor: handle potential invalid device
  configuration (bsc#1051510).
- USB: serial: option: adding support for ublox R410M
  (bsc#1051510).
- usb: musb: trace: fix NULL pointer dereference in musb_g_tx()
  (bsc#1051510).
- usb: musb: host: fix potential NULL pointer dereference
  (bsc#1051510).
- usb: dwc3: gadget: Fix list_del corruption in dwc3_ep_dequeue
  (bsc#1051510).
- USB: serial: ftdi_sio: use jtag quirk for Arrow USB Blaster
  (bsc#1051510).
- commit 3973b8d
* Mon Jul 30 2018 tiwai@suse.de
- USB: serial: cp210x: add ID for NI USB serial console
  (bsc#1051510).
- USB: serial: simple: add libtransistor console (bsc#1051510).
- USB: Increment wakeup count on remote wakeup (bsc#1051510).
- usb: musb: gadget: misplaced out of bounds check (bsc#1051510).
- USB: serial: option: reimplement interface masking
  (bsc#1051510).
- usb: gadget: udc: core: update usb_ep_queue() documentation
  (bsc#1051510).
- USB: gadget: f_midi: fixing a possible double-free in f_midi
  (bsc#1051510).
- usb: dwc3: Update DWC_usb31 GTXFIFOSIZ reg fields (bsc#1051510).
- usb: dwc3: Add SoftReset PHY synchonization delay (bsc#1051510).
- usb: dwc3: pci: Properly cleanup resource (bsc#1051510).
- usb: dwc3: Makefile: fix link error on randconfig (bsc#1051510).
- usb: dwc3: prevent setting PRTCAP to OTG from debugfs
  (bsc#1051510).
- usb: dwc2: host: Fix transaction errors in host mode
  (bsc#1051510).
- usb: dwc2: hcd: Fix host channel halt flow (bsc#1051510).
- usb: gadget: ffs: Let setup() return USB_GADGET_DELAYED_STATUS
  (bsc#1051510).
- usb: gadget: ffs: Execute copy_to_user() with USER_DS set
  (bsc#1051510).
- usb: gadget: composite: fix incorrect handling of OS desc
  requests (bsc#1051510).
- usb: gadget: udc: change comparison to bitshift when dealing
  with a mask (bsc#1051510).
- USB: serial: ftdi_sio: add support for Harman
  FirmwareHubEmulator (bsc#1051510).
- commit 76b6a9f
* Mon Jul 30 2018 tiwai@suse.de
- USB: serial: cp210x: add ELDAT Easywave RX09 id (bsc#1051510).
- USB: serial: ftdi_sio: add RT Systems VX-8 cable (bsc#1051510).
- usb: musb: Fix external abort in musb_remove on omap2430
  (bsc#1051510).
- usb: host: xhci-plat: revert "usb: host: xhci-plat: enable
  clk in resume timing" (bsc#1051510).
- usb: gadget: f_fs: Fix use-after-free in ffs_fs_kill_sb()
  (bsc#1051510).
- usb: musb: call pm_runtime_{get,put}_sync before reading vbus
  registers (bsc#1051510).
- usb: musb: fix enumeration after resume (bsc#1051510).
- USB: gadget: udc: Add missing platform_device_put() on error
  in bdc_pci_probe() (bsc#1051510).
- usb: dwc2: Fix dwc2_hsotg_core_init_disconnected()
  (bsc#1051510).
- usb: gadget: fsl_udc_core: fix ep valid checks (bsc#1051510).
- usb: dwc3: Fix GDBGFIFOSPACE_TYPE values (bsc#1051510).
- usb: gadget: core: Fix use-after-free of usb_request
  (bsc#1051510).
- usb: dwc3: omap: don't miss events during suspend/resume
  (bsc#1051510).
- usb: gadget: f_fs: Use config_ep_by_speed() (bsc#1051510).
- usb: gadget: f_fs: Process all descriptors during bind
  (bsc#1051510).
- usb: dwc3: Undo PHY init if soft reset fails (bsc#1051510).
- usb: gadget: f_uac2: fix bFirstInterface in composite gadget
  (bsc#1051510).
- usb: dwc3: ep0: Reset TRB counter for ep0 IN (bsc#1051510).
- usb: dwc3: gadget: Set maxpacket size for ep0 IN (bsc#1051510).
- usb: ldusb: add PIDs for new CASSY devices supported by this
  driver (bsc#1051510).
- USB: serial: option: Add support for Quectel EP06 (bsc#1051510).
- usb/gadget: Fix "high bandwidth" check in
  usb_gadget_ep_match_desc() (bsc#1051510).
- usb: gadget: dummy: fix nonsensical comparisons (bsc#1051510).
- usb: gadget: f_mass_storage: Fix the logic to iterate all
  common->luns (bsc#1051510).
- usb: gadget: bdc: 64-bit pointer capability check (bsc#1051510).
- commit 19504f6
* Mon Jul 30 2018 tiwai@suse.de
- blacklist.conf: Add renesas_usbhs path and another USB blacklist
- commit a00dfed
* Mon Jul 30 2018 tiwai@suse.de
- posix-timer: Properly check sigevent->sigev_notify
  (CVE-2017-18344,bsc#1102851).
- commit 2e3fc38
* Mon Jul 30 2018 tiwai@suse.de
- ubifs: Fix uninitialized variable in search_dh_cookie()
  (bsc#1051510).
- commit f7dcc38
* Mon Jul 30 2018 tiwai@suse.de
- media: dvb_frontend: fix ifnullfree.cocci warnings
  (bsc#1051510).
- commit b346b24
* Mon Jul 30 2018 tiwai@suse.de
- time: Make sure jiffies_to_msecs() preserves non-zero time
  periods (bsc#1051510).
- timekeeping: Use proper timekeeper for debug code (bsc#1051510).
- commit 74af5dd
* Mon Jul 30 2018 tiwai@suse.de
- UBIFS: Fix potential integer overflow in allocation
  (bsc#1051510).
- ubifs: Fix unlink code wrt. double hash lookups (bsc#1051510).
- ubifs: Fix data node size for truncating uncompressed nodes
  (bsc#1051510).
- commit c67abaa
* Mon Jul 30 2018 tiwai@suse.de
- vfio/pci: Fix potential Spectre v1 (bsc#1051510).
- commit eeecc47
* Mon Jul 30 2018 tiwai@suse.de
- virtio-net: Fix operstate for virtio when no VIRTIO_NET_F_STATUS
  (bsc#1051510).
- virtio_net: fix XDP code path in receive_small() (bsc#1051510).
- virtio_net: Disable interrupts if napi_complete_done rescheduled
  napi (bsc#1051510).
- virtio-net: fix module unloading (bsc#1051510).
- commit 0602b38
* Mon Jul 30 2018 tiwai@suse.de
- wlcore: add missing nvs file name info for wilink8
  (bsc#1051510).
- commit 9d3f03b
* Mon Jul 30 2018 tiwai@suse.de
- nfit: fix unchecked dereference in acpi_nfit_ctl (bsc#1051510).
- commit 3635c9e
* Mon Jul 30 2018 tiwai@suse.de
- dvb_frontend: don't use-after-free the frontend struct
  (bsc#1051510).
- media: dvb-core: always call invoke_release() in fe_free()
  (bsc#1051510).
- commit d414e4c
* Mon Jul 30 2018 tiwai@suse.de
- Move patches.drivers/ALSA-hda-realtek-Yet-another-Clevo-P950-quirk-entry into sorted section
- commit 3f37656
* Mon Jul 30 2018 tiwai@suse.de
- can: xilinx_can: fix power management handling (bsc#1051510).
- can: m_can.c: fix setup of CCCR register: clear CCCR NISO bit
  before checking can.ctrlmode (bsc#1051510).
- can: peak_canfd: fix firmware < v3.3.0: limit allocation to
  32-bit DMA addr only (bsc#1051510).
- commit 6d335ae
* Mon Jul 30 2018 tiwai@suse.de
- batman-adv: Avoid storing non-TT-sync flags on singular entries
  too (bsc#1051510).
- commit a98a77c
* Mon Jul 30 2018 tbogendoerfer@suse.de
- IB/mlx4: Fix an error handling path in 'mlx4_ib_rereg_user_mr()'
  (bsc#1046302 FATE#322945).
- commit 602a3f6
* Mon Jul 30 2018 tbogendoerfer@suse.de
- blacklist.conf
- commit 2ec9098
* Mon Jul 30 2018 tbogendoerfer@suse.de
- net/mlx4_core: Save the qpn from the input modifier in RST2INIT
  wrapper (bsc#1046300 FATE#322946).
- qed: Correct Multicast API to reflect existence of 256
  approximate buckets (bsc#1050536 FATE#322898).
- qed: Fix possible race for the link state value (bsc#1050536
  FATE#322898).
- net/mlx5e: Don't allow aRFS for encapsulated packets
  (bsc#1046303 FATE#322944).
- net/mlx5e: Fix quota counting in aRFS expire flow (bsc#1046303
  FATE#322944).
- net/mlx5: Adjust clock overflow work period (bsc#1046303
  FATE#322944).
- net/mlx4_en: Don't reuse RX page when XDP is set (bsc#1046299
  FATE#322947).
- qlogic: check kstrtoul() for errors (bsc#1050540 FATE#322896).
- bnxt_en: Fix for system hang if request_irq fails (bsc#1050242
  FATE#322914).
- bnxt_en: Do not modify max IRQ count after RDMA driver
  requests/frees IRQs (bsc#1050242 FATE#322914).
- bnxt_en: Always set output parameters in bnxt_get_max_rings()
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix inconsistent BNXT_FLAG_AGG_RINGS logic (bsc#1050242
  FATE#322914).
- net/sched: act_tunnel_key: fix NULL dereference when 'goto
  chain' is used (bsc#1056787).
- IB/hfi1: Fix incorrect mixing of ERR_PTR and NULL return values
  (bsc#1060463 FATE#323043).
- RDMA/uverbs: Protect from attempts to create flows on
  unsupported QP (bsc#1046306 FATE#322942).
- iw_cxgb4: correctly enforce the max reg_mr depth (bsc#1046543
  FATE#322927).
- qede: Adverstise software timestamp caps when PHC is not
  available (bsc#1050538 FATE#322897).
- qed: Fix use of incorrect size in memcpy call (bsc#1050536
  FATE#322898).
- qed: Fix setting of incorrect eswitch mode (bsc#1050536
  FATE#322898).
- qed: Limit msix vectors in kdump kernel to the minimum required
  count (bsc#1050536 FATE#322898).
- net/mlx5: Fix command interface race in polling mode
  (bsc#1046300 FATE#322946).
- net/mlx5: Fix incorrect raw command length parsing (bsc#1046300
  FATE#322946).
- net/mlx5: Fix wrong size allocation for QoS ETC TC regitster
  (bsc#1046300 FATE#322946).
- net/mlx5e: Don't attempt to dereference the ppriv struct if
  not being eswitch manager (bsc#1046300 FATE#322946).
- qed: Do not advertise DCBX_LLD_MANAGED capability (bsc#1050536
  FATE#322898).
- qed: Add sanity check for SIMD fastpath handler (bsc#1050536
  FATE#322898).
- qed: Fix possible memory leak in Rx error path handling
  (bsc#1050536 FATE#322898).
- infiniband: fix a possible use-after-free bug (bsc#1046306
  FATE#322942).
- IB/isert: fix T10-pi check mask setting (bsc#1046306
  FATE#322942).
- RDMA/mlx4: Discard unknown SQP work requests (bsc#1046302
  FATE#322945).
- IB/iser: Do not reduce max_sectors (bsc#1046306 FATE#322942).
- IB/mlx4: Mark user MR as writable if actual virtual memory is
  writable (bsc#1046302 FATE#322945).
- IB/core: Make testing MR flags for writability a static inline
  function (bsc#1046306 FATE#322942).
- IB/mlx5: Fetch soft WQE's on fatal error state (bsc#1046305
  FATE#322943).
- RDMA/ipoib: Update paths on CLIENT_REREG/SM_CHANGE events
  (bsc#1046307 FATE#322941).
- IB/hfi1: Fix fault injection init/exit issues (bsc#1060463
  FATE#323043).
- IB/hfi1: Return actual error value from program_rcvarray()
  (bsc#1060463 FATE#323043).
- sfc: stop the TX queue before pushing new buffers (bsc#1058169
  FATE#322922).
- net/mlx5: Eswitch, Use 'kvfree()' for memory allocated by
  'kvzalloc()' (bsc#1046303 FATE#322944).
- net/mlx5: Vport, Use 'kvfree()' for memory allocated by
  'kvzalloc()' (bsc#1046303 FATE#322944).
- net/mlx5e: Remove redundant vport context vlan update
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix dump_command mailbox length printed (bsc#1046303
  FATE#322944).
- net/mlx5: Refactor num of blocks in mailbox calculation
  (bsc#1046303 FATE#322944).
- igb: Fix queue selection on MAC filters on i210 (bsc#1056651
  FATE#322191).
- igb: Fix not adding filter elements to the list (bsc#1056651
  FATE#322191).
- IB/core: Fix error code for invalid GID entry (bsc#1046306
  FATE#322942).
- IB/umem: Use the correct mm during ib_umem_release (bsc#1046306
  FATE#322942).
- RDMA/i40iw: Avoid reference leaks when processing the AEQ
  (bsc#1058659 FATE#322535).
- RDMA/i40iw: Avoid panic when objects are being created and
  destroyed (bsc#1058659 FATE#322535).
- i40iw: Use correct address in dst_neigh_lookup for IPv6
  (bsc#1058659 FATE#322535).
- i40iw: Fix memory leak in error path of create QP (bsc#1058659
  FATE#322535).
- net: sched: red: avoid hashing NULL child (bsc#1056787).
- net/mlx4_core: Fix error handling in mlx4_init_port_info
  (bsc#1046300 FATE#322946).
- RDMA/iwpm: fix memory leak on map_info (bsc#1046306
  FATE#322942).
- RDMA/cma: Fix use after destroy access to net namespace for
  IPoIB (bsc#1046306 FATE#322942).
- net/mlx5: Properly deal with flow counters when deleting rules
  (bsc#1046303 FATE#322944).
- i40iw: Tear-down connection after CQP Modify QP failure
  (bsc#1058659 FATE#322535).
- i40iw: Refactor of driver generated AEs (bsc#1058659
  FATE#322535).
- net/sched: fix NULL dereference in the error path of
  tcf_sample_init() (bsc#1056787).
- commit 2fd2c4f
* Mon Jul 30 2018 tbogendoerfer@suse.de
- qed: Fix link flap issue due to mismatching EEE capabilities
  (bsc#1050536 FATE#322898).
- net/mlx5e: Refine ets validation function (bsc#1075360).
- IB/mlx5: Use 'kvfree()' for memory allocated by 'kvzalloc()'
  (bsc#1046305 FATE#322943).
- RDMA/mlx5: Use proper spec flow label type (bsc#1046305
  FATE#322943).
- RDMA/mlx5: Don't assume that medium blueFlame register exists
  (bsc#1046305 FATE#322943).
- RDMA/mlx5: Protect from shift operand overflow (bsc#1046305
  FATE#322943).
- RDMA/mlx5: Fix multiple NULL-ptr deref errors in rereg_mr flow
  (bsc#1046305 FATE#322943).
- commit 3c5e0f0
* Mon Jul 30 2018 jthumshirn@suse.de
- nvmet-fc: fix target sgl list on large transfers (FATE#323952,
  FATE#322506).
- nvme: fix handling of metadata_len for NVME_IOCTL_IO_CMD
  (FATE#323952, FATE#322506).
- scsi: qla2xxx: Fix kernel crash due to late workqueue allocation
  (bsc#1077338).
- s390/qeth: fix race when setting MAC address (bnc#1093148,
  LTC#167307).
- s390: move spectre sysfs attribute code (bsc#1090098).
- commit de2cde0
* Mon Jul 30 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/nouveau: Set DRIVER_ATOMIC cap earlier to fix debugfs'
- commit 4f3c523
* Mon Jul 30 2018 tzimmermann@suse.de
- drm/nouveau/drm/nouveau: Fix runtime PM leak in nv50_disp_atomic_commit() (bsc#1090888).
- commit ab6beb7
* Mon Jul 30 2018 tzimmermann@suse.de
- drm/tegra: Acquire a reference to the IOVA cache (bsc#1090888).
- commit 50421a8
* Fri Jul 27 2018 tbogendoerfer@suse.de
- net: mvmdio: simplify the smi read and write error paths
  (bsc#1098633).
- net: mvmdio: add xmdio xsmi support (bsc#1098633).
- net: mvmdio: check the MII_ADDR_C45 bit is not set for smi
  operations (bsc#1098633).
- net: mvmdio: put the poll intervals in the ops structure
  (bsc#1098633).
- net: mvmdio: introduce an ops structure (bsc#1098633).
- net: mvmdio: remove duplicate locking (bsc#1098633).
  Refresh
  patches.suse/net-mvmdio-disable-unprepare-clocks-in-EPROBE_DEFER-.patch.
- net: mvmdio: use GENMASK for masks (bsc#1098633).
- net: mvmdio: use tabs for defines (bsc#1098633).
- net: mvmdio: reorder headers alphabetically (bsc#1098633).
- commit 6bef56f
* Fri Jul 27 2018 tiwai@suse.de
- driver core: Partially revert "driver core: correct device's
  shutdown order" (bsc#1051510).
- commit 0015fab
* Fri Jul 27 2018 jroedel@suse.de
- iommu/vt-d: Clear Page Request Overflow fault bit (fate#326306).
- commit 5c2fc8a
* Fri Jul 27 2018 msuchanek@suse.de
- KABI: powerpc: mmu_context: provide old version of
  mm_iommu_ua_to_hpa (bsc#1077761, git-fixes).
- commit f19fb74
* Fri Jul 27 2018 tiwai@suse.de
- audit: Fix wrong task in comparison of session ID (bsc#1051510).
- audit: return on memory error to avoid null pointer dereference
  (bsc#1051510).
- audit: ensure that 'audit=1' actually enables audit for PID 1
  (bsc#1051510).
- commit 7cd7838
* Fri Jul 27 2018 tiwai@suse.de
- batman-adv: Fix debugfs path for renamed softif (bsc#1051510).
- batman-adv: Fix debugfs path for renamed hardif (bsc#1051510).
- batman-adv: Fix bat_v best gw refcnt after netlink dump
  (bsc#1051510).
- batman-adv: Fix bat_ogm_iv best gw refcnt after netlink dump
  (bsc#1051510).
- batman-adv: Fix TT sync flags for intermediate TT responses
  (bsc#1051510).
- batman-adv: Avoid race in TT TVLV allocator helper
  (bsc#1051510).
- batman-adv: fix packet loss for broadcasted DHCP packets to
  a server (bsc#1051510).
- batman-adv: fix multicast-via-unicast transmission with AP
  isolation (bsc#1051510).
- batman-adv: Fix skbuff rcsum on packet reroute (bsc#1051510).
- batman-adv: fix header size check in batadv_dbg_arp()
  (bsc#1051510).
- batman-adv: update data pointers after skb_cow() (bsc#1051510).
- batman-adv: Fix multicast packet loss with a single
  WANT_ALL_IPV4/6 flag (bsc#1051510).
- batman-adv: Fix internal interface indices types (bsc#1051510).
- batman-adv: Fix netlink dumping of BLA backbones (bsc#1051510).
- batman-adv: Fix netlink dumping of BLA claims (bsc#1051510).
- batman-adv: Ignore invalid batadv_v_gw during netlink send
  (bsc#1051510).
- batman-adv: Ignore invalid batadv_iv_gw during netlink send
  (bsc#1051510).
- batman-adv: invalidate checksum on fragment reassembly
  (bsc#1051510).
- batman-adv: fix packet checksum in receive path (bsc#1051510).
- batman-adv: Fix lock for ogm cnt access in batadv_iv_ogm_calc_tq
  (bsc#1051510).
- batman-adv: Fix check of retrieved orig_gw in
  batadv_v_gw_is_eligible (bsc#1051510).
- batman-adv: Always initialize fragment header priority
  (bsc#1051510).
- batman-adv: fix TT sync flag inconsistencies (bsc#1051510).
- batman-adv: Accept only filled wifi station info (bsc#1051510).
- batman-adv: Use default throughput value on cfg80211 error
  (bsc#1051510).
- commit 87be7cb
* Fri Jul 27 2018 tiwai@suse.de
- KEYS: DNS: fix parsing multiple options (bsc#1051510).
- commit 41e75ac
* Fri Jul 27 2018 tiwai@suse.de
- Add cherry-picked id for KEYS DNS fix
- commit bcaf0a3
* Fri Jul 27 2018 tiwai@suse.de
- smsc75xx: Add workaround for gigabit link up hardware errata
  (bsc#1051510).
- serial: sh-sci: Use spin_{try}lock_irqsave instead of open
  coding version (bsc#1051510).
- serial: sirf: Fix out-of-bounds access through DT alias
  (bsc#1051510).
- serial: pxa: Fix out-of-bounds access through serial port index
  (bsc#1051510).
- serial: imx: drop if that always evaluates to true
  (bsc#1051510).
- smsc75xx: fix smsc75xx_set_features() (bsc#1051510).
- staging: sm750fb: Fix parameter mistake in poke32 (bsc#1051510).
- smsc95xx: Configure pause time to 0xffff when tx flow control
  enabled (bsc#1051510).
- serial: earlycon: Only try fdt when specify 'earlycon' exactly
  (bsc#1051510).
- serial: sh-sci: Update warning message in sci_request_dma_chan()
  (bsc#1051510).
- commit eb9cf00
* Fri Jul 27 2018 msuchanek@suse.de
- vfio/spapr: Use IOMMU pageshift rather than pagesize
  (bsc#1077761, git-fixes).
- commit 2ffee0f
* Fri Jul 27 2018 tiwai@suse.de
- scripts/gdb/linux/tasks.py: fix get_thread_info (bsc#1051510).
- scripts/kernel-doc: Don't fail with status != 0 if error
  encountered with -none (bsc#1051510).
- scripts/dtc: fix '%%zx' warning (bsc#1051510).
- commit cc42476
* Fri Jul 27 2018 tiwai@suse.de
- rtc: pxa: fix probe function (bsc#1051510).
- rtc: ac100: Fix ac100 determine rate bug (bsc#1051510).
- commit 6ceb12c
* Fri Jul 27 2018 tiwai@suse.de
- fuse: don't keep dead fuse_conn at fuse_fill_super()
  (bsc#1051510).
- fuse: fix control dir setup and teardown (bsc#1051510).
- fuse: fix congested state leak on aborted connections
  (bsc#1051510).
- fuse: Remove the buggy retranslation of pids in fuse_dev_do_read
  (bsc#1051510).
- fuse: atomic_o_trunc should truncate pagecache (bsc#1051510).
- commit f20a33c
* Fri Jul 27 2018 tiwai@suse.de
- staging: fbtft: array underflow in fbtft_request_gpios_match()
  (bsc#1051510).
- commit 7b263e0
* Fri Jul 27 2018 tiwai@suse.de
- drbd: fix access after free (bsc#1051510).
- drm/bridge/sii8620: fix potential buffer overflow (bsc#1051510).
- dp83640: Ensure against premature access to PHY registers
  after reset (bsc#1051510).
- commit 5a3d4a5
* Fri Jul 27 2018 tiwai@suse.de
- Add cherry-picked id for i915 patch
- commit a4af68a
* Fri Jul 27 2018 tiwai@suse.de
- bus: arm-ccn: fix module unloading Error: Removing state 147
  which has instances left (bsc#1051510).
- bus: arm-cci: Fix use of smp_processor_id() in preemptible
  context (bsc#1051510).
- bus: arm-ccn: Fix use of smp_processor_id() in preemptible
  context (bsc#1051510).
- bus: arm-ccn: Check memory allocation failure (bsc#1051510).
- commit fb5baef
* Fri Jul 27 2018 tiwai@suse.de
- ahci: Disable LPM on Lenovo 50 series laptops with a too old
  BIOS (bsc#1051510).
- alx: take rtnl before calling __alx_open from resume
  (bsc#1051510).
- staging: comedi: quatech_daqp_cs: fix no-op loop
  daqp_ao_insn_write() (bsc#1051510).
- clockevents/drivers/cs5535: Improve resilience to spurious
  interrupts (bsc#1051510).
- cpufreq: docs: Drop intel-pstate.txt from index.txt
  (bsc#1051510).
- cpufreq: docs: Add missing cpuinfo_cur_freq description
  (bsc#1051510).
- commit 2fe0a57
* Thu Jul 26 2018 tiwai@suse.de
- clk: at91: PLL recalc_rate() now using cached MUL and DIV values
  (bsc#1051510).
- clk: mvebu: use correct bit for 98DX3236 NAND (bsc#1051510).
- clk: imx7d: fix mipi dphy div parent (bsc#1051510).
- clk: qcom: Base rcg parent rate off plan frequency
  (bsc#1051510).
- clk: honor CLK_MUX_ROUND_CLOSEST in generic clk mux
  (bsc#1051510).
- clk: bcm2835: De-assert/assert PLL reset signal when appropriate
  (bsc#1051510).
- clk: rockchip: Fix wrong parent for SDMMC phase clock for rk3228
  (bsc#1051510).
- clk: rockchip: Prevent calculating mmc phase if clock rate is
  zero (bsc#1051510).
- clk: fix false-positive Wmaybe-uninitialized warning
  (bsc#1051510).
- clk: hisilicon: fix potential NULL dereference in
  hisi_clk_alloc() (bsc#1051510).
- clk: hisilicon: mark wdt_mux_p[] as const (bsc#1051510).
- clk: Don't show the incorrect clock phase (bsc#1051510).
- commit 4b2acbb
* Thu Jul 26 2018 tiwai@suse.de
- clk: samsung: exynos5250: Add missing clocks for FIMC LITE
  SYSMMU devices (bsc#1051510).
- clk: samsung: s3c2410: Fix PLL rates (bsc#1051510).
- clk: samsung: exynos7: Fix PLL rates (bsc#1051510).
- clk: samsung: exynos5433: Fix PLL rates (bsc#1051510).
- clk: samsung: exynos5260: Fix PLL rates (bsc#1051510).
- clk: samsung: exynos5250: Fix PLL rates (bsc#1051510).
- clk: samsung: exynos3250: Fix PLL rates (bsc#1051510).
- clk: tegra: Fix pll_u rate configuration (bsc#1051510).
- clk: meson: remove unnecessary rounding in the pll clock
  (bsc#1051510).
- clk: fix mux clock documentation (bsc#1051510).
- clk: sunxi-ng: a31: Fix CLK_OUT_* clock ops (bsc#1051510).
- clk: meson: mpll: use 64-bit maths in params_from_rate
  (bsc#1051510).
- clk: meson: gxbb: fix wrong clock for SARADC/SANA (bsc#1051510).
- clk: si5351: Rename internal plls to avoid name collisions
  (bsc#1051510).
- clk: axi-clkgen: Correctly handle nocount bit in recalc_rate()
  (bsc#1051510).
- commit bc48bc7
* Thu Jul 26 2018 tiwai@suse.de
- clk: fix set_rate_range when current rate is out of range
  (bsc#1051510).
- clk: qcom: msm8916: fix mnd_width for codec_digcodec
  (bsc#1051510).
- clk: ti: dra7-atl-clock: fix child-node lookups (bsc#1051510).
- clk: qcom: common: fix legacy board-clock registration
  (bsc#1051510).
- clk: uniphier: fix DAPLL2 clock rate of Pro5 (bsc#1051510).
- clk: mediatek: add the option for determining PLL source clock
  (bsc#1051510).
- clk: mediatek: mark mtk_infrasys_init_early __init
  (bsc#1051510).
- clk: imx6: refine hdmi_isfr's parent to make HDMI work on
  i.MX6 SoCs w/o VPU (bsc#1051510).
- clk: sunxi: fix build warning (bsc#1051510).
- clk: hi3660: fix incorrect uart3 clock freqency (bsc#1051510).
- clk: hi6220: mark clock cs_atb_syspll as critical (bsc#1051510).
- clk: tegra: Use readl_relaxed_poll_timeout_atomic() in
  tegra210_clock_init() (bsc#1051510).
- commit 64b2885
* Thu Jul 26 2018 tiwai@suse.de
- clk: tegra: Fix cclk_lp divisor register (bsc#1051510).
- clk: sunxi-ng: nm: Check if requested rate is supported by
  fractional clock (bsc#1051510).
- clk: sunxi-ng: sun5i: Fix bit offset of audio PLL post-divider
  (bsc#1051510).
- clk: sunxi-ng: sun6i: Rename HDMI DDC clock to avoid name
  collision (bsc#1051510).
- clk: sunxi-ng: sun6i: Export video PLLs (bsc#1051510).
- clk: sunxi-ng: add CLK_SET_RATE_PARENT flag to H3 GPU clock
  (bsc#1051510).
- clk: sunxi-ng: add CLK_SET_RATE_UNGATE to all H3 PLLs
  (bsc#1051510).
- clk: samsung: Fix m2m scaler clock on Exynos542x (bsc#1051510).
- clk: si5351: fix PLL reset (bsc#1051510).
- clk: Don't write error code into divider register (bsc#1051510).
- clk: hi6220: change watchdog clock source (bsc#1051510).
- clk: sunxi: fix uninitialized access (bsc#1051510).
- clk: qcom: msm8916: Fix bimc gpu clock ops (bsc#1051510).
- clk: renesas: div6: Document fields used for parent selection
  (bsc#1051510).
- commit 05d0c03
* Thu Jul 26 2018 tiwai@suse.de
- clk: sunxi-ng: allow set parent clock (PLL_CPUX) for CPUX
  clock on H3 (bsc#1051510).
- clk: sunxi-ng: h3: gate then ungate PLL CPU clk after rate
  change (bsc#1051510).
- clk: sunxi-ng: Wait for lock when using fractional mode
  (bsc#1051510).
- clk: sunxi-ng: Make fractional helper less chatty (bsc#1051510).
- clk: sunxi-ng: multiplier: Fix fractional mode (bsc#1051510).
- clk: sunxi-ng: Fix fractional mode for N-M clocks (bsc#1051510).
- clk: meson: gxbb: fix clk_mclk_i958 divider flags (bsc#1051510).
- clk: meson: gxbb: fix meson cts_amclk divider flags
  (bsc#1051510).
- clk: qcom: clk-smd-rpm: Fix the reported rate of branches
  (bsc#1051510).
- clk: meson: meson8b: fix protection against undefined clks
  (bsc#1051510).
- clk: meson: mpll: fix mpll0 fractional part ignored
  (bsc#1051510).
- clk: x86: Do not gate clocks enabled by the firmware
  (bsc#1051510).
- clk: scpi: error when clock fails to register (bsc#1051510).
- clk: socfpga: Fix the smplsel on Arria10 and Stratix10
  (bsc#1051510).
- clk: renesas: r8a7795: Correct pwm, gpio, and i2c parent clocks
  on ES2.0 (bsc#1051510).
- clk: renesas: r8a7745: Remove PLL configs for MD19=0
  (bsc#1051510).
- clk: renesas: r8a7745: Remove nonexisting scu-src[0789] clocks
  (bsc#1051510).
- clk: renesas: rcar-gen2: Fix PLL0 on R-Car V2H and E2
  (bsc#1051510).
- clk: Fix __set_clk_rates error print-string (bsc#1051510).
- clk: scpi: fix return type of __scpi_dvfs_round_rate
  (bsc#1051510).
- clk: at91: fix clk-generated parenting (bsc#1051510).
- commit 210a5b3
* Thu Jul 26 2018 msuchanek@suse.de
- KVM: PPC: Check if IOMMU page is contained in the pinned
  physical page (bsc#1077761, git-fixes).
- commit 061ef8b
* Thu Jul 26 2018 tiwai@suse.de
- can: xilinx_can: fix incorrect clear of non-processed interrupts
  (bsc#1051510).
- can: xilinx_can: fix RX overflow interrupt not being enabled
  (bsc#1051510).
- can: xilinx_can: keep only 1-2 frames in TX FIFO to fix TX
  accounting (bsc#1051510).
- can: xilinx_can: fix recovery from error states not being
  propagated (bsc#1051510).
- can: xilinx_can: fix RX loop if RXNEMP is asserted without RXOK
  (bsc#1051510).
- can: xilinx_can: fix device dropping off bus on RX overrun
  (bsc#1051510).
- can: mpc5xxx_can: check of_iomap return before use
  (bsc#1051510).
- atl1c: reserve min skb headroom (bsc#1051510).
- backlight: as3711_bl: Fix Device Tree node leaks (bsc#1051510).
- can: bcm: check for null sk before deferencing it via the call
  to sock_net (bsc#1051510).
- b44: Initialize 64-bit stats seqcount (bsc#1051510).
- commit a560d0a
* Thu Jul 26 2018 tiwai@suse.de
- drm/nouveau: Avoid looping through fake MST connectors
  (bsc#1051510).
- drm/nouveau: Use drm_connector_list_iter_* for iterating
  connectors (bsc#1051510).
- drm/i915: Fix hotplug irq ack on i965/g4x (bsc#1051510).
- drm/i915/dp: Send DPCD ON for MST before phy_up (bsc#1051510).
- drm/i915: Only call tasklet_kill() on the first prepare_reset
  (bsc#1051510).
- drm/exynos: Fix dma-buf import (bsc#1051510).
- commit 8e5e15f
* Thu Jul 26 2018 tiwai@suse.de
- Add another cherry-picked id for i915 patches
- commit b09d939
* Thu Jul 26 2018 tiwai@suse.de
- blacklist.conf: Add amdgpu cherry-picked entry
- commit 3eb7296
* Thu Jul 26 2018 tiwai@suse.de
- blacklist.conf: Add pinctrl, regulator and thermal entries
- commit 8b683f1
* Thu Jul 26 2018 tiwai@suse.de
- iio: pressure: zpa2326: Remove always-true check which confuses
  gcc (bsc#1051510).
- IIO: BME280: Updates to Humidity readings need ctrl_reg
  write! (bsc#1051510).
- commit 7657094
* Thu Jul 26 2018 tiwai@suse.de
- media: staging: omap4iss: Include asm/cacheflush.h after
  generic includes (bsc#1051510).
- commit 8b6cf4f
* Thu Jul 26 2018 tiwai@suse.de
- pinctrl: nsp: Fix potential NULL dereference (bsc#1051510).
- pinctrl: nand: meson-gxbb: fix missing data pins (bsc#1051510).
- pinctrl: mvebu: use correct MPP sel value for dev pins
  (bsc#1051510).
- pinctrl: pinctrl-single: Fix pcs_request_gpio() when
  bits_per_mux != 0 (bsc#1051510).
- pinctrl: sh-pfc: r8a7790: Add missing TX_ER pin to avb_mii group
  (bsc#1051510).
- pinctrl: sh-pfc: r8a7796: Fix IPSR and MOD_SEL register pin
  assignment for NDFC pins group (bsc#1051510).
- pinctrl: sh-pfc: r8a7795: Fix MOD_SEL register pin assignment
  for SSI pins group (bsc#1051510).
- pinctrl: sh-pfc: r8a7796: Fix to delete A20..A25 pins function
  definitions (bsc#1051510).
- pinctrl: sh-pfc: r8a7795: Fix to delete A20..A25 pins function
  definitions (bsc#1051510).
- pinctrl: uniphier: fix members of rmii group for Pro4
  (bsc#1051510).
- pinctrl: intel: Read back TX buffer state (bsc#1051510).
- pinctrl: sh-pfc: r8a7796: Fix to delete FSCLKST pin and IPSR7
  bit[15:12] register definitions (bsc#1051510).
- pinctrl: sunxi: fix wrong irq_banks number for H5 pinctrl
  (bsc#1051510).
- pinctrl: sunxi: fix V3s pinctrl driver IRQ bank base
  (bsc#1051510).
- pinctrl: uniphier: fix pin_config_get() for input-enable
  (bsc#1051510).
- pinctrl: bcm2835: Avoid warning from __irq_do_set_handler
  (bsc#1051510).
- pinctrl: meson-gxbb: remove non-existing pin GPIOX_22
  (bsc#1051510).
- pinctrl: meson-gxl: Fix typo in AO SPDIF pins (bsc#1051510).
- pinctrl: meson-gxl: Fix typo in AO I2S pins (bsc#1051510).
- pinctrl: imx: fix debug message for SHARE_MUX_CONF_REG case
  (bsc#1051510).
- commit 6a8019e
* Thu Jul 26 2018 oneukum@suse.com
- USB: OHCI: Fix NULL dereference in HCDs using HCD_LOCAL_MEM
  (bsc#1087092).
- commit 70842f1
* Thu Jul 26 2018 tiwai@suse.de
- power: gemini-poweroff: Avoid spurious poweroff (bsc#1051510).
- power: supply: act8945a_charger: fix of_irq_get() error check
  (bsc#1051510).
- power: supply: cpcap-charger: add OMAP_USB2 dependency
  (bsc#1051510).
- commit fe4a95d
* Thu Jul 26 2018 tiwai@suse.de
- pwm: stm32: Enforce dependency on CONFIG_MFD_STM32_TIMERS
  (bsc#1051510).
- pwm: meson: Fix allocation of PWM channel array (bsc#1051510).
- pwm: stm32: Remove unused struct device (bsc#1051510).
- pwm: tiehrpwm: fix clock imbalance in probe error path
  (bsc#1051510).
- pwm: tiehrpwm: Fix runtime PM imbalance at unbind (bsc#1051510).
- pwm: meson: Improve PWM calculation precision (bsc#1051510).
- commit 1c7ced7
* Thu Jul 26 2018 tiwai@suse.de
- r8152: napi hangup fix after disconnect (bsc#1051510).
- r8152: fix tx packets accounting (bsc#1051510).
- r8169: Be drop monitor friendly (bsc#1051510).
- commit 1b2cfed
* Thu Jul 26 2018 oneukum@suse.com
- usb: cdc_acm: prevent race at write to acm while system resumes
  (bsc#1087092).
- commit d6fbae7
* Thu Jul 26 2018 tiwai@suse.de
- regulator: max8998: Fix platform data retrieval (bsc#1051510).
- regulator: tps65218: Fix strobe assignment (bsc#1051510).
- regulator: qcom_spmi: Include offset when translating voltages
  (bsc#1051510).
- commit b4b762e
* Thu Jul 26 2018 tiwai@suse.de
- thermal/drivers/hisi: Fix multiple alarm interrupts firing
  (bsc#1051510).
- thermal/drivers/hisi: Simplify the temperature/step computation
  (bsc#1051510).
- thermal/drivers/hisi: Fix kernel panic on alarm interrupt
  (bsc#1051510).
- thermal/drivers/hisi: Fix missing interrupt enablement
  (bsc#1051510).
- thermal: fix INTEL_SOC_DTS_IOSF_CORE dependencies (bsc#1051510).
- thermal: bcm2835: fix an error code in probe() (bsc#1051510).
- commit 42a543a
* Thu Jul 26 2018 oneukum@suse.com
- blacklist.conf: the fix was wrong and and correct fix applied later
- commit e6efac2
* Thu Jul 26 2018 jthumshirn@suse.de
- libnvdimm, label: fix index block size calculation
  (bsc#1102147).
- commit bc246c4
* Thu Jul 26 2018 oneukum@suse.com
- blacklist.conf: change for preparation of changes in Kconfig
- commit f8c9976
* Thu Jul 26 2018 oneukum@suse.com
- usb: option: Add support for FS040U modem (bsc#1087092).
- commit c3dbb73
* Thu Jul 26 2018 jthumshirn@suse.de
- scsi: zfcp: fix missing REC trigger trace on enqueue without
  ERP thread (bsc#1102088, LTC#169699).
- scsi: zfcp: fix missing REC trigger trace for all objects in
  ERP_FAILED (bsc#1102088, LTC#169699).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  for ERP_FAILED (bsc#1102088, LTC#169699).
- scsi: zfcp: fix missing REC trigger trace on terminate_rport_io
  early return (bsc#1102088, LTC#169699).
- scsi: zfcp: fix misleading REC trigger trace where erp_action
  setup failed (bsc#1102088, LTC#169699).
- scsi: zfcp: fix missing SCSI trace for retry of abort /
  scsi_eh TMF (bsc#1102088, LTC#169699).
- scsi: zfcp: fix missing SCSI trace for result of
  eh_host_reset_handler (bsc#1102088, LTC#169699).
- scsi: zfcp: fix infinite iteration on ERP ready list
  (bsc#1102088, LTC#169699).
- s390/qeth: fix error handling in adapter command callbacks
  (bsc#1102088, LTC#169699).
- s390/qdio: don't retry EQBS after CCQ 96 (bsc#1102088,
  LTC#169699).
- commit 58163cf
* Thu Jul 26 2018 oneukum@suse.com
- blacklist.conf: fix for feature we don't use
- commit c9a9251
* Thu Jul 26 2018 oneukum@suse.com
- usb: dwc2: Improve gadget state disconnection handling
  (bsc#1085539).
- commit 275701e
* Thu Jul 26 2018 oneukum@suse.com
- Revert "xhci: plat: Register shutdown for xhci_plat"
  (bsc#1090888).
- commit aaf661a
* Thu Jul 26 2018 jgross@suse.com
- xen/grant-table: log the lack of grants (bnc#1085042).
- commit 940699f
* Thu Jul 26 2018 oneukum@suse.com
- pinctrl: nsp: off by ones in nsp_pinmux_enable() (bsc#1100132).
- commit 4b1905b
* Thu Jul 26 2018 oneukum@suse.com
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bsc#1087092).
- commit 859155e
* Thu Jul 26 2018 tbogendoerfer@suse.de
- kabi mvpp2 10gkr support (bsc#1098633).
- commit b960ffb
* Thu Jul 26 2018 tiwai@suse.de
- ALSA: rawmidi: Change resized buffers atomically (bsc#1051510).
- ALSA: hda/realtek - Add Panasonic CF-SZ6 headset jack quirk
  (bsc#1051510).
- ALSA: hda: add mute led support for HP ProBook 455 G5
  (bsc#1051510).
- commit 70b340b
* Wed Jul 25 2018 tbogendoerfer@suse.de
- net: mvpp2: Fix clock resource by adding missing mg_core_clk
  (bsc#1098633).
- net: mvpp2: Fix clk error path in mvpp2_probe (bsc#1098633).
- net: mvpp2: Fix DMA address mask size (bsc#1098633).
- net: mvpp2: Fix TCAM filter reserved range (bsc#1098633).
- net: mvpp2: Fix parser entry init boundary check (bsc#1098633).
- net: mvpp2: Use relaxed I/O in data path (bsc#1098633).
- net: mvpp2: Don't use dynamic allocs for local variables
  (bsc#1098633).
- net: mvpp2: Make mvpp2_prs_hw_read a parser entry init function
  (bsc#1098633).
- net: mvpp2: use correct index on array mvpp2_pools
  (bsc#1098633).
- net: mvpp2: Add support for unicast filtering (bsc#1098633).
- net: mvpp2: Simplify MAC filtering function parameters
  (bsc#1098633).
- net: mvpp2: mvpp2_check_hw_buf_num() can be static
  (bsc#1098633).
- net: mvpp2: jumbo frames support (bsc#1098633).
- net: mvpp2: enable UDP/TCP checksum over IPv6 (bsc#1098633).
- net: mvpp2: use a data size of 10kB for Tx FIFO on port 0
  (bsc#1098633).
- net: mvpp2: update the BM buffer free/destroy logic
  (bsc#1098633).
- net: mvpp2: use the same buffer pool for all ports
  (bsc#1098633).
- net: mvpp2: Add hardware offloading for VLAN filtering
  (bsc#1098633).
- mvpp2: fix multicast address filter (bsc#1098633).
- net: mvpp2: enable ACPI support in the driver (bsc#1098633).
- net: mvpp2: use device_*/fwnode_* APIs instead of of_*
  (bsc#1098633).
- net: mvpp2: simplify maintaining enabled ports' list
  (bsc#1098633).
- device property: Allow iterating over available child fwnodes
  (bsc#1098633).
- device property: Introduce fwnode_irq_get() (bsc#1098633).
- device property: Introduce fwnode_get_phy_mode() (bsc#1098633).
- device property: Introduce fwnode_get_mac_address()
  (bsc#1098633).
- net: mvpp2: adjust the coalescing parameters (bsc#1098633).
- net: mvpp2: report the tx-usec coalescing information to ethtool
  (bsc#1098633).
- net: mvpp2: align values in ethtool get_coalesce (bsc#1098633).
- net: mvpp2: split the max ring size from the default one
  (bsc#1098633).
- net: mvpp2: only free the TSO header buffers when it was
  allocated (bsc#1098633).
- net: mvpp2: fix the RSS table entry offset (bsc#1098633).
- net: mvpp2: allocate zeroed tx descriptors (bsc#1098633).
- net: mvpp2: check ethtool sets the Tx ring size is to a valid
  min value (bsc#1098633).
- net: mvpp2: do not disable GMAC padding (bsc#1098633).
- net: mvpp2: cleanup probed ports in the probe error path
  (bsc#1098633).
- net: mvpp2: fix the txq_init error path (bsc#1098633).
- net: mvpp2: fix GOP statistics loop start and stop conditions
  (bsc#1098633).
- net: mvpp2: add ethtool GOP statistics (bsc#1098633).
- net: mvpp2: simplify the Tx desc set DMA logic (bsc#1098633).
- net: mvpp2: use the aggr txq size define everywhere
  (bsc#1098633).
- net: mvpp2: limit TSO segments and use stop/wake thresholds
  (bsc#1098633).
- net: mvpp2: initialize the RSS tables (bsc#1098633).
- net: mvpp2: initialize the Tx FIFO size (bsc#1098633).
- net: mvpp2: set the Rx FIFO size depending on the port speeds
  for PPv2.2 (bsc#1098633).
- net: mvpp2: remove useless goto (bsc#1098633).
- net: mvpp2: Prevent userspace from changing TX affinities
  (bsc#1098633).
- net: mvpp2: do not sleep in set_rx_mode (bsc#1098633).
- net: mvpp2: fix invalid parameters order when calling the tcam
  init (bsc#1098633).
- net: mvpp2: fix typo in the tcam setup (bsc#1098633).
- net: mvpp2: do not call txq_done from the Tx path when Tx irqs
  are used (bsc#1098633).
- net: mvpp2: do not unmap TSO headers buffers (bsc#1098633).
- net: mvpp2: fix TSO headers allocation and management
  (bsc#1098633).
- net: mvpp2: Fix clock resource by adding an optional bus clock
  (bsc#1098633).
- net: mvpp2: do not select the internal source clock
  (bsc#1098633).
- net: mvpp2: fix port list indexing (bsc#1098633).
- net: mvpp2: fix parsing fragmentation detection (bsc#1098633).
- net: mvpp2: fallback using h/w and random mac if the dt one
  isn't valid (bsc#1098633).
- net: mvpp2: fix use of the random mac address for PPv2.2
  (bsc#1098633).
- net: mvpp2: move the mac retrieval/copy logic into its own
  function (bsc#1098633).
- net: mvpp2: use the GoP interrupt for link status changes
  (bsc#1098633).
- net: mvpp2: make the phy optional (bsc#1098633).
- net: mvpp2: take advantage of the is_rgmii helper (bsc#1098633).
- net: mvpp2: dynamic reconfiguration of the comphy/GoP/MAC
  (bsc#1098633).
- net: mvpp2: do not set GMAC autoneg when using XLG MAC
  (bsc#1098633).
- net: mvpp2: improve the link management function (bsc#1098633).
- net: mvpp2: simplify the link_event function (bsc#1098633).
- net: mvpp2: initialize the comphy (bsc#1098633).
- phy: add sgmii and 10gkr modes to the phy_mode enum
  (bsc#1098633).
- net: mvpp2: fix the packet size configuration for 10G
  (bsc#1098633).
- net: mvpp2: software tso support (bsc#1098633).
- net: mvpp2: unify the txq size define use (bsc#1098633).
- net: define the TSO header size in net/tso.h (bsc#1098633).
- net: mvpp2: initialize the GoP (bsc#1098633).
- net: mvpp2: set maximum packet size for 10G ports (bsc#1098633).
- net: mvpp2: initialize the XLG MAC when using a port
  (bsc#1098633).
- net: mvpp2: initialize the GMAC when using a port (bsc#1098633).
- net: mvpp2: move the mii configuration in the ndo_open path
  (bsc#1098633).
- net: mvpp2: fix the synchronization module bypass macro name
  (bsc#1098633).
- net: mvpp2: unify register definitions coding style
  (bsc#1098633).
- net: mvpp2: add support for TX interrupts and RX queue
  distribution modes (bsc#1098633).
- net: mvpp2: introduce queue_vector concept (bsc#1098633).
- net: mvpp2: move from cpu-centric naming to "software thread"
  naming (bsc#1098633).
- net: mvpp2: introduce per-port nrxqs/ntxqs variables
  (bsc#1098633).
- net: mvpp2: remove RX queue group reset code (bsc#1098633).
- net: mvpp2: fix MVPP21_ISR_RXQ_GROUP_REG definition
  (bsc#1098633).
- net: mvpp2: remove mvpp2_pool_refill() (bsc#1098633).
- net: mvpp2: remove unused mvpp2_bm_cookie_pool_set() function
  (bsc#1098633).
- net: mvpp2: add comments about smp_processor_id() usage
  (bsc#1098633).
- net: mvpp2: enable basic 10G support (bsc#1098633).
- net: phy: add XAUI and 10GBASE-KR PHY connection types
  (bsc#1098633).
- commit bb14fdc
* Wed Jul 25 2018 oneukum@suse.com
- USB: yurex: fix out-of-bounds uaccess in read handler
  (bsc#1100132).
- commit 5759570
* Wed Jul 25 2018 oneukum@suse.com
- xhci: Fix kernel oops in trace_xhci_free_virt_device
  (bsc#1100132).
- commit 330f69f
* Wed Jul 25 2018 tbogendoerfer@suse.de
- kabi mlx5 hide cpu_rmap (bsc#1046303 FATE#322944).
- commit 29d90f9
* Wed Jul 25 2018 tbogendoerfer@suse.de
- bnxt_en: Fix the vlan_tci exact match check (bsc#1050242
  FATE#32291).
- qed: off by one in qed_parse_mcp_trace_buf() (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- commit 51ed532
* Wed Jul 25 2018 oneukum@suse.com
- xhci: Fix USB3 NULL pointer dereference at logical disconnect
  (bsc#1090888).
- commit 78c4386
* Wed Jul 25 2018 tbogendoerfer@suse.de
- RDMA/mlx5: Fix memory leak in mlx5_ib_create_srq() error path
  (bsc#1046305 FATE#322943).
- Refresh
  patches.kabi/kabi-IB-mlx5-Fix-integer-overflows-in-mlx5_ib_create_srq.patch.
- commit 825ce31
* Wed Jul 25 2018 tbogendoerfer@suse.de
- IB/hfi1: Add bypass register defines and replace blind constants
  (bsc#1060463 FATE#323043).
- IB/core: Remove duplicate declaration of gid_cache_wq
  (bsc#1046306 FATE#322942).
- net/mlx5: FPGA, Call DMA unmap with the right size (bsc#1046303
  FATE#322944).
- net/mlx5: IPSec, Fix a race between concurrent sandbox QP
  commands (bsc#1046303 FATE#322944).
- net/mlx5: Free IRQs in shutdown path (bsc#1046303 FATE#322944).
- RDMA/ucma: ucma_context reference leak in error path
  (bsc#1046306 FATE#322942).
- commit 80081f9
* Wed Jul 25 2018 oneukum@suse.com
- blacklist.conf: only build warning
- commit 062a7b0
* Wed Jul 25 2018 oneukum@suse.com
- xhci: xhci-mem: off by one in xhci_stream_id_to_ring()
  (bsc#1100132).
- commit 6e13d7e
* Wed Jul 25 2018 oneukum@suse.com
- usb: host: ehci: use correct device pointer for dma ops
  (bsc#1087092).
- commit 9a2a851
* Wed Jul 25 2018 oneukum@suse.com
- USB: serial: keyspan_pda: fix modem-status error handling
  (bsc#1100132).
- commit 8f55964
* Wed Jul 25 2018 oneukum@suse.com
- PCI: dwc: Fix enumeration end when reaching root subordinate
  (bsc#1100132).
- commit a63089d
* Wed Jul 25 2018 nstange@suse.de
- x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content
  (bsc#1089343 CVE-2018-3646).
- commit 8564424
* Wed Jul 25 2018 oneukum@suse.com
- xhci: Fix use-after-free in xhci_free_virt_device (bsc#1100132).
- commit 5defecc
* Wed Jul 25 2018 jkosina@suse.cz
- cpu/hotplug: detect SMT disabled by BIOS (bsc#1089343
  CVE-2018-3646).
- commit 0968980
* Wed Jul 25 2018 mhocko@suse.com
- ipc/shm: fix use-after-free of shm file via remap_file_pages()
  (bnc#1102512).
- commit a10faea
* Wed Jul 25 2018 oneukum@suse.com
- PCI: Account for all bridges on bus when distributing bus
  numbers (bsc#1100132).
- commit 09fe2a5
* Tue Jul 24 2018 tiwai@suse.de
- mfd: tps65911-comparator: Fix an off by one bug (bsc#1051510).
- mfd: tps65911-comparator: Fix a build error (bsc#1051510).
- mfd: tps65218: Reorder tps65218_regulator_id enum (bsc#1051510).
- kernel/params.c: downgrade warning for unsafe parameters
  (bsc#1051510).
- hwrng: stm32 - add reset during probe (bsc#1051510).
- mdio-sun4i: Fix a memory leak (bsc#1051510).
- gpio: brcmstb: switch to handle_level_irq flow (bsc#1051510).
- fsi: core: register with postcore_initcall (bsc#1051510).
- commit c4e6ac9
* Tue Jul 24 2018 tiwai@suse.de
- dmaengine: k3dma: Off by one in k3_of_dma_simple_xlate()
  (bsc#1051510).
- dmaengine: pl330: report BURST residue granularity
  (bsc#1051510).
- dmaengine: rcar-dmac: Check the done lists in
  rcar_dmac_chan_get_residue() (bsc#1051510).
- dmaengine: qcom: bam_dma: get num-channels and num-ees from dt
  (bsc#1051510).
- dmaengine: pl330: fix a race condition in case of threaded irqs
  (bsc#1051510).
- dmaengine: mv_xor_v2: Fix clock resource by adding a register
  clock (bsc#1051510).
- dmaengine: rcar-dmac: fix max_chunk_size for R-Car Gen3
  (bsc#1051510).
- dmaengine: zynqmp_dma: Fix race condition in the probe
  (bsc#1051510).
- dmaengine: qcom_hidma: check pending interrupts (bsc#1051510).
- clocksource/drivers/stm32: Fix kernel panic with multiple timers
  (bsc#1051510).
- dmaengine: fsl-edma: disable clks on all error paths
  (bsc#1051510).
- crypto: ccp - remove unused variable qim (bsc#1051510).
- dmaengine: xilinx_dma: Fix error code format specifier
  (bsc#1051510).
- dmaengine: tegra210-adma: fix of_irq_get() error check
  (bsc#1051510).
- dmaengine: tegra-apb: Really fix runtime-pm usage (bsc#1051510).
- dmaengine: omap-dma: port_window support correction for both
  direction (bsc#1051510).
- commit 1cc5a1e
* Tue Jul 24 2018 tiwai@suse.de
- checkpatch: add 6 missing types to --list-types (bsc#1051510).
- commit c9616bd
* Tue Jul 24 2018 tiwai@suse.de
- mmc: dw_mmc: fix card threshold control configuration
  (bsc#1051510).
- mailbox: bcm2835: Fix of_xlate return value (bsc#1051510).
- mmc: cavium: Fix use-after-free in of_platform_device_destroy
  (bsc#1051510).
- mmc: meson-gx: remove CLK_DIVIDER_ALLOW_ZERO clock flag
  (bsc#1051510).
- commit d19f009
* Tue Jul 24 2018 tiwai@suse.de
- hwmon: (ltc2990) Fix incorrect conversion of negative
  temperatures (bsc#1051510).
- hwmon: (nct6683) Enable EC access if disabled at boot
  (bsc#1051510).
- hwmon: Deal with errors from the thermal subsystem
  (bsc#1051510).
- hwmon: (tmp102) Fix first temperature reading (bsc#1051510).
- hwmon: (aspeed-pwm) add THERMAL dependency (bsc#1051510).
- hwmon: (stts751) buffer overrun on wrong chip configuration
  (bsc#1051510).
- hwmon: (ftsteutates) Fix clearing alarm sysfs entries
  (bsc#1051510).
- commit 3061bd4
* Tue Jul 24 2018 tiwai@suse.de
- iio: pressure: bmp280: fix relative humidity unit (bsc#1051510).
- iio: tsl2583: correct values in integration_time_available
  (bsc#1051510).
- staging:iio:ade7854: Fix the wrong number of bits to read
  (bsc#1051510).
- staging:iio:ade7854: Fix error handling on read/write
  (bsc#1051510).
- iio: humidity: hts221: remove warnings in
  hts221_parse_{temp,rh}_caldata() (bsc#1051510).
- staging: iio: ade7759: fix signed extension bug on shift of a u8
  (bsc#1051510).
- iio: adc: twl4030: Return an error if we can not enable the
  vusb3v1 regulator in 'twl4030_madc_probe()' (bsc#1051510).
- iio: magnetometer: st_magn: fix drdy line configuration for
  LIS3MDL (bsc#1051510).
- iio: accel: st_accel: fix data-ready line configuration
  (bsc#1051510).
- iio: pressure: st_pressure: fix drdy configuration for LPS22HB
  and LPS25H (bsc#1051510).
- iio: accel: st_accel_i2c: fix i2c_device_id table (bsc#1051510).
- iio: magnetometer: st_magn_core: enable multiread by default
  for LIS3MDL (bsc#1051510).
- iio: gyro: st_gyro: fix L3GD20H support (bsc#1051510).
- iio: trigger: stm32-timer: fix write_raw return value
  (bsc#1051510).
- iio: trigger: stm32-timer: fix quadrature mode get routine
  (bsc#1051510).
- iio: adc: sun4i-gpadc-iio: fix unbalanced irq enable/disable
  (bsc#1051510).
- iio: imu: inv_mpu6050: test whoami first and against all known
  values (bsc#1051510).
- iio: magnetometer: st_magn_spi: fix spi_device_id table
  (bsc#1051510).
- iio: accel: st_accel_spi: fix spi_device_id table (bsc#1051510).
- iio: pressure: zpa2326: report interrupted case as failure
  (bsc#1051510).
- commit fafe9ca
* Tue Jul 24 2018 tiwai@suse.de
- doc: Rename .system_keyring to .builtin_trusted_keys
  (bsc#1051510).
- docs: segmentation-offloads.txt: Fix ref to
  SKB_GSO_TUNNEL_REMCSUM (bsc#1051510).
- efi/efi_test: Prevent an Oops in efi_runtime_query_capsulecaps()
  (bsc#1051510).
- doc: SKB_GSO_[IPIP|SIT] have been replaced (bsc#1051510).
- docs-rst: fix broken links to dynamic-debug-howto in
  kernel-parameters (bsc#1051510).
- commit 8a72bfa
* Tue Jul 24 2018 tiwai@suse.de
- blacklist.conf: Add firmware/vpd entries
- commit f132923
* Tue Jul 24 2018 tiwai@suse.de
- blacklist.conf: Add an i2c mlxcpld entry that isn't applicable
- commit 93b4768
* Tue Jul 24 2018 tiwai@suse.de
- i2c: tegra: Fix NACK error handling (bsc#1051510).
- i2c: axxia: enable clock before calling clk_get_rate()
  (bsc#1051510).
- i2c: designware: Round down ACPI provided clk to nearest
  supported clk (bsc#1051510).
- i2c: mux: pinctrl: mention correct module name in Kconfig help
  text (bsc#1051510).
- commit 303e2ea
* Tue Jul 24 2018 tiwai@suse.de
- blacklist.conf: Add atomisp entries
- commit b0875d8
* Tue Jul 24 2018 tiwai@suse.de
- media: vivid: potential integer overflow in vidioc_g_edid()
  (bsc#1051510).
- media: cx88: Get rid of spurious call to cx8800_start_vbi_dma()
  (bsc#1051510).
- media: omap3isp/isp: remove an unused static var (bsc#1051510).
- media: dt-bindings: media: rcar_vin: Use status "okay"
  (bsc#1051510).
- media: cxusb: restore RC_MAP for MyGica T230 (bsc#1051510).
- media: dvb_net: ensure that dvb_net_ule_handle is fully
  initialized (bsc#1051510).
- media: s5p-mfc: Fix lock contention - request_firmware() once
  (bsc#1051510).
- media: dvb_frontend: only use kref after initialized
  (bsc#1051510).
- media: mxl111sf: Fix potential null pointer dereference
  (bsc#1051510).
- media: coda/imx-vdoa: Check for platform_get_resource() error
  (bsc#1051510).
- media: s5p-jpeg: fix number of components macro (bsc#1051510).
- commit c613c11
* Tue Jul 24 2018 tiwai@suse.de
- PM / hibernate: Use CONFIG_HAVE_SET_MEMORY for include condition
  (bsc#1051510).
- Refresh
  patches.suse/0007-PM-hibernate-encrypt-hidden-area.patch.
- Refresh
  patches.suse/0008-PM-hibernate-Generate-and-verify-signature-for-snaps.patch.
- commit 68d869a
* Tue Jul 24 2018 tiwai@suse.de
- NFC: pn533: Fix wrong GFP flag usage (bsc#1051510).
- NFC: nfcmrvl_uart: fix device-node leak during probe
  (bsc#1051510).
- commit eaa5baf
* Tue Jul 24 2018 tiwai@suse.de
- nfit, address-range-scrub: fix scrub in-progress reporting
  (bsc#1051510).
- nfit: fix region registration vs block-data-window ranges
  (bsc#1051510).
- commit 8ef3e7d
* Tue Jul 24 2018 tiwai@suse.de
- PM / core: Fix supplier device runtime PM usage counter
  imbalance (bsc#1051510).
- PM / wakeup: Only update last time for active wakeup sources
  (bsc#1051510).
- commit 8aece32
* Tue Jul 24 2018 tiwai@suse.de
- staging: rtl8723bs: fix u8 less than zero check (bsc#1051510).
- staging: rts5208: Fix "seg_no" calculation in reset_ms_card()
  (bsc#1051510).
- staging: rtl8723bs: add missing range check on id (bsc#1051510).
- commit d214912
* Tue Jul 24 2018 tiwai@suse.de
- Fix kABI for rtl_deinit_deferred_work() rewrite (bsc#1051510).
- rtlwifi: rtl8821ae: fix firmware is not ready to run
  (bsc#1051510).
- rtlwifi: Fix kernel Oops "Fw download fail!!" (bsc#1051510).
- commit b06d80b
* Tue Jul 24 2018 tiwai@suse.de
- blacklist.conf: Add a cherry-picked entry for X.509
- commit 9236b0e
* Tue Jul 24 2018 tiwai@suse.de
- X.509: unpack RSA signatureValue field from BIT STRING
  (bsc#1051510).
- commit 3af927a
* Tue Jul 24 2018 tiwai@suse.de
- gpio: pca953x: fix vendor prefix for PCA9654 (bsc#1051510).
- gpio: brcmstb: correct the configuration of level interrupts
  (bsc#1051510).
- gpio: brcmstb: release the bgpio lock during irq handlers
  (bsc#1051510).
- gpio: brcmstb: allow all instances to be wakeup sources
  (bsc#1051510).
- gpio: acpi: work around false-positive -Wstring-overflow warning
  (bsc#1051510).
- gpio: brcmstb: check return value of gpiochip_irqchip_add()
  (bsc#1051510).
- gpio: reject invalid gpio before getting gpio_desc
  (bsc#1051510).
- gpio: tegra: fix unbalanced chained_irq_enter/exit
  (bsc#1051510).
- commit 2f3dbef
* Tue Jul 24 2018 tiwai@suse.de
- Documentation: admin-guide: intel_pstate: Fix sysfs path
  (bsc#1051510).
- Fix English in description of GCC_PLUGIN_STRUCTLEAK
  (bsc#1051510).
- commit 4c0dc28
* Tue Jul 24 2018 tiwai@suse.de
- firewire: net: max MTU off by one (bsc#1051510).
- commit f72f64d
* Tue Jul 24 2018 tiwai@suse.de
- firmware: dmi: Optimize dmi_matches (bsc#1051510).
- drivers/firmware: psci_checker: Add missing
  destroy_timer_on_stack() (bsc#1051510).
- firmware: arm_scpi: fix endianness of dev_id in struct
  dev_pstate_set (bsc#1051510).
- firmware: tegra: Fix locking bugs in BPMP (bsc#1051510).
- commit 393951c
* Tue Jul 24 2018 tiwai@suse.de
- crypto: crypto4xx - fix crypto4xx_build_pdr, crypto4xx_build_sdr
  leak (bsc#1051510).
- crypto: crypto4xx - remove bad list_del (bsc#1051510).
- commit 0748ab4
* Tue Jul 24 2018 tiwai@suse.de
- cfg80211: initialize sinfo in cfg80211_get_station
  (bsc#1051510).
- commit 0935d8b
* Tue Jul 24 2018 tiwai@suse.de
- backlight: lm3630a: Bump REG_MAX value to 0x50 instead of 0x1F
  (bsc#1051510).
- commit 23c61f3
* Tue Jul 24 2018 tiwai@suse.de
- acpi/nfit: fix cmd_rc for acpi_nfit_ctl to always return a value
  (bsc#1051510).
- ACPI / processor: Finish making acpi_processor_ppc_has_changed()
  void (bsc#1051510).
- ACPI, APEI, EINJ: Subtract any matching Register Region from
  Trigger resources (bsc#1051510).
- commit 7857a8e
* Tue Jul 24 2018 tzimmermann@suse.de
- drm/rockchip: Fix build warning in analogix_dp-rockchip.c (bsc#1085536).
- commit 0917bc0
* Tue Jul 24 2018 tbogendoerfer@suse.de
- kabi cxgb4 MU (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588
  bsc#1097583 bsc#1097584).
- commit 7879068
* Tue Jul 24 2018 mbrugger@suse.com
- blacklist.conf: ignore dts folders
- commit 03e4f62
* Mon Jul 23 2018 tiwai@suse.de
- drm/nouveau/gem: off by one bugs in
  nouveau_gem_pushbuf_reloc_apply() (bsc#1051510).
- commit 564220d
* Mon Jul 23 2018 tiwai@suse.de
- driver core: Fix link to device power management documentation
  (bsc#1051510).
- commit 6e0eb75
* Mon Jul 23 2018 tiwai@suse.de
- crypto: caam/qi - explicitly set dma_ops (bsc#1051510).
- crypto: sha512-mb - add some missing unlock on error
  (bsc#1051510).
- commit b1cd3b8
* Mon Jul 23 2018 tzimmermann@suse.de
- gpu: host1x: Acquire a reference to the IOVA cache (bsc#1090888).
- commit efcb635
* Mon Jul 23 2018 tiwai@suse.de
- ath9k_htc: Add a sanity check in ath9k_htc_ampdu_action()
  (bsc#1051510).
- Bluetooth: avoid recursive locking in hci_send_to_channel()
  (bsc#1051510).
- Bluetooth: hci_ll: Add support for the external clock
  (bsc#1051510).
- Bluetooth: hci_ll: Fix download_firmware() return when
  __hci_cmd_sync fails (bsc#1051510).
- Bluetooth: hci_nokia: select BT_HCIUART_H4 (bsc#1051510).
- Bluetooth: hci_uart: fix kconfig dependency (bsc#1051510).
- commit fb47ea2
* Mon Jul 23 2018 tzimmermann@suse.de
- drm: mali-dp: Uninitialized variable in malidp_se_check_scaling() (bsc#1087092).
- commit 0bee75b
* Mon Jul 23 2018 tzimmermann@suse.de
- drm: rcar-du: Remove zpos field from rcar_du_vsp_plane_state structure (bsc#1085539).
- commit c4ffb3c
* Mon Jul 23 2018 tzimmermann@suse.de
- drm/rockchip: dw_hdmi: Move HDMI vpll clock enable to bind() (bsc#1087092).
- commit fc6a9be
* Mon Jul 23 2018 tzimmermann@suse.de
- drm/rockchip: inno_hdmi: Fix error handling path (bsc#1087092).
- commit dde76a1
* Mon Jul 23 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: Add more stuff to Recommends
  ... and move bc to Recommends as well.  All these packages are needed for
  building a kernel manually from scratch with kernel-source files.
- commit 6fcec9a
* Mon Jul 23 2018 tzimmermann@suse.de
- drm: rcar-du: lvds: Fix LVDCR1 for R-Car gen3 (bsc#1085539).
- Refresh
  patches.drivers/drm-rcar-du-lvds-Fix-LVDS-startup-on-R-Car-Gen3.
- commit d852350
* Mon Jul 23 2018 aaptel@suse.com
- cifs: do not allow creating sockets except with SMB1 posix
  exensions (bsc#1102097).
- commit b26635c
* Mon Jul 23 2018 aaptel@suse.com
- fix Patch-mainline header
- commit c1a1fcb
* Mon Jul 23 2018 msuchanek@suse.de
- Refresh patches.drivers/nvme-move-init-of-keep_alive-work-item-to-controller.patch.
  fix commit hash
- commit b98a0c9
* Mon Jul 23 2018 msuchanek@suse.de
- ibmvnic: Fix error recovery on login failure (bsc#1101789).
- commit 7f0b6bd
* Mon Jul 23 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/atomic: Fix memleak on ERESTARTSYS during non-blocking commits'
- commit 4a60e21
* Mon Jul 23 2018 tzimmermann@suse.de
- video/omap: add module license tags (bsc#1090888).
- commit ca9d8b9
* Mon Jul 23 2018 tbogendoerfer@suse.de
- cxgb4: Fix error handling path in 'init_one()' (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- commit 500b966
* Mon Jul 23 2018 tzimmermann@suse.de
- video: remove unused kconfig SH_LCD_MIPI_DSI (bsc#1087092).
- commit d5f1814
* Mon Jul 23 2018 tzimmermann@suse.de
- drm/rockchip: analogix_dp: Remove unnecessary init code (bsc#1085536).
- commit db1b65e
* Mon Jul 23 2018 tzimmermann@suse.de
- drm/rockchip: inno_hdmi: reorder clk_disable_unprepare call in unbind (bsc#1087092).
- commit 9c4f194
* Mon Jul 23 2018 lma@suse.com
- KVM: x86: fix vcpu initialization with userspace lapic
  (bsc#1101564).
- KVM: x86: move LAPIC initialization after VMCS creation
  (bsc#1101564).
- commit 5f3893e
* Sun Jul 22 2018 tiwai@suse.de
- rpm/kernel-source.spec.in: require bc for kernel-source
  This is needed for building include/generated/timeconst.h from
  kernel/time/timeconst.bc.
- commit d725e3b
* Fri Jul 20 2018 tbogendoerfer@suse.de
- Update config files.
- commit fd12fef
* Fri Jul 20 2018 aaptel@suse.com
- cifs: Fix infinite loop when using hard mount option
  (bsc#1091171).
- commit 7f265ee
* Fri Jul 20 2018 tbogendoerfer@suse.de
- cxgb4: enable ZLIB_DEFLATE when building cxgb4 (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- commit 3203abb
* Fri Jul 20 2018 tbogendoerfer@suse.de
- cxgb4: Add FORCE_PAUSE bit to 32 bit port caps (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4/cxgb4vf: Notify link changes to OS-dependent code
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- cxgb4: clean up init_one (bsc#1097585 bsc#1097586 bsc#1097587
  bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4/cxgb4vf: link management changes for new SFP (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Check for kvzalloc allocation failure (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: do L1 config when module is inserted (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: change the port capability bits definition (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Add new T6 device ids (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: copy the length of cpl_tx_pkt_core to fw_wr (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: collect SGE PF/VF queue map (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: update LE-TCAM collection for T6 (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- commit 2e58888
* Fri Jul 20 2018 tbogendoerfer@suse.de
- cxgb4: do not fail vf instatiation in slave mode (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: collect hardware dump in second kernel (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- vmcore: add API to collect hardware dump in second kernel
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- cxgb4: avoid schedule while atomic (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: enable inner header checksum calculation (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Fix {vxlan/geneve}_port initialization (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Add new T5 device id (bsc#1097585 bsc#1097586 bsc#1097587
  bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: fix the wrong conversion of Mbps to Kbps (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: update latest firmware version supported (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: add new T5 device id's (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4vf: display pause settings (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: copy mbox log size to PF0-3 adap instances (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: zero the HMA memory (bsc#1097585 bsc#1097586 bsc#1097587
  bsc#1097588 bsc#1097583 bsc#1097584).
- RDMA/cxgb4: release hw resources on device removal (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- scsi: cxgb4i: silence overflow warning in t4_uld_rx_handler()
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- iw_cxgb4: Add ib_device->get_netdev support (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- RDMA/cxgb4: Use structs to describe the uABI instead of
  opencoding (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588
  bsc#1097583 bsc#1097584).
- iw_cxgb4: initialize ib_mr fields for user mrs (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - don't leak pointers to authenc keys
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Fix iv passed in fallback path for rfc3686
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Update IV before sending request to HW
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Fix src buffer dma length (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - Use kernel round function to align lengths
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Make function aead_ccm_validate_input static
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- cxgb4: support new ISSI flash parts (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: depend on firmware event for link status (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: copy vlan_id in ndo_get_vf_config (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Setup FW queues before registering netdev (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Support firmware rdma write completion work request
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- cxgb4: Support firmware rdma write with immediate work request
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- cxgb4: Add support to query HW SRQ parameters (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Add support to initialise/read SRQ entries (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Adds CPL support for Shared Receive Queues (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Fix queue free path of ULD drivers (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: notify fatal error to uld drivers (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Add HMA support (bsc#1097585 bsc#1097586 bsc#1097587
  bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4/cxgb4vf: check fw caps to set link mode mask (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: do not display 50Gbps as unsupported speed (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: increase max tx rate limit to 100 Gbps (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4vf: Forcefully link up virtual interfaces (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Add TP Congestion map entry for single-port (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: remove dead code when allocating filter (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: rework on-chip memory read (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: do not set needs_free_netdev for mgmt dev's (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: copy adap index to PF0-3 adapter instances (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: free up resources of pf 0-3 (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgbit: call neigh_event_send() to update MAC address
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- cxgb4/cxgb4vf: add support for ndo_set_vf_vlan (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: IPv6 filter takes 2 tids (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- commit 121447a
* Fri Jul 20 2018 tbogendoerfer@suse.de
- cxgb4: use zlib deflate to compress firmware dump (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- Refresh
  patches.drivers/cxgb4-properly-initialize-variables.patch.
- commit 0f81869
* Fri Jul 20 2018 tbogendoerfer@suse.de
- cxgb4: update dump collection logic to use compression
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- cxgb4: restructure VF mgmt code (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Check alignment constraint for T6 (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: use CLIP with LIP6 on T6 for TCAM filters (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: Add support for ethtool i2c dump (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - Fix indentation warning (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - Remove dst sg size zero check (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - Add authenc versions of ctr and sha
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Fix IV updated in XTS operation (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - check for sg null (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - Fix Indentation (bsc#1097585 bsc#1097586
  bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - Fix an error code in chcr_hash_dma_map()
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: change transient busy return code to -ENOSPC
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Move DMA un/mapping to chcr from lld cxgb4
  driver (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588
  bsc#1097583 bsc#1097584).
- crypto: chelsio - Remove allocation of sg list to implement
  2K limit of dsgl header (bsc#1097585 bsc#1097586 bsc#1097587
  bsc#1097588 bsc#1097583 bsc#1097584).
- crypto: chelsio - Use x8_ble gf multiplication to calculate IV
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: gf128mul - The x8_ble multiplication functions
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Check error code with IS_ERR macro
  (bsc#1097585 bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583
  bsc#1097584).
- crypto: chelsio - Remove unused parameter (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- cxgb4: update latest firmware version supported (bsc#1097585
  bsc#1097586 bsc#1097587 bsc#1097588 bsc#1097583 bsc#1097584).
- commit de850aa
* Fri Jul 20 2018 tbogendoerfer@suse.de
- qed: Fix reading stale configuration information (bsc#1086314
  FATE#324886).
- commit 3f9fc3d
* Fri Jul 20 2018 tbogendoerfer@suse.de
- i40e: use the more traditional 'i' loop variable (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: add function doc headers for ethtool stats functions
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: update data pointer directly when copying to the buffer
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: fold prefix strings directly into stat names (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: use WARN_ONCE to replace the commented BUG_ON size check
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: split i40e_get_strings() into smaller functions
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: always return all queue stat strings (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: always return VEB stat strings (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: free skb after clearing lock in ptp_stop (bsc#1101816
  FATE#325147 FATE#325149).
- i40evf: Fix a hardware reset support in VF driver (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: free the skb after clearing the bitlock (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: cleanup wording in a header comment (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: add tx_busy to ethtool stats (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: Fix recalculation of MSI-X vectors for VMDq (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: cleanup whitespace for some ethtool stat definitions
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: remove duplicate pfc stats (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: calculate ethtool stats size in a separate function
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: avoid overflow in i40e_ptp_adjfreq() (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Fix multiple issues with UDP tunnel offload filter
  configuration (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: Fix turning TSO, GSO and GRO on after (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Add advertising 10G LR mode (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: fix reading LLDP configuration (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: cleanup incorrect function doxygen comments
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: Replace GFP_ATOMIC with GFP_KERNEL in i40evf_add_vlan
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: re-number feature flags to remove gaps (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: stop using cmpxchg flow in i40e_set_priv_flags()
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: hold the RTNL lock while changing interrupt schemes
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: move client flags into state bits (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: move I40E_FLAG_TEMP_LINK_POLLING to state field
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: move AUTO_DISABLED flags into the state field (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: move I40E_FLAG_UDP_FILTER_SYNC to the state field
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: move I40E_FLAG_FILTER_SYNC to a state bit (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Fix the polling mechanism of GLGEN_RSTAT.DEVSTATE
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: remove flags that are never used (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Prevent setting link speed on I40E_DEV_ID_25G_B
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: add doxygen comment for new mode parameter (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Prevent setting link speed on KX_X722 (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: restore TCPv4 input set when re-enabling ATR (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: fix for wrong partition id calculation on OCP mezz cards
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: factor out re-enable functions for ATR and SB (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: track filter type statistics when deleting invalid filters
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Fix permission check for VF MAC filters (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Cleanup i40e_vlan_rx_register (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: remove i40e_fcoe files (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: use SW variables for hang detection (bsc#1101816
  FATE#325147 FATE#325149).
- i40evf: Fix double locking the same resource (bsc#1101816
  FATE#325147 FATE#325149).
- i40evf: Fix link up issue when queues are disabled (bsc#1101816
  FATE#325147 FATE#325149).
- i40evf: Make VF reset warning message more clear (bsc#1101816
  FATE#325147 FATE#325149).
- i40evf: use __dev_c_sync routines in .set_rx_mode (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: do not force filter failure in overflow promiscuous
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: refactor promisc_changed in i40e_sync_vsi_filters
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: Use an iterator of the same type as the list
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: broadcast filters can trigger overflow promiscuous
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: don't leak memory addresses (bsc#1101816 FATE#325147
  FATE#325149).
- i40evf: use GFP_ATOMIC under spin lock (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: Add support for new mechanism of updating adaptive
  ITR (bsc#1101816 FATE#325147 FATE#325149).
- i40e/i40evf: Split container ITR into current_itr and target_itr
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: Correctly populate rxitr_idx and txitr_idx (bsc#1101816
  FATE#325147 FATE#325149).
- i40e/i40evf: Use usec value instead of reg value for ITR defines
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e/i40evf: Don't bother setting the CLEARPBA bit (bsc#1101816
  FATE#325147 FATE#325149).
- i40e/i40evf: Clean-up of bits related to using q_vector->reg_idx
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Add delay after EMP reset for firmware to recover
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e/i40evf: Clean up logic for adaptive ITR (bsc#1101816
  FATE#325147 FATE#325149).
- i40e/i40evf: Only track one ITR setting per ring instead of
  Tx/Rx (bsc#1101816 FATE#325147 FATE#325149).
- i40e: fix typo in function description (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: Update DESC_NEEDED value to reflect larger value
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e/i40evf: Record ITR register location in the q_vector
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: disallow programming multiple filters with same criteria
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Fix kdump failure (bsc#1101816 FATE#325147 FATE#325149).
- i40e: cleanup unnecessary parens (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: change flags to use 64 bits (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: Use ring pointers to clean up _set_itr_per_queue
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: Allow turning off offloads when the VF has VLAN set
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Fix for adding multiple ethtool filters on the same
  location (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Add returning AQ critical error to SW (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Delete an error message for a failed memory allocation
  in i40e_init_interrupt_scheme() (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: Disable iWARP VSI PETCP_ENA flag on netdev down events
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: check for invalid DCB config (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: Detect and recover hung queue scenario (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Fix for blinking activity instead of link LEDs
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: remove flush_scheduled_work call in i40evf_remove
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: avoid divide by zero (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: Enable NVMUpdate to retrieve AdminQ and add
  preservation flags for NVM update (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: track id can be 0 (bsc#1101816 FATE#325147 FATE#325149).
- i40e: change ppp name to ddp (bsc#1101816 FATE#325147
  FATE#325149).
- i40evf: Drop i40evf_fire_sw_int as it is prone to races
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: Clean-up flags for promisc mode to avoid high polling
  rate (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: Do not clear MSI-X PBA manually (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: remove redundant initialization of read_size (bsc#1101816
  FATE#325147 FATE#325149).
- i40e/i40evf: Bump driver versions (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: add helper conversion function for link_speed (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: update VFs of link state after GET_VF_RESOURCES
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: hold the critical task bit lock while opening
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: release bit locks in reverse order (bsc#1101816
  FATE#325147 FATE#325149).
- i40evf: use spinlock to protect (mac|vlan)_filter_list
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: display priority_xon and priority_xoff stats (bsc#1101816
  FATE#325147 FATE#325149).
- commit 15c69f4
* Fri Jul 20 2018 hare@suse.de
- nvme-loop: add support for multiple ports (bsc#1054245).
- Refresh
  patches.kabi/Revert-nvmet-constify-struct-nvmet_fabrics_ops.patch.
- commit 703b658
* Fri Jul 20 2018 glin@suse.com
- x86/efi: Access EFI MMIO data as unencrypted when SEV is active
  (bsc#1099193).
- commit bef90b1
* Thu Jul 19 2018 jack@suse.cz
- ext4: include the illegal physical block in the bad map
  ext4_error msg (bsc#1101903).
- commit e425529
* Thu Jul 19 2018 jack@suse.cz
- ext4: check superblock mapped prior to committing (bsc#1101902).
- commit 29e6b6d
* Thu Jul 19 2018 jack@suse.cz
- ext4: add more mount time checks of the superblock
  (bsc#1101900).
- commit e5fffd9
* Thu Jul 19 2018 tbogendoerfer@suse.de
- i40e/virtchnl: fix application of sizeof to pointer (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: restore promiscuous after reset (bsc#1101816 FATE#325147
  FATE#325149).
- i40evf: fix client notify of l2 params (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: Fix FLR reset timeout issue (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: Remove limit of 64 max queues per channel (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Fix for NUP NVM image downgrade failure (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: mark PM functions as __maybe_unused (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: convert i40e_set_link_ksettings to new API (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: rename 'change' variable to 'autoneg_changed' (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: convert i40e_get_settings_link_up to new API (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: convert i40e_phy_type_to_ethtool to new API (bsc#1101816
  FATE#325147 FATE#325149).
- ethtool: add ethtool_intersect_link_masks (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Add new PHY types for 25G AOC and ACC support (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: group autoneg PHY types together (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: fix whitespace issues in i40e_ethtool.c (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: fix comment typo (bsc#1101816 FATE#325147 FATE#325149).
- i40e: fix i40e_phy_type_to_ethtool function header (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: fix clearing link masks in i40e_get_link_ksettings
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: add function header for i40e_get_rxfh (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: remove ifdef SPEED_25000 (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: rename 'cmd' variables in ethtool interface (bsc#1101816
  FATE#325147 FATE#325149).
- i40e/i40evf: don't trust VF to reset itself (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: fix link reporting (bsc#1101816 FATE#325147 FATE#325149).
- i40e: make const array patterns static, reduces object code size
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Add infrastructure for queue channel support (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Add macro for PF reset bit (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: fix a typo (bsc#1101816 FATE#325147 FATE#325149).
- i40e: use a local variable instead of calculating multiple times
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Retry AQC GetPhyAbilities to overcome I2CRead hangs
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: add check for return from find_first_bit call (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: allow XPS with QoS enabled (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: bundle more descriptors when allocating buffers
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: reduce lrxqthresh from 2 to 1 (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: always set the CLEARPBA flag when re-enabling
  interrupts (bsc#1101816 FATE#325147 FATE#325149).
- i40e/i40evf: fix incorrect default ITR values on driver load
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: fix flags declaration (bsc#1101816 FATE#325147
  FATE#325149).
- i40e/i40evf: organize and re-number feature flags (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: ignore skb->xmit_more when deciding to set RS bit
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: enable support for VF VLAN tag stripping control
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: do not enter PHY debug mode while setting LEDs behaviour
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: implement split PCI error reset handler (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Properly maintain flow director filters list (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Display error message if module does not meet thermal
  requirements (bsc#1101816 FATE#325147 FATE#325149).
- i40e: fix merge error (bsc#1101816 FATE#325147 FATE#325149).
- i40e/i40evf: use DECLARE_BITMAP for state (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: fix incorrect register definition (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: redfine I40E_PHY_TYPE_MAX (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: re-enable PTP L4 capabilities for XL710 if FW >6.0
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: fix a typo in i40e_pf documentation (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Stop dropping 802.1ad tags - eth proto 0x88a8 (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: fix handling of vf_states variable (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: make i40evf_map_rings_to_vectors void (bsc#1101816
  FATE#325147 FATE#325149).
- i40evf: Enable VF to request an alternate queue allocation
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: ensure reset occurs when disabling VF (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: make use of i40e_vc_disable_vf (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: drop i40e_pf *pf from i40e_vc_disable_vf() (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: don't hold spinlock while resetting VF (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: use admin queue for setting LEDs behavior (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Add support for 'ethtool -m' (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: Fix reporting of supported link modes (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: Fix a potential NULL pointer dereference (bsc#1101816
  FATE#325147 FATE#325149).
- i40e: remove logically dead code (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: limit lan queue count in large CPU count machine
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: refactor FW version checking (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: Enable VF to negotiate number of allocated queues
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: fix ring to vector mapping (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: shutdown all IRQs and disable MSI-X when suspended
  (bsc#1101816 FATE#325147 FATE#325149).
- commit 8375c42
* Thu Jul 19 2018 jack@suse.cz
- ext4: add more inode number paranoia checks (bsc#1099849
  cve-2018-10882).
- commit 2ef082c
* Thu Jul 19 2018 jack@suse.cz
- ext4: never move the system.data xattr out of the inode body
  (bsc#1099845 cve-2018-10880).
- commit 4f35458
* Thu Jul 19 2018 jack@suse.cz
- ext4: clear i_data in ext4_inode_info when removing inline data
  (bsc#1099864 cve-2018-10881).
- commit baa7a04
* Thu Jul 19 2018 jack@suse.cz
- ext4: verify the depth of extent tree in ext4_find_extent()
  (bsc#1099846 cve-2018-10877).
- commit 721d277
* Thu Jul 19 2018 jack@suse.cz
- ext4: only look at the bg_flags field if it is valid
  (bsc#1099811 cve-2018-10876).
- commit 956ddb3
* Thu Jul 19 2018 jack@suse.cz
- ext4: make sure bitmaps and the inode table don't overlap with
  bg descriptors (bsc#1099813 cve-2018-10878).
- commit c2af81d
* Thu Jul 19 2018 jack@suse.cz
- ext4: always check block group bounds in
  ext4_init_block_bitmap() (bsc#1099813 cve-2018-10878).
- commit 31a8e5b
* Thu Jul 19 2018 jack@suse.cz
- ext4: avoid running out of journal credits when appending to
  an inline file (bsc#1099863 cve-2018-10883).
- commit 4772e39
* Thu Jul 19 2018 jack@suse.cz
- ext4: always verify the magic number in xattr blocks
  (bsc#1099844 cve-2018-10879).
- commit 60a5dc5
* Thu Jul 19 2018 jack@suse.cz
- ext4: add corruption check in ext4_xattr_set_entry()
  (bsc#1099844 cve-2018-10879).
- commit 235be78
* Thu Jul 19 2018 jack@suse.cz
- ext4: bubble errors from ext4_find_inline_data_nolock() up to
  ext4_iget() (bsc#1101896).
- commit d7be984
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist 117166efb1ee
- commit 70a37d4
* Thu Jul 19 2018 jack@suse.cz
- ext4: update mtime in ext4_punch_hole even if no blocks are
  released (bsc#1101895).
- commit 70e3fb4
* Thu Jul 19 2018 tbogendoerfer@suse.de
- i40e: don't clear suspended state until we finish resuming
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: prevent service task from running while we're suspended
  (bsc#1101816 FATE#325147 FATE#325149).
- Refresh
  patches.drivers/i40e-Close-client-on-suspend-and-restore-client-MSIx.patch.
- commit 9df198c
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist 0d9366d67bcf
- commit a5ffaff
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist 98c4f78dcdd8
- commit 87712ae
* Thu Jul 19 2018 jack@suse.cz
- Force log to disk before reading the AGF during a fstrim
  (bsc#1101893).
- commit 71f938b
* Thu Jul 19 2018 jack@suse.cz
- udf: Detect incorrect directory size (bsc#1101891).
- commit 8391b7e
* Thu Jul 19 2018 jack@suse.cz
- udf: Provide saner default for invalid uid / gid (bsc#1101890).
- commit ebbf597
* Thu Jul 19 2018 jack@suse.cz
- jbd2: don't mark block as modified if the handle is out of
  credits (bsc#1099863 cve-2018-10883).
- commit 2926ea8
* Thu Jul 19 2018 jack@suse.cz
- isofs: fix potential memory leak in mount option parsing
  (bsc#1101887).
- commit ad29748
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist 174d1232ebc8
- commit 31a31ab
* Thu Jul 19 2018 tbogendoerfer@suse.de
- i40e: use newer generic PM support instead of legacy PM
  callbacks (bsc#1101816 FATE#325147 FATE#325149).
- i40e: use separate state bit for miscellaneous IRQ setup
  (bsc#1101816 FATE#325147 FATE#325149).
- i40evf: lower message level (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: fix for flow director counters not wrapping as expected
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: relax warning message in case of version mismatch
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: simplify member variable accesses (bsc#1101816 FATE#325147
  FATE#325149).
- i40e: Fix link down message when interface is brought up
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e: Fix unqualified module message while bringing link up
  (bsc#1101816 FATE#325147 FATE#325149).
- i40e/i40evf: rename bytes_per_int to bytes_per_usec (bsc#1101816
  FATE#325147 FATE#325149).
- drivers: net: i40evf: use setup_timer() helper (bsc#1101816
  FATE#325147 FATE#325149).
- net: ethtool: Add macro to clear a link mode setting
  (bsc#1101816 FATE#325147 FATE#325149).
- commit 71db825
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist 92183a42898d
- commit 186b50c
* Thu Jul 19 2018 jack@suse.cz
- fscache: Fix hanging wait on page discarded by writeback
  (bsc#1101885).
- commit e791421
* Thu Jul 19 2018 jack@suse.cz
- fs: don't scan the inode cache before SB_BORN is set
  (bsc#1101883).
- commit b10f1e5
* Thu Jul 19 2018 jack@suse.cz
- fs: clear writeback errors in inode_init_always (bsc#1101882).
- commit b940b30
* Thu Jul 19 2018 jack@suse.cz
- ext2: fix a block leak (bsc#1101875).
- commit 20f71c9
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist 80660f20252d
- commit 2a35b88
* Thu Jul 19 2018 jack@suse.cz
- block: Fix transfer when chunk sectors exceeds max
  (bsc#1101874).
- commit f2d6c9c
* Thu Jul 19 2018 jack@suse.cz
- cdrom: do not call check_disk_change() inside cdrom_open()
  (bsc#1101872).
- commit 326588f
* Thu Jul 19 2018 jack@suse.cz
- bdi: Move cgroup bdi_writeback to a dedicated low concurrency
  workqueue (bsc#1101867).
- commit 7ad957c
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist 428edade4e6c7
- commit 2ea951e
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist a86b06d1ccd21
- commit 8715af2
* Thu Jul 19 2018 jack@suse.cz
- ext4: fix fencepost error in check for inode count overflow
  during resize (bsc#1101853).
- commit f80d662
* Thu Jul 19 2018 jack@suse.cz
- fix io_destroy()/aio_complete() race (bsc#1101852).
- commit 8e12bc8
* Thu Jul 19 2018 jack@suse.cz
- reiserfs: fix buffer overflow with long warning messages
  (bsc#1101847).
- commit 681d5b3
* Thu Jul 19 2018 jack@suse.cz
- orangefs: set i_size on new symlink (bsc#1101845).
- commit 14d9484
* Thu Jul 19 2018 jack@suse.cz
- befs_lookup(): use d_splice_alias() (bsc#1101844).
- commit a42c37f
* Thu Jul 19 2018 jack@suse.cz
- ext4: report delalloc reserve as non-free in statfs for project
  quota (bsc#1101843).
- commit b3fc4b1
* Thu Jul 19 2018 jack@suse.cz
- ext4: factor out helper ext4_sample_last_mounted()
  (bsc#1101841).
- commit c06c679
* Thu Jul 19 2018 jack@suse.cz
- vfs: add the sb_start_intwrite_trylock() helper (bsc#1101841).
- commit 83d517b
* Thu Jul 19 2018 jack@suse.cz
- ext4: do not update s_last_mounted of a frozen fs (bsc#1101841).
- commit 7692686
* Thu Jul 19 2018 jack@suse.cz
- mm: fix __gup_device_huge vs unmap (bsc#1101839).
- commit df63a9f
* Thu Jul 19 2018 jack@suse.cz
- f2fs: call unlock_new_inode() before d_instantiate()
  (bsc#1101837).
- commit ed52048
* Thu Jul 19 2018 jack@suse.cz
- blacklist.conf: blacklist a9af3fdcc425
- commit 9fb6929
* Thu Jul 19 2018 jack@suse.cz
- xfs: prevent creating negative-sized file via INSERT_RANGE
  (bsc#1101833).
- commit bdcecc6
* Thu Jul 19 2018 jack@suse.cz
- orangefs: report attributes_mask and attributes for statx
  (bsc#1101832).
- commit 80952d7
* Thu Jul 19 2018 jack@suse.cz
- afs: Fix directory permissions check (bsc#1101828).
- blacklist.conf: Blacklist 001ab5a67ee5
- commit 008ca23
* Thu Jul 19 2018 tbogendoerfer@suse.de
- fm10k: don't protect fm10k_queue_mac_request by
  fm10k_host_mbx_ready (bsc#1101813 FATE#325148).
- fm10k: warn if the stat size is unknown (bsc#1101813
  FATE#325148).
- fm10k: use macro to avoid passing the array and size separately
  (bsc#1101813 FATE#325148).
- fm10k: use variadic arguments to fm10k_add_stat_strings
  (bsc#1101813 FATE#325148).
- fm10k: reduce duplicate fm10k_stat macro code (bsc#1101813
  FATE#325148).
- fm10k: setup VLANs for l2 accelerated macvlan interfaces
  (bsc#1101813 FATE#325148).
- fm10k: bump version number (bsc#1101813 FATE#325148).
- fm10k: fix incorrect warning for function prototype (bsc#1101813
  FATE#325148).
- fm10k: fix function doxygen comments (bsc#1101813 FATE#325148).
- fm10k: clarify action when updating the VLAN table (bsc#1101813
  FATE#325148).
- fm10k: correct typo in fm10k_pf.c (bsc#1101813 FATE#325148).
- fm10k: don't assume VLAN 1 is enabled (bsc#1101813 FATE#325148).
- fm10k: stop adding VLAN 0 to the VLAN table (bsc#1101813
  FATE#325148).
- fm10k: fix "failed to kill vid" message for VF (bsc#1101813
  FATE#325148).
- fm10k: cleanup unnecessary parenthesis in fm10k_iov.c
  (bsc#1101813 FATE#325148).
- fm10k: Fix configuration for macvlan offload (bsc#1101813
  FATE#325148).
- fm10k: mark PM functions as __maybe_unused (bsc#1101813
  FATE#325148).
- fm10k: prefer %%s and __func__ for diagnostic prints (bsc#1101813
  FATE#325148).
- fm10k: Fix misuse of net_ratelimit() (bsc#1101813 FATE#325148).
- fm10k: bump version number (bsc#1101813 FATE#325148).
- fm10k: use the MAC/VLAN queue for VF<->PF MAC/VLAN requests
  (bsc#1101813 FATE#325148).
- fm10k: introduce a message queue for MAC/VLAN messages
  (bsc#1101813 FATE#325148).
- fm10k: use generic PM hooks instead of legacy PCIe power hooks
  (bsc#1101813 FATE#325148).
- fm10k: use spinlock to implement mailbox lock (bsc#1101813
  FATE#325148).
- fm10k: prepare_for_reset() when we lose PCIe Link (bsc#1101813
  FATE#325148).
- fm10k: prevent race condition of __FM10K_SERVICE_SCHED
  (bsc#1101813 FATE#325148).
- fm10k: move fm10k_prepare_for_reset and fm10k_handle_reset
  (bsc#1101813 FATE#325148).
- fm10k: avoid divide by zero in rare cases when device is
  resetting (bsc#1101813 FATE#325148).
- fm10k: don't loop while resetting VFs due to VFLR event
  (bsc#1101813 FATE#325148).
- fm10k: simplify reading PFVFLRE register (bsc#1101813
  FATE#325148).
- fm10k: avoid needless delay when loading driver (bsc#1101813
  FATE#325148).
- fm10k: add missing fall through comment (bsc#1101813
  FATE#325148).
- fm10k: avoid possible truncation of q_vector->name (bsc#1101813
  FATE#325148).
- fm10k: fix typos on fall through comments (bsc#1101813
  FATE#325148).
- fm10k: stop spurious link down messages when Tx FIFO is full
  (bsc#1101813 FATE#325148).
- fm10k: Use seq_putc() in fm10k_dbg_desc_break() (bsc#1101813
  FATE#325148).
- fm10k: reschedule service event if we stall the PF<->SM mailbox
  (bsc#1101813 FATE#325148).
- commit c3d0148
* Wed Jul 18 2018 tbogendoerfer@suse.de
- ixgbe: Fix setting of TC configuration for macvlan case
  (bsc#1101674 FATE#325150 FATE#325151).
- commit 93b5927
* Wed Jul 18 2018 tiwai@suse.de
- ALSA: hda/realtek - Yet another Clevo P950 quirk entry
  (bsc#1101143).
- commit 3e12cbc
* Wed Jul 18 2018 tbogendoerfer@suse.de
- ixgbe: fix possible race in reset subtask (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: introduce a helper to simplify code (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbevf: fix possible race in the reset subtask (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbevf: fix MAC address changes through ixgbevf_set_mac()
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: force VF to grab new MAC on driver reload (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe/ixgbevf: Free IRQ when PCI error recovery removes the
  device (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Drop support for macvlan specific unicast lists
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: fix ixgbevf_xmit_frame()'s return type (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: return error on unsupported SFP module when resetting
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: fix read-modify-write in x550 phy setup (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: add status reg reads to ixgbe_check_remove (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: fix disabling hide VLAN on VF reset (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbevf: fix unused variable warning (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbe: Add receive length error counter (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbevf: remove redundant initialization of variable 'dma'
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: add build_skb support (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbevf: break out Rx buffer page management (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbevf: allocate the rings as part of q_vector (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbevf: make sure all frames fit minimum size requirements
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: add support for padding packet (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbevf: setup queue counts (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbevf: add support for using order 1 pages to receive large
  frames (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: add ethtool private flag for legacy Rx (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbevf: use page_address offset from page (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: Avoid to write the RETA table when unnecessary
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: remove redundant initialization of 'pool' (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: Fix && vs || typo (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: add support for reporting 5G link speed (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: Don't report unsupported timestamping filters for X550
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: use ARRAY_SIZE for array sizing calculation on array buf
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: use ARRAY_SIZE for various array sizing calculations
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: don't bother clearing tx_buffer_info in
  ixgbevf_clean_tx_ring() (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: improve performance and reduce size of ixgbevf_tx_map()
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: clear rx_buffer_info in configure instead of clean
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: add counters for Rx page allocations (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbevf: update code to better handle incrementing page count
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: add support for DMA_ATTR_SKIP_CPU_SYNC/WEAK_ORDERING
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: use length to determine if descriptor is done
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: only DMA sync frame length (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbevf: add function for checking if we can reuse page
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: Fix kernel-doc format warnings (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbe: Fix kernel-doc format warnings (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbe: Fix handling of macvlan Tx offload (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: avoid bringing rings up/down as macvlans are
  added/removed (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Do not manipulate macvlan Tx queues when performing
  macvlan offload (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe/fm10k: Record macvlan stats instead of Rx queue for
  macvlan offloaded rings (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Don't assume dev->num_tc is equal to hardware TC config
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Default to 1 pool always being allocated (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: Assume provided MAC filter has been verified by macvlan
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Drop l2_accel_priv data pointer from ring struct
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Use ring values to test for Tx pending (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: Fix limitations on macvlan so we can support up to 63
  offloaded devices (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: There is no need to update num_rx_pools in L2 fwd offload
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Add support for macvlan offload RSS on X550 and clean-up
  pool handling (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Perform reinit any time number of VFs change (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: Fix interaction between SR-IOV and macvlan offload
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbevf: remove redundant setting of xcast_mode (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: Remove an obsolete comment about ITR (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: extend firmware version support (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbe: advertise highest capable link speed (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: remove unused enum latency_range (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbe: enable multicast on shutdown for WOL (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: fix crash when injecting AER after failed reset
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Update adaptive ITR algorithm (bsc#1101674 FATE#325150
  FATE#325151).
- ixgbe: fix the FWSM.PT check in ixgbe_mng_present() (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: add counter for times Rx pages gets allocated, not
  recycled (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: split Tx/Rx ring clearing for ethtool loopback test
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: add error checks when initializing the PHY (bsc#1101674
  FATE#325150 FATE#325151).
- ixgbe: restore normal RSS after last macvlan offload is removed
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: declare ixgbe_mac_operations structures as const
  (bsc#1101674 FATE#325150 FATE#325151).
- ixgbe: Clear SWFW_SYNC register during init (bsc#1101674
  FATE#325150 FATE#325151).
- cnic: Fix an error handling path in 'cnic_alloc_bnx2x_resc()'
  (bsc#1086324 FATE#324900).
- commit 5bb101f
* Wed Jul 18 2018 tbogendoerfer@suse.de
- kabi/severities: add qed inter module symbols to kabi ignore list
- commit afcb65f
* Wed Jul 18 2018 tbogendoerfer@suse.de
- qed: Fix use of incorrect shmem address (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix shared memory inconsistency between driver and the MFW
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- commit 9364aa7
* Wed Jul 18 2018 tbogendoerfer@suse.de
- qed*: Support drop action classification (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Support flow classification to the VFs (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed*: Support other classification modes (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Validate unsupported configurations (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Refactor ethtool rx classification flow (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Add support for populating ethernet TLVs (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Add driver infrastucture for handling mfw requests
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed: Add support for processing iscsi tlv request (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Add support for processing fcoe tlv request (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Add support for tlv request processing (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Add MFW interfaces for TLV request support (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Add build_skb() support (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix LL2 race during connection terminate (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix possibility of list corruption during rmmod flows
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed: Add support for Unified Fabric Port (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Add support for multi function mode with 802.1ad tagging
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed: Remove unused data member 'is_mf_default' (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed*: Refactor mf_mode to consist of bits (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- commit b2ad2ff
* Wed Jul 18 2018 hare@suse.de
- Revert "nvme: mark nvme_queue_scan static" (bsc#1054245).
- commit 4eef6f0
* Wed Jul 18 2018 hare@suse.de
- nvme: kabi fixes for nvme_ctrl (bsc#1054245).
- commit dbcdf9b
* Wed Jul 18 2018 jslaby@suse.cz
- tcp: verify the checksum of the first data segment in a new
  connection (networking-stable-18_06_20).
- net: dsa: add error handling for pskb_trim_rcsum
  (networking-stable-18_06_20).
- ipv6: allow PMTU exceptions to local routes
  (networking-stable-18_06_20).
- net: phy: dp83822: use BMCR_ANENABLE instead of BMSR_ANEGCAPABLE
  for DP83620 (networking-stable-18_06_20).
- socket: close race condition between sock_close() and
  sockfs_setattr() (networking-stable-18_06_20).
- udp: fix rx queue len reported by diag and proc interface
  (networking-stable-18_06_20).
- cdc_ncm: avoid padding beyond end of skb
  (networking-stable-18_06_20).
- net/sched: act_simple: fix parsing of TCA_DEF_DATA
  (networking-stable-18_06_20).
- bonding: re-evaluate force_primary when the primary slave name
  changes (networking-stable-18_06_20).
- net: in virtio_net_hdr only add VLAN_HLEN to csum_start if
  payload holds vlan (networking-stable-18_06_20).
- commit 5e9362d
* Tue Jul 17 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/omap: check return value from soc_device_match'
- commit 57b6835
* Tue Jul 17 2018 jeyu@suse.de
- module: make it clear when we're handling the module copy in
  info->hdr (bsc#1093666).
- module: setup load info before module_sig_check() (bsc#1093666).
- modsign: log module name in the event of an error (bsc#1093666).
- ARM: module: fix modsign build error (bsc#1093666).
- modsign: print module name along with error message
  (bsc#1093666).
- Refresh
  patches.drivers/0001-module-warn-if-module-init-probe-takes-long.patch.
- Refresh
  patches.suse/0004-MODSIGN-checking-the-blacklisted-hash-before-loading.patch.
- Refresh
  patches.suse/0042-Enforce-module-signatures-if-the-kernel-is-locked-do.patch.
- scripts/git_sort/git_sort.py: add modules-next tree
- commit 31d0a45
* Tue Jul 17 2018 hare@suse.de
- nvme: kABI fixes for nvmet_ctrl (bsc#1054245).
- Revert 'nvmet: constify struct nvmet_fabrics_ops' (bsc#1054245).
- commit 6d617e4
* Tue Jul 17 2018 yousaf.kaukab@suse.com
- mailbox: PCC: erroneous error message when parsing ACPI PCCT
  (bsc#1096330).
- commit 0791116
* Tue Jul 17 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/amdgpu: Refactor amdgpu_vram_mgr_bo_invisible_size helper'
- commit 1cc7869
* Tue Jul 17 2018 tzimmermann@suse.de
- blacklist.conf: Add 'drm/amdgpu: fix the missed vcn fw version report'
- commit 67c198b
* Tue Jul 17 2018 hare@suse.de
- nvmet: reset keep alive timer in controller enable
  (bsc#1054245).
- nvme: don't rely on the changed namespace list log
  (bsc#1054245).
- nvme: add bio remapping tracepoint (bsc#1054245).
- nvme: cleanup double shift issue (bsc#1054245).
- nvmet: filter newlines from user input (bsc#1054245).
- nvme: don't hold nvmf_transports_rwsem for more than transport
  lookups (bsc#1054245).
- nvmet: return all zeroed buffer when we can't find an active
  namespace (bsc#1054245).
- block: always set partition number to '0' in
  blk_partition_remap() (bsc#1054245).
- nvme: use the changed namespaces list log to clear ns data
  changed AENs (bsc#1054245).
- nvme: mark nvme_queue_scan static (bsc#1054245).
- nvme: submit AEN event configuration on startup (bsc#1054245).
- nvmet: mask pending AENs (bsc#1054245).
- nvmet: add AEN configuration support (bsc#1054245).
- nvmet: implement the changed namespaces log (bsc#1054245).
- nvmet: split log page implementation (bsc#1054245).
- nvmet: add a new nvmet_zero_sgl helper (bsc#1054245).
- nvme.h: add AEN configuration symbols (bsc#1054245).
- nvme.h: add the changed namespace list log (bsc#1054245).
- nvme.h: untangle AEN notice definitions (bsc#1054245).
- nvme: host: core: fix precedence of ternary operator
  (bsc#1054245).
- nvme: fix use-after-free in nvme_free_ns_head (bsc#1054245).
- nvme/multipath: Disable runtime writable enabling parameter
  (bsc#1054245).
- nvme: enforce 64bit offset for nvme_get_log_ext fn
  (bsc#1054245).
- nvme: make nvme_get_log_ext non-static (bsc#1054245).
- nvmet: constify struct nvmet_fabrics_ops (bsc#1054245).
- nvme: centralize ctrl removal prints (bsc#1054245).
- nvme: implement log page low/high offset and dwords
  (bsc#1054245).
- commit cad5ae8
* Tue Jul 17 2018 tiwai@suse.de
- Update config files: enable CONFIG_I2C_PXA for arm64 (bsc#1101465)
- commit 6109613
* Tue Jul 17 2018 tbogendoerfer@suse.de
- qed: Fix copying 2 strings (bsc#1086314 FATE#324886 bsc#1086313
  FATE#324885 bsc#1086301 FATE#3248881).
- qed: Add configuration information to register dump and
  debug data (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885
  bsc#1086301 FATE#3248881).
- qed: Delete unused parameter p_ptt from mcp APIs (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed* : Add new TLV to request PF to update MAC in bulletin board
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed* : use trust mode to allow VF to override forced MAC
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- RDMA/qedr: Fix doorbell bar mapping for dpi > 1 (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: LL2 flush isles when connection is closed (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Fix ref-cnt usage count (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: fix spelling mistake: "taskelt" -> "tasklet" (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: fix spelling mistake: "offloded" -> "offloaded"
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed: fix spelling mistake: "checksumed" -> "checksummed"
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- RDMA/qedr: Fix wmb usage in qedr (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Zero stack memory before copying to user space
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- IB/qedr: Remove GID add/del dummy routines (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qedr: Fix spelling mistake: "hanlde" -> "handle" (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: eliminate duplicate barriers on weakly-ordered archs
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qede: Ethtool flash update support (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Adapter flash update support (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Add APIs for flash access (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix PTT entry leak in the selftest error flow (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Populate nvm image attribute shadow (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed*: Utilize FW 8.33.11.0 (bsc#1086314 FATE#324886 bsc#1086313
  FATE#324885 bsc#1086301 FATE#3248881).
- qed: Use true and false for boolean values (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qlogic/qed: Constify *pkt_type_str (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Do not drop rx-checksum invalidated packets (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: Fix barrier usage after tx doorbell write (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qede: fix spelling mistake: "registeration" -> "registration"
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- RDMA/qedr: Fix iWARP write and send with immediate (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Fix kernel panic when running fio over NFSoRDMA
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- RDMA/qedr: Fix iWARP connect with port mapper (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Fix ipv6 destination address resolution (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- net: qed: use correct strncpy() size (bsc#1086314 FATE#324886
  bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: code indent should use tabs where possible (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Use zeroing memory allocator than allocator/memset
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- qed*: Utilize FW 8.33.1.0 (bsc#1086314 FATE#324886 bsc#1086313
  FATE#324885 bsc#1086301 FATE#3248881).
- qed*: HSI renaming for different types of HW (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed*: Refactoring and rearranging FW API with no functional
  impact (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885
  bsc#1086301 FATE#3248881).
- qede: Use NETIF_F_GRO_HW (bsc#1086314 FATE#324886 bsc#1086313
  FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: lower print level of flushed CQEs (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Fix endian problems around imm_data (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Use zeroing memory allocator than allocator/memset
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- drivers/net/ethernet/qlogic/qed: Fix __qed_spq_block() ordering
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- commit c78531b
* Tue Jul 17 2018 tiwai@suse.de
- ubi: fastmap: Correctly handle interrupted erasures in EBA
  (bsc#1051510).
- commit fbbfe4a
* Tue Jul 17 2018 tiwai@suse.de
- staging: rtl8723bs: Prevent an underflow in
  rtw_check_beacon_data() (bsc#1051510).
- commit 54445f4
* Tue Jul 17 2018 tiwai@suse.de
- PM / hibernate: Fix oops at snapshot_write() (bsc#1051510).
- commit 3cdeea9
* Tue Jul 17 2018 tiwai@suse.de
- media: cx25840: Use subdev host data for PLL override
  (bsc#1051510).
- commit b1d91d2
* Tue Jul 17 2018 tiwai@suse.de
- ASoC: mediatek: preallocate pages use platform device
  (bsc#1051510).
- commit 44a01c9
* Tue Jul 17 2018 tiwai@suse.de
- ALSA: hda/realtek - two more lenovo models need fixup of
  MIC_LOCATION (bsc#1051510).
- ALSA: hda - Handle pm failure during hotplug (bsc#1051510).
- commit 4922c4e
* Tue Jul 17 2018 tbogendoerfer@suse.de
- qed: Free reserved MR tid (bsc#1086314 FATE#324886 bsc#1086313
  FATE#324885 bsc#1086301 FATE#3248881).
- Refresh
  patches.drivers/qed-Free-RoCE-ILT-Memory-on-rmmod-qedr.patch.
- Refresh
  patches.drivers/qed-Use-after-free-in-qed_rdma_free.patch.
- commit 826659e
* Tue Jul 17 2018 tbogendoerfer@suse.de
- qed: Remove reserveration of dpi for kernel (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: Fix potential use-after-free in qed_spq_post() (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- qed: use kzalloc instead of kmalloc and memset (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Remove set-but-not-used variables (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Annotate iomem pointers correctly (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Declare local functions static (bsc#1086314
  FATE#324886 bsc#1086313 FATE#324885 bsc#1086301 FATE#3248881).
- RDMA/qedr: Use NULL instead of 0 to represent a pointer
  (bsc#1086314 FATE#324886 bsc#1086313 FATE#324885 bsc#1086301
  FATE#3248881).
- commit 9ffb606
* Tue Jul 17 2018 jslaby@suse.cz
- netdev-FAQ: clarify DaveM's position for stable backports
  (networking-stable-18_06_08).
- rtnetlink: validate attributes in do_setlink()
  (networking-stable-18_06_08).
- net: metrics: add proper netlink validation
  (networking-stable-18_06_08).
- sctp: not allow transport timeout value less than HZ/5 for
  hb_timer (networking-stable-18_06_08).
- team: use netdev_features_t instead of u32
  (networking-stable-18_06_08).
- net/packet: refine check for priv area size
  (networking-stable-18_06_08).
- vrf: check the original netdevice for generating redirect
  (networking-stable-18_06_08).
- net: usb: cdc_mbim: add flag FLAG_SEND_ZLP
  (networking-stable-18_06_08).
- ip6_tunnel: remove magic mtu value 0xFFF8
  (networking-stable-18_06_08).
- kcm: Fix use-after-free caused by clonned sockets
  (networking-stable-18_06_08).
- net-sysfs: Fix memory leak in XPS configuration
  (networking-stable-18_06_08).
- net: ethernet: davinci_emac: fix error handling in probe()
  (networking-stable-18_06_08).
- mlxsw: spectrum: Forbid creation of VLAN 1 over port/LAG
  (networking-stable-18_06_08).
- ipv6: sr: fix memory OOB access in seg6_do_srh_encap/inline
  (networking-stable-18_06_08).
- enic: set DMA mask to 47 bit (networking-stable-18_06_08).
- ipv4: remove warning in ip_recv_error
  (networking-stable-18_06_08).
- vhost: synchronize IOTLB message with dev cleanup
  (networking-stable-18_06_08).
- net/mlx5e: When RXFCS is set, add FCS data into checksum
  calculation (networking-stable-18_06_08).
- net/mlx4: Fix irq-unsafe spinlock usage
  (networking-stable-18_06_08).
- net: phy: broadcom: Fix bcm_write_exp()
  (networking-stable-18_06_08).
- net: phy: broadcom: Fix auxiliary control register reads
  (networking-stable-18_06_08).
- net: ipv4: add missing RTA_TABLE to rtm_ipv4_policy
  (networking-stable-18_06_08).
- virtio-net: fix leaking page for gso packet during mergeable
  XDP (networking-stable-18_06_08).
- virtio-net: correctly transmit XDP buff after linearizing
  (networking-stable-18_06_08).
- qed: Fix mask for physical address in ILT entry
  (networking-stable-18_06_08).
- ipmr: properly check rhltable_init() return value
  (networking-stable-18_06_08).
- dccp: don't free ccid2_hc_tx_sock struct in dccp_disconnect()
  (networking-stable-18_06_08).
- net: ethernet: ti: cpdma: correct error handling for chan create
  (networking-stable-18_06_08).
- commit 659a5fd
* Tue Jul 17 2018 tbogendoerfer@suse.de
- RDMA/bnxt_re: Fix broken RoCE driver due to recent L2 driver
  changes (bsc#1086283 FATE#324874).
- RDMA/bnxt_re: Remove redundant bnxt_qplib_disable_nq() call
  (bsc#1086283 FATE#324874).
- commit 6b2af6f
* Tue Jul 17 2018 tbogendoerfer@suse.de
- bnxt_en: Always forward VF MAC address to the PF (bsc#1086282
  FATE#324873).
- bnxt_en: Read phy eeprom A2h address only when optical
  diagnostics is supported (bsc#1086282 FATE#324873).
- bnxt_en: Check unsupported speeds in bnxt_update_link() on PF
  only (bsc#1086282 FATE#324873).
- bnxt_en: Fix firmware message delay loop regression (bsc#1086282
  FATE#324873).
- bnxt_en: Reserve rings at driver open if none was reserved at
  probe time (bsc#1086282 FATE#324873).
- bnxt_en: Reserve RSS and L2 contexts for VF (bsc#1086282
  FATE#324873).
- bnxt_en: Don't reserve rings on VF when min rings were not
  provisioned by PF (bsc#1086282 FATE#324873).
- bnxt_en: Reserve rings in bnxt_set_channels() if device is down
  (bsc#1086282 FATE#324873).
- bnxt_en: reduce timeout on initial HWRM calls (bsc#1086282
  FATE#324873).
- bnxt_en: Increase RING_IDLE minimum threshold to 50 (bsc#1086282
  FATE#324873).
- bnxt_en: Do not allow VF to read EEPROM (bsc#1086282
  FATE#324873).
- bnxt_en: Display function level rx/tx_discard_pkts via ethtool
  (bsc#1086282 FATE#324873).
- bnxt_en: Simplify ring alloc/free error messages (bsc#1086282
  FATE#324873).
- bnxt_en: Do not set firmware time from VF driver on older
  firmware (bsc#1086282 FATE#324873).
- bnxt_en: Check the lengths of encapsulated firmware responses
  (bsc#1086282 FATE#324873).
- bnxt_en: Remap TC to hardware queues when configuring PFC
  (bsc#1086282 FATE#324873).
- bnxt_en: Add TC to hardware QoS queue mapping logic (bsc#1086282
  FATE#324873).
- bpf: make bnxt compatible w/ bpf_xdp_adjust_tail (bsc#1086282
  FATE#324873).
- bnxt_en: Fix NULL pointer dereference at bnxt_free_irq()
  (bsc#1086282 FATE#324873).
- bnxt_en: Need to include RDMA rings in bnxt_check_rings()
  (bsc#1086282 FATE#324873).
- bnxt_en: Support max-mtu with VF-reps (bsc#1086282 FATE#324873).
- bnxt_en: Fix ethtool -x crash when device is down (bsc#1086282
  FATE#324873).
- bnxt_en: Add ULP calls to stop and restart IRQs (bsc#1086282
  FATE#324873).
- bnxt_en: Reserve completion rings and MSIX for bnxt_re RDMA
  driver (bsc#1086282 FATE#324873).
- bnxt_en: Refactor bnxt_need_reserve_rings() (bsc#1086282
  FATE#324873).
- bnxt_en: Add IRQ remapping logic (bsc#1086282 FATE#324873).
- bnxt_en: Change IRQ assignment for RDMA driver (bsc#1086282
  FATE#324873).
- bnxt_en: Improve ring allocation logic (bsc#1086282
  FATE#324873).
- bnxt_en: Improve valid bit checking in firmware response message
  (bsc#1086282 FATE#324873).
- bnxt_en: Improve resource accounting for SRIOV (bsc#1086282
  FATE#324873).
- bnxt_en: Check max_tx_scheduler_inputs value from firmware
  (bsc#1086282 FATE#324873).
- bnxt_en: Add extended port statistics support (bsc#1086282
  FATE#324873).
- bnxt_en: Include additional hardware port statistics in ethtool
  - S (bsc#1086282 FATE#324873).
- bnxt_en: Add support for ndo_set_vf_trust (bsc#1086282
  FATE#324873).
- bnxt_en: Use a dedicated VNIC mode for RDMA (bsc#1086282
  FATE#324873).
- bnxt_en: Adjust default rings for multi-port NICs (bsc#1086282
  FATE#324873).
- bnxt_en: Update firmware interface to 1.9.1.15 (bsc#1086282
  FATE#324873).
- bnxt_en: Eliminate duplicate barriers on weakly-ordered archs
  (bsc#1086282 FATE#324873).
- bnxt_en: close & open NIC, only when the interface is in
  running state (bsc#1086282 FATE#324873).
- bnxt_en: Fix regressions when setting up MQPRIO TX rings
  (bsc#1086282 FATE#324873).
- bnxt_en: Pass complete VLAN TCI to the stack (bsc#1086282
  FATE#324873).
- bnxt_en: Fix vnic accounting in the bnxt_check_rings() path
  (bsc#1086282 FATE#324873).
- bnxt_en: Refactor the functions to reserve hardware rings
  (bsc#1086282 FATE#324873).
- bnxt_en: export a common switchdev PARENT_ID for all reps of
  an adapter (bsc#1086282 FATE#324873).
- bnxt_en: Add cache line size setting to optimize performance
  (bsc#1086282 FATE#324873).
- bnxt_en: Forward VF MAC address to the PF (bsc#1086282
  FATE#324873).
- bnxt_en: Add BCM5745X NPAR device IDs (bsc#1086282 FATE#324873).
- bnxt_en: Expand bnxt_check_rings() to check all resources
  (bsc#1086282 FATE#324873).
- bnxt_en: Implement new method for the PF to assign SRIOV
  resources (bsc#1086282 FATE#324873).
- bnxt_en: Reserve resources for RFS (bsc#1086282 FATE#324873).
- bnxt_en: Implement new method to reserve rings (bsc#1086282
  FATE#324873).
- bnxt_en: Set initial default RX and TX ring numbers the same
  in combined mode (bsc#1086282 FATE#324873).
- bnxt_en: Add the new firmware API to query hardware resources
  (bsc#1086282 FATE#324873).
- bnxt_en: Refactor hardware resource data structures (bsc#1086282
  FATE#324873).
- bnxt_en: Restore MSIX after disabling SRIOV (bsc#1086282
  FATE#324873).
- bnxt_en: Refactor bnxt_close_nic() (bsc#1086282 FATE#324873).
- bnxt_en: Update firmware interface to 1.9.0 (bsc#1086282
  FATE#324873).
- ethernet/broadcom: Use zeroing memory allocator than
  allocator/memset (bsc#1086282 FATE#324873).
- commit 4f4d8d1
* Tue Jul 17 2018 nborisov@suse.com
- kmod: fix wait on recursive loop (bsc#1099792).
- wait: add wait_event_killable_timeout() (bsc#1099792).
- kmod: throttle kmod thread limit (bsc#1099792).
- kmod: reduce atomic operations on kmod_concurrent and simplify
  (bsc#1099792).
- commit d8a7e2c
* Mon Jul 16 2018 rgoldwyn@suse.com
- restore cond_resched() in shrink_dcache_parent() (bsc#1098599).
- Refresh patches.fixes/dcache-add-cond_resched-in-shrink_dentry_list.patch.
- commit 460aaf6
* Mon Jul 16 2018 tzimmermann@suse.de
- drm: Use kvzalloc for allocating blob property memory (bsc#1101352).
- commit f1b9fcd
* Mon Jul 16 2018 tiwai@suse.de
- HID: add backlight level quirk for Asus ROG laptops
  (bsc#1101324).
- commit bbee3e0
* Mon Jul 16 2018 tzimmermann@suse.de
- drm/udl: fix display corruption of the last line (bsc#1101337).
- commit dd004cb
* Mon Jul 16 2018 tiwai@suse.de
- nl80211: relax ht operation checks for mesh (bsc#1051510).
- commit 7bed2e0
* Mon Jul 16 2018 tiwai@suse.de
- vmw_balloon: fix inflation with batching (bsc#1051510).
- commit 6791362
* Mon Jul 16 2018 jthumshirn@suse.de
- blacklist.conf: blacklist 68c59fcea1f2 ("scsi: sg: fix SG_DXFER_FROM_DEV transfers")
- commit 3748a31
* Mon Jul 16 2018 jthumshirn@suse.de
- dax: check for QUEUE_FLAG_DAX in bdev_dax_supported()
  (bsc#1101315).
- commit a8f6b16
* Mon Jul 16 2018 msuchanek@suse.de
- Pass x86 as architecture on x86_64 and i386 (bsc#1093118).
- commit 5f24fb0
* Mon Jul 16 2018 tiwai@suse.de
- Fix the build of da9063_wdt module (bsc#1100843)
  Backport the missing prerequisite commit, move the previous fixes into
  the sorted section and refresh.
- commit b022133
* Mon Jul 16 2018 jthumshirn@suse.de
- scsi: sg: mitigate read/write abuse (bsc#1101296).
- commit fb00485
* Mon Jul 16 2018 jthumshirn@suse.de
- vfio: Use get_user_pages_longterm correctly (bsc#1095337).
- commit 8e5df06
* Fri Jul 13 2018 jkosina@suse.cz
- Documentation: Add section about CPU vulnerabilities
  (bsc#1089343 CVE-2018-3646).
- x86/bugs, kvm: Introduce boot-time control of L1TF mitigations
  (bsc#1089343 CVE-2018-3646).
- cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (bsc#1089343
  CVE-2018-3646).
- cpu/hotplug: Expose SMT control init function (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Allow runtime control of L1D flush (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Serialize L1D flush parameter setter (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Add static key for flush always (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Move l1tf setup function (bsc#1089343 CVE-2018-3646).
- x86/l1tf: Handle EPT disabled state proper (bsc#1089343
  CVE-2018-3646).
- x86/kvm: Drop L1TF MSR list approach (bsc#1089343
  CVE-2018-3646).
- x86/litf: Introduce vmx status variable (bsc#1089343
  CVE-2018-3646).
- commit 002bf03
* Fri Jul 13 2018 tiwai@suse.de
- HID: wacom: Add support for One by Wacom (CTL-472 / CTL-672)
  (bsc#1100633).
- commit e78ab26
* Fri Jul 13 2018 tiwai@suse.de
- Correct bug reference in the patch (bnc#1095155)
  Refreshed patches.suse/mremap-Remove-LATENCY_LIMIT-from-mremap-to-reduce-the-number-of-TLB-shootdowns.patch
- commit f9d8d21
* Thu Jul 12 2018 hare@suse.de
- nvme-rdma: don't override opts->queue_size (bsc#1099041).
- nvme-rdma: Fix command completion race at error recovery
  (bsc#1099041).
- nvme-rdma: fix possible double free condition when failing to
  create a controller (bsc#1099041).
- nvme-rdma: fix error flow during mapping request data
  (bsc#1099041).
- nvme-rdma: correctly check for target keyed sgl support
  (bsc#1099041).
- commit 9801f97
* Thu Jul 12 2018 hare@suse.de
- nvme: move init of keep_alive work item to controller
  initialization (bsc#1098706).
- commit 2640b14
* Thu Jul 12 2018 hare@suse.de
- scripts/git_sort/git_sort.py: Update nvme git repository
- commit c956504
* Thu Jul 12 2018 hare@suse.de
- nvme-fc: release io queues to allow fast fail (bsc#1098706).
- commit b66476d
* Wed Jul 11 2018 ggherdovich@suse.cz
- cpuidle: powernv: Fix promotion from snooze if next state
  disabled (bsc#1100884).
- commit e7f4bcc
* Wed Jul 11 2018 ggherdovich@suse.cz
- cpufreq: governors: Fix long idle detection logic in load
  calculation (bsc#1100884).
- commit 2312a75
* Wed Jul 11 2018 ggherdovich@suse.cz
- cpufreq: Fix new policy initialization during limits updates
  via sysfs (bsc#1100884).
- commit eafbeaa
* Wed Jul 11 2018 ggherdovich@suse.cz
- cpufreq: powernv: Fix hardlockup due to synchronous smp_call
  in timer interrupt (bsc#1100884).
- commit 2f2e403
* Wed Jul 11 2018 ggherdovich@suse.cz
- cpufreq: CPPC: Initialize shared perf capabilities of CPUs
  (bsc#1100884).
- commit 1731fd4
* Wed Jul 11 2018 ggherdovich@suse.cz
- cpufreq: cppc_cpufreq: Fix cppc_cpufreq_init() failure path
  (bsc#1100884).
- commit ea23b9f
* Wed Jul 11 2018 ydfan@suse.com
- watchdog: da9063: Fix timeout handling during probe
  (bsc#1100843).
- watchdog: da9063: Fix updating timeout value (bsc#1100843).
- watchdog: da9063: Fix setting/changing timeout (bsc#1100843).
- commit 5377bd8
* Wed Jul 11 2018 tiwai@suse.de
- HID: hiddev: fix potential Spectre v1 (bsc#1051510).
- HID: i2c-hid: Fix "incomplete report" noise (bsc#1051510).
- HID: wacom: Correct touch maximum XY of 2nd-gen Intuos
  (bsc#1051510).
- HID: debug: check length before copy_to_user() (bsc#1051510).
- commit cdce397
* Tue Jul 10 2018 msuchanek@suse.de
- powerpc: Machine check interrupt is a non-maskable interrupt
  (bsc#1094244).
- powerpc/64s: Fix mce accounting for powernv (bsc#1094244).
- commit b198316
* Tue Jul 10 2018 tiwai@suse.de
- hwtracing: stm: fix build error on some arches (bsc#1051510).
- commit 7ee2bee
* Tue Jul 10 2018 tiwai@suse.de
- hwmon: (nct6775) Fix writing pwmX_mode (bsc#1051510).
- hwmon: (pmbus/adm1275) Accept negative page register values
  (bsc#1051510).
- hwmon: (pmbus/max8688) Accept negative page register values
  (bsc#1051510).
- hwmon: (jc42) optionally try to disable the SMBUS timeout
  (bsc#1051510).
- commit fd457f0
* Tue Jul 10 2018 tiwai@suse.de
- libata: Drop SanDisk SD7UB3Q*G1001 NOLPM quirk (bsc#1051510).
- libata: zpodd: small read overflow in eject_tray()
  (bsc#1051510).
- libata: blacklist Micron 500IT SSD with MU01 firmware
  (bsc#1051510).
- libata: Blacklist some Sandisk SSDs for NCQ (bsc#1051510).
- libata: Apply NOLPM quirk for SanDisk SD7UB3Q*G1001 SSDs
  (bsc#1051510).
- libata: zpodd: make arrays cdb static, reduces object code size
  (bsc#1051510).
- commit f52a8e4
* Tue Jul 10 2018 tiwai@suse.de
- mailbox: mailbox-test: don't rely on rx_buffer content to
  signal data ready (bsc#1051510).
- mailbox: bcm-flexrm-mailbox: Fix FlexRM ring flush sequence
  (bsc#1051510).
- mailbox: bcm-flexrm-mailbox: Fix mask used in
  CMPL_START_ADDR_VALUE() (bsc#1051510).
- commit b53502f
* Tue Jul 10 2018 tiwai@suse.de
- NFC: pn533: don't send USB data off of the stack (bsc#1051510).
- NFC: llcp: Limit size of SDP URI (bsc#1051510).
- commit 5478f9f
* Tue Jul 10 2018 tiwai@suse.de
- pwm: lpss: platform: Save/restore the ctrl register over a
  suspend/resume (bsc#1051510).
- commit ee4bbfb
* Tue Jul 10 2018 tiwai@suse.de
- pwm: rcar: Fix a condition to prevent mismatch value setting
  to duty (bsc#1051510).
- pwm: stmpe: Fix wrong register offset for hwpwm=2 case
  (bsc#1051510).
- commit fa9b53a
* Tue Jul 10 2018 tiwai@suse.de
- stm class: Use vmalloc for the master map (bsc#1051510).
- stm class: Fix a use-after-free (bsc#1051510).
- commit 93b84cc
* Tue Jul 10 2018 tiwai@suse.de
- tty/serial: atmel: use port->name as name in request_irq()
  (bsc#1051510).
- tty: pl011: Avoid spuriously stuck-off interrupts (bsc#1051510).
- tty: n_gsm: Fix DLCI handling for ADM mode if debug & 2 is
  not set (bsc#1051510).
- tty: n_gsm: Fix long delays with control frame timeouts in
  ADM mode (bsc#1051510).
- tty: n_gsm: Allow ADM response in addition to UA for control
  dlci (bsc#1051510).
- commit ed20bf1
* Tue Jul 10 2018 rgoldwyn@suse.com
- rmdir(),rename(): do shrink_dcache_parent() only on success (bsc#1100340).
- commit 9a4b149
* Tue Jul 10 2018 tiwai@suse.de
- Fix kABI breakage with CONFIG_RT_GROUP_SCHED=n (bsc#1100734).
- commit 94a75dc
* Tue Jul 10 2018 tiwai@suse.de
- Update config files: disable CONFIG_RT_GROUP_SCHED again (bsc#1100734)
- commit ea3399f
* Mon Jul  9 2018 tiwai@suse.de
- drm/i915: Fix context ban and hang accounting for client
  (bsc#1051510).
- drm/i915/gvt: fix memory leak of a cmd_entry struct on error
  exit path (bsc#1051510).
- drm/i915/psr: Chase psr.enabled only under the psr.lock
  (bsc#1051510).
- drm/i915: Remove unbannable context spam from reset
  (bsc#1051510).
- commit f8dc375
* Mon Jul  9 2018 tiwai@suse.de
- selinux: KASAN: slab-out-of-bounds in xattr_getsecurity
  (bsc#1051510).
- selinux: skip bounded transition processing if the policy
  isn't loaded (bsc#1051510).
- selinux: ensure the context is NUL terminated in
  security_context_to_sid_core() (bsc#1051510).
- commit 5ec0bfb
* Mon Jul  9 2018 jkosina@suse.cz
- cpu/hotplug: Online siblings when SMT control is turned on
  (bsc#1089343 CVE-2018-3646).
- commit a1d8880
* Mon Jul  9 2018 tiwai@suse.de
- blacklist.conf: Add IMA kconfig stable entry
- commit a8ff557
* Mon Jul  9 2018 tiwai@suse.de
- vt: prevent leaking uninitialized data to userspace via
  /dev/vcs* (bsc#1051510).
- commit ef62f0b
* Mon Jul  9 2018 tiwai@suse.de
- vmw_balloon: fixing double free when batching mode is off
  (bsc#1051510).
- commit 5807b07
* Mon Jul  9 2018 tiwai@suse.de
- virtio_console: reset on out of memory (bsc#1051510).
- virtio_console: move removal code (bsc#1051510).
- virtio_console: drop custom control queue cleanup (bsc#1051510).
- virtio_console: free buffers after reset (bsc#1051510).
- virtio: add ability to iterate over vqs (bsc#1051510).
- virtio_console: don't tie bufs to a vq (bsc#1051510).
- virtio_ring: fix num_free handling in error case (bsc#1051510).
- commit f104319
* Mon Jul  9 2018 tiwai@suse.de
- thermal: bcm2835: Stop using printk format %%pCr (bsc#1051510).
- thermal: exynos: Propagate error value from tmu_read()
  (bsc#1051510).
- thermal: exynos: Reading temperature makes sense only when
  TMU is turned on (bsc#1051510).
- thermal: int3403_thermal: Fix NULL pointer deref on module
  load / probe (bsc#1051510).
- thermal: int3400_thermal: fix error handling in
  int3400_thermal_probe() (bsc#1051510).
- commit f4975a6
* Mon Jul  9 2018 tiwai@suse.de
- tee: check shm references are consistent in offset/size
  (bsc#1051510).
- tee: shm: fix use-after-free via temporarily dropped reference
  (bsc#1051510).
- commit 45e76d0
* Mon Jul  9 2018 tiwai@suse.de
- swap: divide-by-zero when zero length swap file on ssd
  (bsc#1051510).
- commit c0e3326
* Mon Jul  9 2018 tiwai@suse.de
- rtc: snvs: Fix usage of snvs_rtc_enable (bsc#1051510).
- rtc: hctosys: Ensure system time doesn't overflow time_t
  (bsc#1051510).
- rtc: tx4939: avoid unintended sign extension on a 24 bit shift
  (bsc#1051510).
- commit 72b2a6a
* Mon Jul  9 2018 tiwai@suse.de
- pty: cancel pty slave port buf's work in tty_release
  (bsc#1051510).
- commit 0a7a1c8
* Mon Jul  9 2018 tiwai@suse.de
- pinctrl: adi2: Fix Kconfig build problem (bsc#1051510).
- commit 1474c28
* Mon Jul  9 2018 tiwai@suse.de
- n_tty: Access echo_* variables carefully (bsc#1051510).
- n_tty: Fix stall at n_tty_receive_char_special() (bsc#1051510).
- commit 5d3649d
* Mon Jul  9 2018 tiwai@suse.de
- lsm: fix smack_inode_removexattr and xattr_getsecurity memleak
  (bsc#1051510).
- commit 8570266
* Mon Jul  9 2018 tiwai@suse.de
- lib/test_bitmap.c: fix bitmap optimisation tests to report
  errors correctly (bsc#1051510).
- commit f2d1c09
* Mon Jul  9 2018 tiwai@suse.de
- cpufreq: intel_pstate: Fix scaling max/min limits with Turbo
  3.0 (bsc#1051510).
- Refresh
  patches.suse/cpufreq-intel_pstate-use-setpoint-of-10-on-servers.patch.
- commit a4772b7
* Mon Jul  9 2018 sndirsch@suse.de
- video: uvesafb: Fix integer overflow in allocation (bsc#1100418,
  CVE-2018-13406).
- commit 0efb882
* Mon Jul  9 2018 pmladek@suse.com
- printk: fix possible reuse of va_list variable (bsc#1100602).
- commit 794ace8
* Mon Jul  9 2018 tiwai@suse.de
- backlight: tps65217_bl: Fix Device Tree node lookup
  (bsc#1051510).
- backlight: max8925_bl: Fix Device Tree node lookup
  (bsc#1051510).
- backlight: as3711_bl: Fix Device Tree node lookup (bsc#1051510).
- pinctrl/amd: Fix build dependency on pinmux code (bsc#1051510).
- commit 4f3ead9
* Mon Jul  9 2018 tiwai@suse.de
- platform/x86: asus-wmi: Fix NULL pointer dereference
  (bsc#1051510).
- platform/chrome: cros_ec_lpc: remove redundant pointer request
  (bsc#1051510).
- commit 87ccf0d
* Mon Jul  9 2018 tiwai@suse.de
- pipe: fix off-by-one error when checking buffer limits
  (bsc#1051510).
- commit 32c6460
* Mon Jul  9 2018 tiwai@suse.de
- pinctrl: sh-pfc: r8a7796: Fix MOD_SEL register pin assignment
  for SSI pins group (bsc#1051510).
- pinctrl: artpec6: dt: add missing pin group uart5nocts
  (bsc#1051510).
- pinctrl: sx150x: Add a static gpio/pinctrl pin range mapping
  (bsc#1051510).
- pinctrl: sx150x: Register pinctrl before adding the gpiochip
  (bsc#1051510).
- pinctrl: sx150x: Unregister the pinctrl on release
  (bsc#1051510).
- pinctrl: sh-pfc: r8a7795-es1: Fix MOD_SEL1 bit[25:24] to 0x3
  when using STP_ISEN_1_D (bsc#1051510).
- pinctrl: rockchip: enable clock when reading pin direction
  register (bsc#1051510).
- pinctrl: pxa: pxa2xx: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bsc#1051510).
- pinctrl: sunxi: Fix A64 UART mux value (bsc#1051510).
- pinctrl: sunxi: Fix A80 interrupt pin bank (bsc#1051510).
- pinctrl: armada-37xx: Fix direction_output() callback behavior
  (bsc#1051510).
- pinctrl/amd: save pin registers over suspend/resume
  (bsc#1051510).
- pinctrl: samsung: Fix invalid register offset used for
  Exynos5433 external interrupts (bsc#1051510).
- pinctrl: samsung: Fix NULL pointer exception on external
  interrupts on S3C24xx (bsc#1051510).
- commit 49874e4
* Mon Jul  9 2018 tiwai@suse.de
- Refresh patches.kabi/iio-kabi-fix-for-iio_buffer.patch.
- commit 9df6e15
* Mon Jul  9 2018 tiwai@suse.de
- iio: buffer: fix the function signature to match implementation
  (bsc#1051510).
- commit 5729024
* Mon Jul  9 2018 tiwai@suse.de
- sunrpc: remove incorrect HMAC request initialization
  (bsc#1051510).
- commit 1fa4951
* Mon Jul  9 2018 tiwai@suse.de
- serdev: fix memleak on module unload (bsc#1051510).
- commit e508309
* Mon Jul  9 2018 tiwai@suse.de
- PCI: aardvark: Fix PCIe Max Read Request Size setting
  (bsc#1051510).
- PCI: aardvark: Use ISR1 instead of ISR0 interrupt in legacy
  irq mode (bsc#1051510).
- PCI: aardvark: Set PIO_ADDR_LS correctly in advk_pcie_rd_conf()
  (bsc#1051510).
- PCI: aardvark: Fix logic in advk_pcie_{rd,wr}_conf()
  (bsc#1051510).
- p54: don't unregister leds when they are not initialized
  (bsc#1051510).
- commit 4572716
* Mon Jul  9 2018 tiwai@suse.de
- mmc: dw_mmc: exynos: fix the suspend/resume issue for exynos5433
  (bsc#1051510).
- commit 4780889
* Mon Jul  9 2018 tiwai@suse.de
- Fix kABI breakage of iio_buffer (bsc#1051510).
- iio:buffer: make length types match kfifo types (bsc#1051510).
- commit 9adbd1a
* Mon Jul  9 2018 tiwai@suse.de
- drm/atmel-hlcdc: check stride values in the first plane
  (bsc#1051510).
- drm/i915: Enable provoking vertex fix on Gen9 systems
  (bsc#1051510).
- drm/amdgpu: Use kvmalloc_array for allocating VRAM manager
  nodes array (bsc#1051510).
- drm/amdgpu: Add APU support in vi_set_vce_clocks (bsc#1051510).
- drm/amdgpu: Add APU support in vi_set_uvd_clocks (bsc#1051510).
- commit ded63ff
* Mon Jul  9 2018 tiwai@suse.de
- alarmtimer: Prevent overflow for relative nanosleep
  (CVE-2018-13053 bsc#1099924).
- commit d4f1d04
* Mon Jul  9 2018 colyli@suse.de
- Revert "scsi: core: return BLK_STS_OK for DID_OK in
  __scsi_error_from_host_byte()" (bsc#1099918).
- blk-mq: make sure that correct hctx->next_cpu is set
  (bsc#1099918).
- macvlan: fix memory hole in macvlan_dev (bsc#1099918).
- blk-mq: make sure hctx->next_cpu is set correctly (bsc#1099918).
- commit 9f84d4b
* Mon Jul  9 2018 tiwai@suse.de
- ARM: amba: Don't read past the end of sysfs "driver_override"
  buffer (CVE-2018-9385,bsc#1100491).
- commit 96313ba
* Fri Jul  6 2018 jkosina@suse.cz
- README.BRANCH: add Takashi as co-maintainer
- commit a08c187
* Fri Jul  6 2018 rgoldwyn@suse.com
- Fix up non-directory creation in SGID directories (CVE-2018-13405, bsc#1100416).
- commit ca27a26
* Fri Jul  6 2018 jkosina@suse.cz
- Update
  patches.arch/02-x86-KVM-VMX-Add-module-argument-for-L1TF-mitigation.patch
  (bsc#1089343 CVE-2018-3646): fix patch metadata
- commit fb616a7
* Fri Jul  6 2018 jkosina@suse.cz
- x86/cpufeatures: Add detection of L1D cache flush support
  (bsc#1089343 CVE-2018-3646).
- commit bd2b58e
* Fri Jul  6 2018 tbogendoerfer@suse.de
- IB/ipoib: Fix for notify send CQ failure messages (bsc#1096793
  FATE#325050).
- IB/ipoib: Change number of TX wqe to 64 (bsc#1096793
  FATE#325050).
- IB/ipoib: Use NAPI in UD/TX flows (bsc#1096793 FATE#325050).
- IB/ipoib: Get rid of the tx_outstanding variable in all modes
  (bsc#1096793 FATE#325050).
- commit 3ef2fb9
* Fri Jul  6 2018 jkosina@suse.cz
- x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required
  (bsc#1089343 CVE-2018-3646).
- kabi/severities: ignore x86_kvm_ops; lttng-modules would have to
  be adjusted in case they depend on this particular change
- x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER
  only MSRs (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number
  accounting (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Add find_msr() helper function (bsc#1089343
  CVE-2018-3646).
- x86/KVM/VMX: Split the VMX MSR LOAD structures to have an
  host/guest numbers (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Add L1D flush logic (bsc#1089343 CVE-2018-3646).
- x86/KVM/VMX: Add L1D MSR based flush (bsc#1089343
  CVE-2018-3646).
- x86/KVM/VMX: Add L1D flush algorithm (bsc#1089343
  CVE-2018-3646).
- x86/KVM/VMX: Add module argument for L1TF mitigation.
- x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being
  present (bsc#1089343 CVE-2018-3646).
- commit 0c0fd37
* Fri Jul  6 2018 jkosina@suse.cz
- Reorder patch stack to have L1TF bare metal preceed further mitigations
- commit f74742c
* Fri Jul  6 2018 jkosina@suse.cz
- cpu/hotplug: Boot HT siblings at least once (bsc#1089343
  CVE-2018-3646).
- commit dbb874a
* Fri Jul  6 2018 tbogendoerfer@suse.de
- bnx2x: use the right constant (bsc#1086323 FATE#324899).
- bnx2x: Collect the device debug information during Tx timeout
  (bsc#1086323 FATE#324899).
- bnx2x: Replace doorbell barrier() with wmb() (bsc#1086323
  FATE#324899).
- bnx2x: fix spelling mistake: "registeration" -> "registration"
  (bsc#1086323 FATE#324899).
- bnx2x: Deprecate pci_get_bus_and_slot() (bsc#1086323
  FATE#324899).
- bnx2x: Use NETIF_F_GRO_HW (bsc#1086323 FATE#324899).
- bnx2x: fix slowpath null crash (bsc#1086323 FATE#324899).
- bnx2x: Use pci_ari_enabled() instead of local copy (bsc#1086323
  FATE#324899).
- drivers: net: bnx2x: use setup_timer() helper (bsc#1086323
  FATE#324899).
- commit 8804b46
* Fri Jul  6 2018 tbogendoerfer@suse.de
- IB/hfi1: Show fault stats in both TX and RX directions
  (bsc#1096793 FATE#325050).
- commit 9714ec8
* Fri Jul  6 2018 tzimmermann@suse.de
- virtio-gpu: fix ioctl and expose the fixed status to userspace (bsc#1100382).
- commit eeb6b0b
* Fri Jul  6 2018 tbogendoerfer@suse.de
- IB/hfi1: Ensure VL index is within bounds (bsc#1096793
  FATE#325050).
- IB/{rdmavt,hfi1}: Change hrtimer add to use pinned version
  (bsc#1096793 FATE#325050).
- IB/hfi1: Set port number for errorinfo MAD response (bsc#1096793
  FATE#325050).
- IB/hfi1: Create common functions for affinity CPU mask
  operations (bsc#1096793 FATE#325050).
- IB/hfi1: Optimize kthread pointer locking when queuing CQ
  entries (bsc#1096793 FATE#325050).
- IB/Hfi1: Read CCE Revision register to verify the device is
  responsive (bsc#1096793 FATE#325050).
- IB/{hfi1, qib}: Add handling of kernel restart (bsc#1096793
  FATE#325050).
- IB/hfi1: Reorder incorrect send context disable (bsc#1096793
  FATE#325050).
- IB/hfi1: Return correct value for device state (bsc#1096793
  FATE#325050).
- IB/hfi1: Complete check for locally terminated smp (bsc#1096793
  FATE#325050).
- IB/hfi1: Prevent LNI hang when LCB can't obtain lanes
  (bsc#1096793 FATE#325050).
- IB/hfi1: Use after free race condition in send context error
  path (bsc#1096793 FATE#325050).
- IB/hfi1: Fix memory leak in exception path in get_irq_affinity()
  (bsc#1096793 FATE#325050).
- IB/{hfi1, rdmavt}: Fix memory leak in hfi1_alloc_devdata()
  upon failure (bsc#1096793 FATE#325050).
- IB/hfi1: Fix loss of BECN with AHG (bsc#1096793 FATE#325050).
- IB/hfi1 Use correct type for num_user_context (bsc#1096793
  FATE#325050).
- IB/hfi1: Convert PortXmitWait/PortVLXmitWait counters to flit
  times (bsc#1096793 FATE#325050).
- IB/hfi1: Do not override given pcie_pset value (bsc#1096793
  FATE#325050).
- IB/hfi1: Look up ibport using a pointer in receive path
  (bsc#1096793 FATE#325050).
- IB/hfi1: Optimize packet type comparison using 9B and bypass
  code paths (bsc#1096793 FATE#325050).
- IB/hfi1: Compute BTH only for RDMA_WRITE_LAST/SEND_LAST packet
  (bsc#1096793 FATE#325050).
- IB/hfi1: Fix for early release of sdma context (bsc#1096793
  FATE#325050).
- IB/rdmavt: Add trace for RNRNAK timer (bsc#1096793 FATE#325050).
- IB/rdmavt: Use correct numa node for SRQ allocation (bsc#1096793
  FATE#325050).
- IB/rdmavt: No need to cancel RNRNAK retry timer when it is
  running (bsc#1096793 FATE#325050).
- IB/hfi1: Handle initial value of 0 for CCTI setting (bsc#1096793
  FATE#325050).
- IB/hfi1: Send 'reboot' as planned down remote reason
  (bsc#1096793 FATE#325050).
- IB/hfi1: Prohibit invalid Init to Armed state transition
  (bsc#1096793 FATE#325050).
- IB/hfi1: Do not allocate PIO send contexts for VNIC (bsc#1096793
  FATE#325050).
- IB/hfi1: Fix a wrapping test to insure the correct timeout
  (bsc#1096793 FATE#325050).
- IB/hfi1: Don't modify num_user_contexts module parameter
  (bsc#1096793 FATE#325050).
- IB/hfi1: Insure int mask for in-kernel receive contexts is clear
  (bsc#1096793 FATE#325050).
- IB/hfi1: Add tx_opcode_stats like the opcode_stats (bsc#1096793
  FATE#325050).
- IB/hfi1: Validate PKEY for incoming GSI MAD packets (bsc#1096793
  FATE#325050).
- commit a7b94f5
* Fri Jul  6 2018 tbogendoerfer@suse.de
- IB/hfi1: Race condition between user notification and driver
  state (bsc#1096793 FATE#325050).
- Refresh
  patches.drivers/IB-hfi1-Allow-MgmtAllowed-on-B2B-setups.patch.
- commit 8ad721b
* Fri Jul  6 2018 tbogendoerfer@suse.de
- IB/hfi1: Fix serdes loopback set-up (bsc#1096793 FATE#325050).
- IB/hfi1: Refactor get_user() IOCTLs (bsc#1096793 FATE#325050).
- IB/hfi1: Refactor hfi_user_exp_rcv_invalid() IOCTLs (bsc#1096793
  FATE#325050).
- IB/hfi1: Refactor hfi_user_exp_rcv_clear() IOCTLs (bsc#1096793
  FATE#325050).
- IB/hfi1: Refactor hfi_user_exp_rcv_setup() IOCTL (bsc#1096793
  FATE#325050).
- IB/hfi1: Refactor get_base_info (bsc#1096793 FATE#325050).
- IB/hfi1: Refactor get_ctxt_info (bsc#1096793 FATE#325050).
- IB/hfi1: Refactor assign_ctxt() IOCTL (bsc#1096793 FATE#325050).
- IB/hfi1: Add a safe wrapper for _rcd_get_by_index (bsc#1096793
  FATE#325050).
- IB/hfi1: Remove unused hfi1_cpulist variables (bsc#1096793
  FATE#325050).
- IB/hfi1: Inline common calculation (bsc#1096793 FATE#325050).
- IB/hfi1: Update HFI to use the latest PCI API (bsc#1096793
  FATE#325050).
- commit c714f7b
* Fri Jul  6 2018 tzimmermann@suse.de
- vfb: fix video mode and line_length being set when loaded (bsc#1100362).
- commit 4b5f7c9
* Fri Jul  6 2018 tzimmermann@suse.de
- drm/msm: don't deref error pointer in the msm_fbdev_create error path (bsc#1100209).
- commit 96e00a5
* Fri Jul  6 2018 tiwai@suse.de
- drm/i915: Try GGTT mmapping whole object as partial
  (bsc#1051510).
- commit fcad981
* Thu Jul  5 2018 tbogendoerfer@suse.de
- net: qlge: use memmove instead of skb_copy_to_linear_data
  (bsc#1050529 FATE#322902 bsc#1086319 FATE#324895).
- commit 911a2e8
* Thu Jul  5 2018 jthumshirn@suse.de
- nvme-multipath: fix sysfs dangerously created links
  (bsc#1096529).
- Refresh
  patches.drivers/Revert-nvme-create-slaves-and-holders-entries-for-hi.patch.
- Refresh
  patches.drivers/nvme-multipath-Fix-multipath-disabled-naming-collisi.patch.
- commit db0cfa2
* Thu Jul  5 2018 colyli@suse.de
- drbd: Fix drbd_request_prepare() discard handling (bsc#1099918).
- block: Fix cloning of requests with a special payload
  (bsc#1099918).
- dm raid: don't use 'const' in function return (bsc#1099918).
- dm zoned: avoid triggering reclaim from inside dmz_map()
  (bsc#1099918).
- dm: use bio_split() when splitting out the already processed
  bio (bsc#1099918).
- block: sed-opal: Fix a couple off by one bugs (bsc#1099918).
- blk-mq: reinit q->tag_set_list entry only after grace period
  (bsc#1099918).
- arch/*: Kconfig: fix documentation for NMI watchdog
  (bsc#1099918).
- lib/string_helpers: Add missed declaration of struct task_struct
  (bsc#1099918).
- vfio: platform: Fix reset module leak in error path
  (bsc#1099918).
- mtd: cmdlinepart: Update comment for introduction of
  OFFSET_CONTINUOUS (bsc#1099918).
- media: smiapp: fix timeout checking in smiapp_read_nvm
  (bsc#1099918).
- powerpc/ptrace: Fix enforcement of DAWR constraints
  (bsc#1099918).
- nbd: fix nbd device deletion (bsc#1099918).
- tracing: Make the snapshot trigger work with instances
  (bsc#1099918).
- dm integrity: use kvfree for kvmalloc'd memory (bsc#1099918).
- earlycon: Use a pointer table to fix __earlycon_table stride
  (bsc#1099918).
- tracing: Fix missing tab for hwlat_detector print format
  (bsc#1099918).
- scsi: target: fix crash with iscsi target and dvd (bsc#1099918).
- block/swim: Remove extra put_disk() call from error path
  (bsc#1099918).
- tracing/uprobe_event: Fix strncpy corner case (bsc#1099918).
- blk-mq: don't keep offline CPUs mapped to hctx 0 (bsc#1099918).
- mtd: jedec_probe: Fix crash in jedec_read_mfr() (bsc#1099918).
- tracing: probeevent: Fix to support minus offset from symbol
  (bsc#1099918).
- mtd: nand: fsl_ifc: Fix eccstat array overflow for IFC ver >=
  2.0.0 (bsc#1099918).
- scsi: core: return BLK_STS_OK for DID_OK in
  __scsi_error_from_host_byte() (bsc#1099918).
- nbd: fix return value in error handling path (bsc#1099918).
- userns: Don't fail follow_automount based on s_user_ns
  (bsc#1099918).
- nubus: Fix up header split (bsc#1099918).
- nubus: Avoid array underflow and overflow (bsc#1099918).
- block: Fix __bio_integrity_endio() documentation (bsc#1099918).
- blk-mq: simplify queue mapping & schedule with each possisble
  CPU (bsc#1099918).
- block, bfq: fix occurrences of request finish method's old name
  (bsc#1099918).
- pktcdvd: Fix a recently introduced NULL pointer dereference
  (bsc#1099918).
- pktcdvd: Fix pkt_setup_dev() error path (bsc#1099918).
- tracing: Fix converting enum's from the map in
  trace_event_eval_update() (bsc#1099918).
- commit dd2c7b5
* Thu Jul  5 2018 colyli@suse.de
- dm mpath: fix bio-based multipath queue_if_no_path handling
  (bsc#1099918).
- Refresh patches.suse/dm-mpath-accept-failed-paths for above change.
- commit 1713506
* Thu Jul  5 2018 colyli@suse.de
- timekeeping: Eliminate the stale declaration of
  ktime_get_raw_and_real_ts64() (bsc#1099918).
- block, bfq: add missing invocations of
  bfqg_stats_update_io_add/remove (bsc#1099918).
- ide: Make ide_cdrom_prep_fs() initialize the sense buffer
  pointer (bsc#1099918).
- driver core: Move device_links_purge() after bus_remove_device()
  (bsc#1099918).
- macvlan: remove unused fields in struct macvlan_dev
  (bsc#1099918).
- tracing: Kconfig text fixes for CONFIG_HWLAT_TRACER
  (bsc#1099918).
- ide: ide-atapi: fix compile error with defining macro DEBUG
  (bsc#1099918).
- nbd: don't start req until after the dead connection logic
  (bsc#1099918).
- nbd: wait uninterruptible for the dead timeout (bsc#1099918).
- block: cope with WRITE ZEROES failing in blkdev_issue_zeroout()
  (bsc#1099918).
- block: factor out __blkdev_issue_zero_pages() (bsc#1099918).
- ide:ide-cd: fix kernel panic resulting from missing
  scsi_req_init (bsc#1099918).
- blk-mq-debugfs: fix device sched directory for default scheduler
  (bsc#1099918).
- nbd: fix -ERESTARTSYS handling (bsc#1099918).
- mm, oom_reaper: skip mm structs with mmu notifiers
  (bsc#1099918).
- Btrfs: use btrfs_op instead of bio_op in __btrfs_map_block
  (bsc#1099918).
- f2fs: fix to wake up all sleeping flusher (bsc#1099918).
- ftrace: Fix selftest goto location on error (bsc#1099918).
- mq-deadline: Enable auto-loading when built as module
  (bsc#1099918).
- bfq: Re-enable auto-loading when built as a module
  (bsc#1099918).
- dm: fix printk() rate limiting code (bsc#1099918).
- mtd: partitions: remove sysfs files when deleting all master's
  partitions (bsc#1099918).
- mtd: partitions: add helper for deleting partition
  (bsc#1099918).
- dm: convert DM printk macros to pr_<level> macros (bsc#1099918).
- commit 2c24b02
* Wed Jul  4 2018 jslaby@suse.cz
- net sched actions: fix refcnt leak in skbmod
  (networking-stable-18_05_15).
- net: sched: fix error path in tcf_proto_create() when modules
  are not configured (networking-stable-18_05_15).
- net/mlx5e: Err if asked to offload TC match on frag being first
  (networking-stable-18_05_15).
- net/mlx5: E-Switch, Include VF RDMA stats in vport statistics
  (networking-stable-18_05_15).
- ipv4: fix memory leaks in udp_sendmsg, ping_v4_sendmsg
  (networking-stable-18_05_15).
- bonding: send learning packets for vlans on slave
  (networking-stable-18_05_15).
- bonding: do not allow rlb updates to invalid mac
  (networking-stable-18_05_15).
- sctp: remove sctp_chunk_put from fail_mark err path in
  sctp_ulpevent_make_rcvmsg (networking-stable-18_05_15).
- net/mlx4_en: Fix an error handling path in
  'mlx4_en_init_netdev()' (networking-stable-18_05_15).
- net/mlx4_en: Verify coalescing parameters are in range
  (networking-stable-18_05_15).
- llc: better deal with too small mtu
  (networking-stable-18_05_15).
- sctp: delay the authentication for the duplicated cookie-echo
  chunk (networking-stable-18_05_15).
- net: ethernet: sun: niu set correct packet size in skb
  (networking-stable-18_05_15).
- net: atm: Fix potential Spectre v1 (networking-stable-18_05_15
  bsc#1068032 CVE-2017-5753).
- atm: zatm: Fix potential Spectre v1
  (networking-stable-18_05_15 bsc#1068032 CVE-2017-5753).
- openvswitch: Don't swap table in nlattr_set() after
  OVS_ATTR_NESTED is found (networking-stable-18_05_15).
- dccp: fix tasklet usage (networking-stable-18_05_15).
- rds: do not leak kernel memory to user land
  (networking-stable-18_05_15).
- ipv4: fix fnhe usage by non-cached routes
  (networking-stable-18_05_15).
- net_sched: fq: take care of throttled flows before reuse
  (networking-stable-18_05_15).
- 8139too: Use disable_irq_nosync() in rtl8139_poll_controller()
  (networking-stable-18_05_15).
- sctp: fix the issue that the cookie-ack with auth can't get
  processed (networking-stable-18_05_15).
- sctp: use the old asoc when making the cookie-ack chunk in
  dupcook_d (networking-stable-18_05_15).
- tcp_bbr: fix to zero idle_restart only upon S/ACKed data
  (networking-stable-18_05_15).
- net: ethernet: ti: cpsw: fix packet leaking in dual_mac mode
  (networking-stable-18_05_15).
- bridge: check iface upper dev when setting master via ioctl
  (networking-stable-18_05_15).
- net: support compat 64-bit time in {s,g}etsockopt
  (networking-stable-18_05_15).
- net/mlx5e: TX, Use correct counter in dma_map error flow
  (networking-stable-18_05_15).
- tcp: ignore Fast Open on repair mode
  (networking-stable-18_05_15).
- commit df113d5
* Wed Jul  4 2018 tbogendoerfer@suse.de
- vmxnet3: use DMA memory barriers where required (bsc#1091860).
- vmxnet3: set the DMA mask before the first DMA map operation
  (bsc#1091860).
- vmxnet3: fix incorrect dereference when rxvlan is disabled
  (bsc#1091860).
- vmxnet3: use correct flag to indicate LRO feature (bsc#1091860).
- vmxnet3: avoid xmit reset due to a race in vmxnet3
  (bsc#1091860).
- vmxnet3: increase default rx ring sizes (bsc#1091860).
- commit 662f8d1
* Wed Jul  4 2018 oneukum@suse.com
- acpi: Add helper for deactivating memory region (bsc#1100132).
- commit 1e0c4c4
* Wed Jul  4 2018 jthumshirn@suse.de
- KABI protect struct nd_region (FATE#324634).
- commit cf06bba
* Wed Jul  4 2018 tiwai@suse.de
- 1wire: family module autoload fails because of upper/lower
  case mismatch (bsc#1051510).
- commit 7c78f2c
* Wed Jul  4 2018 jthumshirn@suse.de
- kabi/severities: add nvdimm internal symbols to kabi ignore list
- commit 4b2c247
* Wed Jul  4 2018 oneukum@suse.com
- usb: typec: ucsi: Fix for incorrect status data issue
  (bsc#1100132).
- commit 10b6319
* Wed Jul  4 2018 oneukum@suse.com
- usb: typec: ucsi: acpi: Workaround for cache mode issue
  (bsc#1100132).
- commit 1dbd373
* Wed Jul  4 2018 jthumshirn@suse.de
- libnvdimm, pmem: Add sysfs notifications to badblocks
  (FATE#324634).
- libnvdimm, region, pmem: fix 'badblocks' sysfs_get_dirent()
  reference lifetime (FATE#324634).
- Refresh
  patches.drivers/x86-libnvdimm-pmem-move-arch_invalidate_pmem-to-libn.patch.
- commit 2582e83
* Wed Jul  4 2018 oneukum@suse.com
- video/fbdev/stifb: Return -ENOMEM after a failed kzalloc()
  in stifb_init_fb() (bsc#1090888 bsc#1099966).
- commit 9bf1f34
* Wed Jul  4 2018 bpoirier@suse.com
- tg3: Fix vunmap() BUG_ON() triggered from tg3_free_consistent()
  (bsc#1086286 FATE#324876).
- tg3: prevent scheduling while atomic splat (bsc#1086286
  FATE#324876).
- tg3: APE heartbeat changes (bsc#1086286 FATE#324876).
- tg3: Add Macronix NVRAM support (bsc#1086286 FATE#324876).
- commit b446739
* Wed Jul  4 2018 jslaby@suse.cz
- sctp: handle two v4 addrs comparison in sctp_inet6_cmp_addr
  (git-fixes).
- commit dfa0d20
* Wed Jul  4 2018 bpoirier@suse.com
- Move build fixes before sorted section
  Otherwise it is very inconvenient to build with a partially applied series
  and gcc-8.
- commit 6125496
* Wed Jul  4 2018 jslaby@suse.cz
- packet: fix bitfield update race (networking-stable-18_04_26).
- team: fix netconsole setup over team
  (networking-stable-18_04_26).
- amd-xgbe: Only use the SFP supported transceiver signals
  (networking-stable-18_04_26).
- amd-xgbe: Improve KR auto-negotiation and training
  (networking-stable-18_04_26).
- amd-xgbe: Add pre/post auto-negotiation phy hooks
  (networking-stable-18_04_26).
- pppoe: check sockaddr length in pppoe_connect()
  (networking-stable-18_04_26).
- l2tp: check sockaddr length in pppol2tp_connect()
  (networking-stable-18_04_26).
- ipv6: add RTA_TABLE and RTA_PREFSRC to rtm_ipv6_policy
  (networking-stable-18_04_26).
- bonding: do not set slave_dev npinfo before slave_enable_netpoll
  in bond_enslave (networking-stable-18_04_26).
- tcp: don't read out-of-bounds opsize
  (networking-stable-18_04_26).
- net: sched: ife: check on metadata length
  (networking-stable-18_04_26).
- net: sched: ife: handle malformed tlv length
  (networking-stable-18_04_26).
- kABI: protect ife_tlv_meta_decode (kabi).
- net: sched: ife: signal not finding metaid
  (networking-stable-18_04_26).
- strparser: Do not call mod_delayed_work with a timeout of
  LONG_MAX (networking-stable-18_04_26).
- llc: fix NULL pointer deref for SOCK_ZAPPED
  (networking-stable-18_04_26).
- net: ethernet: ti: cpsw: fix tx vlan priority mapping
  (networking-stable-18_04_26).
- llc: delete timers synchronously in llc_sk_free()
  (networking-stable-18_04_26).
- virtio_net: fix adding vids on big-endian
  (networking-stable-18_04_26).
- virtio_net: split out ctrl buffer (networking-stable-18_04_26).
- llc: hold llc_sap before release_sock()
  (networking-stable-18_04_26).
- KEYS: DNS: limit the length of option strings
  (networking-stable-18_04_26).
- vlan: Fix reading memory beyond skb->tail in
  skb_vlan_tagged_multi (networking-stable-18_04_26).
- tipc: add policy for TIPC_NLA_NET_ADDR
  (networking-stable-18_04_26).
- net: af_packet: fix race in PACKET_{R|T}X_RING
  (networking-stable-18_04_26).
- team: avoid adding twice the same option to the event list
  (networking-stable-18_04_26).
- net: fix deadlock while clearing neighbor proxy table
  (networking-stable-18_04_26).
- sctp: do not check port in sctp_inet6_cmp_addr
  (networking-stable-18_04_26).
- strparser: Fix incorrect strp->need_bytes value
  (networking-stable-18_04_26).
- net: validate attribute sizes in neigh_dump_table()
  (networking-stable-18_04_26).
- tcp: md5: reject TCP_MD5SIG or TCP_MD5SIG_EXT on established
  sockets (networking-stable-18_04_26).
- commit b2a5626
* Tue Jul  3 2018 tiwai@suse.de
- test_firmware: fix setting old custom fw path back on exit,
  second try (bsc#1051510).
- commit e469a2d
* Tue Jul  3 2018 tiwai@suse.de
- watchdog: f71808e_wdt: Fix magic close handling (bsc#1051510).
- watchdog: sp5100_tco: Fix watchdog disable bit (bsc#1051510).
- commit d1c96bd
* Tue Jul  3 2018 tiwai@suse.de
- tty: Use __GFP_NOFAIL for tty_ldisc_get() (bsc#1051510).
- tty: Don't call panic() at tty_ldisc_init() (bsc#1051510).
- tty: Avoid possible error pointer dereference at
  tty_ldisc_restore() (bsc#1051510).
- commit fbaa1b6
* Tue Jul  3 2018 tiwai@suse.de
- test_firmware: fix missing unlock on error in
  config_num_requests_store() (bsc#1051510).
- test_firmware: fix setting old custom fw path back on exit
  (bsc#1051510).
- commit d9210c3
* Tue Jul  3 2018 tiwai@suse.de
- regulator: of: Add a missing 'of_node_put()' in an error
  handling path of 'of_regulator_match()' (bsc#1051510).
- commit 66aa83f
* Tue Jul  3 2018 tiwai@suse.de
- PCI: Add ACS quirk for Intel 300 series (bsc#1051510).
- PCI: Add ACS quirk for Intel 7th & 8th Gen mobile (bsc#1051510).
- PCI: pciehp: Clear Presence Detect and Data Link Layer Status
  Changed on resume (bsc#1051510).
- commit eec6d57
* Tue Jul  3 2018 tiwai@suse.de
- of: platform: stop accessing invalid dev in
  of_platform_device_destroy (bsc#1051510).
- of: overlay: validate offset from property fixups (bsc#1051510).
- of: unittest: for strings, account for trailing \0 in property
  length field (bsc#1051510).
- commit 3b3a1ed
* Tue Jul  3 2018 tiwai@suse.de
- mfd: intel-lpss: Fix Intel Cannon Lake LPSS I2C input clock
  (bsc#1051510).
- mfd: intel-lpss: Program REMAP register in PIO mode
  (bsc#1051510).
- commit a981b43
* Tue Jul  3 2018 tiwai@suse.de
- media: cx231xx: Add support for AverMedia DVD EZMaker 7
  (bsc#1051510).
- media: v4l2-compat-ioctl32: prevent go past max size
  (bsc#1051510).
- media: dvb_frontend: fix locking issues at
  dvb_frontend_get_event() (bsc#1051510).
- commit 8ac41a1
* Tue Jul  3 2018 tiwai@suse.de
- kernel/relay.c: limit kmalloc size to KMALLOC_MAX_SIZE
  (bsc#1051510).
- commit 5080000
* Tue Jul  3 2018 tiwai@suse.de
- Input: elan_i2c_smbus - fix more potential stack buffer
  overflows (bsc#1051510).
- Input: elan_i2c - add ELAN0618 (Lenovo v330 15IKB) ACPI ID
  (bsc#1051510).
- Input: elantech - fix V4 report decoding for module with middle
  key (bsc#1051510).
- Input: elantech - enable middle button of touchpads on ThinkPad
  P52 (bsc#1051510).
- commit 5144ba7
* Tue Jul  3 2018 tiwai@suse.de
- idr: fix invalid ptr dereference on item delete (bsc#1051510).
- commit be80860
* Tue Jul  3 2018 tiwai@suse.de
- Bluetooth: hci_qca: Avoid missing rampatch failure with
  userspace fw loader (bsc#1051510).
- commit 89da3e9
* Tue Jul  3 2018 tiwai@suse.de
- auxdisplay: fix broken menu (bsc#1051510).
- auxdisplay: img-ascii-lcd: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bsc#1051510).
- auxdisplay: img-ascii-lcd: Only build on archs that have IOMEM
  (bsc#1051510).
- commit 215cae7
* Tue Jul  3 2018 tiwai@suse.de
- ACPI / LPSS: Add missing prv_offset setting for byt/cht PWM
  devices (bsc#1051510).
- commit aa3e853
* Tue Jul  3 2018 tiwai@suse.de
- ASoC: cs35l35: Add use_single_rw to regmap config (bsc#1051510).
- ASoC: dapm: delete dapm_kcontrol_data paths list before freeing
  it (bsc#1051510).
- ASoC: cirrus: i2s: Fix {TX|RX}LinCtrlData setup (bsc#1051510).
- ASoC: cirrus: i2s: Fix LRCLK configuration (bsc#1051510).
- commit 8e9fd2f
* Tue Jul  3 2018 tiwai@suse.de
- ALSA: seq: Fix UBSAN warning at
  SNDRV_SEQ_IOCTL_QUERY_NEXT_CLIENT ioctl (bsc#1051510).
- ALSA: timer: Fix UBSAN warning at SNDRV_TIMER_IOCTL_NEXT_DEVICE
  ioctl (bsc#1051510).
- commit 545ff8d
* Mon Jul  2 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1089762)
  Set NR_CPUS to 256.
- commit fcc7072
* Mon Jul  2 2018 lhenriques@suse.com
- ceph: fix dentry leak in splice_dentry() (bsc#1098236).
- commit 3b8a702
* Mon Jul  2 2018 tiwai@suse.de
- Input: xpad - fix GPD Win 2 controller name (bsc#1051510).
- iwlwifi: pcie: compare with number of IRQs requested for,
  not number of CPUs (bsc#1051510).
- PCI: Mark Broadcom HT1100 and HT2000 Root Port Extended Tags
  as broken (bsc#1051510).
- PCI: Add function 1 DMA alias quirk for Marvell 88SE9220
  (bsc#1051510).
- PCI: Restore config space on runtime resume despite being
  unbound (bsc#1051510).
- ACPI / watchdog: properly initialize resources (bsc#1051510).
- commit bd85685
* Mon Jul  2 2018 tiwai@suse.de
- ALSA: hda/realtek - Fix the problem of two front mics on more
  machines (bsc#1051510).
- ALSA: hda/realtek - Add a quirk for FSC ESPRIMO U9210
  (bsc#1051510).
- ALSA: hda/realtek - Fix pop noise on Lenovo P50 & co
  (bsc#1051510).
- commit 091cd56
* Mon Jul  2 2018 tiwai@suse.de
- ALSA: hda/ca0132: make array ca0132_alt_chmaps static
  (bsc#1051510).
- ALSA: hda/ca0132: Fix DMic data rate for Alienware M17x R4
  (bsc#1051510).
- ALSA: hda/ca0132: Restore PCM Analog Mic-In2 (bsc#1051510).
- ALSA: hda/ca0132: Don't test for QUIRK_NONE (bsc#1051510).
- ALSA: hda/ca0132: Restore behavior of QUIRK_ALIENWARE
  (bsc#1051510).
- ALSA: hda/ca0132: Delete redundant UNSOL event requests
  (bsc#1051510).
- ALSA: hda/ca0132: Delete pointless assignments to struct
  auto_pin_cfg fields (bsc#1051510).
- commit ae06174
* Mon Jul  2 2018 tiwai@suse.de
- ALSA: hda/ca0132 - use ARRAY_SIZE (bsc#1051510).
- Refresh
  patches.drivers/ALSA-hda-ca0132-Add-PCI-region2-iomap-for-SBZ.
- commit 5d7aadb
* Mon Jul  2 2018 jthumshirn@suse.de
- s390/qdio: don't merge ERROR output buffers (bsc#1099715).
- s390/qeth: lock read device while queueing next buffer
  (bsc#1099715).
- s390/qeth: when thread completes, wake up all waiters
  (bsc#1099715).
- s390/qeth: free netdevice when removing a card (bsc#1099715).
- s390/qeth: fix IPA command submission race (bsc#1099715).
- s390/qeth: fix overestimated count of buffer elements
  (bsc#1099715).
- s390/qeth: don't dump control cmd twice (bsc#1099715).
- commit e1ac104
* Mon Jul  2 2018 jslaby@suse.cz
- vhost: fix vhost_vq_access_ok() log check
  (networking-stable-18_04_13).
- vhost: Fix vhost_copy_to_user() (networking-stable-18_04_13).
- cdc_ether: flag the Cinterion AHS8 modem by gemalto as WWAN
  (networking-stable-18_04_13).
- slip: Check if rstate is initialized before uncompressing
  (networking-stable-18_04_13).
- kABI: protect struct cstate (kabi).
- rds: MP-RDS may use an invalid c_path
  (networking-stable-18_04_13).
- commit eec5545
* Mon Jul  2 2018 jslaby@suse.cz
- Update upstream status.
- commit baa4fcf
* Mon Jul  2 2018 jslaby@suse.cz
- sctp: sctp_sockaddr_af must check minimal addr length for
  AF_INET6 (networking-stable-18_04_10).
- sctp: do not leak kernel memory to user space
  (networking-stable-18_04_10).
- net/ipv6: Increment OUTxxx counters after netfilter hook
  (networking-stable-18_04_10).
- arp: fix arp_filter on l3slave devices
  (networking-stable-18_04_10).
- vti6: better validate user provided tunnel names
  (networking-stable-18_04_10).
- ip6_tunnel: better validate user provided tunnel names
  (networking-stable-18_04_10).
- ip6_gre: better validate user provided tunnel names
  (networking-stable-18_04_10).
- ipv6: sit: better validate user provided tunnel names
  (networking-stable-18_04_10).
- ip_tunnel: better validate user provided tunnel names
  (networking-stable-18_04_10).
- net: fool proof dev_valid_name() (networking-stable-18_04_10).
- pptp: remove a buggy dst release in pptp_connect()
  (networking-stable-18_04_10).
- route: check sysctl_fib_multipath_use_neigh earlier than hash
  (networking-stable-18_04_10).
- vlan: also check phy_driver ts_info for vlan's real device
  (networking-stable-18_04_10).
- net/ipv6: Fix route leaking between VRFs
  (networking-stable-18_04_10).
- vrf: Fix use after free and double free in vrf_finish_output
  (networking-stable-18_04_10).
- ipv6: sr: fix seg6 encap performances with TSO enabled
  (networking-stable-18_04_10).
- vhost: validate log when IOTLB is enabled
  (networking-stable-18_04_10).
- lan78xx: Crash in lan78xx_writ_reg (Workqueue: events
  lan78xx_deferred_multicast_write) (networking-stable-18_04_10).
- vhost: correctly remove wait queue during poll failure
  (networking-stable-18_04_10).
- strparser: Fix sign of err codes (networking-stable-18_04_10).
- net: fix possible out-of-bound read in skb_network_protocol()
  (networking-stable-18_04_10).
- vhost_net: add missing lock nesting notation
  (networking-stable-18_04_10).
- team: move dev_mc_sync after master_upper_dev_link in
  team_port_add (networking-stable-18_04_10).
- bonding: process the err returned by dev_set_allmulti properly
  in bond_enslave (networking-stable-18_04_10).
- bonding: move dev_mc_sync after master_upper_dev_link in
  bond_enslave (networking-stable-18_04_10).
- bonding: fix the err path for dev hwaddr sync in bond_enslave
  (networking-stable-18_04_10).
- ipv6: the entire IPv6 header chain must fit the first fragment
  (networking-stable-18_04_10).
- netlink: make sure nladdr has correct size in netlink_connect()
  (networking-stable-18_04_10).
- commit bd99c84
* Mon Jul  2 2018 neilb@suse.com
- NFSv4: Revert commit 5f83d86cf531d ("NFSv4.x: Fix wraparound
  issues..") (git-fixes).
- xprtrdma: Return -ENOBUFS when no pages are available
  (git-fixes).
- ip6mr: only set ip6mr_table from setsockopt when ip6mr_new_table
  succeeds (git-fixes).
- xprtrdma: Fix list corruption / DMAR errors during MR recovery
  (git-fixes).
- commit c72bef4
* Sat Jun 30 2018 bp@suse.de
- Delete
  patches.arch/15-x86-apic-ignore-secondary-threads-if-nosmt-force.patch.
- commit b32c883
* Fri Jun 29 2018 hare@suse.de
- nvme: fix NULL pointer dereference in nvme_init_subsystem
  (bsc#1098706).
- nvmet: switch loopback target state to connecting when resetting
  (bsc#1098706).
- commit dc833e9
* Fri Jun 29 2018 bp@suse.de
- Update config files.
- commit 6ab6e84
* Fri Jun 29 2018 bp@suse.de
- x86/CPU/AMD: Move TOPOEXT reenablement before reading
  smp_num_siblings (bsc#1089343).
- x86/apic: Ignore secondary threads if nosmt=force (bsc#1089343).
- x86/cpu/AMD: Evaluate smp_num_siblings early (bsc#1089343).
- x86/CPU/AMD: Do not check CPUID max ext level before parsing
  SMP info (bsc#1089343).
- x86/cpu/intel: Evaluate smp_num_siblings early (bsc#1089343).
- x86/cpu/topology: Provide detect_extended_topology_early()
  (bsc#1089343).
- x86/cpu/common: Provide detect_ht_early() (bsc#1089343).
- x86/cpu/AMD: Remove the pointless detect_ht() call
  (bsc#1089343).
- x86/cpu: Remove the pointless CPU printout (bsc#1089343).
- cpu/hotplug: Provide knobs to control SMT (bsc#1089343).
- cpu/hotplug: Split do_cpu_down() (bsc#1089343).
- cpu/hotplug: Make bringup/teardown of smp threads symmetric
  (bsc#1089343).
- x86/topology: Provide topology_smt_supported() (bsc#1089343).
- x86/smp: Provide topology_is_primary_thread() (bsc#1089343).
- sched/smt: Update sched_smt_present at runtime (bsc#1089343).
- jump_label: Provide hotplug context variants (bsc#1089343).
- jump_label: Fix concurrent static_key_enable/disable()
  (bsc#1089343).
- jump_label: Reorder hotplug lock and jump_label_lock
  (bsc#1089343).
- commit 0ff8503
* Fri Jun 29 2018 hare@suse.de
- nvme-fabrics: fix and refine state checks in __nvmf_check_ready
  (bsc#1098706).
- nvme-fabrics: handle the admin-only case properly in
  nvmf_check_ready (bsc#1098706).
- nvme-fabrics: refactor queue ready check (bsc#1098706).
- nvme-fc: fix nulling of queue data on reconnect (bsc#1098706).
- nvme-fc: remove reinit_request routine (bsc#1098706).
- nvme-fc: change controllers first connect to use reconnect path
  (bsc#1098706).
- nvme-fabrics: allow internal passthrough command on deleting
  controllers (bsc#1098706).
- nvme: allow duplicate controller if prior controller being
  deleted (bsc#1098706).
- nvmet-fc: increase LS buffer count per fc port (bsc#1098706).
- nvme-fabrics: allow duplicate connections to the discovery
  controller (bsc#1098706).
- nvme-fabrics: centralize discovery controller defaults
  (bsc#1098706).
- nvme-fabrics: remove unnecessary controller subnqn validation
  (bsc#1098706).
- nvme-fc: remove setting DNR on exception conditions
  (bsc#1098706).
- nvme/multipath: Fix multipath disabled naming collisions
  (bsc#1098706).
- nvme: Set integrity flag for user passthrough commands
  (bsc#1098706).
- nvme: fix potential memory leak in option parsing (bsc#1098706).
- nvme: expand nvmf_check_if_ready checks (bsc#1098706).
- nvme: Use admin command effects for admin commands
  (bsc#1098706).
- nvme: check return value of init_srcu_struct function
  (bsc#1098706).
- nvme: Skip checking heads without namespaces (bsc#1098706).
- commit 410877f
* Fri Jun 29 2018 tbogendoerfer@suse.de
- i40e: Close client on suspend and restore client MSIx on resume
  (bsc#1088821).
- commit 2475198
* Fri Jun 29 2018 jthumshirn@suse.de
- scsi: lpfc: update driver version to 12.0.0.4 (bsc#1088866).
- scsi: lpfc: Fix crash in blk_mq layer when executing modprobe
  - r lpfc (bsc#1088866).
- scsi: lpfc: correct oversubscription of nvme io requests for
  an adapter (bsc#1088866).
- scsi: lpfc: Fix MDS diagnostics failure (Rx < Tx) (bsc#1088866).
- scsi: lpfc: fix spelling mistakes: "mabilbox" and "maibox"
  (bsc#1088866).
- scsi: lpfc: Comment cleanup regarding Broadcom copyright header
  (bsc#1088866).
- scsi: lpfc: update driver version to 12.0.0.3 (bsc#1088866).
- scsi: lpfc: Enhance log messages when reporting CQE errors
  (bsc#1088866).
- scsi: lpfc: Fix up log messages and stats counters in IO submit
  code path (bsc#1088866).
- scsi: lpfc: Driver NVME load fails when CPU cnt > WQ resource
  cnt (bsc#1088866).
- scsi: lpfc: Handle new link fault code returned by adapter
  firmware (bsc#1088866).
- scsi: lpfc: Correct fw download error message (bsc#1088866).
- scsi: lpfc: enhance LE data structure copies to hardware
  (bsc#1088866).
- scsi: lpfc: Change IO submit return to EBUSY if remote port
  is recovering (bsc#1088866).
- scsi: lpfc: update driver version to 12.0.0.2 (bsc#1088866).
- scsi: lpfc: Correct missing remoteport registration during
  link bounces (bsc#1088866).
- scsi: lpfc: Fix NULL pointer reference when resetting adapter
  (bsc#1088866).
- scsi: lpfc: Fix nvme remoteport registration race conditions
  (bsc#1088866).
- scsi: lpfc: Fix driver not recovering NVME rports during target
  link faults (bsc#1088866).
- scsi: lpfc: Fix NULL pointer access in lpfc_nvme_info_show
  (bsc#1088866).
- scsi: lpfc: Fix lingering lpfc_wq resource after driver unload
  (bsc#1088866).
- scsi: lpfc: Fix Abort request WQ selection (bsc#1088866).
- scsi: lpfc: Enlarge nvmet asynchronous receive buffer counts
  (bsc#1088866).
- scsi: lpfc: Add per io channel NVME IO statistics (bsc#1088866).
- scsi: lpfc: Correct target queue depth application changes
  (bsc#1088866).
- scsi: lpfc: Fix multiple PRLI completion error path
  (bsc#1088866).
- commit 8c78da4
* Fri Jun 29 2018 jthumshirn@suse.de
- scsi: lpfc: Fix 16gb hbas failing cq create (bsc#1093290).
- scsi: lpfc: Fix port initialization failure (bsc#1093290).
- commit 0ee922c
* Fri Jun 29 2018 jslaby@suse.cz
- net: ipv4: avoid unused variable warning for sysctl (git-fixes).
- commit 7a52639
* Fri Jun 29 2018 jslaby@suse.cz
- x86/spectre_v1: Disable compiler optimizations over
  array_index_mask_nospec() (bsc#1068032 CVE-2017-5753).
- ipv6: sr: fix NULL pointer dereference in seg6_do_srh_encap()-
  v4 pkts (git-fixes).
- netlink: avoid a double skb free in genlmsg_mcast() (git-fixes).
- commit 22bc1da
* Thu Jun 28 2018 jslaby@suse.cz
- ppp: avoid loop in xmit recursion detection code
  (networking-stable-18_03_28).
- ipv6: sr: fix NULL pointer dereference when setting encap
  source address (networking-stable-18_03_28).
- ipv6: sr: fix scheduling in RCU when creating seg6 lwtunnel
  state (networking-stable-18_03_28).
- s390/qeth: lock read device while queueing next buffer
  (networking-stable-18_03_28).
- s390/qeth: when thread completes, wake up all waiters
  (networking-stable-18_03_28).
- s390/qeth: free netdevice when removing a card
  (networking-stable-18_03_28).
- ipv6: old_dport should be a __be16 in __ip6_datagram_connect()
  (networking-stable-18_03_28).
- net: ethernet: arc: Fix a potential memory leak if an optional
  regulator is deferred (networking-stable-18_03_28).
- devlink: Remove redundant free on error path
  (networking-stable-18_03_28).
- net: fec: Fix unbalanced PM runtime calls
  (networking-stable-18_03_28).
- net: ethernet: ti: cpsw: add check for in-band mode setting
  with RGMII PHY interface (networking-stable-18_03_28).
- commit ae40f43
* Thu Jun 28 2018 jslaby@suse.cz
- mlxsw: spectrum_buffers: Set a minimum quota for CPU port
  traffic (networking-stable-18_03_28).
- skbuff: Fix not waking applications when errors are enqueued
  (networking-stable-18_03_28).
- net/iucv: Free memory obtained by kzalloc
  (networking-stable-18_03_28).
- net: systemport: Rewrite __bcm_sysport_tx_reclaim()
  (networking-stable-18_03_28).
- kcm: lock lower socket in kcm_attach
  (networking-stable-18_03_28).
- dpaa_eth: remove duplicate increment of the tx_errors counter
  (networking-stable-18_03_28).
- dpaa_eth: increment the RX dropped counter when needed
  (networking-stable-18_03_28).
- dpaa_eth: remove duplicate initialization
  (networking-stable-18_03_28).
- soc/fsl/qbman: fix issue in qman_delete_cgr_safe()
  (networking-stable-18_03_28).
- net: use skb_to_full_sk() in skb_update_prio()
  (networking-stable-18_03_28).
- net: ipv6: keep sk status consistent after datagram connect
  failure (networking-stable-18_03_28).
- net: phy: Tell caller result of phy_change()
  (networking-stable-18_03_28).
- macvlan: filter out unsupported feature flags
  (networking-stable-18_03_28).
- ieee802154: 6lowpan: fix possible NULL deref in
  lowpan_device_event() (networking-stable-18_03_28).
- ipv6: fix access to non-linear packet in
  ndisc_fill_redirect_hdr_option() (networking-stable-18_03_28).
- team: Fix double free in error path
  (networking-stable-18_03_28).
- net: Fix hlist corruptions in inet_evict_bucket()
  (networking-stable-18_03_28).
- sch_netem: fix skb leak in netem_enqueue()
  (networking-stable-18_03_28).
- net: Only honor ifindex in IP_PKTINFO if non-0
  (networking-stable-18_03_28).
- commit 510e182
* Thu Jun 28 2018 jslaby@suse.cz
- ppp: prevent unregistered channels from connecting to PPP units
  (networking-stable-18_03_07).
- mlxsw: spectrum_switchdev: Check success of FDB add operation
  (networking-stable-18_03_07).
- tcp: revert F-RTO extension to detect more spurious timeouts
  (networking-stable-18_03_07).
- s390/qeth: fix IPA command submission race
  (networking-stable-18_03_07).
- s390/qeth: fix overestimated count of buffer elements
  (networking-stable-18_03_07).
- net: ipv4: don't allow setting net.ipv4.route.min_pmtu below 68
  (networking-stable-18_03_07).
- hdlc_ppp: carrier detect ok, don't turn off negotiation
  (networking-stable-18_03_07).
- ipv6 sit: work around bogus gcc-8 -Wrestrict warning
  (networking-stable-18_03_07).
- rxrpc: Fix send in rxrpc_send_data_packet()
  (networking-stable-18_03_07).
- amd-xgbe: Restore PCI interrupt enablement setting on resume
  (networking-stable-18_03_07).
- net: sched: report if filter is too large to dump
  (networking-stable-18_03_07).
- fib_semantics: Don't match route with mismatching tclassid
  (networking-stable-18_03_07).
- mlxsw: spectrum_router: Fix error path in mlxsw_sp_vr_create
  (networking-stable-18_03_07).
- net: phy: fix phy_start to consider PHY_IGNORE_INTERRUPT
  (networking-stable-18_03_07).
- net/sched: cls_u32: fix cls_u32 on filter replace
  (networking-stable-18_03_07).
- netlink: ensure to loop over all netns in
  genlmsg_multicast_allns() (networking-stable-18_03_07).
- net: ethernet: ti: cpsw: fix net watchdog timeout
  (networking-stable-18_03_07).
- sctp: fix dst refcnt leak in sctp_v6_get_dst()
  (networking-stable-18_03_07).
- commit 020b588
* Thu Jun 28 2018 bpoirier@suse.com
- e1000e: Ignore TSYNCRXCTL when getting I219 clock attributes
  (bsc#1075876).
- commit abb70b0
* Wed Jun 27 2018 jslaby@suse.cz
- soreuseport: fix mem leak in reuseport_add_sock()
  (networking-stable-18_02_06).
- rocker: fix possible null pointer dereference in
  rocker_router_fib_event_work (networking-stable-18_02_06).
- ip6mr: fix stale iterator (networking-stable-18_02_06).
- qmi_wwan: Add support for Quectel EP06
  (networking-stable-18_02_06).
- tcp: release sk_frag.page in tcp_disconnect
  (networking-stable-18_02_06).
- vhost_net: stop device during reset owner
  (networking-stable-18_02_06).
- commit b7048a3
* Wed Jun 27 2018 jslaby@suse.cz
- dccp: don't restart ccid2_hc_tx_rto_expire() if sk in closed
  state (networking-stable-18_01_28).
- net: vrf: Add support for sends to local broadcast address
  (networking-stable-18_01_28).
- net: tcp: close sock if net namespace is exiting
  (networking-stable-18_01_28).
- mlxsw: spectrum_router: Don't log an error on missing neighbor
  (networking-stable-18_01_28).
- pppoe: take ->needed_headroom of lower device into account on
  xmit (networking-stable-18_01_28).
- net: qdisc_pkt_len_init() should be more robust
  (networking-stable-18_01_28).
- ip6_gre: init dev->mtu and dev->hard_header_len correctly
  (networking-stable-18_01_28).
- flow_dissector: properly cap thoff field
  (networking-stable-18_01_28).
- netlink: reset extack earlier in netlink_rcv_skb
  (networking-stable-18_01_28).
- ipv4: Make neigh lookup keys for loopback/point-to-point
  devices be INADDR_ANY (networking-stable-18_01_28).
- net: Allow neigh contructor functions ability to modify the
  primary_key (networking-stable-18_01_28).
- netlink: extack needs to be reset each time through loop
  (networking-stable-18_01_28).
- tipc: fix a memory leak in tipc_nl_node_get_link()
  (networking-stable-18_01_28).
- ipv6: fix udpv6 sendmsg crash caused by too small MTU
  (networking-stable-18_01_28).
- ppp: unlock all_ppp_mutex before registering device
  (networking-stable-18_01_28).
- commit 7a88b2e
* Wed Jun 27 2018 jroedel@suse.de
- kvm: nVMX: Enforce cpl=0 for VMX instructions (bsc#1099183).
- commit a1ac0dc
* Wed Jun 27 2018 neilb@suse.com
- NFS: Revert "NFS: Move the flock open mode check into
  nfs_flock()" (bsc#1098983).
- commit 11f1646
* Tue Jun 26 2018 dbueso@suse.de
- locking/qspinlock: Ensure node->count is updated before
  initialising node (bsc#1050549).
- locking/qspinlock: Ensure node is initialised before updating
  prev->next (bsc#1050549).
- locking: Remove smp_read_barrier_depends() from
  queued_spin_lock_slowpath() (bsc#1050549).
- commit 0699d86
* Tue Jun 26 2018 rgoldwyn@suse.com
- procfs: add tunable for fd/fdinfo dentry retention
  (bsc#1086652).
- commit a552a50
* Tue Jun 26 2018 tiwai@suse.de
- serial: sh-sci: Stop using printk format %%pCr (bsc#1051510).
- serial: 8250: omap: Fix idling of clocks for unused uarts
  (bsc#1051510).
- serial: samsung: fix maxburst parameter for DMA transactions
  (bsc#1051510).
- serial: xuartps: Fix out-of-bounds access through DT alias
  (bsc#1051510).
- serial: sh-sci: Fix out-of-bounds access through DT alias
  (bsc#1051510).
- serial: samsung: Fix out-of-bounds access through serial port
  index (bsc#1051510).
- serial: mxs-auart: Fix out-of-bounds access through serial
  port index (bsc#1051510).
- serial: imx: Fix out-of-bounds access through serial port index
  (bsc#1051510).
- serial: fsl_lpuart: Fix out-of-bounds access through DT alias
  (bsc#1051510).
- serial: arc_uart: Fix out-of-bounds access through DT alias
  (bsc#1051510).
- serial: altera: ensure port->regshift is honored consistently
  (bsc#1051510).
- commit 88d8bc4
* Tue Jun 26 2018 tiwai@suse.de
- kobject: don't use WARN for registration failures (bsc#1051510).
- lib/kobject: Join string literals back (bsc#1051510).
- commit 7847332
* Tue Jun 26 2018 tiwai@suse.de
- kconfig: Fix expr_free() E_NOT leak (bsc#1051510).
- kconfig: Fix automatic menu creation mem leak (bsc#1051510).
- kconfig: Don't leak main menus during parsing (bsc#1051510).
- commit c9d208f
* Tue Jun 26 2018 tiwai@suse.de
- kconfig: Avoid format overflow warning from GCC 8.1
  (bsc#1051510).
- commit 362ff21
* Tue Jun 26 2018 tiwai@suse.de
- iio:kfifo_buf: check for uint overflow (bsc#1051510).
- iio: ad7793: implement IIO_CHAN_INFO_SAMP_FREQ (bsc#1051510).
- commit 16858f3
* Tue Jun 26 2018 tiwai@suse.de
- i2c: viperboard: return message count on master_xfer success
  (bsc#1051510).
- i2c: pmcmsp: fix error return from master_xfer (bsc#1051510).
- i2c: pmcmsp: return message count on master_xfer success
  (bsc#1051510).
- commit e8e6bb6
* Tue Jun 26 2018 tiwai@suse.de
- can: hi311x: Work around TX complete interrupt erratum
  (bsc#1051510).
- can: hi311x: Acquire SPI lock on ->do_get_berr_counter
  (bsc#1051510).
- commit 611da87
* Tue Jun 26 2018 ggherdovich@suse.cz
- cpufreq: intel_pstate: enable boost for Skylake Xeon
  (bsc#1066110).
- commit 263c6ed
* Tue Jun 26 2018 ggherdovich@suse.cz
- cpufreq: intel_pstate: New sysfs entry to control HWP boost
  (bsc#1066110).
- commit 27d65e5
* Tue Jun 26 2018 ggherdovich@suse.cz
- cpufreq: intel_pstate: HWP boost performance on IO wakeup
  (bsc#1066110).
- commit 31b1def
* Tue Jun 26 2018 ggherdovich@suse.cz
- cpufreq: intel_pstate: Add HWP boost utility and sched util
  hooks (bsc#1066110).
- commit 4c5d4c5
* Tue Jun 26 2018 jthumshirn@suse.de
- libnvdimm, pmem: Do not flush power-fail protected CPU caches
  (bsc#1091424).
- libnvdimm, pmem: Unconditionally deep flush on *sync
  (bsc#1091424).
- commit 7fc6830
* Tue Jun 26 2018 lhenriques@suse.com
- fs/binfmt_misc.c: do not allow offset overflow (bsc#1099142).
- commit efa14c2
* Tue Jun 26 2018 tiwai@suse.de
- HID: intel_ish-hid: ipc: register more pm callbacks to support
  hibernation (bsc#1051510).
- HID: intel-ish-hid: use put_device() instead of kfree()
  (bsc#1051510).
- HID: wacom: Release device resource data obtained by
  devres_alloc() (bsc#1051510).
- HID: lenovo: Add support for IBM/Lenovo Scrollpoint mice
  (bsc#1051510).
- commit f6bebf1
* Tue Jun 26 2018 tiwai@suse.de
- HID: wacom: Correct logical maximum Y for 2nd-gen Intuos Pro
  large (bsc#1051510).
- iwlwifi: fw: harden page loading code (bsc#1051510).
- driver core: Don't ignore class_dir_create_and_add() failure
  (bsc#1051510).
- w1: mxc_w1: Enable clock before calling clk_get_rate() on it
  (bsc#1051510).
- commit fabed48
* Tue Jun 26 2018 tiwai@suse.de
- media: uvcvideo: Support realtek's UVC 1.5 device (bsc#1099109).
- commit 72d7cdf
* Tue Jun 26 2018 tiwai@suse.de
- dell_rbu: make firmware payload memory uncachable (bsc#1087978).
- commit 810fc1b
* Tue Jun 26 2018 tiwai@suse.de
- Downgrade printk level for MMC SDHCI host version error
  (bsc#1097941).
- commit 3226bd3
* Tue Jun 26 2018 tiwai@suse.de
- Move upstreamed ideapad-laptop patch to sorted section (bsc#1093035)
- commit eac2cbe
* Tue Jun 26 2018 tiwai@suse.de
- platform/x86: ideapad-laptop: Apply no_hw_rfkill to Y20-15IKBM,
  too (bsc#1098626).
- commit a10c509
* Mon Jun 25 2018 tiwai@suse.de
- Refresh
  patches.drivers/drm-msm-Fix-possible-null-dereference-on-failure-of-.
  Add the no-fix tag
- commit 7a9b29c
* Mon Jun 25 2018 tiwai@suse.de
- drm/i915: Apply batch location restrictions before pinning
  (bsc#1051510).
- drm/qxl: Call qxl_bo_unref outside atomic context (bsc#1051510).
- commit c810981
* Mon Jun 25 2018 lhenriques@suse.com
- regulator: Don't return or expect -errno from of_map_mode()
  (bsc#1099029).
- commit ba7726f
* Mon Jun 25 2018 msuchanek@suse.de
- rpm/kernel-source.changes.old: Add pre-SLE15 history (bsc#1098995).
- commit 9340111
* Mon Jun 25 2018 tbogendoerfer@suse.de
- i40e: Fix the number of queues available to be mapped for use
  (bsc#1094978).
- i40e: Do not allow use more TC queue pairs than MSI-X vectors
  exist (bsc#1094978).
- commit d111601
* Mon Jun 25 2018 bp@suse.de
- vhost: fix info leak due to uninitialized memory (bsc#1092472
  CVE-2018-1118).
- commit 600e954
* Mon Jun 25 2018 ohering@suse.de
- add mainline tag to one hyperv patch
- commit 0287ab4
* Sat Jun 23 2018 jslaby@suse.cz
- x86/stacktrace: Do not unwind after user regs (bnc#1058115).
- x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (bnc#1058115).
- x86/stacktrace: Clarify the reliable success paths
  (bnc#1058115).
- x86/stacktrace: Do not fail for ORC with regs on stack
  (bnc#1058115).
- x86/unwind/orc: Detect the end of the stack (bnc#1058115).
- x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC
  unwinder (bnc#1058115).
- Delete
  patches.suse/0001-x86-stacktrace-do-now-unwind-after-user-regs.patch.
- Delete
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
- Delete
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Delete
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0005-x86-stacktrace-orc-mark-it-as-reliable.patch.
  Replace the ORC patches by the upstream patches. Finally...
  0005 is disabled here by a guard in series.conf, but should be enabled
  in 12-sp4 definitely.
- commit 9925d74
* Fri Jun 22 2018 aaptel@suse.com
- cifs: Check for timeout on Negotiate stage (bsc#1091171).
- commit 5c8f09d
* Fri Jun 22 2018 msuchanek@suse.de
- Refresh patches.arch/mm-powerpc-x86-introduce-an-additional-vma-bit-for-p.patch.
- commit d28cd3d
* Fri Jun 22 2018 msuchanek@suse.de
- Refresh patches.arch/mm-powerpc-x86-define-VM_PKEY_BITx-bits-if-CONFIG_AR.patch.
- commit b94492f
* Fri Jun 22 2018 msuchanek@suse.de
- scsi: ipr: Format HCAM overlay ID 0x41 (bsc#1097961).
- commit f0c061b
* Fri Jun 22 2018 msuchanek@suse.de
- mm/pkeys, x86, powerpc: Display pkey in smaps if arch supports
  pkeys (FATE#322447, bsc#1078248).
- mm/pkeys: Add an empty arch_pkeys_enabled() (FATE#322447,
  bsc#1078248).
- mm/pkeys: Remove include of asm/mmu_context.h from pkeys.h
  (FATE#322447, bsc#1078248).
- mm/pkeys, powerpc, x86: Provide an empty vma_pkey() in
  linux/pkeys.h (FATE#322447, bsc#1078248).
- x86/pkeys: Add arch_pkeys_enabled() (FATE#322447, bsc#1078248).
- x86/pkeys: Move vma_pkey() into asm/pkeys.h (FATE#322447,
  bsc#1078248).
- Delete patches.arch/mm-x86-powerpc-display-pkey-in-smaps-only-if-arch-su.patch.
- commit d9483bb
* Fri Jun 22 2018 msuchanek@suse.de
- powerpc/pkeys: Detach execute_only key on !PROT_EXEC
  (FATE#322447, bsc#1078248, git-fixes).
- powerpc/mm: Fix thread_pkey_regs_init() (FATE#322447,
  bsc#1078248, git-fixes).
- powerpc/pkeys: Drop private VM_PKEY definitions (FATE#322447,
  bsc#1078248).
- commit a8be076
* Thu Jun 21 2018 jgross@suse.com
- xen: don't print error message in case of missing Xenstore entry
  (bnc#1065600).
- commit ec662c5
* Thu Jun 21 2018 tiwai@suse.de
- staging: wilc1000: Fix bssid buffer offset in Txq (bsc#1051510).
- commit 64122fd
* Thu Jun 21 2018 tiwai@suse.de
- mac80211: use timeout from the AddBA response instead of the
  request (bsc#1051510).
- mac80211: Adjust SAE authentication timeout (bsc#1051510).
- commit e651094
* Thu Jun 21 2018 tiwai@suse.de
- crypto: vmx - Remove overly verbose printk from AES XTS init
  (bsc#1051510).
- crypto: vmx - Remove overly verbose printk from AES init
  routines (bsc#1051510).
- crypto: omap-sham - fix memleak (bsc#1051510).
- commit 2e10430
* Thu Jun 21 2018 tiwai@suse.de
- crypto: caam - strip input zeros from RSA input buffer
  (bsc#1051510).
- commit f8a4c3c
* Thu Jun 21 2018 tiwai@suse.de
- crypto: caam - fix IV DMA mapping and updating (bsc#1051510).
- crypto: caam - fix DMA mapping dir for generated IV
  (bsc#1051510).
- commit bdb533c
* Thu Jun 21 2018 glin@suse.com
- bpf: properly enforce index mask to prevent out-of-bounds
  speculation (bsc#1098425).
- kabi: add struct bpf_map back (References: bsc#1098425).
- Refresh
  patches.kabi/bpf-prevent-memory-disambiguation-attack.patch.
- Refresh
  patches.suse/bpf-prevent-memory-disambiguation-attack.patch.
- commit 63c00fe
* Thu Jun 21 2018 tiwai@suse.de
- ASoC: topology: Check widget kcontrols before deref
  (bsc#1051510).
- Refresh
  patches.drivers/ASoC-topology-Check-widget-kcontrols-before-deref.
- commit f36a345
* Thu Jun 21 2018 tiwai@suse.de
- drm/dumb-buffers: Integer overflow in drm_mode_create_ioctl()
  (bsc#1051510).
- drm/omap: handle alloc failures in omap_connector (bsc#1051510).
- drm/omap: fix possible NULL ref issue in tiler_reserve_2d
  (bsc#1051510).
- drm/omap: fix uninitialized ret variable (bsc#1051510).
- drm/omap: silence unititialized variable warning (bsc#1051510).
- drm/msm/dsi: use correct enum in dsi_get_cmd_fmt (bsc#1051510).
- drm/amdkfd: fix clock counter retrieval for node without GPU
  (bsc#1051510).
- commit cccb30d
* Thu Jun 21 2018 tiwai@suse.de
- gpio: fix aspeed_gpio unmask irq (bsc#1051510).
- gpio: No NULL owner (bsc#1051510).
- commit c6dac49
* Thu Jun 21 2018 tiwai@suse.de
- ACPI / watchdog: Prefer iTCO_wdt on Lenovo Z50-70 (bsc#1051510).
- commit c72ccee
* Thu Jun 21 2018 tiwai@suse.de
- Input: elan_i2c - add ELAN0612 (Lenovo v330 14IKB) ACPI ID
  (bsc#1051510).
- Input: goodix - add new ACPI id for GPD Win 2 touch screen
  (bsc#1051510).
- Input: xpad - add GPD Win 2 Controller USB IDs (bsc#1051510).
- Input: atmel_mxt_ts - fix the firmware update (bsc#1051510).
- Input: synaptics-rmi4 - fix an unchecked out of memory error
  path (bsc#1051510).
- commit 1ccaca3
* Thu Jun 21 2018 tiwai@suse.de
- Input: xpad - sync supported devices with XBCD (bsc#1051510).
- commit 070cc49
* Thu Jun 21 2018 tiwai@suse.de
- Input: xpad - sync supported devices with 360Controller
  (bsc#1051510).
- Refresh
  patches.drivers/Input-xpad-add-support-for-PDP-Xbox-One-controllers.
- commit b065ed1
* Thu Jun 21 2018 dchang@suse.com
- ethernet: Use octal not symbolic permissions (bsc#1086288
  FATE#324877).
- emulex/benet: Constify *be_misconfig_evt_port_state (bsc#1086288
  FATE#324877).
- be2net: Handle transmit completion errors in Lancer (bsc#1086288
  FATE#324877).
- be2net: Fix HW stall issue in Lancer (bsc#1086288 FATE#324877).
- commit 43a7f05
* Wed Jun 20 2018 jeffm@suse.com
- ext4: fix unsupported feature message formatting (bsc#1098435).
- commit 54744d1
* Wed Jun 20 2018 mbrugger@suse.com
- irqchip/gic-v3-its: Ensure nr_ites >= nr_lpis (bsc#1098401).
- commit efcaaf4
* Wed Jun 20 2018 mhocko@suse.com
- mm, l1tf: Disallow non privileged high MMIO PROT_NONE mappings
  (bnc#1087081, CVE-2018-3620).
- x86, l1tf: Limit swap file size to MAX_PA/2 (bnc#1087081,
  CVE-2018-3620).
- x86, l1tf: Add sysfs report for l1tf (bnc#1087081,
  CVE-2018-3620).
- x86, l1tf: Make sure the first page is always reserved
  (bnc#1087081, CVE-2018-3620).
- x86, l1tf: Protect PROT_NONE PTEs against speculation
  (bnc#1087081, CVE-2018-3620).
- x86, l1tf: Protect swap entries against L1TF (bnc#1087081,
  CVE-2018-3620).
- x86/speculation/l1tf: Change order of offset/type in swap entry
  (bnc#1087081, CVE-2018-3620).
- x86, l1tf: Increase 32bit PAE __PHYSICAL_PAGE_MASK (bnc#1087081,
  CVE-2018-3620).
- commit 56f4d90
* Wed Jun 20 2018 vbabka@suse.cz
- mm, swap: fix false error message in __swp_swapcount()
  (VM Functionality, bsc#1098043).
- commit 329f690
* Tue Jun 19 2018 lhenriques@suse.com
- ceph: fix alignment of rasize (bsc#1098236).
- ceph: fix use-after-free in ceph_statfs() (bsc#1098236).
- ceph: prevent i_version from going back (bsc#1098236).
- ceph: fix wrong check for the case of updating link count
  (bsc#1098236).
- ceph: support file lock on directory (bsc#1098236).
- commit f97eb64
* Tue Jun 19 2018 jkosina@suse.cz
- x86/pti: don't report XenPV as vulnerable (bsc#1097551).
- scripts/git_sort/git_sort.py:
- commit 39b6104
* Tue Jun 19 2018 gqjiang@suse.com
- md: fix two problems with setting the "re-add" device state
  (bsc#1098176).
- raid10: check bio in r10buf_pool_free to void NULL pointer
  dereference (bsc#1098174).
- commit 1a6926b
* Tue Jun 19 2018 nborisov@suse.com
- jfs: Fix inconsistency between memory allocation and
  ea_buf->max_size (bsc#1097234, CVE-2018-12233).
- Delete patches.suse/jfs-Fix-buffer-overrun-in-ea_get.patch.
- commit 871f006
* Mon Jun 18 2018 msuchanek@suse.de
- macros.kernel-source: define linux_arch for KMPs (boo#1098050).
  CONFIG_64BIT is no longer defined so KMP spec files need to include
  %%{?linux_make_arch} in any make call to build modules or descent into
  the kernel directory for any reason.
- commit 5dc40af
* Mon Jun 18 2018 msuchanek@suse.de
- scsi: ipr: new IOASC update (bsc#1097961).
- commit 7f29a4f
* Mon Jun 18 2018 tiwai@suse.de
- Refresh patches.drivers/ACPI-scan-Initialize-watchdog-before-PNP.patch
  Moved to the upstream section, too.
- commit 57124fc
* Mon Jun 18 2018 vbabka@suse.cz
- blacklist.conf: blacklist some mm git-fixes that are not needed in our kernels
- commit 18461bb
* Mon Jun 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-numa-Stagger-NUMA-balancing-scan-periods-for-new-threads.patch.
- commit eaea181
* Mon Jun 18 2018 oneukum@suse.com
- xhci: add port speed ID to portsc tracing (FATE#325103).
- xhci: add port status tracing (FATE#325103).
- commit b0a7d42
* Mon Jun 18 2018 oneukum@suse.com
- xhci: Add port status decoder for tracing purposes
  (FATE#325103).
- commit b31aeac
* Mon Jun 18 2018 oneukum@suse.com
- xhci: add definitions for all port link states (FATE#325103).
- commit 7b825fb
* Mon Jun 18 2018 nborisov@suse.com
- jfs: Fix buffer overrun in ea_get (bsc#1097234, CVE-2018-12233).
- commit f7cd7d0
* Mon Jun 18 2018 mgorman@suse.de
- Refresh
  patches.suse/mremap-Remove-LATENCY_LIMIT-from-mremap-to-reduce-the-number-of-TLB-shootdowns.patch.
- commit fdc45b2
* Mon Jun 18 2018 nborisov@suse.com
- Sort series.conf
- commit 4d4f556
* Mon Jun 18 2018 nborisov@suse.com
- Refresh
  patches.drivers/0001-qla2xxx-Mask-off-Scope-bits-in-retry-delay.patch.
- commit e944492
* Mon Jun 18 2018 jgross@suse.com
- xen/netfront: raise max number of slots in
  xennet_get_responses() (bnc#1076049).
- commit 1b73c5e
* Mon Jun 18 2018 mkubecek@suse.cz
- rpm: ignore CONFIG_GCC_VERSION when checking for oldconfig changes
  Since 4.18-rc1, "make oldconfig" writes gcc version and capabilities into
  generated .config. Thus whenever we build the package or run checks with
  different gcc version than used to update config/*/*, check for "outdated
  configs" fails.
  As a quick band-aid, omit the lines with CONFIG_GCC_VERSION from both
  configs before comparing them. This way, the check won't fail unless run
  with newer gcc which would add new capabilities. More robust solution will
  require a wider discussion.
- commit 546ef32
* Fri Jun 15 2018 lhenriques@suse.com
- Refresh patches.fixes/ceph-fix-st_nlink-stat-for-directories.patch.
- commit 031bfc5
* Fri Jun 15 2018 jslaby@suse.cz
- Update
  patches.fixes/vti-fix-use-after-free-in-vti_tunnel_xmit-vti6_tnl_x.patch
  (bsc#1076830 networking-stable-17_10_09).
- commit 5da2974
* Fri Jun 15 2018 ptesarik@suse.cz
- x86/setup: Do not reserve a crash kernel region if booted on
  Xen PV (bsc#1085626).
- commit 90613d9
* Fri Jun 15 2018 tiwai@suse.de
- blacklist.conf: Add ASoC entry breaking kABI
- commit a377ffd
* Fri Jun 15 2018 tiwai@suse.de
- drm/i915: Remove stale asserts from
  i915_gem_find_active_request() (bsc#1051510).
- ubi: fastmap: Cancel work upon detach (bsc#1051510).
- drm/i915: Restore planes after load detection (bsc#1051510).
- crypto: caam/qi - fix IV DMA mapping and updating (bsc#1051510).
- iio: trigger: stm32-timer: fix get/set down count direction
  (bsc#1051510).
- drm/i915: Remove stale asserts from
  i915_gem_find_active_request() (bsc#1051510).
- ubi: fastmap: Cancel work upon detach (bsc#1051510).
- drm/i915: Restore planes after load detection (bsc#1051510).
- crypto: caam/qi - fix IV DMA mapping and updating (bsc#1051510).
- iio: trigger: stm32-timer: fix get/set down count direction
  (bsc#1051510).
- commit 6238d67
* Fri Jun 15 2018 jroedel@suse.de
- iommu/vt-d: Fix race condition in add_unmap() (bsc#1096790, bsc#1097034).
- commit 5296753
* Fri Jun 15 2018 tiwai@suse.de
- isdn: eicon: fix a missing-check bug (bsc#1051510).
- drm: set FMODE_UNSIGNED_OFFSET for drm files (bsc#1051510).
- i2c: mv64xxx: Apply errata delay only in standard mode
  (bsc#1051510).
- crypto: sunxi-ss - Add MODULE_ALIAS to sun4i-ss (bsc#1051510).
- rtlwifi: rtl8192cu: Remove variable self-assignment in rf.c
  (bsc#1051510).
- gpu: ipu-v3: prg: avoid possible array underflow (bsc#1051510).
- gpu: ipu-v3: prg: fix device node leak in
  ipu_prg_lookup_by_phandle (bsc#1051510).
- gpu: ipu-v3: pre: fix device node leak in
  ipu_pre_lookup_by_phandle (bsc#1051510).
- commit b2aeaf7
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: simplify set_sync_ep_implicit_fb_quirk
  (bsc#1051510).
- commit 520d40f
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: Remove explicitly listed Mytek devices
  (bsc#1051510).
- ALSA: usb-audio: Generic DSD detection for XMOS-based
  implementations (bsc#1051510).
- ALSA: usb-audio: Add native DSD support for Mytek DACs
  (bsc#1051510).
- commit 1407c17
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: Disable the quirk for Nura headset
  (bsc#1051510).
- commit 8a928b8
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: add boot quirk for Axe-Fx III (bsc#1051510).
- commit d9745dc
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: add more quirks for DSD interfaces
  (bsc#1051510).
- ALSA: usb-audio: Integrate native DSD support for ITF-USB
  based DACs (bsc#1051510).
- commit 6b13495
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: FIX native DSD support for TEAC UD-501 DAC
  (bsc#1051510).
- commit a4151ea
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: Support changing input on Sound Blaster E1
  (bsc#1051510).
- Refresh
  patches.drivers/ALSA-usb-audio-Initialize-Dell-Dock-playback-volumes.
- commit 7cdbbde
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: Add a quirk for Nura's first gen headset
  (bsc#1051510).
- commit 6bf51b8
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: Change the semantics of the enable option
  (bsc#1051510).
- ALSA: line6: Add yet more sanity checks for invalid EPs
  (bsc#1051510).
- ALSA: hiface: Add sanity checks for invalid EPs (bsc#1051510).
- ALSA: usb-audio: Add sanity checks for invalid EPs
  (bsc#1051510).
- commit a5f919f
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: Apply vendor ID matching for sample rate quirk
  (bsc#1051510).
- commit 0ebc179
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: line6: add support for POD HD DESKTOP (bsc#1051510).
- commit d06b8f4
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: usb-audio: Add sample rate quirk for Plantronics P610
  (bsc#1051510).
- ALSA: usb-audio: Add sample rate quirk for Plantronics
  C310/C520-M (bsc#1051510).
- commit 051d536
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: line6: remove unnecessary initialization to PODHD500X
  (bsc#1051510).
- ALSA: line6: add support for POD HD500X (bsc#1051510).
- commit 48fb9b8
* Fri Jun 15 2018 tiwai@suse.de
- ALSA: hda/realtek - Add shutup hint (bsc#1051510).
- ALSA: hda: add dock and led support for HP ProBook 640 G4
  (bsc#1051510).
- ALSA: hda: add dock and led support for HP EliteBook 830 G5
  (bsc#1051510).
- commit 5517119
* Fri Jun 15 2018 vbabka@suse.cz
- mm/huge_memory.c: __split_huge_page() use atomic
  ClearPageDirty() (VM Functionality, bsc#1097800).
- commit f3662c4
* Fri Jun 15 2018 vbabka@suse.cz
- mm, slab: reschedule cache_reap() on the same CPU (VM
  Functionality, bsc#1097796).
- commit a6231a1
* Fri Jun 15 2018 vbabka@suse.cz
- mm/ksm.c: fix inconsistent accounting of zero pages (VM
  Functionality, bsc#1097780).
- commit 392d0c5
* Thu Jun 14 2018 vbabka@suse.cz
- blacklist.conf: blacklist stable fix 880cd276dff1 ("mm, slab:
  memcg_link the SLAB's kmem_cache"), bsc#1097471
- commit bc9af26
* Wed Jun 13 2018 vbabka@suse.cz
- mm/page_owner: fix recursion bug after changing skip entries
  (VM Functionality, bsc#1097472).
- commit bfb3aeb
* Wed Jun 13 2018 vbabka@suse.cz
- mm/thp: do not wait for lock_page() in deferred_split_scan()
  (VM Functionality, bsc#1097470).
- commit 23a211a
* Wed Jun 13 2018 vbabka@suse.cz
- mm/khugepaged.c: convert VM_BUG_ON() to collapse fail (VM
  Functionality, bsc#1097468).
- commit 854b555
* Wed Jun 13 2018 vbabka@suse.cz
- mm/mempolicy.c: avoid use uninitialized preferred_node (VM
  Functionality, bsc#1097465).
- commit aba0b63
* Wed Jun 13 2018 vbabka@suse.cz
- mm: Fix memory size alignment in devm_memremap_pages_release()
  (VM Functionality, bsc#1097439).
- commit 245e5a1
* Wed Jun 13 2018 vbabka@suse.cz
- mm, swap: fix race between swap count continuation operations
  (VM Functionality, bsc#1097373).
  mm, swap: fix race between swap count continuation operations -
  KABI fix (VM Functionality, bsc#1097373).
- commit 2e5c587
* Wed Jun 13 2018 tiwai@suse.de
- wil6210: missing length check in wmi_set_ie
  (CVE-2018-5848,bsc#1097356).
- commit e7f0b07
* Tue Jun 12 2018 mhocko@suse.com
- ACPI / NUMA: ia64: Parse all entries of SRAT memory affinity
  table (bnc#1088796, fate#325665).
- commit 9176a12
* Tue Jun 12 2018 nborisov@suse.com
- btrfs: return error value if create_io_em failed in
  cow_file_range (bsc#1097105).
- Btrfs: fix xattr loss after power failure (bsc#1097105).
- btrfs: Take trans lock before access running trans in
  check_delayed_ref (bsc#1097105).
- Btrfs: fix copy_items() return value when logging an inode
  (bsc#1097105).
- commit 04ec4bc
* Tue Jun 12 2018 jgross@suse.com
- xen/acpi: off by one in read_acpi_id() (bnc#1065600).
- commit d86994a
* Tue Jun 12 2018 colyli@suse.de
- bcache: return 0 from bch_debug_init() if CONFIG_DEBUG_FS=n
  (bsc#1093023).
- dm bufio: fix buffer alignment (bsc#1093023).
- tools headers: Restore READ_ONCE() C++ compatibility
  (bsc#1093023).
- commit 59a0dc1
* Tue Jun 12 2018 colyli@suse.de
- bcache: use pr_info() to inform duplicated CACHE_SET_IO_DISABLE
  set (bsc#1093023).
- bcache: set dc->io_disable to true in
  conditional_stop_bcache_device() (bsc#1093023).
- bcache: add wait_for_kthread_stop() in bch_allocator_thread()
  (bsc#1093023).
- bcache: count backing device I/O error for writeback I/O
  (bsc#1093023).
- bcache: set CACHE_SET_IO_DISABLE in bch_cached_dev_error()
  (bsc#1093023).
- bcache: store disk name in struct cache and struct cached_dev
  (bsc#1093023).
- raid1: copy write hint from master bio to behind bio
  (bsc#1093023).
- md/raid1: exit sync request if MD_RECOVERY_INTR is set
  (bsc#1093023).
- md-cluster: don't update recovery_offset for faulty device
  (bsc#1093023).
- dax, dm: allow device-mapper to operate without dax support
  (bsc#1093023).
- dm raid: fix parse_raid_params() variable range issue
  (bsc#1093023).
- dm bufio: don't embed a bio in the dm_buffer structure
  (bsc#1093023).
- dm bufio: support non-power-of-two block sizes (bsc#1093023).
- dm bufio: use slab cache for dm_buffer structure allocations
  (bsc#1093023).
- dm bufio: reorder fields in dm_buffer structure (bsc#1093023).
- dm bufio: relax alignment constraint on slab cache
  (bsc#1093023).
- dm bufio: remove code that merges slab caches (bsc#1093023).
- dm bufio: get rid of slab cache name allocations (bsc#1093023).
- dm bufio: move dm-bufio.h to include/linux/ (bsc#1093023).
- dm bufio: delete outdated comment (bsc#1093023).
- dm raid: fix nosync status (bsc#1093023).
- dm stripe: get rid of a Variable Length Array (VLA)
  (bsc#1093023).
- dm log writes: record metadata flag for better flags record
  (bsc#1093023).
- dm integrity: fail early if required HMAC key is not available
  (bsc#1093023).
- dm: remove unused macro DM_MOD_NAME_SIZE (bsc#1093023).
- dm crypt: limit the number of allocated pages (bsc#1093023).
- scsi: raid_class: Add 'JBOD' RAID level (bsc#1093023).
- bcache: Fix a compiler warning in bcache_device_init()
  (bsc#1093023).
- bcache: Reduce the number of sparse complaints about lock
  imbalances (bsc#1093023).
- bcache: Suppress more warnings about set-but-not-used variables
  (bsc#1093023).
- bcache: Remove an unused variable (bsc#1093023).
- bcache: Fix kernel-doc warnings (bsc#1093023).
- bcache: Annotate switch fall-through (bsc#1093023).
- bcache: Add __printf annotation to __bch_check_keys()
  (bsc#1093023).
- bcache: Fix indentation (bsc#1093023).
- bcache: add io_disable to struct cached_dev (bsc#1093023).
- bcache: add backing_request_endio() for bi_end_io (bsc#1093023).
- bcache: move closure debug file into debug directory
  (bsc#1093023).
- bcache: fix using of loop variable in memory shrink
  (bsc#1093023).
- bcache: fix error return value in memory shrink (bsc#1093023).
- bcache: fix incorrect sysfs output value of strip size
  (bsc#1093023).
- bcache: fix inaccurate io state for detached bcache devices
  (bsc#1093023).
- bcache: add stop_when_cache_set_failed option to backing device
  (bsc#1093023).
- bcache: add CACHE_SET_IO_DISABLE to struct cache_set flags
  (bsc#1093023).
- bcache: stop dc->writeback_rate_update properly (bsc#1093023).
- bcache: quit dc->writeback_thread when BCACHE_DEV_DETACHING
  is set (bsc#1093023).
- bcache: fix cached_dev->count usage for bch_cache_set_error()
  (bsc#1093023).
- md: Delete gendisk before cleaning up the request queue
  (bsc#1093023).
- raid: remove tile specific raid6 implementation (bsc#1093023).
- dm raid: fix incorrect sync_ratio when degraded (bsc#1093023).
- bcache: fix kcrashes with fio in RAID5 backend dev
  (bsc#1093023).
- bcache: correct flash only vols (check all uuids) (bsc#1093023).
- md/raid1: fix NULL pointer dereference (bsc#1093023).
- md: fix a potential deadlock of raid5/raid10 reshape
  (bsc#1093023).
- md-cluster: choose correct label when clustered layout is not
  supported (bsc#1093023).
- md: raid5: avoid string overflow warning (bsc#1093023).
- raid5-ppl: fix handling flush requests (bsc#1093023).
- md: only allow remove_and_add_spares when no sync_thread running
  (bsc#1093023).
- md: document lifetime of internal rdev pointer (bsc#1093023).
- MD: Free bioset when md_run fails (bsc#1093023).
- md-multipath: Use seq_putc() in multipath_status()
  (bsc#1093023).
- md/raid1: Fix trailing semicolon (bsc#1093023).
- md/raid5: simplify uninitialization of shrinker (bsc#1093023).
- dm: correctly handle chained bios in dec_pending()
  (bsc#1093023).
- bcache: fix for data collapse after re-attaching an attached
  device (bsc#1093023).
- bcache: return attach error when no cache set exist
  (bsc#1093023).
- bcache: set writeback_rate_update_seconds in range [1, 60]
  seconds (bsc#1093023).
- bcache: fix for allocator and register thread race
  (bsc#1093023).
- bcache: set error_limit correctly (bsc#1093023).
- bcache: properly set task state in bch_writeback_thread()
  (bsc#1093023).
- bcache: fix high CPU occupancy during journal (bsc#1093023).
- bcache: add journal statistic (bsc#1093023).
- dm thin: fix trailing semicolon in __remap_and_issue_shared_cell
  (bsc#1093023).
- dm log writes: fix max length used for kstrndup (bsc#1093023).
- dm: backfill missing calls to mutex_destroy() (bsc#1093023).
- dm flakey: check for null arg_name in parse_features()
  (bsc#1093023).
- dm: move dm_table_destroy() to same header as dm_table_create()
  (bsc#1093023).
- dm raid: make raid_sets symbol static (bsc#1093023).
- dm bufio: eliminate unnecessary labels in
  dm_bufio_client_create() (bsc#1093023).
- dm bufio: check result of register_shrinker() (bsc#1093023).
- dm bufio: add missed destroys of client mutex (bsc#1093023).
- dm bufio: use REQ_OP_READ and REQ_OP_WRITE (bsc#1093023).
- dm: simplify start of block stats accounting for bio-based
  (bsc#1093023).
- dm: rename 'bio' member of dm_io structure to 'orig_bio'
  (bsc#1093023).
- dm: remove stale comment blocks (bsc#1093023).
- dm: set QUEUE_FLAG_DAX accordingly in
  dm_table_set_restrictions() (bsc#1093023).
- dm: fix __send_changing_extent_only() to send first bio and
  chain remainder (bsc#1093023).
- dm: ensure bio-based DM's bioset and io_pool support targets'
  maximum IOs (bsc#1093023).
- dm: remove BIOSET_NEED_RESCUER based dm_offload infrastructure
  (bsc#1093023).
- dm: safely allocate multiple bioset bios (bsc#1093023).
- dm: remove unused 'num_write_bios' target interface
  (bsc#1093023).
- dm: ensure bio submission follows a depth-first tree walk
  (bsc#1093023).
- dm io: remove BIOSET_NEED_RESCUER flag from bios bioset
  (bsc#1093023).
- dm crypt: remove BIOSET_NEED_RESCUER flag (bsc#1093023).
- dm: fix comment above dm_accept_partial_bio (bsc#1093023).
- dm raid: use rs_is_raid*() (bsc#1093023).
- dm raid: simplify rs_get_progress() (bsc#1093023).
- dm raid: ensure 'a' chars during reshape (bsc#1093023).
- dm raid: stop keeping raid set frozen altogether (bsc#1093023).
- dm raid: validate current raid sets redundancy (bsc#1093023).
- dm raid: bump target version to reflect numerous fixes
  (bsc#1093023).
- dm raid: small cleanup and remove unsed "struct raid_set"
  member (bsc#1093023).
- dm raid: fix rs_get_progress() synchronization state/ratio
  (bsc#1093023).
- dm raid: avoid passing array_in_sync variable to raid_status()
  callees (bsc#1093023).
- dm raid: display a consistent copy of the MD status via
  raid_status() (bsc#1093023).
- dm raid: fix raid_resume() to keep raid set frozen as needed
  (bsc#1093023).
- dm raid: add component device size checks to avoid runtime
  failure (bsc#1093023).
- dm raid: fix raid set size revalidation (bsc#1093023).
- dm raid: correct resizing state relative to reshape space in
  ctr (bsc#1093023).
- dm raid: consume sizes after md_finish_reshape() completes
  changing them (bsc#1093023).
- dm raid: fix deadlock caused by premature md_stop_writes()
  (bsc#1093023).
- raid5-ppl: PPL support for disks with write-back cache enabled
  (bsc#1093023).
- md/r5cache: print more info of log recovery (bsc#1093023).
- md/raid1,raid10: silence warning about wait-within-wait
  (bsc#1093023).
- bcache: closures: move control bits one bit right (bsc#1093023).
- bcache: fix writeback target calc on large devices
  (bsc#1093023).
- bcache: fix misleading error message in bch_count_io_errors()
  (bsc#1093023).
- bcache: reduce cache_set devices iteration by devices_max_used
  (bsc#1093023).
- bcache: fix unmatched generic_end_io_acct() &
  generic_start_io_acct() (bsc#1093023).
- bcache: mark closure_sync() __sched (bsc#1093023).
- bcache: Fix, improve efficiency of closure_sync() (bsc#1093023).
- kabi/severities: add 'drivers/md/bcache/* PASS' for above change.
- bcache: allow quick writeback when backing idle (bsc#1093023).
- bcache: writeback: properly order backing device IO
  (bsc#1093023).
- bcache: fix wrong return value in bch_debug_init()
  (bsc#1093023).
- bcache: segregate flash only volume write streams (bsc#1093023).
- bcache: Use PTR_ERR_OR_ZERO() (bsc#1093023).
- bcache: stop writeback thread after detaching (bsc#1093023).
- bcache: ret IOERR when read meets metadata error (bsc#1093023).
- dm-crypt: don't clear bvec->bv_page in crypt_free_buffer_pages()
  (bsc#1093023).
- bcache: comment on direct access to bvec table (bsc#1093023).
- dm: limit the max bio size as BIO_MAX_PAGES * PAGE_SIZE
  (bsc#1093023).
- dm crypt: fix error return code in crypt_ctr() (bsc#1093023).
- dm crypt: wipe kernel key copy after IV initialization
  (bsc#1093023).
- dm integrity: don't store cipher request on the stack
  (bsc#1093023).
- dm crypt: fix crash by adding missing check for auth key size
  (bsc#1093023).
- dm btree: fix serious bug in btree_split_beneath()
  (bsc#1093023).
- dm thin metadata: THIN_MAX_CONCURRENT_LOCKS should be 6
  (bsc#1093023).
- dm bufio: fix shrinker scans when (nr_to_scan < retain_target)
  (bsc#1093023).
- dm: fix various targets to dm_register_target after module
  __init resources created (bsc#1093023).
- commit 6ccf1e3
* Tue Jun 12 2018 colyli@suse.de
- dm table: fix regression from improper dm_dev_internal.count
  refcount_t conversion (bsc#1093023).
- Refresh for above change,
  patches.fixes/dm-table-switch-to-readonly.
- commit 244a17e
* Tue Jun 12 2018 colyli@suse.de
- md/raid1/10: add missed blk plug (bsc#1093023).
- md: limit mdstat resync progress to max_sectors (bsc#1093023).
- md/r5cache: move mddev_lock() out of r5c_journal_mode_set()
  (bsc#1093023).
- md/raid5: correct degraded calculation in raid5_error
  (bsc#1093023).
- dm bufio: fix integer overflow when limiting maximum cache size
  (bsc#1093023).
- dm: clear all discard attributes in queue_limits when discards
  are disabled (bsc#1093023).
- dm: do not set 'discards_supported' in targets that do not
  need it (bsc#1093023).
- dm: discard support requires all targets in a table support
  discards (bsc#1093023).
- bitops: Introduce assign_bit() (bsc#1093023).
- md: free unused memory after bitmap resize (bsc#1093023).
- md: release allocated bitset sync_set (bsc#1093023).
- md/bitmap: clear BITMAP_WRITE_ERROR bit before writing it to sb
  (bsc#1093023).
- md: be cautious about using ->curr_resync_completed for
  - >recovery_offset (bsc#1093023).
- md: don't check MD_SB_CHANGE_CLEAN in md_allow_write
  (bsc#1093023).
- md: remove redundant variable q (bsc#1093023).
- raid1: remove obsolete code in raid1_write_request
  (bsc#1093023).
- md: use lockdep_assert_held (bsc#1093023).
- raid1: prevent freeze_array/wait_all_barriers deadlock
  (bsc#1093023).
- md: use TASK_IDLE instead of blocking signals (bsc#1093023).
- md: remove special meaning of ->quiesce(.., 2) (bsc#1093023).
- md: allow metadata update while suspending (bsc#1093023).
- commit aae3f35
* Tue Jun 12 2018 colyli@suse.de
- md: use mddev_suspend/resume instead of ->quiesce()
  (bsc#1093023).
- Update for above change
  patches.drivers/0003-md-cluster-Suspend-writes-in-RAID10-if-within-range.patch
  (fate#323171, bsc#1093023).
- commit 23a5e8e
* Tue Jun 12 2018 colyli@suse.de
- md: move suspend_hi/lo handling into core md code (bsc#1093023).
- md: don't call bitmap_create() while array is quiesced
  (bsc#1093023).
- md: always hold reconfig_mutex when calling mddev_suspend()
  (bsc#1093023).
- md: forbid a RAID5 from having both a bitmap and a journal
  (bsc#1093023).
- raid5: Set R5_Expanded on parity devices as well as data
  (bsc#1093023).
- md: raid10: remove a couple of redundant variables and
  initializations (bsc#1093023).
- md: rename some drivers/md/ files to have an "md-" prefix
  (bsc#1093023).
- md: raid10: remove VLAIS (bsc#1093023).
- md-cluster: make function cluster_check_sync_size static
  (bsc#1093023).
- md/bitmap: revert a patch (bsc#1093023).
- commit 7554ed8
* Tue Jun 12 2018 colyli@suse.de
- md: fix deadlock error in recent patch (bsc#1093023).
- Refresh for above change
  patches.fixes/0003-md-fix-md_write_start-deadlock-w-o-metadata-devices.patch.
- commit d173846
* Tue Jun 12 2018 colyli@suse.de
- dm cache: lift common migration preparation code to
  alloc_migration() (bsc#1093023).
- dm cache: remove usused deferred_cells member from struct cache
  (bsc#1093023).
- dm cache policy smq: allocate cache blocks in order
  (bsc#1093023).
- dm cache policy smq: change max background work from 10240 to
  4096 blocks (bsc#1093023).
- dm cache background tracker: limit amount of background work
  that may be issued at once (bsc#1093023).
- dm cache policy smq: take origin idle status into account when
  queuing writebacks (bsc#1093023).
- dm cache policy smq: handle races with queuing background_work
  (bsc#1093023).
- dm raid: fix panic when attempting to force a raid to sync
  (bsc#1093023).
- dm integrity: allow unaligned bv_offset (bsc#1093023).
- dm crypt: allow unaligned bv_offset (bsc#1093023).
- dm: small cleanup in dm_get_md() (bsc#1093023).
- dm zoned: ignore last smaller runt zone (bsc#1093023).
- dm space map metadata: use ARRAY_SIZE (bsc#1093023).
- dm log writes: add support for DAX (bsc#1093023).
- dm log writes: add support for inline data buffers
  (bsc#1093023).
- dm cache: simplify get_per_bio_data() by removing data_size
  argument (bsc#1093023).
- dm cache: remove all obsolete writethrough-specific code
  (bsc#1093023).
- dm cache: submit writethrough writes in parallel to origin
  and cache (bsc#1093023).
- dm cache: pass cache structure to mode functions (bsc#1093023).
- dm cache: fix race condition in the writeback mode overwrite_bio
  optimisation (bsc#1093023).
- dm cache: convert dm_cache_metadata.ref_count from atomic_t
  to refcount_t (bsc#1093023).
- dm: convert table_device.count from atomic_t to refcount_t
  (bsc#1093023).
- commit a328660
* Tue Jun 12 2018 colyli@suse.de
- dm: convert dm_dev_internal.count from atomic_t to refcount_t
  (bsc#1093023).
- Refresh for above change,
  patches.fixes/dm-table-switch-to-readonly.
- commit a0f5f3e
* Tue Jun 12 2018 colyli@suse.de
- locking/atomics: COCCINELLE/treewide: Convert trivial
  ACCESS_ONCE() patterns to READ_ONCE()/WRITE_ONCE()
  (bsc#1093023).
- Refresh for above change,
  patches.arch/s390-sles15-03-01-rwlock.patch.
- commit 34f3b87
* Tue Jun 12 2018 colyli@suse.de
- locking/atomics, dm-integrity: Convert ACCESS_ONCE() to
  READ_ONCE()/WRITE_ONCE() (bsc#1093023).
- dm raid: fix incorrect status output at the end of a "recover"
  process (bsc#1093023).
- dm crypt: reject sector_size feature if device length is not
  aligned to it (bsc#1093023).
- dm crypt: fix memory leak in crypt_ctr_cipher_old()
  (bsc#1093023).
- md/raid5: cap worker count (bsc#1093023).
- dm-raid: fix a race condition in request handling (bsc#1093023).
- md: fix a race condition for flush request handling
  (bsc#1093023).
- md: separate request handling (bsc#1093023).
- dm integrity: use init_completion instead of
  COMPLETION_INITIALIZER_ONSTACK (bsc#1093023).
- dm integrity: make blk_integrity_profile structure const
  (bsc#1093023).
- dm integrity: do not check integrity for failed read operations
  (bsc#1093023).
- dm log writes: fix >512b sectorsize support (bsc#1093023).
- dm log writes: don't use all the cpu while waiting to log blocks
  (bsc#1093023).
- dm ioctl: constify ioctl lookup table (bsc#1093023).
- dm integrity: count and display checksum failures (bsc#1093023).
- dm integrity: optimize writing dm-bufio buffers that are
  partially changed (bsc#1093023).
- dm rq: do not update rq partially in each ending bio
  (bsc#1093023).
- dm rq: make dm-sq requeuing behavior consistent with dm-mq
  behavior (bsc#1093023).
- md/raid0: attach correct cgroup info in bio (bsc#1093023).
- raid5: remove raid5_build_block (bsc#1093023).
- md/r5cache: call mddev_lock/unlock() in r5c_journal_mode_show
  (bsc#1093023).
- md: replace seq_release_private with seq_release (bsc#1093023).
- md/bitmap: copy correct data for bitmap super (bsc#1093023).
- dm-crypt: don't mess with BIP_BLOCK_INTEGRITY (bsc#1093023).
- commit 52a2220
* Tue Jun 12 2018 colyli@suse.de
- Refresh with upstream version
  patches.fixes/0001-md-use-a-separate-bio_set-for-synchronous-IO.patch.
- commit c20af71
* Tue Jun 12 2018 colyli@suse.de
- bio-integrity: move the bio integrity profile check earlier
  in bio_integrity_prep (bsc#1093023).
- Refresh for above change,
  patches.suse/block-replace-bi_bdev-with-a-gendisk-pointer-and-par.patch.
- commit e3db737
* Tue Jun 12 2018 colyli@suse.de
- block: Add comment to submit_bio_wait() (bsc#1093023).
- md/r5cache: fix io_unit handling in r5l_log_endio()
  (bsc#1093023).
- commit 405d1a4
* Mon Jun 11 2018 jthumshirn@suse.de
- scsi: qla2xxx: Delete session for nport id change (bsc#1077338).
- commit 91c8931
* Mon Jun 11 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-lpfc-fix-wq-cq-creation-for-older-asic-s.patch.
- commit 4c60141
* Mon Jun 11 2018 ohering@suse.de
- hv_netvsc: Fix a network regression after ifdown/ifup (bsc#1094420).
- commit 37bf478
* Mon Jun 11 2018 jthumshirn@suse.de
- s390/zcrypt: Fix CCA and EP11 CPRB processing failure memory
  leak (bnc#1096753, LTC#168037).
- s390/archrandom: Rework arch random implementation (bnc#1096753,
  LTC#168037).
- s390/qdio: fix access to uninitialized qdio_q fields
  (bnc#1096753, LTC#168037).
- s390/cpum_sf: ensure sample frequency of perf event attributes
  is non-zero (bnc#1096753, LTC#168037).
- s390/archrandom: Reconsider s390 arch random implementation
  (bnc#1096753, LTC#168037).
- commit 1f5f124
* Mon Jun 11 2018 jthumshirn@suse.de
- scsi: sg: allocate with __GFP_ZERO in sg_build_indirect()
  (bsc#1096728 CVE-2018-1000204).
- commit 36bd58c
* Fri Jun  8 2018 mcgrof@suse.com
- blacklist.conf: blacklist tools specific change bsc#1085941
- commit ed8a770
* Fri Jun  8 2018 mcgrof@suse.com
- firmware: provide helpers for registering the syfs loader
  (bsc#1085937).
- commit 3adefef
* Fri Jun  8 2018 mcgrof@suse.com
- firmware: fix capturing errors on fw_cache_init() on early init
  (bsc#1085937).
- commit 70c4a7b
* Fri Jun  8 2018 mcgrof@suse.com
- firmware: always enable the reboot notifier (bsc#1085937).
- commit 1871033
* Fri Jun  8 2018 mcgrof@suse.com
- firmware: share fw fallback killing on reboot/suspend
  (bsc#1085937).
- commit 56fccb7
* Fri Jun  8 2018 mcgrof@suse.com
- firmware: move kill_requests_without_uevent() up above
  (bsc#1085937).
- commit 94ab276
* Fri Jun  8 2018 mcgrof@suse.com
- firmware: add helper to unregister pm ops (bsc#1085937).
- commit 1e37b1e
* Fri Jun  8 2018 mcgrof@suse.com
- firmware: fix detecting error on register_reboot_notifier()
  (bsc#1085936).
- commit 0e1bbe6
* Fri Jun  8 2018 mcgrof@suse.com
- blacklist.conf: add tools commits to blacklist
- commit 2de7366
* Fri Jun  8 2018 mcgrof@suse.com
- blacklist.conf: blacklist further commits not needed (bsc#1085933,
  bsc#1085938, bsc#1085939)
- commit 77e477f
* Fri Jun  8 2018 mcgrof@suse.com
- blacklist.conf: blacklist 3a0b3bbbff0f
  This will not be backported as we don't use rcutorture on selftetsts.
- commit debceb0
* Fri Jun  8 2018 mbenes@suse.cz
- powerpc/livepatch: Fix build error with kprobes disabled
  (bsc#1071995 fate#323487).
- commit 74a0947
* Fri Jun  8 2018 mbenes@suse.cz
- Refresh
  patches.suse/powerpc-livepatch-implement-reliable-stack-tracing-for-the-consistency-model.patch.
- commit 5218a66
* Fri Jun  8 2018 vbabka@suse.cz
- mm, page_alloc: do not break __GFP_THISNODE by zonelist reset
  (bsc#1079152, VM Functionality).
- commit e7f5d20
* Fri Jun  8 2018 tiwai@suse.de
- ALSA: hda/realtek - Fixup for HP x360 laptops with B&O speakers
  (bsc#1096705).
- ALSA: hda/realtek - Refactor alc269_fixup_hp_mute_led_mic*()
  (bsc#1096705).
- ALSA: hda/realtek - Fixup mute led on HP Spectre x360
  (bsc#1096705).
- commit 16e47dd
* Fri Jun  8 2018 tiwai@suse.de
- ALSA: hda/ca0132: constify parameter table for effects
  (bsc#1096696).
- ALSA: hda/ca0132: merge strings just for printk (bsc#1096696).
- ALSA: hda/ca0132: constify read-only members of string array
  (bsc#1096696).
- ALSA: hda/ca0132: constify templates for control element set
  (bsc#1096696).
- ALSA: hda/ca0132: fix array_size.cocci warnings (bsc#1096696).
- ALSA: hda/ca0132: Add new control changes for SBZ + R3Di
  (bsc#1096696).
- ALSA: hda/ca0132: add ca0132_alt_set_vipsource (bsc#1096696).
- ALSA: hda/ca0132: Add DSP Volume set and New mixers for SBZ +
  R3Di (bsc#1096696).
- ALSA: hda/ca0132: add alt_select_in/out for R3Di + SBZ
  (bsc#1096696).
- ALSA: hda/ca0132: add the ability to set src_id on scp commands
  (bsc#1096696).
- ALSA: hda/ca0132: Add dsp setup + gpio functions for r3di
  (bsc#1096696).
- ALSA: hda/ca0132: add dsp setup related commands for the sbz
  (bsc#1096696).
- ALSA: hda/ca0132: update core functions for sbz + r3di
  (bsc#1096696).
- ALSA: hda/ca0132: add extra init functions for r3di + sbz
  (bsc#1096696).
- ALSA: hda/ca0132: Add extra exit functions for R3Di and SBZ
  (bsc#1096696).
- ALSA: hda/ca0132: Add PCI region2 iomap for SBZ (bsc#1096696).
- ALSA: hda/ca0132: Add pincfg for SBZ + R3Di, add fp hp
  auto-detect (bsc#1096696).
- ALSA: hda/ca0132: R3Di and SBZ quirk entires + alt firmware
  loading (bsc#1096696).
- commit 720c517
* Fri Jun  8 2018 tiwai@suse.de
- ALSA: usx2y: Fix invalid stream URBs (bsc#1051510).
- ALSA: caiaq: Add yet more sanity checks for invalid EPs
  (bsc#1051510).
- ALSA: usx2y: Add sanity checks for invalid EPs (bsc#1051510).
- commit 2ba7058
* Fri Jun  8 2018 tiwai@suse.de
- ALSA: hda - Handle kzalloc() failure in
  snd_hda_attach_pcm_stream() (bsc#1051510).
- ALSA: hda: Add Intel NUC5i7RY to the power_save blacklist
  (bsc#1051510).
- ALSA: hda: Add ASRock H81M-HDS to the power_save blacklist
  (bsc#1051510).
- ALSA: hda: Add Gigabyte P55A-UD3 and Z87-D3HP to the power_save
  blacklist (bsc#1051510).
- ALSA: hda: Add Clevo W35xSS_370SS to the power_save blacklist
  (bsc#1051510).
- ALSA: hda: Add Intel NUC7i3BNB to the power_save blacklist
  (bsc#1051510).
- ALSA: hda/realtek - Clevo P950ER ALC1220 Fixup (bsc#1051510).
- commit cc2998f
* Fri Jun  8 2018 mkubecek@suse.cz
- bpf: fix bpf_skb_adjust_net/bpf_skb_proto_xlat to deal with
  gso sctp skbs (bsc#1076830).
- l2tp: do not accept arbitrary sockets (bsc#1076830).
- netfilter: use skb_to_full_sk in ip6_route_me_harder
  (bsc#1076830).
- rds: Incorrect reference counting in TCP socket creation
  (bsc#1076830).
- tcp: revert F-RTO middle-box workaround (bsc#1076830).
- ip_gre: fix IFLA_MTU ignored on NEWLINK (bsc#1076830).
- vti: fix use after free in vti_tunnel_xmit/vti6_tnl_xmit
  (bsc#1076830).
- commit 413a62a
* Fri Jun  8 2018 mkubecek@suse.cz
- refresh sorted section
- update ustream references:
  patches.arch/powerpc-64-Use-barrier_nospec-in-syscall-entry.patch.
  patches.arch/powerpc-64-kexec-fix-race-in-kexec-when-XIVE-is-shut.patch.
  patches.arch/powerpc-64s-Add-barrier_nospec.patch.
  patches.arch/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch.
  patches.arch/powerpc-64s-Enable-barrier_nospec-based-on-firmware-.patch.
  patches.arch/powerpc-64s-Patch-barrier_nospec-in-modules.patch.
  patches.arch/powerpc-Use-barrier_nospec-in-copy_from_user.patch.
  patches.arch/powerpc-fadump-Do-not-use-hugepages-when-fadump-is-a.patch.
  patches.arch/powerpc-fadump-exclude-memory-holes-while-reserving-.patch.
  patches.arch/powerpc-xive-fix-hcall-H_INT_RESET-to-support-long-b.patch.
  patches.arch/powerpc-xive-prepare-all-hcalls-to-support-long-busy.patch.
  patches.arch/powerpc-xive-shutdown-XIVE-when-kexec-or-kdump-is-pe.patch.
  patches.arch/powerpc-xmon-Also-setup-debugger-hooks-when-single-stepping.patch.
  patches.arch/powerpc64-ftrace-Add-a-field-in-paca-to-disable-ftra.patch.
  patches.arch/powerpc64-ftrace-Add-helpers-to-hard-disable-ftrace.patch.
  patches.arch/powerpc64-ftrace-Delay-enabling-ftrace-on-secondary-.patch.
  patches.arch/powerpc64-ftrace-Disable-ftrace-during-hotplug.patch.
  patches.arch/powerpc64-ftrace-Disable-ftrace-during-kvm-entry-exi.patch.
  patches.arch/powerpc64-ftrace-Rearrange-ifdef-sections-in-ftrace..patch.
  patches.arch/powerpc64-kexec-Hard-disable-ftrace-before-switching.patch.
  patches.arch/powerpc64-module-Tighten-detection-of-mcount-call-si.patch.
  patches.suse/powerpc-64s-Enhance-the-information-in-cpu_show_spec.patch.
- commit 6b2c486
* Fri Jun  8 2018 jslaby@suse.cz
- ipv6: sr: fix TLVs not being copied using setsockopt
  (networking-stable-18_01_12).
- 8021q: fix a memory leak for VLAN 0 device
  (networking-stable-18_01_12).
- net: core: fix module type in sock_diag_bind
  (networking-stable-18_01_12).
- sctp: fix the handling of ICMP Frag Needed for too small MTUs
  (networking-stable-18_01_12).
- sctp: do not retransmit upon FragNeeded if PMTU discovery is
  disabled (networking-stable-18_01_12).
- sh_eth: fix SH7757 GEther initialization
  (networking-stable-18_01_12).
- net: fec: free/restore resource in related probe error pathes
  (networking-stable-18_01_12).
- sh_eth: fix TSU resource handling (networking-stable-18_01_12).
- net: stmmac: enable EEE in MII, GMII or RGMII only
  (networking-stable-18_01_12).
- net: fec: defer probe if regulator is not ready
  (networking-stable-18_01_12).
- net: fec: restore dev_id in the cases of probe error
  (networking-stable-18_01_12).
- ethtool: do not print warning for applications using legacy API
  (networking-stable-18_01_12).
- mlxsw: spectrum: Relax sanity checks during enslavement
  (networking-stable-18_01_12).
- mlxsw: spectrum_router: Fix NULL pointer deref
  (networking-stable-18_01_12).
- commit 072d5d2
* Fri Jun  8 2018 wqu@suse.com
- objtool, perf: Fix GCC 8 -Wrestrict error (Fix gcc 8 restrict
  error).
- tools/lib/subcmd/pager.c: do not alias select() params (Fix
  gcc 8 restrict error).
- commit 83717be
* Thu Jun  7 2018 msuchanek@suse.de
- scsi: cxlflash: Isolate external module dependencies
  (FATE#325192).
- scsi: cxlflash: Abstract hardware dependent assignments
  (FATE#325192).
- scsi: cxlflash: Add include guards to backend.h (FATE#325192).
- scsi: cxlflash: Use local mutex for AFU serialization
  (FATE#325192).
- scsi: cxlflash: Acquire semaphore before invoking ioctl services
  (FATE#325192).
- scsi: cxlflash: Limit the debug logs in the IO path
  (FATE#325192).
- scsi: cxlflash: Yield to active send threads (FATE#325192).
- scsi: cxlflash: Handle spurious interrupts (FATE#325192).
- scsi: cxlflash: Remove commmands from pending list on timeout
  (FATE#325192).
- scsi: cxlflash: Synchronize reset and remove ops (FATE#325192).
- scsi: cxlflash: Enable OCXL operations (FATE#325192).
- scsi: cxlflash: Support AFU reset (FATE#325192).
- scsi: cxlflash: Register for translation errors (FATE#325192).
- scsi: cxlflash: Introduce OCXL context state machine
  (FATE#325192).
- scsi: cxlflash: Update synchronous interrupt status bits
  (FATE#325192).
- scsi: cxlflash: Setup LISNs for master contexts (FATE#325192).
- scsi: cxlflash: Setup LISNs for user contexts (FATE#325192).
- scsi: cxlflash: Introduce object handle fop (FATE#325192).
- scsi: cxlflash: Support file descriptor mapping (FATE#325192).
- scsi: cxlflash: Support adapter context mmap and release
  (FATE#325192).
- scsi: cxlflash: Support adapter context reading (FATE#325192).
- scsi: cxlflash: Support adapter context polling (FATE#325192).
- scsi: cxlflash: Support starting user contexts (FATE#325192).
- scsi: cxlflash: Support AFU interrupt mapping and registration
  (FATE#325192).
- scsi: cxlflash: Support AFU interrupt management (FATE#325192).
- scsi: cxlflash: Support process element lifecycle (FATE#325192).
- scsi: cxlflash: Setup OCXL transaction layer (FATE#325192).
- scsi: cxlflash: Setup function OCXL link (FATE#325192).
- scsi: cxlflash: Support reading adapter VPD data (FATE#325192).
- scsi: cxlflash: Support AFU state toggling (FATE#325192).
- scsi: cxlflash: Support process specific mappings (FATE#325192).
- scsi: cxlflash: Support starting an adapter context
  (FATE#325192).
- scsi: cxlflash: MMIO map the AFU (FATE#325192).
- scsi: cxlflash: Support image reload policy modification
  (FATE#325192).
- scsi: cxlflash: Support adapter context discovery (FATE#325192).
- scsi: cxlflash: Support adapter file descriptors for OCXL
  (FATE#325192).
- scsi: cxlflash: Use IDR to manage adapter contexts
  (FATE#325192).
- scsi: cxlflash: Adapter context support for OCXL (FATE#325192).
- scsi: cxlflash: Setup AFU PASID (FATE#325192).
- scsi: cxlflash: Setup AFU acTag range (FATE#325192).
- scsi: cxlflash: Read host AFU configuration (FATE#325192).
- scsi: cxlflash: Setup function acTag range (FATE#325192).
- scsi: cxlflash: Read host function configuration (FATE#325192).
- scsi: cxlflash: Hardware AFU for OCXL (FATE#325192).
- scsi: cxlflash: Introduce OCXL backend (FATE#325192).
- scsi: cxlflash: Add argument identifier names (FATE#325192).
- scsi: cxlflash: Avoid clobbering context control register value
  (FATE#325192).
- scsi: cxlflash: Preserve number of interrupts for master
  contexts (FATE#325192).
- scsi: cxlflash: Staging to support future accelerators
  (FATE#325192).
- scsi: cxlflash: Adapter context init can return error
  (FATE#325192).
- scsi: cxlflash: Remove embedded CXL work structures
  (FATE#325192).
- scsi: cxlflash: Explicitly cache number of interrupts per
  context (FATE#325192).
- scsi: cxlflash: Update cxl-specific arguments to generic cookie
  (FATE#325192).
- commit 69ce72c
* Thu Jun  7 2018 oneukum@suse.com
- usbip: usbip_host: fix bad unlock balance during stub_probe()
  (bsc#1096480).
- commit 19a6a6f
* Thu Jun  7 2018 oneukum@suse.com
- usbip: usbip_host: fix NULL-ptr deref and use-after-free errors
  (bsc#1096480).
- commit 946c4ab
* Thu Jun  7 2018 oneukum@suse.com
- usbip: usbip_host: run rebind from exit when module is removed
  (bsc#1096480).
- commit 2af8d93
* Thu Jun  7 2018 oneukum@suse.com
- usbip: usbip_host: delete device from busid_table after rebind
  (bsc#1096480).
- commit ce8aa81
* Thu Jun  7 2018 oneukum@suse.com
- usbip: usbip_host: fix to hold parent lock for device_attach()
  calls (bsc#1096480).
- commit f09fb5d
* Thu Jun  7 2018 oneukum@suse.com
- USB:fix USB3 devices behind USB3 hubs not resuming at hibernate
  thaw (bsc#1090888).
- commit 5b0d550
* Thu Jun  7 2018 oneukum@suse.com
- usb: core: Add quirk for HP v222w 16GB Mini (bsc#1090888).
- USB: serial: pl2303: new device id for Chilitag (bsc#1087092).
- commit ae105f8
* Thu Jun  7 2018 oneukum@suse.com
- USB: serial: simple: add Motorola Tetra driver (bsc#1087092).
- commit bac2d92
* Thu Jun  7 2018 mgorman@suse.de
- mm: fix the NULL mapping case in __isolate_lru_page()
  (bnc#971975 VM -- git fixes).
- commit 49e56df
* Thu Jun  7 2018 oneukum@suse.com
- NET: usb: qmi_wwan: add support for ublox R410M PID 0x90b2
  (bsc#1090888).
- commit 831f20c
* Thu Jun  7 2018 oneukum@suse.com
- net/usb/qmi_wwan.c: Add USB id for lt4120 modem (bsc#1087092).
- commit a542d6f
* Thu Jun  7 2018 oneukum@suse.com
- blacklist.conf: fix for 32bit only
- commit d4d6158
* Thu Jun  7 2018 oneukum@suse.com
- xhci: Fix USB ports for Dell Inspiron 5775 (bsc#1090888).
- commit 21f554a
* Thu Jun  7 2018 oneukum@suse.com
- blacklist.conf: patch changes only debug messages
- commit a0e9d38
* Thu Jun  7 2018 oneukum@suse.com
- xhci: zero usb device slot_id member when disabling and freeing
  a xhci slot (bsc#1090888).
- commit d1a948e
* Thu Jun  7 2018 jslaby@suse.cz
- ip6_tunnel: disable dst caching if tunnel is dual-stack
  (networking-stable-18_01_12).
- mlxsw: spectrum_router: Simplify a piece of code
  (networking-stable-18_01_12).
- commit ca8f732
* Thu Jun  7 2018 jslaby@suse.cz
- mlxsw: spectrum: Forbid linking to devices that have uppers FIX
  (stable-fixes).
- commit b0f5584
* Thu Jun  7 2018 mkubecek@suse.cz
- ipv6: omit traffic class when calculating flow hash
  (bsc#1095042).
- commit 6cd0f9a
* Thu Jun  7 2018 mkubecek@suse.cz
- Refresh sorted section
- update upstream references:
  patches.drivers/ibmvnic-Check-CRQ-command-return-codes.patch
  patches.drivers/ibmvnic-Create-separate-initialization-routine-for-r.patch
  patches.drivers/ibmvnic-Handle-error-case-when-setting-link-state.patch
  patches.drivers/ibmvnic-Introduce-active-CRQ-state.patch
  patches.drivers/ibmvnic-Introduce-hard-reset-recovery.patch
  patches.drivers/ibmvnic-Mark-NAPI-flag-as-disabled-when-released.patch
  patches.drivers/ibmvnic-Return-error-code-if-init-interrupted-by-tra.patch
  patches.drivers/ibmvnic-Set-resetting-state-at-earliest-possible-poi.patch
- commit 97cb00f
* Thu Jun  7 2018 tiwai@suse.de
- blacklist.conf: Add entry for ALSA core change in 4.18-rc1
- commit 143726f
* Thu Jun  7 2018 tiwai@suse.de
- drm/exynos: Fix default value for zpos plane property
  (bsc#1051510).
- drm/exynos/dsi: mask frame-done interrupt (bsc#1051510).
- drm/i915: Don't request a bug report for unsafe module
  parameters (bsc#1051510).
- drm/exynos: Allow DRM_EXYNOS on s5pv210 (bsc#1051510).
- commit 206e486
* Thu Jun  7 2018 tiwai@suse.de
- iwlwifi: fix non_shared_ant for 9000 devices (bsc#1051510).
- iwlwifi: mvm: fix race in queue notification wait (bsc#1051510).
- iwlwifi: mvm: honor the max_amsdu_subframes limit (bsc#1051510).
- iwlwifi: mvm: fix TSO with highly fragmented SKBs (bsc#1051510).
- iwlmvm: tdls: Check TDLS channel switch support (bsc#1051510).
- ath10k: search all IEs for variant before falling back
  (bsc#1051510).
- ath10k: correct target assert problem due to CE5 stuck
  (bsc#1051510).
- mwifiex: pcie: tighten a check in
  mwifiex_pcie_process_event_ready() (bsc#1051510).
- commit ed01b8d
* Thu Jun  7 2018 tiwai@suse.de
- ASoC: omap: Remove OMAP_MUX dependency from Nokia N810 audio
  support (bsc#1051510).
- ALSA: hda/realtek - Enable mic-mute hotkey for several Lenovo
  AIOs (bsc#1051510).
- ALSA: hda/ca0132: fix build failure when a local macro is
  defined (bsc#1051510).
- commit d28606d
* Thu Jun  7 2018 tiwai@suse.de
- Move btusb patch to upstream sorted section
- commit 46f18a1
* Thu Jun  7 2018 ghe@suse.com
- dlm: remove O_NONBLOCK flag in sctp_connect_to_sock
  (bsc#1080542).
- commit 33c1136
* Thu Jun  7 2018 ghe@suse.com
- dlm: make sctp_connect_to_sock() return in specified time
  (bsc#1080542).
- commit 4f3fe6a
* Thu Jun  7 2018 ghe@suse.com
- dlm: fix a clerical error when set SCTP_NODELAY (bsc#1091594).
- commit 9f84e4d
* Wed Jun  6 2018 mgorman@suse.de
- mremap: Remove LATENCY_LIMIT from mremap to reduce the number
  of TLB shootdowns (bnc#1095115).
- commit b11f786
* Wed Jun  6 2018 tiwai@suse.de
- Move HD-audio and USB-audio patches to sorted section
  They've merged to 4.18-rc1 upstream
- commit cfd715d
* Wed Jun  6 2018 jack@suse.cz
- blacklist.conf: Blacklist 8a2b307c21
- commit 43a6f85
* Wed Jun  6 2018 jack@suse.cz
- blacklist.conf: Blacklist e254d1afac83
- commit 551f89f
* Wed Jun  6 2018 jack@suse.cz
- rpm/config.sh: Fixup BUGZILLA_PRODUCT variable
- commit 5129d49
* Wed Jun  6 2018 jack@suse.cz
- Update tags in
  patches.fixes/ext4-Fix-hole-length-detection-in-ext4_ind_map_block.patch.
- commit a589549
* Wed Jun  6 2018 tiwai@suse.de
- media: lgdt3306a: Fix a double kfree on i2c device remove
  (bsc#1051510).
- media: lgdt3306a: Fix module count mismatch on usb unplug
  (bsc#1051510).
- commit 9b281a7
* Wed Jun  6 2018 tiwai@suse.de
- media: cx23885: Override 888 ImpactVCBe crystal frequency
  (bsc#1051510).
- media: cx23885: Set subdev host data to clk_freq pointer
  (bsc#1051510).
- media: em28xx: Add Hauppauge SoloHD/DualHD bulk models
  (bsc#1051510).
- media: em28xx: USB bulk packet size fix (bsc#1051510).
- media: dmxdev: fix error code for invalid ioctls (bsc#1051510).
- commit 12ffd09
* Wed Jun  6 2018 jslaby@suse.cz
- kABI: protect struct ipv6_pinfo (kabi).
- commit a562dc4
* Wed Jun  6 2018 jslaby@suse.cz
- net: igmp: add a missing rcu locking section (git-fixes).
- ipv6: Fix getsockopt() for sockets with default
  IPV6_AUTOFLOWLABEL (git-fixes).
- net: igmp: fix source address check for IGMPv3 reports
  (git-fixes).
- commit c29e781
* Wed Jun  6 2018 jslaby@suse.cz
- netlink: put module reference if dump start fails (git-fixes).
- sctp: use right member as the param of list_for_each_entry
  (git-fixes).
- commit 02cc0e2
* Wed Jun  6 2018 jslaby@suse.cz
- tipc: fix hanging poll() for stream sockets
  (networking-stable-17_12_31).
- net: fec: unmap the xmit buffer that are not transferred by DMA
  (networking-stable-17_12_31).
- RDS: Check cmsg_len before dereferencing CMSG_DATA
  (networking-stable-17_12_31).
- net: phy: micrel: ksz9031: reconfigure autoneg after phy
  autoneg workaround (networking-stable-17_12_31).
- ip6_gre: fix device features for ioctl setup
  (networking-stable-17_12_31).
- net: reevalulate autoflowlabel setting after sysctl setting
  (networking-stable-17_12_31).
- ipv4: Fix use-after-free when flushing FIB tables
  (networking-stable-17_12_31).
- net: bridge: fix early call to br_stp_change_bridge_id and
  plug newlink leaks (networking-stable-17_12_31).
- net: phy: marvell: Limit 88m1101 autoneg errata to 88E1145 as
  well (networking-stable-17_12_31).
- sock: free skb in skb_complete_tx_timestamp on error
  (networking-stable-17_12_31).
- mlxsw: spectrum: Disable MAC learning for ovs port
  (networking-stable-17_12_31).
- net: igmp: Use correct source address on IGMPv3 reports
  (networking-stable-17_12_31).
- ipv6: mcast: better catch silly mtu values
  (networking-stable-17_12_31).
- ptr_ring: add barriers (networking-stable-17_12_31).
- tcp_bbr: reset long-term bandwidth sampling on loss recovery
  undo (networking-stable-17_12_31).
- tcp_bbr: reset full pipe detection on loss recovery undo
  (networking-stable-17_12_31).
- tcp_bbr: record "full bw reached" decision in new
  full_bw_reached bit (networking-stable-17_12_31).
- adding missing rcu_read_unlock in ipxip6_rcv
  (networking-stable-17_12_31).
- net: mvmdio: disable/unprepare clocks in EPROBE_DEFER case
  (networking-stable-17_12_31).
- net: dsa: bcm_sf2: Clear IDDQ_GLOBAL_PWR bit for PHY
  (networking-stable-17_12_31).
- commit db31b88
* Wed Jun  6 2018 nborisov@suse.com
- f2fs: fix a panic caused by NULL flush_cmd_control (bsc#1086400).
- commit b95c39c
* Wed Jun  6 2018 jslaby@suse.cz
- kABI: protect tap_create_cdev (kabi).
- commit d6151ad
* Wed Jun  6 2018 bpoirier@suse.com
- Empty out-of-tree section
  Tags were updated for the simple cases. Others are moved to subsystem
  appropriate sections after the sorted section.
- scsi: qla2xxx: Add FC-NVMe abort processing (bsc#1084570).
- scsi: qla2xxx: Add changes for devloss timeout in driver
  (bsc#1084570).
- scsi: qla2xxx: Cleanup code to improve FC-NVMe error handling
  (bsc#1084570).
- scsi: qla2xxx: Fix Async GPN_FT for FCP and FC-NVMe scan
  (bsc#1084570).
- scsi: qla2xxx: Fix FC-NVMe IO abort during driver reset
  (bsc#1084570).
- scsi: qla2xxx: Fix n2n_ae flag to prevent dev_loss on PDB change
  (bsc#1084570).
- scsi: qla2xxx: Fix retry for PRLI RJT with reason of BUSY
  (bsc#1084570).
- scsi: qla2xxx: Remove nvme_done_list (bsc#1084570).
- scsi: qla2xxx: Remove unneeded message and minor cleanup for
  FC-NVMe (bsc#1084570).
- scsi: qla2xxx: Restore ZIO threshold setting (bsc#1084570).
- scsi: qla2xxx: Return busy if rport going away (bsc#1084570).
- scsi: qla2xxx: Set IIDMA and fcport state before
  qla_nvme_register_remote() (bsc#1084570).
- scsi: qla2xxx: Update driver version to 10.00.00.06-k
  (bsc#1084570).
- ext4: fix hole length detection in ext4_ind_map_blocks()
  (bsc#1090953).
- ext4: fix offset overflow on 32-bit archs in ext4_iomap_begin()
  (bsc#1079747).
- commit 4eed96d
* Wed Jun  6 2018 dchang@suse.com
- be2net: Fix error detection logic for BE3 (bsc#1050252
  FATE#322920).
- commit 2961002
* Tue Jun  5 2018 bp@suse.de
- KVM/VMX: Expose SSBD properly to guests (bsc#1087082
  CVE-2018-3639).
- commit 605f9fd
* Tue Jun  5 2018 bp@suse.de
- kvm: x86: IA32_ARCH_CAPABILITIES is always supported
  (bsc#1087082 CVE-2018-3639).
- commit b26e2f7
* Tue Jun  5 2018 rgoldwyn@suse.com
- ovl: fix lookup with middle layer opaque dir and absolute path
  redirects (bsc#1090605).
- ovl: Return -ENOMEM if an allocation fails ovl_lookup()
  (bsc#1096065).
- commit b8d2af2
* Tue Jun  5 2018 bp@suse.de
- kabi: Fix kvm kABI (bsc#1087082 CVE-2018-3639).
- commit d619bbf
* Tue Jun  5 2018 rgoldwyn@suse.com
- apparmor: fix memory leak on buffer on error exit path
  (bsc#1095893).
- apparmor: fix logging of the existence test for signals
  (bsc#1095893).
- apparmor: fix dangling symlinks to policy rawdata after
  replacement (bsc#1095893).
- apparmor: fix display of .ns_name for containers (bsc#1095893).
- commit 322e0cf
* Tue Jun  5 2018 tiwai@suse.de
- ACPICA: Events: add a return on failure from
  acpi_hw_register_read (bsc#1051510).
- ACPICA: Fix memory leak on unusual memory leak (bsc#1051510).
- ACPICA: acpi: acpica: fix acpi operand cache leak in nseval.c
  (bsc#1051510).
- commit f7ec8c5
* Tue Jun  5 2018 tiwai@suse.de
- ACPI / button: make module loadable when booted in non-ACPI mode
  (bsc#1051510).
- ACPI: acpi_pad: Fix memory leak in power saving threads
  (bsc#1051510).
- ACPI: processor_perflib: Do not send _PPC change notification
  if not ready (bsc#1051510).
- ACPI / scan: Use acpi_bus_get_status() to initialize
  ACPI_TYPE_DEVICE devs (bsc#1051510).
- ACPI / bus: Do not call _STA on battery devices with unmet
  dependencies (bsc#1051510).
- commit 3422612
* Tue Jun  5 2018 bp@suse.de
- x86/bugs: Rename SSBD_NO to SSB_NO (bsc#1087082 CVE-2018-3639).
- KVM: SVM: Implement VIRT_SPEC_CTRL support for SSBD (bsc#1087082
  CVE-2018-3639).
- x86/speculation, KVM: Implement support for
  VIRT_SPEC_CTRL/LS_CFG (bsc#1087082 CVE-2018-3639).
- x86/bugs: Rework spec_ctrl base and mask logic (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Remove x86_spec_ctrl_set() (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Expose x86_spec_ctrl_base directly (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Unify x86_spec_ctrl_{set_guest,restore_host}
  (bsc#1087082 CVE-2018-3639).
- x86/speculation: Rework speculative_store_bypass_update()
  (bsc#1087082 CVE-2018-3639).
- x86/speculation: Add virtualized speculative store bypass
  disable support (bsc#1087082 CVE-2018-3639).
- x86/bugs, KVM: Extend speculation control for VIRT_SPEC_CTRL
  (bsc#1087082 CVE-2018-3639).
- x86/speculation: Handle HT correctly on AMD (bsc#1087082
  CVE-2018-3639).
- x86/cpufeatures: Add FEATURE_ZEN (bsc#1087082 CVE-2018-3639).
- x86/cpufeatures: Disentangle SSBD enumeration (bsc#1087082
  CVE-2018-3639).
- x86/cpufeatures: Disentangle MSR_SPEC_CTRL enumeration from IBRS
  (bsc#1087082 CVE-2018-3639).
- x86/speculation: Use synthetic bits for IBRS/IBPB/STIBP
  (bsc#1087082 CVE-2018-3639).
- x86/bugs: Fix the parameters alignment and missing void
  (bsc#1087082 CVE-2018-3639).
- x86/bugs: Make cpu_show_common() static (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Fix __ssb_select_mitigation() return type (bsc#1087082
  CVE-2018-3639).
- commit f950281
* Tue Jun  5 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-64s-Add-support-for-a-store-forwarding-barri.patch.
- commit a862707
* Tue Jun  5 2018 tiwai@suse.de
- Revert "rt2800: use TXOP_BACKOFF for probe frames"
  (bsc#1051510).
- commit 40efa74
* Tue Jun  5 2018 tiwai@suse.de
- r8169: fix powering up RTL8168h (bsc#1051510).
- r8169: fix setting driver_data after register_netdev
  (bsc#1051510).
- commit 61dd159
* Tue Jun  5 2018 tiwai@suse.de
- mac80211: drop frames with unexpected DS bits from fast-rx to
  slow path (bsc#1051510).
- mac80211: Fix sending ADDBA response for an ongoing session
  (bsc#1051510).
- mac80211: Do not disconnect on invalid operating class
  (bsc#1051510).
- mac80211: round IEEE80211_TX_STATUS_HEADROOM up to multiple of 4
  (bsc#1051510).
- mac80211: mesh: fix wrong mesh TTL offset calculation
  (bsc#1051510).
- commit 2171580
* Tue Jun  5 2018 tiwai@suse.de
- drm/i915: Disable LVDS on Radiant P845 (bsc#1051510).
- drm/amd/powerplay: Fix enum mismatch (bsc#1051510).
- commit 8db260d
* Tue Jun  5 2018 tiwai@suse.de
- ASoC: Intel: sst: remove redundant variable dma_dev_name
  (bsc#1051510).
- commit c43b27a
* Tue Jun  5 2018 tiwai@suse.de
- Input: elan_i2c_smbus - fix corrupted stack (bsc#1051510).
- Input: synaptics - add Lenovo 80 series ids to SMBus
  (bsc#1051510).
- Input: synaptics - add Intertouch support on X1 Carbon 6th
  and X280 (bsc#1051510).
- Input: synaptics - Lenovo Thinkpad X1 Carbon G5 (2017) with
  Elantech trackpoints should use RMI (bsc#1051510).
- Input: synaptics - Lenovo Carbon X1 Gen5 (2017) devices should
  use RMI (bsc#1051510).
- commit 12d3278
* Tue Jun  5 2018 tiwai@suse.de
- drm/psr: Fix missed entry in PSR setup time table (bsc#1051510).
- drm/i915/lvds: Move acpi lid notification registration to
  registration phase (bsc#1051510).
- intel_th: Use correct device when freeing buffers (bsc#1051510).
- drm/i915/userptr: reject zero user_size (bsc#1051510).
- crypto: caam - fix incorrect define (bsc#1051510).
- commit c659f07
* Tue Jun  5 2018 jslaby@suse.cz
- net: remove hlist_nulls_add_tail_rcu()
  (networking-stable-17_12_12).
- tipc: fix memory leak in tipc_accept_from_sock()
  (networking-stable-17_12_12).
- stmmac: reset last TSO segment size after device open
  (networking-stable-17_12_12).
- sit: update frag_off info (networking-stable-17_12_12).
- net: realtek: r8169: implement set_link_ksettings()
  (networking-stable-17_12_12).
- commit df7b21a
* Tue Jun  5 2018 tiwai@suse.de
- kabi/severities: Ignore kABI incompatibility for meson drm
  The symbols are used only between meson modules, so mostly internal.
- commit c4375de
* Tue Jun  5 2018 jslaby@suse.cz
- net/sctp: Always set scope_id in sctp_inet6_skb_msgname
  (networking-stable-17_11_20).
- fealnx: Fix building error on MIPS (networking-stable-17_11_20).
- vxlan: fix the issue that neigh proxy blocks all icmpv6 packets
  (networking-stable-17_11_20).
- af_netlink: ensure that NLMSG_DONE never fails in dumps
  (networking-stable-17_11_20).
- vlan: fix a use-after-free in vlan_device_event()
  (networking-stable-17_11_20).
- qmi_wwan: Add missing skb_reset_mac_header-call
  (networking-stable-17_11_20).
- bonding: discard lowest hash bit for 802.3ad layer3+4
  (networking-stable-17_11_20).
- netfilter/ipvs: clear ipvs_property flag when SKB net namespace
  changed (networking-stable-17_11_20).
- net: systemport: Correct IPG length settings
  (networking-stable-17_11_20).
- tcp_nv: fix division by zero in tcpnv_acked()
  (networking-stable-17_11_20).
- commit 5de7a3f
* Tue Jun  5 2018 tiwai@suse.de
- drm: rcar-du: lvds: Fix LVDS startup on R-Car Gen3
  (bsc#1051510).
- drm: rcar-du: lvds: Fix LVDS startup on R-Car Gen2
  (bsc#1051510).
- drm/meson: Fix some error handling paths in
  'meson_drv_bind_master()' (bsc#1051510).
- drm/meson: Fix an un-handled error path in
  'meson_drv_bind_master()' (bsc#1051510).
- drm/rockchip: Respect page offset for PRIME mmap calls
  (bsc#1051510).
- drm/imx: move arming of the vblank event to atomic_flush
  (bsc#1051510).
- drm/tegra: Shutdown on driver unbind (bsc#1051510).
- drm/sun4i: Fix dclk_set_phase (bsc#1051510).
- drm/meson: fix vsync buffer update (bsc#1051510).
- drm/exynos: fix comparison to bitshift when dealing with a mask
  (bsc#1051510).
- drm/exynos: g2d: use monotonic timestamps (bsc#1051510).
- commit 9cb4eb7
* Tue Jun  5 2018 tiwai@suse.de
- ASoC: topology: create TLV data for dapm widgets (bsc#1051510).
- ASoC: samsung: odroid: Fix 32000 sample rate handling
  (bsc#1051510).
- ASoC: samsung: odroid: Drop requirement of clocks in the sound
  node (bsc#1051510).
- ASoC: samsung: odroid: Fix EPLL frequency values (bsc#1051510).
- commit 98a5562
* Tue Jun  5 2018 tiwai@suse.de
- drm/amdgpu: Fix deadlock on runtime suspend (bsc#1051510).
- blacklist.conf: Remove the entry
- commit 8b2b629
* Tue Jun  5 2018 tiwai@suse.de
- drm/radeon: Fix deadlock on runtime suspend (bsc#1051510).
- blacklist.conf: Remove the entry
- commit 35caacb
* Tue Jun  5 2018 tiwai@suse.de
- drm/nouveau: Fix deadlock on runtime suspend (bsc#1051510).
- blacklist.conf: Remove the entry
- commit 97d81e2
* Tue Jun  5 2018 tiwai@suse.de
- drm: Allow determining if current task is output poll worker
  (bsc#1051510).
- blacklist.conf: Remove the entry
- commit ecce7e0
* Tue Jun  5 2018 tiwai@suse.de
- workqueue: use put_device() instead of kfree() (bsc#1051510).
- workqueue: Allow retrieval of current task's work struct
  (bsc#1051510).
- commit aacc423
* Tue Jun  5 2018 jthumshirn@suse.de
- nvme: fix lockdep warning in nvme_mpath_clear_current_path
  (FATE#323952, FATE#322506).
- commit 320c37c
* Tue Jun  5 2018 lhenriques@suse.com
- blacklist.conf: blacklist fc218544fbc8
  This commit requires major changes from 4.17, namely commit
  b9e281c2b388 ("libceph: introduce BVECS data type")
- commit 2a0450b
* Tue Jun  5 2018 oneukum@suse.com
- xhci: fix endpoint context tracer output (bsc#1087092).
- commit 2a9b0d2
* Tue Jun  5 2018 jslaby@suse.cz
- tun/tap: sanitize TUNSETSNDBUF input
  (networking-stable-17_11_14).
- sctp: reset owner sk for data chunks on out queues when
  migrating a sock (networking-stable-17_11_14).
- tap: reference to KVA of an unloaded module causes kernel panic
  (networking-stable-17_11_14).
- ip6_gre: update dst pmtu if dev mtu has been updated by toobig
  in __gre6_xmit (networking-stable-17_11_14).
- ip6_gre: only increase err_count for some certain type icmpv6
  in ip6gre_err (networking-stable-17_11_14).
- ipip: only increase err_count for some certain type icmp in
  ipip_err (networking-stable-17_11_14).
- tun: allow positive return values on dev_get_valid_name() call
  (networking-stable-17_11_14).
- net/unix: don't show information about sockets from other
  namespaces (networking-stable-17_11_14).
- net: dsa: check master device before put
  (networking-stable-17_11_14).
- sctp: full support for ipv6 ip_nonlocal_bind & IP_FREEBIND
  (networking-stable-17_11_14).
- ipv6: flowlabel: do not leave opt->tot_len with garbage
  (networking-stable-17_11_14).
- net: bridge: fix returning of vlan range op errors
  (networking-stable-17_11_14).
- tun: call dev_get_valid_name() before register_netdevice()
  (networking-stable-17_11_14).
- netlink: do not set cb_running if dump's start() errs
  (networking-stable-17_11_14).
- ppp: fix race in ppp device destruction
  (networking-stable-17_11_14).
- commit 218b0d9
* Tue Jun  5 2018 jslaby@suse.cz
- iwlwifi: mvm: don't warn in queue sync on RF-kill (bsc#1051510
  FATE#322675).
- Delete
  patches.drivers/0065-iwlwifi-mvm-don-t-warn-in-queue-sync-on-RF-kill.patch.
- Delete
  patches.drivers/iwlwifi-mvm-don-t-warn-in-queue-sync-on-RF-kill.
  Merge two semi-patches into the one real. This was 1 upstream commit
  dissected into two semi-patches. It must have been a mistake.
- commit dc38de7
* Tue Jun  5 2018 jslaby@suse.cz
- iwlwifi: mvm: remove DQA non-STA client mode special case
  (bsc#1051510 FATE#322675).
- Delete
  patches.drivers/0125-iwlwifi-mvm-remove-DQA-non-STA-client-mode-special-c.patch.
- Delete
  patches.drivers/iwlwifi-mvm-remove-DQA-non-STA-client-mode-special-c.
  Merge two semi-patches into the one real. This was 1 upstream commit
  dissected into two semi-patches. It must have been a mistake.
- commit e688642
* Tue Jun  5 2018 jslaby@suse.cz
- Refresh
  patches.suse/0012-btrfs-allow-backref-search-checks-for-shared-extents.patch.
  Fix invalid SHA.
- commit db29e43
* Mon Jun  4 2018 mbrugger@suse.com
- thermal: enable broadcom menu for arm64 bcm2835 (bsc#1095573).
- Update config files.
- supported.conf: fix folder of the driver module
- commit 6072587
* Mon Jun  4 2018 msuchanek@suse.de
- Refresh powerpc nospec patches.
- Refresh patches.arch/powerpc-64-Use-barrier_nospec-in-syscall-entry.patch.
- Refresh patches.arch/powerpc-64s-Add-barrier_nospec.patch.
- Refresh patches.arch/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch.
- Refresh patches.arch/powerpc-64s-Enable-barrier_nospec-based-on-firmware-.patch.
- Refresh patches.suse/powerpc-64s-Enhance-the-information-in-cpu_show_spec.patch.
- Refresh patches.arch/powerpc-64s-Patch-barrier_nospec-in-modules.patch
- Refresh patches.arch/powerpc-Use-barrier_nospec-in-copy_from_user.patch.
- commit 23825dd
* Mon Jun  4 2018 msuchanek@suse.de
- Refresh sorted patches.
- commit e2bcb54
* Mon Jun  4 2018 tiwai@suse.de
- Fix kABI breakage for iwl_fw_runtime_ops change (bsc#1051510).
- commit 4324b93
* Mon Jun  4 2018 oneukum@suse.com
- xhci: workaround for AMD Promontory disabled ports wakeup
  (bsc#1087092).
- Refresh
  patches.fixes/0001-xhci-Fix-front-USB-ports-on-ASUS-PRIME-B350M-A.patch.
- commit 94fc9ba
* Mon Jun  4 2018 tiwai@suse.de
- drm/vmwgfx: Fix 32-bit VMW_PORT_HB_[IN|OUT] macros
  (bsc#1051510).
- drm/vmwgfx: Set dmabuf_size when vmw_dmabuf_init is successful
  (bsc#1051510).
- rfkill: gpio: fix memory leak in probe error path (bsc#1051510).
- can: kvaser_usb: Increase correct stats counter in
  kvaser_usb_rx_can_msg() (bsc#1051510).
- firmware: dmi_scan: Fix UUID length safety check (bsc#1051510).
- ALSA: vmaster: Propagate slave error (bsc#1051510).
- staging: rtl8192u: return -ENOMEM on failed allocation of
  priv->oldaddr (bsc#1051510).
- ath9k: fix crash in spectral scan (bsc#1051510).
- ath10k: Fix kernel panic while using worker
  (ath10k_sta_rc_update_wk) (bsc#1051510).
- drm/vmwgfx: Unpin the screen object backup buffer when not used
  (bsc#1051510).
- drm/amdgpu: disable GFX ring and disable PQ wptr in hw_fini
  (bsc#1051510).
- drm/amdgpu: adjust timeout for ib_ring_tests(v2) (bsc#1051510).
- brcmfmac: Fix check for ISO3166 code (bsc#1051510).
- iwlwifi: mvm: fix array out of bounds reference (bsc#1051510).
- iwlwifi: mvm: make sure internal station has a valid id
  (bsc#1051510).
- iwlwifi: mvm: clear tx queue id when unreserving aggregation
  queue (bsc#1051510).
- iwlwifi: mvm: Increase session protection time after CS
  (bsc#1051510).
- iwlwifi: mvm: fix error checking for multi/broadcast sta
  (bsc#1051510).
- iwlwifi: mvm: Correctly set IGTK for AP (bsc#1051510).
- iwlwifi: mvm: set the correct tid when we flush the MCAST sta
  (bsc#1051510).
- drm/ast: Fixed 1280x800 Display Issue (bsc#1051510).
- iwlwifi: mvm: Correctly set the tid for mcast queue
  (bsc#1051510).
- iwlwifi: mvm: Direct multicast frames to the correct station
  (bsc#1051510).
- iwlwifi: mvm: fix "failed to remove key" message (bsc#1051510).
- iwlwifi: avoid collecting firmware dump if not loaded
  (bsc#1051510).
- iwlwifi: mvm: fix assert 0x2B00 on older FWs (bsc#1051510).
- iwlwifi: mvm: Fix channel switch for count 0 and 1
  (bsc#1051510).
- iwlwifi: mvm: fix TX of CCMP 256 (bsc#1051510).
- iwlwifi: mvm: always init rs with 20mhz bandwidth rates
  (bsc#1051510).
- iwlwifi: mvm: fix IBSS for devices that support station type
  API (bsc#1051510).
- cfg80211: clear wep keys after disconnection (bsc#1051510).
- coresight: Fix disabling of CoreSight TPIU (bsc#1051510).
- commit ff636ab
* Mon Jun  4 2018 jthumshirn@suse.de
- radix tree: fix multi-order iteration race (bsc#1095467).
- radix tree test suite: multi-order iteration race (bsc#1095467).
- radix tree test suite: add item_delete_rcu() (bsc#1095467).
- radix tree test suite: fix compilation issue (bsc#1095467).
- radix tree test suite: fix mapshift build target (bsc#1095467).
- commit 6cf3aa4
* Mon Jun  4 2018 jthumshirn@suse.de
- libnvdimm, namespace: use a safe lookup for dimm device name
  (bsc#1095321).
- vfio: disable filesystem-dax page pinning (bsc#1095337).
- commit 1b4ae46
* Mon Jun  4 2018 jthumshirn@suse.de
- nvme: fix extended data LBA supported setting (FATE#323952,
  FATE#322506).
- commit 8095826
* Mon Jun  4 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Fix-partial-success-login-retries.patch.
- Refresh
  patches.drivers/ibmvnic-Only-do-H_EOI-for-mobility-events.patch.
- Refresh
  patches.drivers/nvme_fc-fix-abort-race-on-teardown-with-lld-reject.patch.
- Refresh
  patches.drivers/nvme_fc-fix-ctrl-create-failures-racing-with-workq-i.patch.
- Refresh
  patches.drivers/nvme_fc-io-timeout-should-defer-abort-to-ctrl-reset.patch.
- Refresh
  patches.drivers/nvme_fc-on-remoteport-reuse-set-new-nport_id-and-rol.patch.
- Refresh
  patches.drivers/nvmet_fc-prevent-new-io-rqsts-in-possible-isr-comple.patch.
- Refresh
  patches.fixes/0001-iov_iter-fix-return-type-of-_pipe_get_pages.patch.
- Refresh
  patches.fixes/0002-iov_iter-fix-memory-leak-in-pipe_get_pages_alloc.patch.
- commit 1a86fbf
* Sun Jun  3 2018 jslaby@suse.cz
- ip6_tunnel: update mtu properly for ARPHRD_ETHER tunnel device
  in tx path (networking-stable-17_10_09).
- ip6_gre: ip6gre_tap device should keep dst
  (networking-stable-17_10_09).
- netlink: do not proceed if dump's start() errs
  (networking-stable-17_10_09).
- net: Set sk_prot_creator when cloning sockets to the right proto
  (networking-stable-17_10_09).
- net: dsa: mv88e6xxx: lock mutex when freeing IRQs
  (networking-stable-17_10_09).
- tun: bail out from tun_get_user() if the skb is empty
  (networking-stable-17_10_09).
- net: qcom/emac: specify the correct size when mapping a DMA
  buffer (networking-stable-17_10_09).
- net: emac: Fix napi poll list corruption
  (networking-stable-17_10_09).
- 8139too: revisit napi_complete_done() usage
  (networking-stable-17_10_09).
- ip6_tunnel: do not allow loading ip6_tunnel if ipv6 is disabled
  in cmdline (networking-stable-17_10_09).
- net: phy: Fix mask value write on gmii2rgmii converter speed
  register (networking-stable-17_10_09).
- ip6_gre: skb_push ipv6hdr before packing the header in
  ip6gre_header (networking-stable-17_10_09).
- tcp: fix data delivery rate (networking-stable-17_10_09).
- tcp: update skb->skb_mstamp more carefully
  (networking-stable-17_10_09).
- sctp: potential read out of bounds in
  sctp_ulpevent_type_enabled() (networking-stable-17_10_09).
- net: bonding: fix tlb_dynamic_lb default value
  (networking-stable-17_10_09).
- mlxsw: spectrum: Prevent mirred-related crash on removal
  (networking-stable-17_10_09).
- net: bonding: Fix transmit load balancing in balance-alb mode
  if specified by sysfs (networking-stable-17_10_09).
- commit 6a14623
* Fri Jun  1 2018 tiwai@suse.de
- Revert "drm/i915/edp: Allow alternate fixed mode for eDP if
  available." (bsc#1093604).
- commit 1425838
* Fri Jun  1 2018 yousaf.kaukab@suse.com
- config: arm64: enable Spectre-v4 per-thread mitigation
- commit a71e164
* Fri Jun  1 2018 yousaf.kaukab@suse.com
- arm64: ssbd: Add prctl interface for per-thread mitigation
  (bsc#1085308).
- arm64: ssbd: Introduce thread flag to control userspace
  mitigation (bsc#1085308).
- arm64: ssbd: Restore mitigation status on CPU resume
  (bsc#1085308).
- arm64: ssbd: Skip apply_ssbd if not using dynamic mitigation
  (bsc#1085308).
- arm64: ssbd: Add global mitigation state accessor (bsc#1085308).
- arm64: Add 'ssbd' command-line option (bsc#1085308).
- arm64: Add ARCH_WORKAROUND_2 probing (bsc#1085308).
- arm64: Add per-cpu infrastructure to call ARCH_WORKAROUND_2
  (bsc#1085308).
- arm64: Call ARCH_WORKAROUND_2 on transitions between EL0 and
  EL1 (bsc#1085308).
- arm/arm64: smccc: Add SMCCC-specific return codes (bsc#1085308).
- arm64: alternatives: Add dynamic patching feature (bsc#1085308).
- arm64: fix endianness annotation for
  __apply_alternatives()/get_alt_insn() (bsc#1085308).
- commit e864b8a
* Fri Jun  1 2018 bpoirier@suse.com
- Refresh patch order (and some tags) in sorted section
  Patch patches.drivers/i40iw-Avoid-panic-when-reading-back-the-IRQ-aff.patch
  seems to have been misplaced from the start.
  The git-commit tags in the nvme patches needed to be updated, the nvme-4.17
  branch was rebased :'(
- Refresh
  patches.drivers/ibmvnic-Fix-partial-success-login-retries.patch.
- Refresh
  patches.drivers/ibmvnic-Only-do-H_EOI-for-mobility-events.patch.
- Refresh
  patches.drivers/nvme_fc-fix-abort-race-on-teardown-with-lld-reject.patch.
- Refresh
  patches.drivers/nvme_fc-fix-ctrl-create-failures-racing-with-workq-i.patch.
- Refresh
  patches.drivers/nvme_fc-io-timeout-should-defer-abort-to-ctrl-reset.patch.
- Refresh
  patches.drivers/nvme_fc-on-remoteport-reuse-set-new-nport_id-and-rol.patch.
- Refresh
  patches.drivers/nvmet_fc-prevent-new-io-rqsts-in-possible-isr-comple.patch.
- Refresh
  patches.fixes/0001-iov_iter-fix-return-type-of-_pipe_get_pages.patch.
- Refresh
  patches.fixes/0002-iov_iter-fix-memory-leak-in-pipe_get_pages_alloc.patch.
- commit 6c54b6a
* Thu May 31 2018 dbond@suse.com
- qla2xxx: Mask off Scope bits in retry delay (bsc#1068054).
- commit 08dc2b1
* Thu May 31 2018 jslaby@suse.cz
- kernel/sys.c: fix potential Spectre v1 issue (bnc#1068032
  CVE-2017-5753).
- commit 3a70d9d
* Thu May 31 2018 jroedel@suse.de
- iommu/vt-d: Clear pasid table entry when memory unbound
  (bsc#1087214).
- commit 2081b9a
* Thu May 31 2018 jslaby@suse.cz
- n_tty: fix EXTPROC vs ICANON interaction with TIOCINQ (aka
  FIONREAD) (bnc#1094825).
- commit f8b3f75
* Thu May 31 2018 jroedel@suse.de
- KVM: MMU: consider host cache mode in MMIO page check
  (bsc#1087213).
- x86/mm: add a function to check if a pfn is UC/UC-/WC
  (bsc#1087213).
- commit e4370ae
* Thu May 31 2018 jroedel@suse.de
- Refresh
  patches.drivers/nvme_fc-fix-abort-race-on-teardown-with-lld-reject.patch.
- Refresh
  patches.drivers/nvme_fc-fix-ctrl-create-failures-racing-with-workq-i.patch.
- Refresh
  patches.drivers/nvme_fc-io-timeout-should-defer-abort-to-ctrl-reset.patch.
- Refresh
  patches.drivers/nvme_fc-on-remoteport-reuse-set-new-nport_id-and-rol.patch.
- Refresh
  patches.drivers/nvmet_fc-prevent-new-io-rqsts-in-possible-isr-comple.patch.
- commit dc86362
* Thu May 31 2018 tiwai@suse.de
- drm/i915: Adjust eDP's logical vco in a reliable place
  (bsc#1095265).
- drm/i915/glk: Add MODULE_FIRMWARE for Geminilake (bsc#1095265).
- drm/i915/audio: set minimum CD clock to twice the BCLK
  (bsc#1095265).
- commit a5b2c85
* Thu May 31 2018 tiwai@suse.de
- Input: synaptics: Add intertouch blacklist for Thinkpad Helix
  (bsc#1090457).
- commit 722c30b
* Wed May 30 2018 bp@suse.de
- kabi/severities: Ignore removed bugs.c symbols
  The second wave of SSBD patches drops those symbols and we can ignore them
  from kABI because nothing external should use them - they were exported only
  for kvm.
- commit 61bc32c
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/bl: fix backlight regression (bsc#1095094).
- commit 40a8de9
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/disp/gf119: add missing drive vfunc ptr
  (bsc#1095094).
- blacklist.conf:
- commit 57c1f66
* Wed May 30 2018 msuchanek@suse.de
- Update kabi files from MR#8172.
- commit 826e9fe
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau: silence suspend/resume debugging messages
  (bsc#1095094).
- drm/nouveau/kms/nv04-nv4x: fix exposed format list
  (bsc#1095094).
- drm/nouveau/kms/nv10-nv40: add NV21 support to overlay
  (bsc#1095094).
- drm/nouveau/kms/nv04-nv40: improve overlay error detection,
  fix pitch setting (bsc#1095094).
- drm/nouveau/kms/nv04-nv40: prevent undisplayable framebuffers
  from creation (bsc#1095094).
- drm/nouveau/mpeg: print more debug info when rejecting dma
  objects (bsc#1095094).
- drm/nouveau/fb/gf100-: zero mmu debug buffers (bsc#1095094).
- drm/nouveau/bar/gf100: add config option to limit BAR2 to 16MiB
  (bsc#1095094).
- initial support (display-only) for GP108 (bsc#1095094).
- drm/nouveau/falcon: use a more reasonable msgqueue timeout value
  (bsc#1095094).
- drm/nouveau/disp: Silence DCB warnings (bsc#1095094).
- drm/nouveau/bios: Demote missing fp table message to NV_DEBUG
  (bsc#1095094).
- drm/nouveau/pmu/gt215-: abstract detection of whether reset
  is needed (bsc#1095094).
- drm/nouveau/pmu/gt215: fix reset (bsc#1095094).
- commit 95d8fc2
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/mc/gf100: add pmu to reset mask (bsc#1095094).
- drm/nouveau/disp/gf119-: avoid creating non-existent heads
  (bsc#1095094).
- drm/nouveau/therm/gm200: Added (bsc#1095094).
- drm/nouveau/therm: fix spelling mistake on array thresolds
  (bsc#1095094).
- commit b0a0bab
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau: Fix merge commit (bsc#1095094).
- drm/nouveau/disp/nv04: avoid creation of output paths
  (bsc#1095094).
- commit c534f7b
* Wed May 30 2018 tiwai@suse.de
- drm: nouveau: remove dead code and pointless local lut storage
  (bsc#1095094).
- drm/nouveau/disp: add tv encoders to output resource mapping
  (bsc#1095094).
- commit a23a7b7
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau: Convert nouveau to use new iterator macros, v2
  (bsc#1095094).
- commit 8406e59
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau: Use the drm_driver.dumb_destroy default
  (bsc#1095094).
- drm/nouveau: Handle drm_atomic_helper_swap_state failure
  (bsc#1095094).
- drm/nouveau/disp/nv50-: avoid creating ORs that aren't present
  on HW (bsc#1095094).
- drm/nouveau: Skip vga_fini on non-PCI device (bsc#1095094).
- drm/nouveau/tegra: Don't leave GPU in reset (bsc#1095094).
- drm/nouveau/tegra: Skip manual unpowergating when not necessary
  (bsc#1095094).
- commit 60c1e20
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/hwmon: Change permissions to numeric (bsc#1095094).
- drm/nouveau/hwmon: expose the auto_point and pwm_min/max attrs
  (bsc#1095094).
- drm/nouveau/hwmon: Remove old code, add .write/.read operations
  (bsc#1095094).
- drm/nouveau/hwmon: Add nouveau_hwmon_ops structure with
  .is_visible/.read_string (bsc#1095094).
- drm/nouveau/hwmon: Add config for all sensors and their settings
  (bsc#1095094).
- drm/nouveau/disp/gm200-: allow non-identity mapping of SOR <->
  macro links (bsc#1095094).
- drm/nouveau/disp/nv50-: implement a common supervisor 3.0
  (bsc#1095094).
- drm/nouveau/disp/nv50-: implement a common supervisor 2.2
  (bsc#1095094).
- drm/nouveau/disp/nv50-: implement a common supervisor 2.1
  (bsc#1095094).
- drm/nouveau/disp/nv50-: implement a common supervisor 2.0
  (bsc#1095094).
- commit 31b3d5f
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/disp/nv50-: implement a common supervisor 1.0
  (bsc#1095094).
- drm/nouveau/disp/nv50-gt21x: remove workaround for dp->tmds
  hotplug issues (bsc#1095094).
- drm/nouveau/disp/dp: use new devinit script interpreter
  entry-point (bsc#1095094).
- drm/nouveau/disp/dp: determine link bandwidth requirements
  from head state (bsc#1095094).
- drm/nouveau/disp: introduce acquire/release display path methods
  (bsc#1095094).
- drm/nouveau/disp: remove hw-specific customisation of output
  paths (bsc#1095094).
- drm/nouveau/disp/gf119-: port OR DP VCPI control to nvkm_ior
  (bsc#1095094).
- drm/nouveau/disp/gt215-: port HDA ELD controls to nvkm_ior
  (bsc#1095094).
- drm/nouveau/disp/g94-: port OR DP drive setting control to
  nvkm_ior (bsc#1095094).
- drm/nouveau/disp/g94-: port OR DP training pattern control to
  nvkm_ior (bsc#1095094).
- commit da64444
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/disp/g94-: port OR DP link power control to nvkm_ior
  (bsc#1095094).
- drm/nouveau/disp/g94-: port OR DP link setup to nvkm_ior
  (bsc#1095094).
- drm/nouveau/disp/g94-: port OR DP lane mapping to nvkm_ior
  (bsc#1095094).
- drm/nouveau/disp/g84-: port OR HDMI control to nvkm_ior
  (bsc#1095094).
- drm/nouveau/disp/nv50-: port OR manual sink detection to
  nvkm_ior (bsc#1095094).
- drm/nouveau/disp/nv50-: port OR power state control to nvkm_ior
  (bsc#1095094).
- drm/nouveau/disp/nv50-: fetch head/OR state at beginning of
  supervisor (bsc#1095094).
- drm/nouveau/disp/nv50-: execute supervisor on its own workqueue
  (bsc#1095094).
- drm/nouveau/disp/dp: train link only when actively displaying
  an image (bsc#1095094).
- drm/nouveau/disp/dp: only check for re-train when the link is
  active (bsc#1095094).
- commit b83eb1a
* Wed May 30 2018 tbogendoerfer@suse.de
- iw_cxgb4: Fix an error handling path in 'c4iw_get_dma_mr()'
  (bsc#1064802 bsc#1066129).
- cxgb4: fix offset in collecting TX rate limit info
  (bsc#1073513).
- net/mlx5: Fix build break when CONFIG_SMP=n (bsc#1046303
  FATE#322944).
- cxgb4: Correct ntuple mask validation for hash filters
  (bsc#1064802 bsc#1066129).
- commit 6609289
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau: Pass mode-dependent AVI and Vendor HDMI InfoFrames
  to NVKM (bsc#1095094).
- Refresh
  patches.drivers/drm-handle-HDMI-2.0-VICs-in-AVI-info-frames.
- commit 1df105c
* Wed May 30 2018 jroedel@suse.de
- iommu/amd: Take into account that alloc_dev_data() may return
  NULL (bsc#975772).
- commit 4a16421
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/disp/dp: determine a failsafe link training rate
  (bsc#1095094).
- drm/nouveau/disp/dp: use cached link configuration when checking
  link status (bsc#1095094).
- drm/nouveau/disp/dp: no need for lt_state except during manual
  link training (bsc#1095094).
- drm/nouveau/disp/dp: store current link configuration in
  nvkm_ior (bsc#1095094).
- drm/nouveau/disp/dp: remove DP_PWR method (bsc#1095094).
- drm/nouveau/disp: identity-map display paths to output resources
  (bsc#1095094).
- drm/nouveau/disp: fork off some new hw-specific implementations
  (bsc#1095094).
- drm/nouveau/disp: introduce input/output resource abstraction
  (bsc#1095094).
- commit 04c0581
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/disp: common implementation of scanoutpos method
  in nvkm_head (bsc#1095094).
- commit 56aaa7a
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/disp: move vblank_{get,put} methods into nvkm_head
  (bsc#1095094).
- commit 326cea3
* Wed May 30 2018 msuchanek@suse.de
- Delete patches.arch/powerpc64-ftrace-Use-the-generic-version-of-ftrace_r.patch (bsc#1088804).
- commit 054e09e
* Wed May 30 2018 oneukum@suse.com
- usb: xhci: Make some static functions global (FATE#325197).
- commit 7f391e4
* Wed May 30 2018 mkubecek@suse.cz
- disable patches.drivers/s390-qeth-use-Read-device-to-query-hypervisor-for-MA.patch
  Backport of mainline commit b7493e91c11a ("s390/qeth: use Read device to
  query hypervisor for MAC") changes assigned MAC address (and breaks
  networking) on one of our machines and it's not clear which address is
  actually correct (bsc#1094575). Disable the patch for now with a marker so
  that we prevent releasing a maintenance update incompatible with GM. Once
  the bug is resolved, we will either reenable the patch or drop it.
- commit 9da59a6
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/disp: introduce object to track per-head
  functions/state (bsc#1095094).
- drm/nouveau/disp: delay output path / connector construction
  until oneinit() (bsc#1095094).
- drm/nouveau/disp: s/nvkm_connector/nvkm_conn/ (bsc#1095094).
- drm/nouveau/disp: rename nvkm_output_dp to nvkm_dp
  (bsc#1095094).
- drm/nouveau/disp: rename nvkm_output to nvkm_outp (bsc#1095094).
- drm/nouveau/disp: shuffle functions around (bsc#1095094).
- commit 6fbaf71
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/kms/nv04: use new devinit script interpreter
  entry-point (bsc#1095094).
- drm/nouveau/fb/ram/nv40-: use new devinit script interpreter
  entry-point (bsc#1095094).
- drm/nouveau/devinit: use new devinit script interpreter
  entry-point (bsc#1095094).
- drm/nouveau/bios/init: add a new devinit script interpreter
  entry-point (bsc#1095094).
- commit 2ec036f
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau/bios/init: add or/link args separate from output
  path (bsc#1095094).
- drm/nouveau/bios/init: bump script offset to 32-bits
  (bsc#1095094).
- drm/nouveau/bios/init: rename 'crtc' to 'head' (bsc#1095094).
- drm/nouveau/bios/init: remove internal use of nvbios_init.bios
  (bsc#1095094).
- drm/nouveau/bios/init: rename nvbios_init() to nvbios_devinit()
  (bsc#1095094).
- drm/nouveau/tmr: remove nvkm_timer_alarm_cancel() (bsc#1095094).
- drm/nouveau/bios/iccsense: rails for power sensors have a mask
  of 0xf8 for version 0x10 (bsc#1095094).
- drm/nouveau/bios/volt: Parse min and max for Version 0x40
  (bsc#1095094).
- drm/nouveau: Enable stereoscopic 3D output over HDMI
  (bsc#1095094).
- drm/nouveau: Handle frame-packing mode geometry and timing
  effects (bsc#1095094).
- commit 1d38f1a
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau: Drop drm_vblank_cleanup (bsc#1095094).
- drm/nouveau/disp/gk104-: Use supplied HDMI InfoFrames
  (bsc#1095094).
- drm/nouveau/disp/gf119: Use supplied HDMI InfoFrames
  (bsc#1095094).
- drm/nouveau/disp/gt215: Use supplied HDMI InfoFrames
  (bsc#1095094).
- drm/nouveau/disp/g84-gt200: Use supplied HDMI InfoFrames
  (bsc#1095094).
- drm/nouveau/disp: Add mechanism to convert HDMI InfoFrames to
  hardware format (bsc#1095094).
- drm/nouveau/disp/g84-: Extend NVKM HDMI power control method
  to set InfoFrames (bsc#1095094).
- drm/nouveau: Clean up nv50_head_atomic_check_mode() and fix
  blankus calculation (bsc#1095094).
- commit cbc811b
* Wed May 30 2018 tiwai@suse.de
- drm/nouveau: use drm_for_each_connector_iter() (bsc#1095094).
- commit e658e6c
* Wed May 30 2018 jthumshirn@suse.de
- nfit: skip region registration for incomplete control regions
  (bsc#1091666).
- libnvdimm, label: change min label storage size per UEFI 2.7
  (bsc#1091666).
- commit 0745987
* Wed May 30 2018 tiwai@suse.de
- Bluetooth: Apply QCA Rome patches for some ATH3012 models
  (bsc#1082504).
- commit 683b865
* Tue May 29 2018 jeffm@suse.com
- rpm: fix typo, SUSE_KERNEL_RELEASE -> SUSE_KERNEL_RELEASED (bsc#1095104).
  This causes release kernels to report as (unreleased).
- commit cd0437b
* Tue May 29 2018 mbenes@suse.cz
- powerpc/livepatch: Fix KABI breaker in stacktrace.c (bsc#1071995
  bsc#1072856 bsc#1087458 bsc#1089664 bsc#1089669).
- commit eaac7dc
* Tue May 29 2018 jroedel@suse.de
- PCI/DPC: Do not enable DPC if AER control is not allowed by
  the BIOS (bsc#1093184).
- commit 17be4d4
* Tue May 29 2018 mbenes@suse.cz
- Delete patches.suse/ppc64le-fix-idle-stacktrace.patch.
- Delete
  patches.suse/ppc64le-stacktrace-fix-graph-ftrace-interaction.patch.
- Delete patches.suse/ppc64le-stacktrace-fix-text-check.patch.
- Delete
  patches.suse/ppc64le-stacktrace-mark-exception-stacks-unreliable.patch.
- Delete
  patches.suse/ppc64le-stacktrace-mark-kretprobe-stacks-unreliable.patch.
- commit f051f84
* Tue May 29 2018 oneukum@suse.com
- usb: xhci: Disable slot even when virt-dev is null
  (bsc#1085539).
- Refresh
  patches.fixes/0001-usb-xhci-Fix-potential-memory-leak-in-xhci_disable_s.patch.
- commit 8097e68
* Tue May 29 2018 oneukum@suse.com
- usb: quirks: add control message delay for 1b1c:1b20
  (bsc#1087092).
- commit d7fe2fb
* Tue May 29 2018 oneukum@suse.com
- usb: xhci: Fix potential memory leak in xhci_disable_slot()
  (bsc#1085539).
- commit 2cb4035
* Tue May 29 2018 oneukum@suse.com
- usbip: vudc: fix null pointer dereference on udc->lock
  (bsc#1087092).
- commit 9e8764b
* Tue May 29 2018 oneukum@suse.com
- blacklist.conf: cosmetic build fix irrelevant to our configs
- commit b16d3f1
* Mon May 28 2018 msuchanek@suse.de
- ibmvnic: Introduce hard reset recovery (bsc#1094840).
- ibmvnic: Set resetting state at earliest possible point
  (bsc#1094840).
- ibmvnic: Create separate initialization routine for resets
  (bsc#1094840).
- ibmvnic: Handle error case when setting link state
  (bsc#1094840).
- ibmvnic: Return error code if init interrupted by transport
  event (bsc#1094840).
- ibmvnic: Check CRQ command return codes (bsc#1094840).
- ibmvnic: Introduce active CRQ state (bsc#1094840).
- ibmvnic: Mark NAPI flag as disabled when released (bsc#1094840).
- ibmvnic: Fix partial success login retries (bsc#1094840).
- commit dc74a91
* Mon May 28 2018 jthumshirn@suse.de
- nvme: add quirk to force medium priority for SQ creation
  (FATE#323952, FATE#322506).
- commit c3c65dd
* Mon May 28 2018 jthumshirn@suse.de
- nvme: target: fix buffer overflow (FATE#323952, FATE#322506).
- nvme: don't send keep-alives to the discovery controller
  (FATE#323952, FATE#322506).
- commit b661970
* Mon May 28 2018 jthumshirn@suse.de
- libnvdimm, dimm: handle EACCES failures from label reads
  (FATE#324505).
- commit 58ba8f8
* Mon May 28 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix small memory leak in qla2x00_probe_one on
  probe failure (bsc#1077338).
- nvmet: fix space padding in serial number (FATE#323952,
  FATE#322506).
- commit dfc7ea1
* Mon May 28 2018 ohering@suse.de
- PCI: hv: Fix a __local_bh_enable_ip warning in
  hv_compose_msi_msg() (bnc#1094541).
- commit 93066c8
* Sun May 27 2018 tiwai@suse.de
- cfg80211: further limit wiphy names to 64 bytes (bsc#1051510).
- commit 95eb5e7
* Sun May 27 2018 tiwai@suse.de
- cfg80211: limit wiphy names to 128 bytes (bsc#1051510).
- ASoC: rockchip: Fix dai_name for HDMI codec (bsc#1051510).
- staging: bcm2835-audio: Release resources on module_exit()
  (bsc#1051510).
- Bluetooth: btusb: Add USB ID 7392:a611 for Edimax EW-7611ULB
  (bsc#1051510).
- Bluetooth: btusb: Add device ID for RTL8822BE (bsc#1051510).
- commit 077bc0e
* Sun May 27 2018 tiwai@suse.de
- ASoC: rockchip: rk3288-hdmi-analog: Select needed codecs
  (bsc#1051510).
- ASoC: samsung: i2s: Ensure the RCLK rate is properly determined
  (bsc#1051510).
- ALSA: usb-audio: Add native DSD support for Luxman DA-06
  (bsc#1051510).
- ASoC: hdmi-codec: Fix module unloading caused kernel crash
  (bsc#1051510).
- ASoC: hdmi-codec: remove multi detection support (bsc#1051510).
- ASoC: hdmi-codec: fix spelling mistake: "deteced" -> "detected"
  (bsc#1051510).
- commit 1f38e74
* Sun May 27 2018 tiwai@suse.de
- mmc: sdhci-iproc: add SDHCI_QUIRK2_HOST_OFF_CARD_ON for cygnus
  (bsc#1051510).
- mmc: sdhci-iproc: fix 32bit writes for TRANSFER_MODE register
  (bsc#1051510).
- mmc: sdhci-iproc: remove hard coded mmc cap 1.8v (bsc#1051510).
- commit 59892a6
* Sun May 27 2018 tiwai@suse.de
- drm/nouveau/fbcon: fix oops without fbdev emulation
  (bsc#1094751).
- commit 6458fdb
* Sat May 26 2018 tiwai@suse.de
- ALSA: timer: Fix pause event notification (bsc#1051510).
- commit 74fed8d
* Fri May 25 2018 mfleming@suse.de
- cpufreq: schedutil: Avoid using invalid next_freq (git-fixes).
- commit d9c2ab8
* Fri May 25 2018 ppyu@suse.com
- RDMA/i40iw: Avoid panic when reading back the IRQ affinity hint
  (bsc#1084001).
- commit ff5f957
* Fri May 25 2018 msuchanek@suse.de
- powerpc/xmon: Also setup debugger hooks when single-stepping
  (bsc#1072829).
- commit d585167
* Fri May 25 2018 hare@suse.de
- lpfc: Fix port initialization failure (bsc#1093290).
- lpfc: Fix 16gb hbas failing cq create (bsc#1093290).
- commit e7cee22
* Thu May 24 2018 mbenes@suse.cz
- Refresh
  patches.suse/livepatch-allow-to-call-a-custom-callback-when-freeing-shadow-variables.patch.
- Refresh
  patches.suse/livepatch-initialize-shadow-variables-safely-by-a-custom-callback.patch.
- commit a7102df
* Thu May 24 2018 lhenriques@suse.com
- ceph: fix st_nlink stat for directories (bsc#1093904).
- commit a584927
* Thu May 24 2018 bp@suse.de
- x86/cpuinfo: Ignore ->initialized member (bsc#1091543).
- commit e40c5a4
* Thu May 24 2018 bp@suse.de
- x86/smpboot: Fix uncore_pci_remove() indexing bug when
  hot-removing a physical CPU (bsc#1091543).
- x86/topology: Avoid wasting 128k for package id array
  (bsc#1091543).
- Refresh
  patches.arch/x86-smpboot-fix-_max_logical_packages-estimate.patch.
- commit 7e6af23
* Thu May 24 2018 msuchanek@suse.de
- ibmvnic: Only do H_EOI for mobility events (bsc#1094356).
- commit cb5fb4c
* Wed May 23 2018 msuchanek@suse.de
- mkspec: only build docs for default variant kernel.
- commit 045f5ac
* Wed May 23 2018 tiwai@suse.de
- firmware: fix checking for return values for fw_add_devm_name()
  (bsc#1051510).
- crypto: atmel-aes - fix the keys zeroing on errors
  (bsc#1051510).
- drm/panel: simple: Fix the bus format for the Ontat panel
  (bsc#1051510).
- KEYS: Use individual pages in big_key for crypto buffers
  (bsc#1051510).
- PCI: designware-ep: Fix find_first_zero_bit() usage
  (bsc#1051510).
- commit 809527b
* Wed May 23 2018 tiwai@suse.de
- drm/i915/gen9: Add WaClearHIZ_WM_CHICKEN3 for bxt and glk
  (bsc#1051510).
- drm: Match sysfs name in link removal to link creation
  (bsc#1051510).
- ALSA: usb: mixer: volume quirk for CM102-A+/102S+ (bsc#1051510).
- ALSA: hda: Add Lenovo C50 All in one to the power_save blacklist
  (bsc#1051510).
- ALSA: control: fix a redundant-copy issue (bsc#1051510).
- commit c91847f
* Wed May 23 2018 tiwai@suse.de
- blacklist.conf: Add 4.14.x stable and git-fixes entries
- commit 2e0c8f6
* Wed May 23 2018 tiwai@suse.de
- i2c: designware: fix poll-after-enable regression (bsc#1051510).
- drm/i915/execlists: Use rmb() to order CSB reads (bsc#1051510).
- gpio: fix error path in lineevent_create (bsc#1051510).
- gpioib: do not free unrequested descriptors (bsc#1051510).
- PCI: Remove messages about reassigning resources (bsc#1051510).
- iwlwifi: mvm: fix security bug in PN checking (bsc#1051510).
- PCI/ASPM: Calculate LTR_L1.2_THRESHOLD from device
  characteristics (bsc#1051510).
- ACPI: sysfs: Make ACPI GPE mask kernel parameter cover all GPEs
  (bsc#1051510).
- PCI/ASPM: Add L1 Substates definitions (bsc#1051510).
- crypto: qat - remove unused and redundant pointer vf_info
  (bsc#1051510).
- PM: docs: Drop an excess character from devices.rst
  (bsc#1051510).
- Bluetooth: btrtl: Fix a error code in rtl_load_config()
  (bsc#1051510).
- commit 0ab3e88
* Wed May 23 2018 jkosina@suse.cz
- patches.suse/bpf-prevent-memory-disambiguation-attack.patch: update
  upstream references
- commit 4896c66
* Tue May 22 2018 jthumshirn@suse.de
- libnvdimm, nfit: fix persistence domain reporting (bsc#1091424).
- libnvdimm, region: hide persistence_domain when unknown
  (bsc#1091424).
- commit 77c2ab1
* Tue May 22 2018 mhocko@suse.com
- proc: do not access cmdline nor environ from file-backed areas
  (bnc#1093158, CVE-2018-1120).
- commit ea6dcee
* Tue May 22 2018 jthumshirn@suse.de
- kabi protect struct acpi_nfit_desc (bsc#1091424).
- commit 7ebc432
* Tue May 22 2018 jthumshirn@suse.de
- libnvdimm: re-enable deep flush for pmem devices via fsync()
  (bsc#1091424).
- nfit-test: Add platform cap support from ACPI 6.2a to test
  (bsc#1091424).
- libnvdimm: expose platform persistence attribute for nd_region
  (bsc#1091424).
- acpi: nfit: add persistent memory control flag for nd_region
  (bsc#1091424).
- acpi: nfit: Add support for detect platform CPU cache flush
  on power loss (bsc#1091424).
- ACPICA: ACPI 6.0A: Changes to the NFIT ACPI table (bsc#1091424).
- commit b0e80fc
* Mon May 21 2018 msuchanek@suse.de
- powerpc/fadump: Do not use hugepages when fadump is active
  (bsc#1092772).
- powerpc/fadump: exclude memory holes while reserving memory
  in second kernel (bsc#1092772).
- ibmvnic: Fix statistics buffers memory leak (bsc#1093990).
- ibmvnic: Fix non-fatal firmware error reset (bsc#1093990).
- ibmvnic: Free coherent DMA memory if FW map failed
  (bsc#1093990).
- commit ceb9040
* Mon May 21 2018 glin@suse.com
- bpf, x64: fix memleak when not converging after image
  (bsc#1083647).
- commit 8c0d872
* Fri May 18 2018 tbogendoerfer@suse.de
- RDMA/core: Reduce poll batch for direct cq polling (bsc#1046306
  FATE#322942).
- commit e6718a9
* Fri May 18 2018 tbogendoerfer@suse.de
- blacklist.conf: not applicable patch
- commit 9c0c786
* Fri May 18 2018 tbogendoerfer@suse.de
- IB/hfi1: Fix NULL pointer dereference when invalid num_vls is
  used (bsc#1060463 FATE#323043).
- commit a03f34c
* Fri May 18 2018 tbogendoerfer@suse.de
- iw_cxgb4: Atomically flush per QP HW CQEs (bsc#1046543
  FATE#322927).
- IB/mlx5: Use unlimited rate when static rate is not supported
  (bsc#1046305 FATE#322943).
- IB/srp: Fix srp_abort() (bsc#1046306 FATE#322942).
- i40e: Fix attach VF to VM issue (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- IB/ipoib: Fix for potential no-carrier state (bsc#1046307
  FATE#322941).
- IB/hfi1: Re-order IRQ cleanup to address driver cleanup race
  (bsc#1060463 FATE#323043).
- i40e: program fragmented IPv4 filter input set (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- ixgbe: don't set RXDCTL.RLPML for 82599 (bsc#1056657
  FATE#322189).
- igb: Clear TXSTMP when ptp_tx_work() is timeout (bsc#1056651
  FATE#322191).
- igb: Allow to remove administratively set MAC on VFs
  (bsc#1056651 FATE#322191).
- i40evf: ignore link up if not running (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: Don't schedule reset_task when device is being removed
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- IB/cq: Don't force IB_POLL_DIRECT poll context for
  ib_process_cq_direct (bsc#1046306 FATE#322942).
- i40iw: Zero-out consumer key on allocate stag for FMR
  (bsc#1058659 FATE#322535).
- commit 478a78b
* Fri May 18 2018 tbogendoerfer@suse.de
- qede: Fix gfp flags sent to rdma event node allocation
  (bsc#1050538 FATE#322897 bsc#1050545 FATE#322893).
- qed: Fix l2 initializations over iWARP personality (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- IB/mlx4: Fix integer overflow when calculating optimal MTT size
  (bsc#1071218).
- IB/hfi1: Fix handling of FECN marked multicast packet
  (bsc#1060463 FATE#323043).
- IB/uverbs: Fix validating mandatory attributes (bsc#1046306
  FATE#322942).
- RDMA/ucma: Allow resolving address w/o specifying source address
  (bsc#1046306 FATE#322942).
- net/mlx5: Fix mlx5_get_vector_affinity function (bsc#1046303
  FATE#322944).
- net/mlx5e: Allow offloading ipv4 header re-write for icmp
  (bsc#1046303 FATE#322944).
- net: ethtool: Add missing kernel doc for FEC parameters
  (bsc#1046540 FATE#322930).
- s390/qeth: use Read device to query hypervisor for MAC
  (bsc#1061024 FATE#323301).
- commit 22f22c5
* Fri May 18 2018 jkosina@suse.cz
- bpf: prevent memory disambiguation attack (bsc#1087082
  CVE-2018-3639).
- commit f1ac4a9
* Fri May 18 2018 tbogendoerfer@suse.de
- IB/mlx5: Respect new UMR capabilities (bsc#1093205).
- IB/mlx5:: pr_err() and mlx5_ib_dbg() strings should end with
  newlines (bsc#1093205).
- commit 16e6605
* Fri May 18 2018 tiwai@suse.de
- ALSA: hda/conexant - Add hp-mic-fix model string (bsc#1092975).
- ALSA: hda/conexant - Add fixup for HP Z2 G4 workstation
  (bsc#1092975).
- commit 5d0df0f
* Fri May 18 2018 jack@suse.cz
- blacklist.conf: Blacklist 191eac33009e
- commit 1b481a4
* Thu May 17 2018 dbueso@suse.de
- kvm: Introduce nopvspin kernel parameter (bsc#1056427).
- commit 570c828
* Thu May 17 2018 lduncan@suse.com
- target: transport should handle st FM/EOM/ILI reads
  (bsc#1081599).
- commit ca764ea
* Thu May 17 2018 jack@suse.cz
- ext4: Make checks for metadata_csum feature safer (bsc#1087007
  CVE-2018-1094).
- commit 6181ff6
* Thu May 17 2018 msuchanek@suse.de
- Re-sort some patches to match SLE15
- commit 6a7749f
* Thu May 17 2018 tiwai@suse.de
- platform/x86: ideapad-laptop: Add MIIX 720-12IKB to no_hw_rfkill
  (bsc#1093035).
- commit 6221bce
* Thu May 17 2018 lhenriques@suse.com
- rbd: use GFP_NOIO for parent stat and data requests
  (bsc#1093728).
- commit 44d096a
* Thu May 17 2018 yousaf.kaukab@suse.com
- init: fix false positives in W+X checking (bsc#1093721).
- commit a677380
* Thu May 17 2018 jack@suse.cz
- udf: Fix leak of UTF-16 surrogates into encoded strings
  (bsc#1052766).
- commit e33d1c5
* Thu May 17 2018 jack@suse.cz
- ubifs: Check ubifs_wbuf_sync() return code (bsc#1052766).
- commit a179714
* Thu May 17 2018 jack@suse.cz
- ocfs2/acl: use 'ip_xattr_sem' to protect getting extended
  attribute (bsc#1052766).
- commit c0afed7
* Thu May 17 2018 jack@suse.cz
- ocfs2: return -EROFS to mount.ocfs2 if inode block is invalid
  (bsc#1052766).
- commit da97770
* Thu May 17 2018 jack@suse.cz
- mm/fadvise: discard partial page if endbyte is also EOF
  (bsc#1052766).
- commit 3f997d0
* Thu May 17 2018 jack@suse.cz
- jffs2_kill_sb(): deal with failed allocations (bsc#1052766).
- commit de4aa95
* Thu May 17 2018 jack@suse.cz
- jbd2: if the journal is aborted then don't allow update of
  the log tail (bsc#1052766).
- commit 67b57ee
* Thu May 17 2018 jack@suse.cz
- fs/reiserfs/journal.c: add missing resierfs_warning() arg
  (bsc#1052766).
- commit 7822e11
* Thu May 17 2018 jack@suse.cz
- f2fs: avoid hungtask when GC encrypted block if io_bits is set
  (bsc#1052766).
- commit 7911426
* Thu May 17 2018 msuchanek@suse.de
- kernel-{binary,docs}.spec sort dependencies.
- commit d2ab971
* Thu May 17 2018 jack@suse.cz
- f2fs: fix heap mode to reset it back (bsc#1052766).
- commit 465478b
* Thu May 17 2018 jack@suse.cz
- ext4: add bounds checking to ext4_xattr_find_entry()
  (bsc#1052766).
- commit 4d6bdef
* Thu May 17 2018 jack@suse.cz
- ext4: move call to ext4_error() into ext4_xattr_check_block()
  (bsc#1052766).
- commit 965aee5
* Thu May 17 2018 jack@suse.cz
- ext4: fail ext4_iget for root directory if unallocated
  (bsc#1087012 cve-2018-1092).
- commit f34f410
* Thu May 17 2018 jack@suse.cz
- ext4: add MODULE_SOFTDEP to ensure crc32c is included in the
  initramfs (bsc#1087007 cve-2018-1094).
- commit 35cde8f
* Thu May 17 2018 jack@suse.cz
- ext4: fix bitmap position validation (bsc#1087095
  cve-2018-1093).
- commit 1c6e15e
* Thu May 17 2018 jack@suse.cz
- ext4: add validity checks for bitmap block numbers (bsc#1087095
  cve-2018-1093).
- commit 7cf212c
* Thu May 17 2018 jack@suse.cz
- ext4: always initialize the crc32c checksum driver (bsc#1087007
  cve-2018-1094).
- commit 6b4bb4d
* Thu May 17 2018 jack@suse.cz
- ext4: don't allow r/w mounts if metadata blocks overlap the
  superblock (bsc#1087007 CVE-2018-1094).
- commit b6c942a
* Thu May 17 2018 jack@suse.cz
- ext4: protect i_disksize update by i_data_sem in direct write
  path (bsc#1052766).
- commit 2c7821b
* Thu May 17 2018 jack@suse.cz
- ext4: don't update checksum of new initialized bitmaps
  (bsc#1052766).
- commit 01962a6
* Thu May 17 2018 jack@suse.cz
- ext4: pass -ESHUTDOWN code to jbd2 layer (bsc#1052766).
- commit dfe0ff7
* Thu May 17 2018 jack@suse.cz
- ext4: eliminate sleep from shutdown ioctl (bsc#1052766).
- commit dcd32a5
* Thu May 17 2018 jack@suse.cz
- ext4: shutdown should not prevent get_write_access
  (bsc#1052766).
- commit b753cba
* Thu May 17 2018 jack@suse.cz
- block: Set BIO_TRACE_COMPLETION on new bio during split
  (bsc#1052766).
- commit 2f880da
* Thu May 17 2018 jack@suse.cz
- block/loop: fix deadlock after loop_set_status (bsc#1052766).
- commit 475b06c
* Thu May 17 2018 jack@suse.cz
- blacklist.conf: Blacklist 6e2fb22103b9
- commit 605d806
* Thu May 17 2018 jack@suse.cz
- block, bfq: put async queues for root bfq groups too
  (bsc#1052766).
- commit ac0e526
* Thu May 17 2018 jack@suse.cz
- afs: Connect up the CB.ProbeUuid (bsc#1052766).
- commit d895d36
* Thu May 17 2018 jack@suse.cz
- afs: Fix missing error handling in afs_write_end()
  (bsc#1052766).
- commit 2e06e76
* Thu May 17 2018 jack@suse.cz
- 9p/trans_virtio: discard zero-length reply (bsc#1052766).
- commit 0110526
* Thu May 17 2018 jack@suse.cz
- delayacct: Account blkio completion on the correct task
  (bsc#1052766).
- commit 2e845da
* Thu May 17 2018 jack@suse.cz
- f2fs: fix to clear CP_TRIMMED_FLAG (bsc#1052766).
- blacklist.conf: Blacklist 3172485f4f80
- commit 38f8eeb
* Thu May 17 2018 jack@suse.cz
- blacklist.conf: Blacklist 2e898e4c0a38
- commit db7d2b4
* Thu May 17 2018 jack@suse.cz
- loop: handle short DIO reads (bsc#1052766).
- commit 5da5b57
* Thu May 17 2018 jack@suse.cz
- bfq-iosched: ensure to clear bic/bfqq pointers when preparing
  request (bsc#1052766).
- commit b6992de
* Thu May 17 2018 jack@suse.cz
- ext4: set h_journal if there is a failure starting a reserved
  handle (bsc#1052766).
- commit ea7ff62
* Thu May 17 2018 jack@suse.cz
- bdi: Fix oops in wb_workfn() (bsc#1052766).
- commit 9cf4d8d
* Thu May 17 2018 jack@suse.cz
- bdi: wake up concurrent wb_shutdown() callers (bsc#1052766).
- commit b3bf0f2
* Thu May 17 2018 tiwai@suse.de
- Bluetooth: btusb: Add Dell XPS 13 9360 to
  btusb_needs_reset_resume_table (bsc#1051510).
- Bluetooth: btusb: Only check needs_reset_resume DMI table for
  QCA rome chipsets (bsc#1051510).
- Revert "Bluetooth: btusb: Fix quirk for Atheros 1525/QCA6174"
  (bsc#1051510).
- drm/nouveau: Fix deadlock in nv50_mstm_register_connector()
  (bsc#1051510).
- drm/vc4: Fix scaling of uni-planar formats (bsc#1051510).
- drm/atomic: Clean old_state/new_state in
  drm_atomic_state_default_clear() (bsc#1051510).
- drm/i915: Fix drm:intel_enable_lvds ERROR message in kernel log
  (bsc#1051510).
- Bluetooth: Set HCI_QUIRK_SIMULTANEOUS_DISCOVERY for
  BTUSB_QCA_ROME (bsc#1051510).
- commit 717100e
* Thu May 17 2018 bpoirier@suse.com
- Move patches.arch/powerpc-64-kexec-fix-race-in-kexec-when-XIVE-is-shut.patch back into sorted section.
  Using the --upstream option of series_sort was needed to move the patch out
  of the out-of-tree section after having updated its tags.
- commit 8000f4d
* Wed May 16 2018 jack@suse.cz
- fsnotify: Hide kABI changes in fsnotify_mark_connector
  (bsc#1052766).
- commit 9542f03
* Wed May 16 2018 tiwai@suse.de
- drm/msm: Fix possible null dereference on failure of get_pages()
  (bsc#1051510).
- commit 6e060f3
* Wed May 16 2018 tiwai@suse.de
- supported.conf: Remove external flag from iwlwifi modules (bsc#1093273)
- commit 6601bf3
* Wed May 16 2018 jack@suse.cz
- ocfs2/dlm: Fix up kABI in dlm_ctxt (bsc#1052766).
- commit 4fb2c31
* Wed May 16 2018 ppyu@suse.com
- x86/cpu_entry_area: Map also trace_idt_table (bsc#1089878).
- commit 84c016e
* Wed May 16 2018 jack@suse.cz
- blacklist.conf: Blacklist a09acf4b43b905
- commit b015d58
* Wed May 16 2018 jack@suse.cz
- blacklist.conf: Blacklist 8a1ac5dc7be0
- commit 2e356a2
* Wed May 16 2018 jack@suse.cz
- eCryptfs: don't pass up plaintext names when using filename
  encryption (bsc#1052766).
- commit 4218bd8
* Wed May 16 2018 jack@suse.cz
- <linux/uaccess.h>: Fix copy_in_user() declaration (bsc#1052766).
- commit 1bf0eca
* Wed May 16 2018 jack@suse.cz
- fsnotify: Fix fsnotify_mark_connector race (bsc#1052766).
- commit 27c3d64
* Wed May 16 2018 jack@suse.cz
- mm/filemap.c: fix NULL pointer in page_cache_tree_insert()
  (bsc#1052766).
- commit 6efc69c
* Wed May 16 2018 jack@suse.cz
- ocfs2/dlm: wait for dlm recovery done when migrating all lock
  resources (bsc#1052766).
- commit 4a66c16
* Wed May 16 2018 jack@suse.cz
- fanotify: fix logic of events on child (bsc#1052766).
- commit 898aece
* Wed May 16 2018 jack@suse.cz
- ext4: prevent right-shifting extents beyond EXT_MAX_BLOCKS
  (bsc#1052766).
- blacklist.conf: blacklist 1202d4ba2899
- commit ec5f585
* Wed May 16 2018 jack@suse.cz
- device-dax: allow MAP_SYNC to succeed (bsc#1052766).
- commit ae5091e
* Wed May 16 2018 mhocko@suse.com
- mm/shmem: do not wait for lock_page() in
  shmem_unused_huge_shrink() (bnc#1089667).
- commit d867479
* Wed May 16 2018 mhocko@suse.com
- mm, oom: fix concurrent munlock and oom reaper unmap, v3
  (bnc#1090150, CVE-2018-1000200).
- commit 47447cd
* Wed May 16 2018 mkubecek@suse.cz
- dccp: check sk for closed state in dccp_sendmsg() (CVE-2018-1130
  bsc#1092904).
- commit ceeb802
* Wed May 16 2018 mkubecek@suse.cz
- Refresh series.conf
  Update upstream reference:
  patches.fixes/vti6-Change-minimum-MTU-to-IPV4_MIN_MTU-vti6-can-car.patch
- commit 6528141
* Wed May 16 2018 msuchanek@suse.de
- macros.kernel-source: Fix building non-x86 KMPs
- commit 8631d05
* Wed May 16 2018 mgorman@suse.de
- sched/numa: Stagger NUMA balancing scan periods for new threads
  (Automatic NUMA Balancing (fate#315482)).
- commit 4201a3f
* Wed May 16 2018 oneukum@suse.com
- USB: Accept bulk endpoints with 1024-byte maxpacket
  (bsc#1092888).
- commit 9797940
* Tue May 15 2018 msuchanek@suse.de
- powerpc/64s: Add support for a store forwarding barrier at
  kernel entry/exit (CVE-2018-3639, bsc#1087082).
- commit 908c138
* Tue May 15 2018 jlee@suse.com
- acpi, nfit: rework NVDIMM leaf method detection (bsc#1091782).
- commit 87ec38c
* Tue May 15 2018 jeffm@suse.com
- reiserfs: package in separate KMP (FATE#323394).
- commit d14f152
* Tue May 15 2018 jeffm@suse.com
- reiserfs: mark read-write mode unsupported (FATE#323394).
- commit 0e79976
* Tue May 15 2018 jeffm@suse.com
- allow_unsupported: add module tainting on feature use (FATE#323394).
- commit 41cd8e7
* Tue May 15 2018 palcantara@suse.de
- blacklist.conf: add cifs commit
  RDMA is unsupported in all SLE versions.
- commit 5b79c0d
* Tue May 15 2018 jlee@suse.com
- update series.conf
- commit aca3df0
* Tue May 15 2018 oneukum@suse.com
- qmi_wwan: do not steal interfaces from class drivers
  (bsc#1092888).
- commit c28e58a
* Tue May 15 2018 oneukum@suse.com
- blacklist.conf: would break kABI
- commit da58da7
* Tue May 15 2018 oneukum@suse.com
- blacklist.conf: build bug not hitting us
- commit a0086b1
* Tue May 15 2018 oneukum@suse.com
- usb: typec: ucsi: Increase command completion timeout value
  (bsc#1090888).
- commit 01614a9
* Tue May 15 2018 jthumshirn@suse.de
- s390/cio: update chpid descriptor after resource accessibility
  event (bnc#1093148, LTC#167307).
- s390/dasd: fix IO error for newly defined devices (bnc#1093148,
  LTC#167307).
- s390/qeth: fix MAC address update sequence (bnc#1093148,
  LTC#167307).
- s390/qeth: translate SETVLAN/DELVLAN errors (bnc#1093148,
  LTC#167307).
- s390/uprobes: implement arch_uretprobe_is_alive() (bnc#1093148,
  LTC#167307).
- commit a741d19
* Tue May 15 2018 jroedel@suse.de
- KVM: SVM: Move spec control call after restore of GS
  (bsc#1087082 CVE-2018-3639).
- commit 65e82a4
* Tue May 15 2018 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 3005f35
* Tue May 15 2018 bpoirier@suse.com
- Fix patch order in sorted section
  Problem introduced in
  bd8adff3d4 Merge branch 'SLE15' into SLE15-UPDATE
- commit 9d5f51b
* Mon May 14 2018 msuchanek@suse.de
- Move 0008-kabi-arm64-reserve-space-in-cpu_hwcaps-and-cpu_hwcap.patch
  Patches in patches.kabi are removed when kabi files are deleted.
  This is not wanted for padding patches.
- commit 0ee5d8b
* Mon May 14 2018 msuchanek@suse.de
- macros.kernel-source: ignore errors when using make to print kernel release
  There is no way to handle the errors anyway and including the error into
  package version does not give good results.
- commit 282e9a6
* Mon May 14 2018 tiwai@suse.de
- ALSA: emu10k1: Fix kABI breakage (bsc#1093027).
- ALSA: emu10k1: add a IOMMU workaround (bsc#1093027).
- ALSA: emu10k1: make sure synth DMA pages are allocated with
  DMA functions (bsc#1093027).
- ALSA: emu10k1: add optional debug printouts with DMA addresses
  (bsc#1093027).
- ALSA: emu10k1: use dma_set_mask_and_coherent() (bsc#1093027).
- ALSA: emu10k1: remove reserved_page (bsc#1093027).
- commit 851a387
* Mon May 14 2018 tiwai@suse.de
- Move to sorted section
  Refresh patches.drivers/ALSA-hda-Fix-incorrect-usage-of-IS_REACHABLE.
- commit d2d47c0
* Mon May 14 2018 lhenriques@suse.com
- ceph: fix rsize/wsize capping in ceph_direct_read_write()
  (bsc#1089115).
- commit ea924b0
* Mon May 14 2018 tiwai@suse.de
- ALSA: aloop: Add missing cable lock to ctl API callbacks
  (bsc#1051510).
- commit dff1fc0
* Mon May 14 2018 tiwai@suse.de
- mac80211: Fix condition validating WMM IE (bsc#1051510).
- drm/atomic: Clean private obj old_state/new_state in
  drm_atomic_state_default_clear() (bsc#1051510).
- platform/x86: asus-wireless: Fix NULL pointer dereference
  (bsc#1051510).
- drm/vmwgfx: Fix a buffer object leak (bsc#1051510).
- drm/bridge: vga-dac: Fix edid memory leak (bsc#1051510).
- ALSA: pcm: Check PCM state at xfern compat ioctl (bsc#1051510).
- ALSA: dice: fix kernel NULL pointer dereference due to invalid
  calculation for array index (bsc#1051510).
- ALSA: seq: Fix races at MIDI encoding in
  snd_virmidi_output_trigger() (bsc#1051510).
- Input: atmel_mxt_ts - add touchpad button mapping for Samsung
  Chromebook Pro (bsc#1051510).
- Input: leds - fix out of bound access (bsc#1051510).
- ALSA: aloop: Mark paused device as inactive (bsc#1051510).
- regulator: cpcap: Fix standby mode (bsc#1051510).
- commit a0aac68
* Mon May 14 2018 tiwai@suse.de
- Preliminary series sort
- commit e06d957
* Mon May 14 2018 msuchanek@suse.de
- Refresh powerpc ftrace patches
- commit 74a0e90
* Mon May 14 2018 msuchanek@suse.de
- powerpc/64/kexec: fix race in kexec when XIVE is shutdown (bsc#1088273).
  Refresh patchset with upstream patches
- Refresh patches.arch/powerpc-64-kexec-fix-race-in-kexec-when-XIVE-is-shut.patch
- Refresh patches.arch/powerpc-xive-fix-hcall-H_INT_RESET-to-support-long-b.patch.
- Refresh patches.arch/powerpc-xive-prepare-all-hcalls-to-support-long-busy.patch.
- Refresh patches.arch/powerpc-xive-shutdown-XIVE-when-kexec-or-kdump-is-pe.patch.
- commit 39957bd
* Mon May 14 2018 bp@suse.de
- blacklist.conf:
- commit a76527a
* Fri May 11 2018 msuchanek@suse.de
- Revert "kernel-binary: do not package extract-cert when not signing modules"
  This reverts commit 10a8bc496a553b8069d490a8ae7508bdb19f58d9.
- commit 1f7acca
* Fri May 11 2018 bp@suse.de
- proc: Use underscores for SSBD in 'status' (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Rename _RDS to _SSBD (bsc#1087082 CVE-2018-3639).
- x86/speculation: Make "seccomp" the default mode for Speculative
  Store Bypass (bsc#1087082 CVE-2018-3639).
- seccomp: Move speculation migitation control to arch code
  (bsc#1087082 CVE-2018-3639).
- seccomp: Add filter flag to opt-out of SSB mitigation
  (bsc#1087082 CVE-2018-3639).
- seccomp: Use PR_SPEC_FORCE_DISABLE (bsc#1087082 CVE-2018-3639).
- prctl: Add force disable speculation (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Make boot modes __ro_after_init (bsc#1087082
  CVE-2018-3639).
- seccomp: Enable speculation flaw mitigations (bsc#1087082
  CVE-2018-3639).
- proc: Provide details on speculation flaw mitigations
  (bsc#1087082 CVE-2018-3639).
- nospec: Allow getting/setting on non-current task (bsc#1087082
  CVE-2018-3639).
- x86/speculation: Add prctl for Speculative Store Bypass
  mitigation (bsc#1087082 CVE-2018-3639).
- x86/process: Allow runtime control of Speculative Store Bypass
  (bsc#1087082 CVE-2018-3639).
- prctl: Add speculation control prctls (bsc#1087082
  CVE-2018-3639).
- x86/speculation: Create spec-ctrl.h to avoid include hell
  (bsc#1087082 CVE-2018-3639).
- x86/KVM/VMX: Expose SPEC_CTRL Bit(2) to the guest (bsc#1087082
  CVE-2018-3639).
- x86/bugs/AMD: Add support to disable RDS on Fam[15,16,17]h if
  requested (bsc#1087082 CVE-2018-3639).
- x86/bugs: Whitelist allowed SPEC_CTRL MSR values (bsc#1087082
  CVE-2018-3639).
- x86/bugs/intel: Set proper CPU features and setup RDS
  (bsc#1087082 CVE-2018-3639).
- x86/bugs: Provide boot parameters for the
  spec_store_bypass_disable mitigation (bsc#1087082
  CVE-2018-3639).
- x86/cpufeatures: Add X86_FEATURE_RDS (bsc#1087082
  CVE-2018-3639).
- x86/bugs: Expose /sys/../spec_store_bypass (bsc#1087082
  CVE-2018-3639).
- x86/bugs, KVM: Support the combination of guest and host IBRS
  (bsc#1087082 CVE-2018-3639).
- x86/bugs: Read SPEC_CTRL MSR during boot and re-use reserved
  bits (bsc#1087082 CVE-2018-3639).
- x86/bugs: Concentrate bug reporting into a separate function
  (bsc#1087082 CVE-2018-3639).
- x86/bugs: Concentrate bug detection into a separate function
  (bsc#1087082 CVE-2018-3639).
- x86/nospec: Simplify alternative_msr_write() (bsc#1087082
  CVE-2018-3639).
- commit 62d3255
* Fri May 11 2018 wqu@suse.com
- btrfs: Fix wrong first_key parameter in replace_path (follow
  up fix for bsc#1084721).
- commit 4346da1
* Fri May 11 2018 jeffm@suse.com
- btrfs: suspend qgroups during relocation recovery (bsc#1086467).
- commit f0b899a
* Fri May 11 2018 jeffm@suse.com
- Refresh
  patches.suse/btrfs-qgroups-fix-rescan-worker-running-races.patch.
  The previous version reintroduced the race that upstream commit 8d9eddad194
  was intended to fix.  This version addresses that issue as well as fixing
  a separate issue where the rescan worker might not have resumed on mount.
- commit 3847d2d
* Fri May 11 2018 jeffm@suse.com
- Delete
  patches.suse/btrfs-push-relocation-recovery-into-helper-thread.patch.
  Pushing relocation recovery into a thread allowed mounts to proceed
  but the file system would end up being unable to be unmounted for some
  time.
- commit a456afe
* Thu May 10 2018 jack@suse.cz
- ext4: Fix hole length detection in ext4_ind_map_blocks()
  (bsc#1090953).
- commit 6264cfb
* Thu May 10 2018 lhenriques@suse.com
- iov_iter: fix memory leak in pipe_get_pages_alloc()
  (bsc#1092710).
- iov_iter: fix return type of __pipe_get_pages() (bsc#1092710).
- commit 0ace052
* Thu May 10 2018 lhenriques@suse.com
- scripts/git_sort/git_sort.py: add Viro's vfs git
- commit 82df85f
* Thu May 10 2018 lhenriques@suse.com
- run series_sort.py
- commit c46ab68
* Thu May 10 2018 jkosina@suse.cz
- scripts/git_sort/git_sort.py: Remove duplicated repo entry
- commit 5449163
* Thu May 10 2018 msuchanek@suse.de
- powerpc/64s: Enhance the information in cpu_show_spectre_v1()
  (bsc#1068032).
- commit 447e243
* Thu May 10 2018 mgorman@suse.de
- Delete
  patches.suse/sched-numa-Delay-retrying-placement-for-automatic-NUMA-balance-after-wake_affine.patch.
- commit d676b29
* Wed May  9 2018 msuchanek@suse.de
- Enable uniput driver (bsc#1092566).
- commit 7e93d22
* Wed May  9 2018 nborisov@suse.com
- Refresh
  patches.suse/revert-btrfs-qgroup-move-half-of-the-qgroup-accounting-time-out-of-commit-trans.patch.
- commit 6bb3a77
* Wed May  9 2018 jthumshirn@suse.de
- libnvdimm, btt: fix format string warnings (bsc#1087205).
- commit 840b821
* Wed May  9 2018 jthumshirn@suse.de
- libnvdimm, btt: add a couple of missing kernel-doc lines
  (bsc#1087210).
- Refresh
  patches.drivers/libnvdimm-btt-fix-an-incompatibility-in-the-log-layout.patch.
- commit a3acfa5
* Wed May  9 2018 jthumshirn@suse.de
- libnvdimm, btt: clean up warning and error messages
  (bsc#1087205).
- Refresh
  patches.drivers/libnvdimm-btt-fix-an-incompatibility-in-the-log-layout.patch.
- commit f89db23
* Tue May  8 2018 msuchanek@suse.de
- powerpc/lib: Fix off-by-one in alternate feature patching
  (bsc#1065729).
- commit 64ed10b
* Tue May  8 2018 msuchanek@suse.de
- ibmvnic: Clean actual number of RX or TX pools (bsc#1092289).
- commit 87e794b
* Mon May  7 2018 jthumshirn@suse.de
- acpi, nfit: quiet invalid block-aperture-region warnings
  (bsc#1091781).
- commit 02372d1
* Fri May  4 2018 rgoldwyn@suse.com
- ovl: treat btrfs mounts as different superblocks (bsc#1059336).
- commit f3a38b6
* Fri May  4 2018 tbogendoerfer@suse.de
- net/mlx5: Avoid cleaning flow steering table twice during
  error flow (bsc#1091532).
- commit 62f9ca0
* Fri May  4 2018 bp@suse.de
- x86/xen: Calculate __max_logical_packages on PV domains
  (bsc#1091543).
- x86/smpboot: Do not use smp_num_siblings in
  __max_logical_packages calculation (bsc#1091543).
- xen/vcpu: Handle xen_vcpu_setup() failure at boot (bsc#1091543).
- commit bbde611
* Fri May  4 2018 lhenriques@suse.com
- regulator: gpio: Fix some error handling paths in
  'gpio_regulator_probe()' (bsc#1091960).
- commit 11d5f9c
* Fri May  4 2018 tiwai@suse.de
- ALSA: hda - Fix incorrect usage of IS_REACHABLE() (bsc#1051510).
- commit 80496e0
* Thu May  3 2018 tiwai@suse.de
- ACPI / video: Only default only_lcd to true on Win8-ready
  _desktops_ (bsc#1051510).
- commit 0fc9eb6
* Thu May  3 2018 tiwai@suse.de
- Bluetooth: hci_bcm: Remove DMI quirk for the MINIX Z83-4
  (bsc#1051510).
- Bluetooth: hci_bcm: Add 6 new ACPI HIDs (bsc#1051510).
- commit b8563e2
* Thu May  3 2018 tiwai@suse.de
- Bluetooth: hci_bcm: Treat Interrupt ACPI resources as always
  being active-low (bsc#1051510).
- Bluetooth: hci_bcm: Add support for BCM2E72 (bsc#1051510).
- commit a0d1341
* Thu May  3 2018 tiwai@suse.de
- Bluetooth: hci_bcm: Add support for MINIX Z83-4 based devices
  (bsc#1051510).
- Refresh
  patches.drivers/Bluetooth-hci_bcm-Add-support-for-BCM2E7E.
- commit 72f23eb
* Thu May  3 2018 msuchanek@suse.de
- powerpc/64s: Enable barrier_nospec based on firmware settings
  (bsc#1068032, bsc#1080157).
  Delete patches.arch/powerpc-64-barrier_nospec-Add-commandline-trigger.patch.
  Delete patches.arch/powerpc-64s-barrier_nospec-Add-hcall-trigger.patch.
- commit a3f6f3e
* Thu May  3 2018 tiwai@suse.de
- Bluetooth: hci_bcm: Fix setting of irq trigger type
  (bsc#1051510).
- commit 4e523f8
* Thu May  3 2018 tiwai@suse.de
- Bluetooth: hci_bcm: Handle empty packet after firmware loading
  (bsc#1051510).
- Bluetooth: hci_bcm: Make bcm_request_irq fail if no IRQ resource
  (bsc#1051510).
- Bluetooth: hci_bcm: Add active_low irq polarity quirk for Asus
  T100CHI (bsc#1051510).
- commit c5294d7
* Thu May  3 2018 tiwai@suse.de
- ima: Fallback to the builtin hash algorithm (bsc#1091686).
- commit f2a7590
* Thu May  3 2018 msuchanek@suse.de
- Delete patches.arch/powerpc-64s-Use-barrier_nospec-in-RFI_FLUSH_SLOT.patch.
- commit f4a4c12
* Thu May  3 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-64-Use-barrier_nospec-in-syscall-entry.patch.
- commit 238866b
* Thu May  3 2018 msuchanek@suse.de
- powerpc: Use barrier_nospec in copy_from_user() (bsc#1068032,
  bsc#1080157).
- commit 080b1ec
* Thu May  3 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-Add-barrier_nospec.patch
  Refresh patches.arch/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch
  Refresh patches.arch/powerpc-64-Patch-barrier_nospec-in-modules.patch
  Delete patches.arch/powerpc-64-barrier_nospec-Add-debugfs-trigger.patch
- commit 40ed6a0
* Thu May  3 2018 tiwai@suse.de
- Delete patches.drivers/ASoC-rt5514-Add-the-missing-register-in-the-readable
  This is not really needed for SLE15 kernel (yet).
- commit 5784e60
* Thu May  3 2018 tiwai@suse.de
- Fix the build error in adau17x1 soc driver (bsc#1051510)
  Refreshed patch:
  patches.drivers/ASoC-adau17x1-Handling-of-DSP_RUN-register-during-fw
- commit 50449fc
* Thu May  3 2018 mkubecek@suse.cz
- vti6: Change minimum MTU to IPV4_MIN_MTU, vti6 can carry IPv4
  too (bsc#1082869).
- commit 2585ed1
* Thu May  3 2018 mkubecek@suse.cz
- vti6: Fix dev->max_mtu setting (bsc#1082869).
- commit 0b18cdf
* Thu May  3 2018 mkubecek@suse.cz
- vti6: Keep set MTU on link creation or change, validate it
  (bsc#1082869).
- commit 4b40c7c
* Thu May  3 2018 mkubecek@suse.cz
- vti6: Properly adjust vti6 MTU from MTU of lower device
  (bsc#1082869).
- commit 68cda33
* Thu May  3 2018 mkubecek@suse.cz
- ip6_vti: adjust vti mtu according to mtu of lower device
  (bsc#1082869).
- commit 3a6c0fa
* Thu May  3 2018 mkubecek@suse.cz
- ipv4: igmp: guard against silly MTU values (bsc#1082869).
- commit 82d3d2c
* Thu May  3 2018 mkubecek@suse.cz
- Update mainline reference:
  patches.fixes/netfilter-ebtables-fix-erroneous-reject-of-last-rule.patch
- commit 5d4c7dd
* Thu May  3 2018 mkubecek@suse.cz
- sctp: verify size of a new chunk in _sctp_make_chunk()
  (CVE-2018-5803 bsc#1083900).
- commit 51d8978
* Thu May  3 2018 mkubecek@suse.cz
- rds: Fix NULL pointer dereference in __rds_rdma_map
  (CVE-2018-7492 bsc#1082962).
- commit 23bba58
* Wed May  2 2018 tiwai@suse.de
- crypto: drbg - set freed buffers to NULL (bsc#1051510).
- drm/i915: Enable display WA#1183 from its correct spot
  (bsc#1051510).
- drm/virtio: fix vq wait_event condition (bsc#1051510).
- drm/amdgpu: set COMPUTE_PGM_RSRC1 for SGPR/VGPR clearing shaders
  (bsc#1051510).
- thermal: imx: Fix race condition in imx_thermal_probe()
  (bsc#1051510).
- thunderbolt: Resume control channel after hibernation image
  is created (bsc#1051510).
- thermal: power_allocator: fix one race condition issue for
  thermal_instances list (bsc#1051510).
- pinctrl: baytrail: Enable glitch filter for GPIOs used as
  interrupts (bsc#1051510).
- omapdrm: panel: fix compatible vendor string for td028ttec1
  (bsc#1051510).
- pinctrl: denverton: Fix UART2 RTS pin mode (bsc#1051510).
- thermal/drivers/step_wise: Fix temperature regulation
  misbehavior (bsc#1051510).
- commit d15623c
* Wed May  2 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvfc-avoid-unnecessary-port-relogin.patch
- commit d88d95f
* Wed May  2 2018 tiwai@suse.de
- Fix kABI breakage due to snd_usb_audio_quirk profile_name
  addition (bsc#1091678).
- ALSA: usb-audio: Give proper vendor/product name for Dell WD15
  Dock (bsc#1091678).
- ALSA: usb-audio: Allow to override the longname string
  (bsc#1091678).
- ALSA: usb-audio: Add "Keep Interface" control (bsc#1089467).
- ALSA: usb-audio: Add keep_iface flag (bsc#1089467).
- ALSA: usb-audio: Avoid superfluous usb_set_interface() calls
  (bsc#1089467).
- ALSA: usb-audio: Initialize Dell Dock playback volumes
  (bsc#1089467).
- commit fe9e40b
* Wed May  2 2018 tiwai@suse.de
- blacklist.conf: Add drm/i915/gvt entries
- commit 608a429
* Wed May  2 2018 tiwai@suse.de
- drm/i915/bios: filter out invalid DDC pins from VBT child
  devices (bsc#1051510).
- commit 45ac78f
* Wed May  2 2018 bp@suse.de
- x86/smpboot: Fix __max_logical_packages estimate (bsc#1091543).
- commit 2eb7ead
* Wed May  2 2018 msuchanek@suse.de
- kernel-binary: also default klp_symbols to 0 here.
- commit e35f14a
* Wed May  2 2018 msuchanek@suse.de
- klp_symbols: make --klp-symbols argument semantic sane
  It selects build of klp symbols and defaults to off
- commit 0e53042
* Wed May  2 2018 jthumshirn@suse.de
- qla2xxx: Enable T10-DIF with FC-NVMe enabled (bsc#1091264).
- commit fa61ec8
* Wed May  2 2018 msuchanek@suse.de
- powerpc/perf: fix bug references.
- commit 9413630
* Wed May  2 2018 lhenriques@suse.com
- libceph: validate con->state at the top of try_write()
  (bsc#1089115).
- libceph: reschedule a tick in finish_hunting() (bsc#1089115).
- libceph: un-backoff on tick when we have a authenticated session
  (bsc#1089115).
- commit bafc6da
* Wed May  2 2018 lhenriques@suse.com
- ceph: check if mds create snaprealm when setting quota
  (FATE#323422 bsc#1089115).
- commit c1584f3
* Wed May  2 2018 jlee@suse.com
- kexec_file: do not add extra alignment to efi memmap
  (bsc#1089268).
- commit b74811e
* Mon Apr 30 2018 bp@suse.de
- x86,sched: Allow topologies where NUMA nodes share an LLC
  (bsc#1091158).
- commit a8d2942
* Mon Apr 30 2018 jeffm@suse.com
- Refresh patches.suse/btrfs-use-kvzalloc-to-allocate-btrfs_fs_info.patch
  - Fixed References (bsc#1062897).
  - Updated patch tags.
- commit aeff055
* Mon Apr 30 2018 tiwai@suse.de
- spi: atmel: init FIFOs before spi enable (bsc#1051510).
- spi: Fix scatterlist elements size in spi_map_buf (bsc#1051510).
- spi: sun6i: disable/unprepare clocks on remove (bsc#1051510).
- spi: imx: do not access registers while clocks disabled
  (bsc#1051510).
- spi: xilinx: Detect stall with Unknown commands (bsc#1051510).
- spi: sun4i: disable clocks in the remove function (bsc#1051510).
- spi: atmel: fixed spin_lock usage inside atmel_spi_remove
  (bsc#1051510).
- spi: a3700: Fix clk prescaling for coefficient over 15
  (bsc#1051510).
- spi: spi-axi: fix potential use-after-free after deregistration
  (bsc#1051510).
- spi: sh-msiof: Fix DMA transfer size check (bsc#1051510).
- spi: bcm-qspi: Fix use after free in bcm_qspi_probe() in error
  path (bsc#1051510).
- spi: a3700: Return correct value on timeout detection
  (bsc#1051510).
- spi: armada-3700: Fix failing commands with quad-SPI
  (bsc#1051510).
- commit e6b76f4
* Mon Apr 30 2018 tiwai@suse.de
- partitions/msdos: Unable to mount UFS 44bsd partitions
  (bsc#1051510).
- commit 5e36816
* Mon Apr 30 2018 tiwai@suse.de
- iio: st_pressure: st_accel: pass correct platform data to init
  (bsc#1051510).
- hwmon: (ina2xx) Fix access to uninitialized mutex (bsc#1051510).
- hwmon: (ina2xx) Make calibration register value fixed
  (bsc#1051510).
- iio: st_pressure: st_accel: Initialise sensor platform data
  properly (bsc#1051510).
- commit a13dfdc
* Mon Apr 30 2018 tiwai@suse.de
- etnaviv: fix gem object list corruption (bsc#1051510).
- etnaviv: fix submit error path (bsc#1051510).
- commit b019495
* Mon Apr 30 2018 tiwai@suse.de
- dmaengine: ti-dma-crossbar: Fix possible race condition with
  dma_inuse (bsc#1051510).
- commit 419987b
* Mon Apr 30 2018 tiwai@suse.de
- dmaengine: at_xdmac: fix rare residue corruption (bsc#1051510).
- crypto: arm,arm64 - Fix random regeneration of S_shipped
  (bsc#1051510).
- dmaengine: ti-dma-crossbar: Fix event mapping for
  TPCC_EVT_MUX_60_63 (bsc#1051510).
- dmaengine: dmatest: fix container_of member in dmatest_callback
  (bsc#1051510).
- dmaengine: jz4740: disable/unprepare clk if probe fails
  (bsc#1051510).
- dmaengine: dmatest: move callback wait queue to thread context
  (bsc#1051510).
- dmaengine: at_hdmac: fix potential NULL pointer dereference
  in atc_prep_dma_interleaved (bsc#1051510).
- dmaengine: ioat: Fix error handling path (bsc#1051510).
- dmaengine: ti-dma-crossbar: Correct am335x/am43xx mux value type
  (bsc#1051510).
- dmaengine: dmatest: warn user when dma test times out
  (bsc#1051510).
- dmaengine: edma: Align the memcpy acnt array size with the
  transfer (bsc#1051510).
- commit a771c38
* Mon Apr 30 2018 tiwai@suse.de
- mtd: ubi: wl: Fix error return code in ubi_wl_init()
  (bsc#1051510).
- commit 25a7288
* Mon Apr 30 2018 tiwai@suse.de
- ubi: Reject MLC NAND (bsc#1051510).
- ubi: Fix error for write access (bsc#1051510).
- ubi: fastmap: Don't flush fastmap work on detach (bsc#1051510).
- ubi: block: Fix locking for idr_alloc/idr_remove (bsc#1051510).
- ubi: fastmap: Erase outdated anchor PEBs during attach
  (bsc#1051510).
- ubi: Fix race condition between ubi volume creation and udev
  (bsc#1051510).
- commit 5d7894b
* Mon Apr 30 2018 tiwai@suse.de
- blacklist.conf: Add a blacklist entry for geneve
- commit b5d829a
* Mon Apr 30 2018 tiwai@suse.de
- cdrom: information leak in cdrom_ioctl_media_changed()
  (bsc#1051510).
- watchdog: f71808e_wdt: Fix WD_EN register read (bsc#1051510).
- Revert "ath10k: send (re)assoc peer command when NSS changed"
  (bsc#1051510).
- drm: bridge: dw-hdmi: Fix overflow workaround for Amlogic
  Meson GX SoCs (bsc#1051510).
- platform/x86: thinkpad_acpi: suppress warning about palm
  detection (bsc#1051510).
- PCI: Add function 1 DMA alias quirk for Marvell 9128
  (bsc#1051510).
- firmware: dmi_scan: Fix handling of empty DMI strings
  (bsc#1051510).
- efi/esrt: Use memunmap() instead of kfree() to free the
  remapping (bsc#1051510).
- geneve: fix fill_info when link down (bsc#1051510).
- geneve: Fix function matching VNI and tunnel ID on big-endian
  (bsc#1051510).
- commit 330b2a7
* Mon Apr 30 2018 tiwai@suse.de
- Delete patches.drivers/pinctrl-intel-Initialize-GPIO-properly-when-used-thr
  It's reverted in the stable tree due to reported regression
- commit 3133199
* Sat Apr 28 2018 tiwai@suse.de
- ALSA: dice: fix error path to destroy initialized stream data
  (bsc#1051510).
- ALSA: hda - Skip jack and others for non-existing PCM streams
  (bsc#1051510).
- ASoC: topology: Check widget kcontrols before deref
  (bsc#1051510).
- ASoC: topology: Fix bugs of freeing soc topology (bsc#1051510).
- ASoC: rt5514: Add the missing register in the readable table
  (bsc#1051510).
- ASoC: adau17x1: Handling of DSP_RUN register during fw setup
  (bsc#1051510).
- ASoC: topology: fix some tiny memory leaks (bsc#1051510).
- ASoC: rsnd: mark PM functions __maybe_unused (bsc#1051510).
- ASoC: fsl_esai: Fix divisor calculation failure at lower ratio
  (bsc#1051510).
- ALSA: hda/realtek - change the location for one of two front
  mics (bsc#1051510).
- ALSA: rme9652: Hardening for potential Spectre v1 (bsc#1051510).
- ALSA: hdspm: Hardening for potential Spectre v1 (bsc#1051510).
- ALSA: asihpi: Hardening for potential Spectre v1 (bsc#1051510).
- ALSA: opl3: Hardening for potential Spectre v1 (bsc#1051510).
- ALSA: hda: Hardening for potential Spectre v1 (bsc#1051510).
- ALSA: control: Hardening for potential Spectre v1 (bsc#1051510).
- ALSA: seq: oss: Hardening for potential Spectre v1
  (bsc#1051510).
- ALSA: seq: oss: Fix unbalanced use lock for synth MIDI device
  (bsc#1051510).
- ALSA: hda/realtek - Update ALC255 depop optimize (bsc#1051510).
- ALSA: hda/realtek - Add some fixes for ALC233 (bsc#1051510).
- ALSA: dice: fix OUI for TC group (bsc#1051510).
- ALSA: core: Report audio_tstamp in snd_pcm_sync_ptr
  (bsc#1051510).
- commit c706327
* Fri Apr 27 2018 tiwai@suse.de
- Sort & update the upstreamed patch
- commit 073ffc8
* Fri Apr 27 2018 tiwai@suse.de
- PM / wakeirq: Fix unbalanced IRQ enable for wakeirq
  (bsc#1051510).
- firewire-ohci: work around oversized DMA reads on JMicron
  controllers (bsc#1051510).
- Input: synaptics - reset the ABS_X/Y fuzz after initializing
  MT axes (bsc#1051510).
- HID: roccat: prevent an out of bounds read in
  kovaplus_profile_activated() (bsc#1051510).
- commit 33bdbae
* Fri Apr 27 2018 tiwai@suse.de
- drm/i915/audio: Fix audio detection issue on GLK (bsc#1051510).
- drm/i915/gvt: throw error on unhandled vfio ioctls
  (bsc#1051510).
- drm/i915: Fix LSPCON TMDS output buffer enabling from low-power
  state (bsc#1051510).
- drm/vc4: Fix memory leak during BO teardown (bsc#1051510).
- drm/nouveau/pmu/fuc: don't use movw directly anymore
  (bsc#1051510).
- commit 51fec3e
* Fri Apr 27 2018 tiwai@suse.de
- staging: comedi: ni_mio_common: ack ai fifo error interrupts
  (bsc#1051510).
- rhashtable: Fix rhlist duplicates insertion (bsc#1051510).
- staging: comedi: fix comedi_nsamples_left (bsc#1051510).
- commit 9211443
* Fri Apr 27 2018 tiwai@suse.de
- tty: vt: fix up tabstops properly (bsc#1051510).
- tty/serial: atmel: add new version check for usart
  (bsc#1051510).
- tty: make n_tty_read() always abort if hangup is in progress
  (bsc#1051510).
- vmxnet3: repair memory leak (bsc#1051510).
- virtio: release virtio index when fail to device_register
  (bsc#1051510).
- tty: fix tty_ldisc_receive_buf() documentation (bsc#1051510).
- tty fix oops when rmmod 8250 (bsc#1051510).
- tty: fix __tty_insert_flip_char regression (bsc#1051510).
- tty: improve tty_insert_flip_char() slow path (bsc#1051510).
- tty: improve tty_insert_flip_char() fast path (bsc#1051510).
- commit f0d5a29
* Fri Apr 27 2018 tiwai@suse.de
- random: crng_reseed() should lock the crng instance that it
  is modifying (bsc#1051510).
- random: use a different mixing algorithm for
  add_device_randomness() (bsc#1051510).
- ACPI / hotplug / PCI: Check presence of slot itself in
  get_slot_status() (bsc#1051510).
- random: use a tighter cap in credit_entropy_bits_safe()
  (bsc#1051510).
- ACPI / video: Add quirk to force acpi-video backlight on
  Samsung 670Z5E (bsc#1051510).
- radeon: hide pointless #warning when compile testing
  (bsc#1051510).
- commit 12b5734
* Fri Apr 27 2018 palcantara@suse.de
- cifs: silence compiler warnings showing up with gcc-8.0.0
  (bsc#1090734).
- commit 13d9001
* Fri Apr 27 2018 msuchanek@suse.de
- kernel-binary: only install modules.fips on modular kernels.
- commit 6408562
* Thu Apr 26 2018 msuchanek@suse.de
- powerpc/64s/idle: Fix restore of AMOR on POWER9 after deep sleep
  (bsc#1055186, fate#323286).
- commit 6368307
* Thu Apr 26 2018 msuchanek@suse.de
- Update config files.
- commit 6174b6c
* Thu Apr 26 2018 msuchanek@suse.de
- powerpc/mm/radix: Fix checkstops caused by invalid tlbiel
  (bsc#1055186, fate#323286).
- powerpc/mm/radix: Update command line parsing for disable_radix
  (bsc#1055186, fate#323286).
- powerpc/mm/radix: Parse disable_radix commandline correctly
  (bsc#1055186, fate#323286).
- powerpc/mm/radix: Update pte fragment count from 16 to 256 on
  radix (bsc#1055186, fate#323286).
- powerpc/mm/radix: Fix always false comparison against
  MMU_NO_CONTEXT (bsc#1055186, fate#323286).
- powerpc/mm: Add a CONFIG option to choose if radix is used by
  default (bsc#1055186, fate#323286).
- commit e9d987c
* Thu Apr 26 2018 msuchanek@suse.de
- powerpc/xive: Fix wrong xmon output caused by typo
  (bsc#1088273).
- commit f3598fe
* Thu Apr 26 2018 jeffm@suse.com
- btrfs: qgroups, fix rescan worker running races (bsc#1091101).
- commit 3c4b9ba
* Thu Apr 26 2018 tiwai@suse.de
- Fix kABI breakage for iwlwifi (bsc#1051510).
- commit 6a7a6df
* Thu Apr 26 2018 tiwai@suse.de
- cros_ec: fix nul-termination for firmware build info
  (bsc#1051510).
- commit 174eb4e
* Thu Apr 26 2018 tiwai@suse.de
- extcon: intel-cht-wc: Set direction and drv flags for V5 boost
  GPIO (bsc#1051510).
- commit 64fbab3
* Thu Apr 26 2018 tiwai@suse.de
- HID: wacom: bluetooth: send exit report for recent Bluetooth
  devices (bsc#1051510).
- HID: hidraw: Fix crash on HIDIOCGFEATURE with a destroyed device
  (bsc#1051510).
- HID: i2c-hid: fix size check and type usage (bsc#1051510).
- commit 993f9a1
* Thu Apr 26 2018 tiwai@suse.de
- iwlwifi: add a bunch of new 9000 PCI IDs (1051510).
- iwlwifi: add shared clock PHY config flag for some devices
  (bsc#1051510).
- commit 7b9cdea
* Wed Apr 25 2018 duwe@suse.de
- supported.conf: mark new FIPS modules as supported:
  sha2-mb, sha3, crc32 and crypto_engine (bsc#1074984)
- commit 9e8aa4a
* Wed Apr 25 2018 tiwai@suse.de
- random: fix crng_ready() test (CVE-2018-1108,bsc#1090818).
- commit 8c55b94
* Wed Apr 25 2018 jeffm@suse.com
- btrfs: use spinlock to protect ->caching_block_groups list
  (bsc#1083684).
- commit bb913e1
* Wed Apr 25 2018 oneukum@suse.com
- thunderbolt: Prevent crash when ICM firmware is not running
  (bsc#1090888).
- commit 55c6570
* Wed Apr 25 2018 oneukum@suse.com
- thunderbolt: Wait a bit longer for ICM to authenticate the
  active NVM (bsc#1090888).
- commit 6659ddb
* Wed Apr 25 2018 oneukum@suse.com
- thunderbolt: Serialize PCIe tunnel creation with PCI rescan
  (bsc#1090888).
- commit a096906
* Wed Apr 25 2018 tbogendoerfer@suse.de
- bnxt_en: Fix memory fault in bnxt_ethtool_init() (bsc#1050242
  FATE#322914).
- commit 65193fa
* Wed Apr 25 2018 jroedel@suse.de
- kvm/x86: fix icebp instruction handling (bsc#1087088).
- commit 364bcca
* Wed Apr 25 2018 mbrugger@suse.com
- crypto: cavium - Fix smp_processor_id() warnings (bsc#1089141).
- crypto: cavium - Fix statistics pending request value (bsc#1089141).
- crypto: cavium - Prevent division by zero (bsc#1089141).
- crypto: cavium - Limit result reading attempts (bsc#1089141).
- crypto: cavium - Fix fallout from CONFIG_VMAP_STACK (bsc#1089141).
- commit 6ff9496
* Wed Apr 25 2018 mgalbraith@suse.de
- timers: Unconditionally check deferrable base (Git-fixes).
- commit 037afa6
* Wed Apr 25 2018 mgalbraith@suse.de
- timers: Invoke timer_start_debug() where it makes sense (Git-fixes).
- commit 5e14924
* Wed Apr 25 2018 mgalbraith@suse.de
- timers: Reinitialize per cpu bases on hotplug (Git-fixes).
- commit c719ba1
* Wed Apr 25 2018 mgalbraith@suse.de
- timers: Use deferrable base independent of base::nohz_active (Git-fixes).
- commit 022b1b5
* Wed Apr 25 2018 mgalbraith@suse.de
- kernel/relay.c: revert "kernel/relay.c: fix potential memory leak" (Git-fixes).
- commit 430af9e
* Wed Apr 25 2018 mgalbraith@suse.de
- kernel/async.c: revert "async: simplify lowest_in_progress()" (Git-fixes).
- commit ed38813
* Wed Apr 25 2018 mgalbraith@suse.de
- kernel/acct.c: fix the acct->needcheck check in check_free_space() (Git-fixes).
- commit 9e7e582
* Wed Apr 25 2018 mgalbraith@suse.de
- kernel/signal.c: remove the no longer needed SIGNAL_UNKILLABLE check in complete_signal() (Git-fixes).
- commit 93f2736
* Wed Apr 25 2018 mgalbraith@suse.de
- kernel/signal.c: protect the SIGNAL_UNKILLABLE tasks from !sig_kernel_only() signals (Git-fixes).
- commit 639bb8b
* Wed Apr 25 2018 mgalbraith@suse.de
- kernel/signal.c: protect the traced SIGNAL_UNKILLABLE tasks from SIGKILL (Git-fixes).
- commit dec725f
* Wed Apr 25 2018 mgalbraith@suse.de
- cpuidle: fix broadcast control when broadcast can not be entered (Git-fixes).
- commit ff8d2ee
* Wed Apr 25 2018 mgalbraith@suse.de
- cgroup: Fix deadlock in cpu hotplug path (Git-fixes).
- commit 9b3c11e
* Wed Apr 25 2018 mgalbraith@suse.de
- cgroup: Reinit cgroup_taskset structure before cgroup_migrate_execute() returns (Git-fixes).
- commit 283d1e4
* Wed Apr 25 2018 mgalbraith@suse.de
- sched: Stop switched_to_rt() from sending IPIs to offline CPUs (Git-fixes).
- commit ee6573f
* Wed Apr 25 2018 mgalbraith@suse.de
- sched: Stop resched_cpu() from sending IPIs to offline CPUs (Git-fixes).
- commit 73d0b6a
* Wed Apr 25 2018 mgalbraith@suse.de
- sched: Make resched_cpu() unconditional (Git-fixes).
- commit 3dbb06c
* Tue Apr 24 2018 msuchanek@suse.de
- split-modules: use MAKE_ARGS
- commit d8fe174
* Tue Apr 24 2018 mcgrof@suse.com
- xfs: set format back to extents if xfs_bmap_extents_to_btree (bsc#1090717, CVE-2018-10323).
- commit cd127e8
* Tue Apr 24 2018 msuchanek@suse.de
- powerpc/kvm: Fix lockups when running KVM guests on Power8
  (bsc#1061840).
- KVM: PPC: Book3S HV: trace_tlbie must not be called in realmode
  (bsc#1061840).
- powerpc/64s/idle: avoid sync for KVM state when waking from idle
  (bsc#1061840).
- commit 80221b7
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass MAKE_ARGS to install script as well.
- commit ce62ae7
* Tue Apr 24 2018 tiwai@suse.de
- mmc: sdhci-pci: Only do AMD tuning for HS200 (bsc#1051510).
- mmc: jz4740: Fix race condition in IRQ mask update
  (bsc#1051510).
- media: atomisp_fops.c: disable atomisp_compat_ioctl32
  (bsc#1051510).
- media: vivid: check if the cec_adapter is valid (bsc#1051510).
- commit ee04250
* Tue Apr 24 2018 tiwai@suse.de
- i2c: i801: Restore configuration at shutdown (bsc#1051510).
- i2c: i801: Save register SMBSLVCMD value only once
  (bsc#1051510).
- commit 471916c
* Tue Apr 24 2018 tiwai@suse.de
- drm/rockchip: Clear all interrupts before requesting the IRQ
  (bsc#1051510).
- commit e5e94e3
* Tue Apr 24 2018 tiwai@suse.de
- drm/radeon: add PX quirk for Asus K73TK (bsc#1051510).
- drm/amdgpu: Fix PCIe lane width calculation (bsc#1051510).
- drm/radeon: Fix PCIe lane width calculation (bsc#1051510).
- drm/amdgpu/si: implement get/set pcie_lanes asic callback
  (bsc#1051510).
- drm/amdgpu/sdma: fix mask in emit_pipeline_sync (bsc#1051510).
- drm/amdgpu: Add an ATPX quirk for hybrid laptop (bsc#1051510).
- drm/amdgpu: Fix always_valid bos multiple LRU insertions
  (bsc#1051510).
- drm/radeon: make MacBook Pro d3_delay quirk more generic
  (bsc#1051510).
- commit 1eaebf1
* Tue Apr 24 2018 tiwai@suse.de
- ASoC: topology: Fix kcontrol name string handling (bsc#1051510).
- ASoC: ssm2602: Replace reg_default_raw with reg_default
  (bsc#1051510).
- commit 633441a
* Tue Apr 24 2018 tiwai@suse.de
- ALSA: usb-audio: Skip broken EU on Dell dock USB-audio
  (bsc#1090658).
- commit e97ea42
* Tue Apr 24 2018 msuchanek@suse.de
- kernel-binary: pass ARCH= to kernel build
  Recent kernel does not save CONFIG_64BIT so it has to be specified by
  arch.
- commit fb21b73
* Tue Apr 24 2018 tiwai@suse.de
- Remove the old fallback for iTCO/WDAT conflict (bsc#1073960)
  Now the upstream fix is included, so let's rip off the old trickery.
- commit da64882
* Tue Apr 24 2018 tiwai@suse.de
- ACPI / scan: Initialize watchdog before PNP (bsc#1073960).
- commit 263ebe9
* Tue Apr 24 2018 tiwai@suse.de
- Patch tag update for UDL security fix (CVE-2018-8781, bsc#1090643).
- commit d84720c
* Tue Apr 24 2018 msuchanek@suse.de
- supported.conf: remove obsolete entry
  drivers/tty/serial/of_serial -> drivers/tty/serial/8250/8250_of
- commit 8e4b38c
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: convert XFS_AGFL_SIZE to a helper function (bsc#1090534).
- commit 027dd64
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: detect agfl count corruption and reset agfl (bsc#1090534).
- commit b1c0509
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: allow CoW remap transactions to use reserve blocks (bsc#1090535).
- commit 03d1b76
* Mon Apr 23 2018 mcgrof@suse.com
- xfs: fix transaction allocation deadlock in IO path (bsc#1090535).
- commit 8697899
* Mon Apr 23 2018 nstange@suse.de
- ppc64le: reliable stacktrace: mark stacktraces with
  kretprobe_trampoline as unreliable (bsc#1090522).
- commit ed9151a
* Mon Apr 23 2018 lhenriques@suse.com
- ceph: always update atime/mtime/ctime for new inode
  (bsc#1089115).
- commit eca01ee
* Mon Apr 23 2018 tiwai@suse.de
- resource: fix integer overflow at reallocation (bsc#1086739).
- commit 2ed06e1
* Mon Apr 23 2018 tiwai@suse.de
- drm/i915: Call i915_perf_fini() on init_hw error unwind
  (bsc#1051510).
- drm/i915: Do no use kfree() to free a kmem_cache_alloc()
  return value (bsc#1051510).
- ALSA: rawmidi: Fix missing input substream checks in compat
  ioctls (bsc#1051510).
- ALSA: hda/realtek - adjust the location of one mic
  (bsc#1051510).
- ALSA: hda/realtek - set PINCFG_HEADSET_MIC to parse_flags
  (bsc#1051510).
- ALSA: hda - New VIA controller suppor no-snoop path
  (bsc#1051510).
- ALSA: line6: Use correct endpoint type for midi output
  (bsc#1051510).
- commit 2ac2d9f
* Mon Apr 23 2018 tiwai@suse.de
- Refresh patches.drivers/gpio-fix-gpio-line-names-property-retrieval
  Fix the trivial compile warnings due to const.
- commit 0fa7c5f
* Mon Apr 23 2018 nborisov@suse.com
- Refresh
  patches.suse/btrfs-fix-race-condition-between-delayed-refs-and-blockgroup-removal.patch.
- commit 1ba0893
* Mon Apr 23 2018 neilb@suse.com
- xprtrdma: Fix corner cases when handling device removal
  (git-fixes).
- nfsd: fix incorrect umasks (git-fixes).
- fs: Teach path_connected to handle nfs filesystems with multiple
  roots (git-fixes).
- md raid10: fix NULL deference in handle_write_completed()
  (git-fixes).
- fix kabi breaker in md.h (git-fixes).
- md: fix md_write_start() deadlock w/o metadata devices
  (git-fixes).
- nfs: system crashes after NFS4ERR_MOVED recovery (git-fixes).
- commit 69e2c71
* Fri Apr 20 2018 jeffm@suse.com
- Refresh
  patches.suse/btrfs-push-relocation-recovery-into-helper-thread.patch.
  There was a missing variable initialization due a stale patch refresh.
- commit 297fd49
* Fri Apr 20 2018 msuchanek@suse.de
- powerpc: Add ppc_breakpoint_available() (bsc#1055117).
- commit 0b632a4
* Fri Apr 20 2018 msuchanek@suse.de
- selftests/powerpc: Fix copyloops build since Power4 assembler
  change (bsc#1055117).
- commit e26f88f
* Fri Apr 20 2018 msuchanek@suse.de
- powerpc/64s: Fix CPU_FTRS_ALWAYS vs DT CPU features
  (bsc#1055117).
- powerpc/64s: Fix POWER9 DD2.2 and above in cputable features
  (bsc#1055117).
- powerpc/64s: Fix pkey support in dt_cpu_ftrs, add CPU_FTR_PKEY
  bit (bsc#1055117).
- powerpc/64s: Fix dt_cpu_ftrs to have restore_cpu clear unwanted
  LPCR bits (bsc#1055117).
- powerpc/64s: Refine feature sets for little endian builds
  (bsc#1055117).
- powerpc/64s: Remove POWER4 support (bsc#1055117).
- powerpc: Remove unused CPU_FTR_ARCH_201 (bsc#1055117).
- powerpc/64s: Fix POWER9 DD2.2 and above in DT CPU features
  (bsc#1055117).
- powerpc/64s: Set assembler machine type to POWER4 (bsc#1055117).
- powerpc/64s: Explicitly add vector features to CPU_FTRS_POSSIBLE
  (bsc#1055117).
- powerpc/64s: Add all POWER9 features to CPU_FTRS_ALWAYS
  (bsc#1055117).
- commit d8e1408
* Fri Apr 20 2018 mcgrof@suse.com
- xfs: fix intent use-after-free on abort (bsc#1085400).
- commit a15e224
* Fri Apr 20 2018 tiwai@suse.de
- platform/x86: fujitsu-laptop: Support Lifebook U7x7 hotkeys
  (bsc#1087284).
- commit 603de09
* Fri Apr 20 2018 msuchanek@suse.de
- powerpc/pseries: Restore default security feature flags on setup
  (bsc#1068032).
  Refresh
  patches.arch/powerpc-64s-barrier_nospec-Add-hcall-trigger.patch.
- commit ff6c8ce
* Fri Apr 20 2018 msuchanek@suse.de
- Refresh patches.drivers/scsi-lpfc-fix-wq-cq-creation-for-older-asic-s.patch.
  fix commit hash
- commit bbbc951
* Fri Apr 20 2018 mhocko@suse.com
- kernel/signal.c: avoid undefined behaviour in
  kill_something_info (bnc1089752, CVE-2018-10124).
- commit 00e311c
* Fri Apr 20 2018 nborisov@suse.com
- btrfs: Fix race condition between delayed refs and blockgroup
  removal (bsc#1086224).
- commit ff195d7
* Fri Apr 20 2018 nborisov@suse.com
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit c920800
* Fri Apr 20 2018 jthumshirn@suse.de
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-wq-cq-creation-for-older-asic-s.patch.
- commit 853016c
* Fri Apr 20 2018 mbenes@suse.cz
- kabi/severities: Ignore klp_shadow_* kABI changes
- commit a1324c3
* Fri Apr 20 2018 mbenes@suse.cz
- livepatch: Allow to call a custom callback when freeing shadow
  variables (bsc#1071995 fate#323487).
- commit add477a
* Fri Apr 20 2018 mbenes@suse.cz
- livepatch: Initialize shadow variables safely by a custom
  callback (bsc#1071995 fate#323487).
- commit ae78a45
* Fri Apr 20 2018 mbenes@suse.cz
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 98517c6
* Thu Apr 19 2018 tiwai@suse.de
- gpio: stmpe: i2c transfer are forbiden in atomic context
  (bsc#1051510).
- gpio: label descriptors using the device name (bsc#1051510).
- leds: pm8058: Silence pointer to integer size warning
  (bsc#1051510).
- gpio: fix "gpio-line-names" property retrieval (bsc#1051510).
- gpio: davinci: Assign first bank regs for unbanked case
  (bsc#1051510).
- docs: disable KASLR when debugging kernel (bsc#1051510).
- commit af0230a
* Thu Apr 19 2018 tiwai@suse.de
- Update patch tag and move into sorted section
  Refresh patches.suse/brcmsmac-allocate-ucode-with-GFP_KERNEL.patch
- commit 7f5e814
* Thu Apr 19 2018 jthumshirn@suse.de
- Update config files, add CONFIG_EXPOLINE_AUTO=y for s390x (bsc#1090098).
- commit 5c5cecd
* Thu Apr 19 2018 tiwai@suse.de
- iio: buffer: check if a buffer has been set up when poll is
  called (bsc#1051510).
- iio: adis_lib: Initialize trigger before requesting interrupt
  (bsc#1051510).
- staging: iio: ad5933: switch buffer mode to software
  (bsc#1051510).
- staging: iio: adc: ad7192: fix external frequency setting
  (bsc#1051510).
- iio: adc: stm32: fix scan of multiple channels with DMA
  (bsc#1051510).
- iio: imu: st_lsm6dsx: fix endianness in
  st_lsm6dsx_read_oneshot() (bsc#1051510).
- iio: ABI: Fix name of timestamp sysfs file (bsc#1051510).
- iio: health: max30102: Add power enable parameter to get_temp
  function (bsc#1051510).
- iio: adc/accel: Fix up module licenses (bsc#1051510).
- iio: health: max30102: Temperature should be in milli Celsius
  (bsc#1051510).
- iio: fix kernel-doc build errors (bsc#1051510).
- iio: adc: meson-saradc: fix the bit_idx of the adc_en clock
  (bsc#1051510).
- iio: adc: cpcap: fix incorrect validation (bsc#1051510).
- iio: adc: ti-ads1015: add 10%% to conversion wait time
  (bsc#1051510).
- staging: iio: ad7192: Fix - use the dedicated reset function
  avoiding dma from stack (bsc#1051510).
- iio: core: Return error for failed read_reg (bsc#1051510).
- iio: ad7793: Fix the serial interface reset (bsc#1051510).
- iio: ad_sigma_delta: Implement a dedicated reset function
  (bsc#1051510).
- iio: adc: mcp320x: Fix readout of negative voltages
  (bsc#1051510).
- iio: adc: mcp320x: Fix oops on module unload (bsc#1051510).
- iio: trigger: stm32-timer: preset shouldn't be buffered
  (bsc#1051510).
- iio: adc: twl4030: Disable the vusb3v1 rugulator in the error
  handling path of 'twl4030_madc_probe()' (bsc#1051510).
- iio: adc: twl4030: Fix an error handling path in
  'twl4030_madc_probe()' (bsc#1051510).
- commit 157dcf9
* Thu Apr 19 2018 jthumshirn@suse.de
- s390: add automatic detection of the spectre defense
  (bsc#1090098).
- s390: add sysfs attributes for spectre (bsc#1090098).
- s390: correct nospec auto detection init order (bsc#1090098).
- s390/crypto: Adjust s390 aes and paes cipher priorities
  (bsc#1090098).
- s390: move nobp parameter functions to nospec-branch.c
  (bsc#1090098).
- s390: report spectre mitigation via syslog (bsc#1090098).
- Refresh patches.arch/s390-sles15-05-01-gmb.patch.
- commit 14f6493
* Thu Apr 19 2018 tiwai@suse.de
- media: v4l2-compat-ioctl32: don't oops on overlay (bsc#1051510).
- rtl8187: Fix NULL pointer dereference in priv->conf_mutex
  (bsc#1051510).
- commit 46d4cfb
* Thu Apr 19 2018 jthumshirn@suse.de
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-wq-cq-creation-for-older-asic-s.patch.
- commit 287c94f
* Wed Apr 18 2018 jeffm@suse.com
- btrfs: push relocation recovery into a helper thread
  (bsc#1086467).
- commit 37d11e6
* Wed Apr 18 2018 mgorman@suse.de
- run series_sort.py
- commit eb1f119
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-numa-avoid-trapping-faults-and-attempting-migration-of-file-backed-dirty-pages.patch.
- commit 8af5d8d
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-numa-Delay-retrying-placement-for-automatic-NUMA-balance-after-wake_affine.patch.
- commit 6d0019c
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Do-not-migrate-on-wake_affine_weight-if-weights-are-equal.patch.
- commit ddeae7e
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Do-not-migrate-due-to-a-sync-wakeup-on-exit.patch.
- commit 809ffb9
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Defer-calculation-of-prev_eff_load-in-wake_affine-until-needed.patch.
- commit 5fcf087
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Consider-SD_NUMA-when-selecting-the-most-idle-group-to-schedule-on.patch.
- commit 60ba15e
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Avoid-an-unnecessary-lookup-of-current-CPU-ID-during-wake_affine.patch.
- commit 9343174
* Wed Apr 18 2018 mgorman@suse.de
- run series_sort.py
- commit 56bd2a7
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/mm-free_pcppages_bulk-prefetch-buddy-while-not-holding-lock.patch.
- commit bfb478c
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/mm-free_pcppages_bulk-update-pcp-count-inside.patch.
- commit 6f08862
* Wed Apr 18 2018 mgorman@suse.de
- Refresh
  patches.suse/mm-free_pcppages_bulk-do-not-hold-lock-when-picking-pages-to-free.patch.
- commit 4f66e2c
* Wed Apr 18 2018 jthumshirn@suse.de
- nvme-rdma: Don't flush delete_wq by default during remove_one
  (bsc#1089977).
- commit c185cad
* Wed Apr 18 2018 jthumshirn@suse.de
- nvmet-rdma: Don't flush system_wq by default during remove_one
  (bsc#1089977).
- commit 902e88b
* Wed Apr 18 2018 jthumshirn@suse.de
- supported.conf: add arch/s390/crypto/crc32-vx_s390 (bsc#1089889).
- commit 3e7cb03
* Wed Apr 18 2018 glin@suse.com
- mm, percpu: add support for __GFP_NOWARN flag (bsc#1089753).
- commit b007d55
* Tue Apr 17 2018 bp@suse.de
- x86/tsc: Future-proof native_calibrate_tsc() (bsc#1074873).
- blacklist.conf:
- commit 407f4fc
* Tue Apr 17 2018 bp@suse.de
- x86/mm/64: Fix vmapped stack syncing on very-large-memory
  4-level systems (bsc#1088374).
- commit 2ccb700
* Tue Apr 17 2018 nstange@suse.de
- ppc64le: reliable stacktrace: mark stacktraces with exception
  frames as unreliable (bsc#1089669).
- commit 6716d08
* Tue Apr 17 2018 bp@suse.de
- Sort series.conf
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 5e8c6bc
* Tue Apr 17 2018 nstange@suse.de
- ppc64le: reliable stacktrace: handle graph traced functions (bsc#1089664).
- commit df850c8
* Tue Apr 17 2018 jlee@suse.com
- ACPI / scan: Send change uevent with offine environmental data
  (bsc#1082485).
- commit e28a6c2
* Tue Apr 17 2018 glin@suse.com
- bpf, ppc64: fix out of bounds access in tail call (bsc#1083647).
- commit f682288
* Tue Apr 17 2018 wqu@suse.com
- btrfs: Only check first key for committed tree blocks
  (bsc#1084721).
- btrfs: Validate child tree block's level and first key
  (bsc#1084721).
- commit 82a46d9
* Mon Apr 16 2018 msuchanek@suse.de
- ibmvnic: Clear pending interrupt after device reset
  (bsc#1089644).
- commit 7d7ebab
* Mon Apr 16 2018 dbueso@suse.de
- sched/rt: Fix rq->clock_update_flags < RQCF_ACT_SKIP warning (bsc#1022476).
- commit 6643f8c
* Mon Apr 16 2018 dbueso@suse.de
- run series_sort.py
- commit 5f59a40
* Mon Apr 16 2018 msuchanek@suse.de
- config.sh: build against openSUSE:Leap:15.0:Update
- commit 61f2f25
* Mon Apr 16 2018 tbogendoerfer@suse.de
- virtio_net: fix return value check in receive_mergeable()
  (bsc#1089271).
- commit e169907
* Mon Apr 16 2018 tbogendoerfer@suse.de
- Re-sorted patches
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 18304f1
* Mon Apr 16 2018 tbogendoerfer@suse.de
- drivers/infiniband/ulp/srpt/ib_srpt.c: fix build with gcc-4.4.4
  (bsc#1046306 FATE#322942).
- drivers/infiniband/core/verbs.c: fix build with gcc-4.4.4
  (bsc#1046306 FATE#322942).
- qed: Use after free in qed_rdma_free() (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- commit cce8e1a
* Mon Apr 16 2018 tbogendoerfer@suse.de
- net/sched: fix NULL dereference in the error path of
  tcf_bpf_init() (bsc#1056787).
- iw_cxgb4: print mapped ports correctly (bsc#1046543
  FATE#322927).
- IB/core: Refer to RoCE port property instead of GID table
  property (bsc#1046306 FATE#322942).
- IB/core: Generate GID change event regardless of RoCE GID
  table property (bsc#1046306 FATE#322942).
- IB/mlx5: Enable ECN capable bits for UD RoCE v2 QPs (bsc#1046305
  FATE#322943).
- IB/mlx5: Set the default active rate and width to QDR and 4X
  (bsc#1046305 FATE#322943).
- commit 7e03b32
* Mon Apr 16 2018 tbogendoerfer@suse.de
- RDMA/mlx5: Protect from NULL pointer derefence (bsc#1046305
  FATE#322943).
- IB/srpt: Fix an out-of-bounds stack access in
  srpt_zerolength_write() (bsc#1046306 FATE#322942).
- RDMA/rxe: Fix an out-of-bounds read (bsc#1050662 FATE#323951).
- RDMA/core: Avoid that ib_drain_qp() triggers an out-of-bounds
  stack access (bsc#1046306 FATE#322942).
- IB/srp: Fix completion vector assignment algorithm (bsc#1046306
  FATE#322942).
- nfp: use full 40 bits of the NSP buffer address (bsc#1055968).
- net/mlx5: Eliminate query xsrq dead code (bsc#1046303
  FATE#322944).
- commit 592e964
* Mon Apr 16 2018 tbogendoerfer@suse.de
- net/mlx5e: Do not reset Receive Queue params on every type
  change (bsc#1046303 FATE#322944).
- net/mlx5e: Remove unused define MLX5_MPWRQ_STRIDES_PER_PAGE
  (bsc#1046303 FATE#322944).
- ixgbe: prevent ptp_rx_hang from running when in FILTER_ALL mode
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- commit 33533e8
* Mon Apr 16 2018 tbogendoerfer@suse.de
- igb: Fix a test with HWTSTAMP_TX_ON (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- RDMA/ucma: Introduce safer rdma_addr_size() variants
  (bsc#1046306 FATE#322942).
- net/sched: fix NULL dereference on the error path of
  tcf_skbmod_init() (bsc#1056787).
- net/sched: fix NULL dereference in the error path of
  tunnel_key_init() (bsc#1056787).
- qede: Fix qedr link update (bsc#1050538 FATE#322897 bsc#1050545
  FATE#322893).
- qed: Fix non TCP packets should be dropped on iWARP ll2
  connection (bsc#1050545 FATE#322893).
- net sched actions: return explicit error when tunnel_key mode
  is not specified (bsc#1056787).
- qed: Free RoCE ILT Memory on rmmod qedr (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- RDMA/mlx5: Fix crash while accessing garbage pointer and freed
  memory (bsc#1046305 FATE#322943).
- RDMAVT: Fix synchronization around percpu_ref (bsc#1058717
  FATE#322789).
- i40evf: don't rely on netif_running() outside rtnl_lock()
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- cxgb4vf: Fix SGE FL buffer initialization logic for 64K pages
  (bsc#1046542 FATE#322928).
- IB/rdmavt: Allocate CQ memory on the correct node (bsc#1058717
  FATE#322789).
- infiniband: drop unknown function from core_priv.h (bsc#1046306
  FATE#322942).
- RDMA/ocrdma: Fix permissions for OCRDMA_RESET_STATS (bsc#1058513
  FATE#322520).
- IB/ipoib: Avoid memory leak if the SA returns a different DGID
  (bsc#1046307 FATE#322941).
- commit b05ce6b
* Mon Apr 16 2018 tiwai@suse.de
- blacklist.conf: update for drm/i915 entry
- commit 1fbdf2d
* Mon Apr 16 2018 tiwai@suse.de
- HID: intel-ish-hid: Enable Gemini Lake ish driver
  (bsc#1073765,FATE#322842).
- commit f77cff5
* Mon Apr 16 2018 tbogendoerfer@suse.de
- blacklist.conf: added duplicate patches
- commit 097f3d3
* Mon Apr 16 2018 tbogendoerfer@suse.de
- bnxt_en: Ignore src port field in decap filter nodes
  (bsc#1050242 FATE#322914).
- bnxt_en: do not allow wildcard matches for L2 flows (bsc#1050242
  FATE#32291).
- RDMA/mlx4: Fix uABI structure layouts for 32/64 compat
  (bsc#1071218).
- IB/mlx4: Move mlx4_uverbs_ex_query_device_resp to include/uapi/
  (bsc#1071218).
- bnxt_en: fix clear flags in ethtool reset handling (bsc#1050242
  FATE#322914).
- cxgb4: fix error return code in adap_init0() (bsc#1064802
  bsc#1066129).
- net/mlx5e: Fixed sleeping inside atomic context (bsc#1046303
  FATE#322944).
- commit ba767aa
* Mon Apr 16 2018 mhocko@suse.com
- mm, thp: do not cause memcg oom for thp (bnc#1089663).
- commit 9d99b2b
* Mon Apr 16 2018 mhocko@suse.com
- series_sort.py: update the ordering
- commit 7021d9e
* Mon Apr 16 2018 mhocko@suse.com
- kernel/exit.c: avoid undefined behaviour when calling wait4()
  (bnc#1089608, CVE-2018-10087).
- commit 3052efc
* Mon Apr 16 2018 hare@suse.de
- Revert "scsi: make 'state' device attribute pollable"
  (bsc#1085341).
- commit aab4000
* Mon Apr 16 2018 hare@suse.de
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- Refresh
  patches.drivers/ibmvnic-Do-not-reset-CRQ-for-Mobility-driver-resets.patch.
- Refresh patches.drivers/ibmvnic-Fix-DMA-mapping-mistakes.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-failover-case-for-non-redundant-configur.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-reset-scheduler-error-handling.patch.
- Refresh
  patches.drivers/ibmvnic-Zero-used-TX-descriptor-counter-on-reset.patch.
- commit 30e2159
* Mon Apr 16 2018 ptesarik@suse.cz
- kexec: export PG_swapbacked to VMCOREINFO (bsc#1088354).
- Refresh
  patches.apparmor/apparmor-fix-resource-audit-messages-when-auditing-peer.patch.
- commit f31c123
* Mon Apr 16 2018 glin@suse.com
- bpf, x64: implement retpoline for tail call (bsc#1068032
  CVE-2017-5715).
- Refresh
  patches.suse/x86-speculation-Move-firmware_restrict_branch_specul.patch.
- commit c383630
* Mon Apr 16 2018 glin@suse.com
- bpf: fix mlock precharge on arraymaps (bsc#1083647).
- commit 521f8f2
* Fri Apr 13 2018 tiwai@suse.de
- vt: change SGR 21 to follow the standards (bsc#1051510).
- serial: sh-sci: prevent lockup on full TTY buffers
  (bsc#1051510).
- platform/chrome: Use proper protocol transfer function
  (bsc#1051510).
- rtc-opal: Fix handling of firmware error codes, prevent busy
  loops (bsc#1051510).
- HID: wacom: Fix reporting of touch toggle
  (WACOM_HID_WD_MUTE_DEVICE) events (bsc#1051510).
- HID: wacom: EKR: ensure devres groups at higher indexes are
  released (bsc#1051510).
- gpio: ath79: add missing MODULE_DESCRIPTION/LICENSE
  (bsc#1051510).
- gpio: iop: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bsc#1051510).
- sdhci: Advertise 2.0v supply on SDIO host controller
  (bsc#1051510).
- mfd: cros ec: spi: Don't send first message too soon
  (bsc#1051510).
- rtc: pcf8563: fix output clock rate (bsc#1051510).
- rtc: pl031: make interrupt optional (bsc#1051510).
- fbdev: controlfb: Add missing modes to fix out of bounds access
  (bsc#1051510).
- HID: cp2112: fix broken gpio_direction_input callback
  (bsc#1051510).
- vt6655: Fix a possible sleep-in-atomic bug in vt6655_suspend
  (bsc#1051510).
- staging: vchiq_2835_arm: Fix NULL ptr dereference in
  free_pagelist (bsc#1051510).
- commit 402c02c
* Fri Apr 13 2018 tiwai@suse.de
- drm/msm: fix leak in failed get_pages (bsc#1051510).
- drm/omap: DMM: Check for DMM readiness after successful
  transaction commit (bsc#1051510).
- drm/tilcdc: ensure nonatomic iowrite64 is not used
  (bsc#1051510).
- drm/armada: fix leak of crtc structure (bsc#1051510).
- drm/sun4i: Fix error path handling (bsc#1051510).
- drm/bridge: analogix dp: Fix runtime PM state in get_modes()
  callback (bsc#1051510).
- drm/bridge: tc358767: fix 1-lane behavior (bsc#1051510).
- drm/bridge: tc358767: fix AUXDATAn registers access
  (bsc#1051510).
- drm/bridge: tc358767: fix timing calculations (bsc#1051510).
- drm/bridge: tc358767: fix DP0_MISC register set (bsc#1051510).
- drm/bridge: tc358767: filter out too high modes (bsc#1051510).
- drm/bridge: tc358767: do no fail on hi-res displays
  (bsc#1051510).
- drm/rockchip: dw-mipi-dsi: fix possible un-balanced runtime
  PM enable (bsc#1051510).
- drm/fsl-dcu: enable IRQ before drm_atomic_helper_resume()
  (bsc#1051510).
- drm/hisilicon: Ensure LDI regs are properly configured
  (bsc#1051510).
- commit bbe4533
* Fri Apr 13 2018 tiwai@suse.de
- Fix kABI breakage due to acpi_ec gpe field change (bsc#1051510).
- commit 230712a
* Fri Apr 13 2018 tiwai@suse.de
- crypto: aes-generic - fix aes-generic regression on powerpc
  (bsc#1051510).
- commit c74537a
* Fri Apr 13 2018 tiwai@suse.de
- wcn36xx: Fix dynamic power saving (bsc#1051510).
- wcn36xx: Introduce mutual exclusion of fw configuration
  (bsc#1051510).
- commit 9464f21
* Fri Apr 13 2018 tiwai@suse.de
- wl1251: check return from call to wl1251_acx_arp_ip_filter
  (bsc#1051510).
- crypto: aes-generic - build with -Os on gcc-7+ (bsc#1051510).
- commit 567b06d
* Fri Apr 13 2018 tiwai@suse.de
- can: cc770: Fix use after free in cc770_tx_interrupt()
  (bsc#1051510).
- can: cc770: Fix queue stall & dropped RTR reply (bsc#1051510).
- can: cc770: Fix stalls on rt-linux, remove redundant IRQ ack
  (bsc#1051510).
- can: peak/pcie_fd: remove useless code when interface starts
  (bsc#1051510).
- can: peak/pcie_fd: fix echo_skb is occupied! bug (bsc#1051510).
- can: ifi: Repair the error handling (bsc#1051510).
- can: ifi: Check core revision upon probe (bsc#1051510).
- can: af_can: canfd_rcv(): replace WARN_ONCE by pr_warn_once
  (bsc#1051510).
- can: af_can: can_rcv(): replace WARN_ONCE by pr_warn_once
  (bsc#1051510).
- can: peak: fix potential bug in packet fragmentation
  (bsc#1051510).
- can: flex_can: Correct the checking for frame length in
  flexcan_start_xmit() (bsc#1051510).
- can: gs_usb: fix return value of the "set_bittiming" callback
  (bsc#1051510).
- can: vxcan: improve handling of missing peer name attribute
  (bsc#1051510).
- can: peak/pcie_fd: fix potential bug in restarting tx queue
  (bsc#1051510).
- can: usb_8dev: cancel urb on -EPIPE and -EPROTO (bsc#1051510).
- can: kvaser_usb: cancel urb on -EPIPE and -EPROTO (bsc#1051510).
- can: esd_usb2: cancel urb on -EPIPE and -EPROTO (bsc#1051510).
- can: ems_usb: cancel urb on -EPIPE and -EPROTO (bsc#1051510).
- can: mcba_usb: cancel urb on -EPROTO (bsc#1051510).
- can: mcba_usb: fix device disconnect bug (bsc#1051510).
- can: flexcan: fix VF610 state transition issue (bsc#1051510).
- can: peak/pci: fix potential bug when probe() fails
  (bsc#1051510).
- can: ti_hecc: Fix napi poll return value for repoll
  (bsc#1051510).
- can: kvaser_usb: ratelimit errors if incomplete messages are
  received (bsc#1051510).
- can: kvaser_usb: Fix comparison bug in
  kvaser_usb_read_bulk_callback() (bsc#1051510).
- can: kvaser_usb: free buf in error paths (bsc#1051510).
- can: ifi: Fix transmitter delay calculation (bsc#1051510).
- can: peak: Add support for new PCIe/M2 CAN FD interfaces
  (bsc#1051510).
- can: sun4i: handle overrun in RX FIFO (bsc#1051510).
- can: c_can: don't indicate triple sampling support for D_CAN
  (bsc#1051510).
- can: kvaser_usb: Ignore CMD_FLUSH_QUEUE_REPLY messages
  (bsc#1051510).
- can: kvaser_usb: Correct return value in printout (bsc#1051510).
- can: sun4i: fix loopback mode (bsc#1051510).
- can: gs_usb: fix busy loop if no more TX context is available
  (bsc#1051510).
- can: esd_usb2: Fix can_dlc value for received RTR, frames
  (bsc#1051510).
- can: af_can: can_pernet_init(): add missing error handling
  for kzalloc returning NULL (bsc#1051510).
- can: flexcan: fix p1010 state transition issue (bsc#1051510).
- can: flexcan: fix i.MX28 state transition issue (bsc#1051510).
- can: flexcan: fix i.MX6 state transition issue (bsc#1051510).
- can: flexcan: implement error passive state quirk (bsc#1051510).
- can: flexcan: rename legacy error state quirk (bsc#1051510).
- can: flexcan: fix state transition regression (bsc#1051510).
- commit dedd27d
* Fri Apr 13 2018 tiwai@suse.de
- bitmap: fix memset optimization on big-endian systems
  (bsc#1051510).
- commit 2760afb
* Fri Apr 13 2018 tiwai@suse.de
- backlight: tdo24m: Fix the SPI CS between transfers
  (bsc#1051510).
- commit 4e744b2
* Fri Apr 13 2018 tiwai@suse.de
- ACPI / video: Default lcd_only to true on Win8-ready and newer
  machines (bsc#1051510).
- ACPI: EC: Fix debugfs_create_*() usage (bsc#1051510).
- commit f76ac0e
* Fri Apr 13 2018 tiwai@suse.de
- ACPI / APEI: Replace ioremap_page_range() with fixmap
  (bsc#1051510).
- Refresh
  patches.arch/0015-arm64-mm-Map-entry-trampoline-into-trampoline-and-ke.patch.
- Refresh
  patches.arch/0051-arm64-kaslr-Put-kernel-vectors-address-in-separate-d.patch.
- Refresh
  patches.arch/08-x86-mm-fixmap-generalize-the-gdt-fixmap-mechanism-introduce-struct-cpu_entry_area.patch.
- Refresh
  patches.arch/22-x86-cpu_entry_area-move-it-out-of-the-fixmap.patch.
- commit f14230c
* Fri Apr 13 2018 msuchanek@suse.de
- ibmvnic: Do not notify peers on parameter change resets
  (bsc#1089198).
- ibmvnic: Handle all login error conditions (bsc#1089198).
- ibmvnic: Define vnic_login_client_data name field as unsized
  array (bsc#1089198).
- commit 6882e8d
* Fri Apr 13 2018 yousaf.kaukab@suse.com
- kabi: arm64: update crc for cpu_hwcaps and cpu_hwcap_keys
  References: bsc#1089086
- commit e99d689
* Fri Apr 13 2018 glin@suse.com
- bpf: add schedule points in percpu arrays management
  (bsc#1083647).
- commit 34ad2d8
* Thu Apr 12 2018 tiwai@suse.de
- power: supply: axp288_charger: Properly stop work on probe-error
  / remove (bsc#1051510).
- power: supply: ab8500_charger: Bail out in case of error in
  'ab8500_charger_init_hw_registers()' (bsc#1051510).
- power: supply: ab8500_charger: Fix an error handling path
  (bsc#1051510).
- commit 181aab3
* Thu Apr 12 2018 tiwai@suse.de
- mei: remove dev_err message on an unsupported ioctl
  (bsc#1051510).
- mei: me: add cannon point device ids for 4th device
  (FATE#321195).
- mei: me: add cannon point device ids (FATE#321195).
- commit 4fdb929
* Thu Apr 12 2018 tiwai@suse.de
- parport_pc: Add support for WCH CH382L PCI-E single parallel
  port card (bsc#1051510).
- sky2: Increase D3 delay to sky2 stops working after suspend
  (bsc#1051510).
- media: videobuf2-core: don't go out of the buffer range
  (bsc#1051510).
- rt2x00: do not pause queue unconditionally on error path
  (bsc#1051510).
- mac80211: Fix setting TX power on monitor interfaces
  (bsc#1051510).
- commit 93068e8
* Thu Apr 12 2018 tiwai@suse.de
- PM / devfreq: Fix potential NULL pointer dereference in
  governor_store (bsc#1051510).
- PM / s2idle: Clear the events_check_enabled flag (bsc#1051510).
- PM / OPP: Add missing of_node_put(np) (bsc#1051510).
- PM / OPP: Move error message to debug level (bsc#1051510).
- PM / OPP: Call notifier without holding opp_table->lock
  (bsc#1051510).
- commit 45e6113
* Thu Apr 12 2018 tiwai@suse.de
- PCI: Add function 1 DMA alias quirk for Highpoint RocketRAID
  644L (bsc#1051510).
- PCI: Detach driver before procfs & sysfs teardown on device
  remove (bsc#1051510).
- PCI: Create SR-IOV virtfn/physfn links before attaching driver
  (bsc#1051510).
- PCI/PME: Handle invalid data when reading Root Status
  (bsc#1051510).
- PCI: shpchp: Enable bridge bus mastering if MSI is enabled
  (bsc#1051510).
- commit c099ae3
* Thu Apr 12 2018 tiwai@suse.de
- Input: goodix - disable IRQs while suspended (bsc#1051510).
- commit d982e27
* Thu Apr 12 2018 tiwai@suse.de
- Bluetooth: Add a new 04ca:3015 QCA_ROME device (bsc#1051510).
- commit 3086838
* Thu Apr 12 2018 tiwai@suse.de
- Bluetooth: btusb: add ID for LiteOn 04ca:3016 (bsc#1051510).
- Refresh patches.drivers/Bluetooth-btusb-Add-new-NFA344A-entry.
- commit 4961eba
* Thu Apr 12 2018 tiwai@suse.de
- ASoC: Intel: cht_bsw_rt5645: Analog Mic support (bsc#1051510).
- ASoC: Intel: Skylake: Disable clock gating during firmware
  and library download (bsc#1051510).
- commit 105df12
* Thu Apr 12 2018 jack@suse.cz
- mm: fix device-dax pud write-faults triggered by
  get_user_pages() (bsc#1052766).
- commit 388d581
* Thu Apr 12 2018 jack@suse.cz
- srcu: Provide ordering for CPU not involved in grace period
  (bsc#1052766).
- commit 3dfab13
* Thu Apr 12 2018 jack@suse.cz
- sget(): handle failures of register_shrinker() (bsc#1052766).
- commit 71c7f1c
* Thu Apr 12 2018 jack@suse.cz
- udf: Avoid overflow when session starts at large offset
  (bsc#1052766).
- commit 6389cee
* Thu Apr 12 2018 jack@suse.cz
- ubifs: free the encrypted symlink target (bsc#1052766).
- commit cc5da14
* Thu Apr 12 2018 jack@suse.cz
- mbcache: initialize entry->e_referenced in
  mb_cache_entry_create() (bsc#1052766).
- commit d322665
* Thu Apr 12 2018 jack@suse.cz
- lock_parent() needs to recheck if dentry got __dentry_kill'ed
  under it (bsc#1052766).
- commit 3079da3
* Thu Apr 12 2018 jack@suse.cz
- GFS2: Take inode off order_write list when setting jdata flag
  (bsc#1052766).
- commit e6bc04f
* Thu Apr 12 2018 jack@suse.cz
- gfs2: Fix debugfs glocks dump (bsc#1052766).
- commit 2fec0ed
* Thu Apr 12 2018 jack@suse.cz
- fs/fat/inode.c: fix sb_rdonly() change (bsc#1052766).
- commit eddf3bd
* Thu Apr 12 2018 jack@suse.cz
- f2fs: expose some sectors to user in inline data or dentry case
  (bsc#1052766).
- commit 9d854aa
* Thu Apr 12 2018 jack@suse.cz
- direct-io: Prevent NULL pointer access in submit_page_section
  (bsc#1052766).
- commit 163ef37
* Thu Apr 12 2018 jack@suse.cz
- blacklist.conf: Blacklist 0a3ff78699d1
- commit 3442c44
* Thu Apr 12 2018 lhenriques@suse.com
- Update ceph quota patchset after being merged into mainline
- Update patches.suse/ceph-don-t-check-quota-for-snap-inode.patch
  (FATE#323422 bsc#1089115).
- Update patches.suse/ceph-fix-root-quota-realm-check.patch
  (FATE#323422 bsc#1089115).
- Update
  patches.suse/ceph-quota-add-counter-for-snaprealms-with-quota.patch
  (FATE#323422 bsc#1089115).
- Update
  patches.suse/ceph-quota-add-initial-infrastructure-to-support-cephfs-quotas.patch
  (FATE#323422 bsc#1089115).
- Update
  patches.suse/ceph-quota-cache-inode-pointer-in-ceph_snap_realm.patch
  (FATE#323422 bsc#1089115).
- Update
  patches.suse/ceph-quota-don-t-allow-cross-quota-renames.patch
  (FATE#323422 bsc#1089115).
- Update
  patches.suse/ceph-quota-support-for-ceph-quota-max_bytes.patch
  (FATE#323422 bsc#1089115).
- Update
  patches.suse/ceph-quota-support-for-ceph-quota-max_files.patch
  (FATE#323422 bsc#1089115).
- Update
  patches.suse/ceph-quota-update-mds-when-max_bytes-is-approaching.patch
  (FATE#323422 bsc#1089115).
- ceph: quota: report root dir quota usage in statfs (FATE#323422
  bsc#1089115).
- Delete
  patches.suse/ceph-quota-add-quotas-to-the-in-tree-cephfs-documentation.patch.
- commit d624342
* Thu Apr 12 2018 jack@suse.cz
- brd: fix overflow in __brd_direct_access (bsc#1052766).
- commit eee7c77
* Thu Apr 12 2018 lhenriques@suse.com
- ceph: fix invalid point dereference for error case in mdsc
  destroy (bsc#1089115).
- ceph: return proper bool type to caller instead of pointer
  (bsc#1089115).
- ceph: optimize memory usage (bsc#1089115).
- ceph: optimize mds session register (bsc#1089115).
- ceph: filter out used flags when printing unused open flags
  (bsc#1089115).
- ceph: don't wait on writeback when there is no more dirty pages
  (bsc#1089115).
- ceph: mark the cap cache as unreclaimable (bsc#1089115).
- ceph: change variable name to follow common rule (bsc#1089115).
- ceph: optimizing cap reservation (bsc#1089115).
- ceph: release unreserved caps if having enough available caps
  (bsc#1089115).
- ceph: optimizing cap allocation (bsc#1089115).
- ceph: adding protection for showing cap reservation info
  (bsc#1089115).
- libceph: adding missing message types to ceph_msg_type_name()
  (bsc#1089115).
- ceph: use seq_show_option for string type options (bsc#1089115).
- libceph: fix misjudgement of maximum monitor number
  (bsc#1089115).
- libceph, ceph: change permission for readonly debugfs entries
  (bsc#1089115).
- ceph: keep consistent semantic in fscache related option
  combination (bsc#1089115).
- commit 5b07ad7
* Wed Apr 11 2018 tiwai@suse.de
- serial: 8250_pci: Add Brainboxes UC-260 4 port serial device
  (bsc#1051510).
- serial: core: mark port as initialized in autoconfig
  (bsc#1051510).
- serial: imx: Only wakeup via RTSDEN bit if the system has
  RTS/CTS (bsc#1051510).
- serial: 8250_dw: Disable clock on error (bsc#1051510).
- serial: omap: Fix EFR write on RTS deassertion (bsc#1051510).
- serial: 8250_fintek: Fix finding base_port with activated
  SuperIO (bsc#1051510).
- serial: 8250: Preserve DLD[7:4] for PORT_XR17V35X (bsc#1051510).
- commit 79fc869
* Wed Apr 11 2018 tiwai@suse.de
- serdev: ttyport: fix tty locking in close (bsc#1051510).
- serdev: ttyport: fix NULL-deref on hangup (bsc#1051510).
- serdev: fix receive_buf return value when no callback
  (bsc#1051510).
- serdev: ttyport: add missing receive_buf sanity checks
  (bsc#1051510).
- serdev: fix registration of second slave (bsc#1051510).
- serdev: ttyport: add missing open() error handling
  (bsc#1051510).
- serdev: ttyport: enforce tty-driver open() requirement
  (bsc#1051510).
- commit 8a2b23b
* Wed Apr 11 2018 tiwai@suse.de
- X.509: fix NULL dereference when restricting key with
  unsupported_sig (bsc#1051510).
- X.509: fix BUG_ON() when hash algorithm is unsupported
  (bsc#1051510).
- X.509: fix comparisons of ->pkey_algo (bsc#1051510).
- X.509: reject invalid BIT STRING for subjectPublicKey
  (bsc#1051510).
- commit 06f6b64
* Wed Apr 11 2018 yousaf.kaukab@suse.com
- mmc: dw_mmc: Fix the DTO/CTO timeout overflow calculation for
  32-bit systems (bsc#1088713).
- commit 0b4165d
* Wed Apr 11 2018 tiwai@suse.de
- ALSA: hda: Add Icelake PCI ID (bsc#1051510).
- commit 2b421f6
* Wed Apr 11 2018 tiwai@suse.de
- Bluetooth: Fix missing encryption refresh on Security Request
  (bsc#1051510).
- commit 436757d
* Wed Apr 11 2018 yousaf.kaukab@suse.com
- kabi: arm64: reserve space in cpu_hwcaps and cpu_hwcap_keys
  arrays (bsc#1089086).
- KVM: arm64: Fix HYP idmap unmap when using 52bit PA
  (bsc#1089074).
- ipmi_ssif: Fix kernel panic at msg_done_handler (bsc#1088872).
- commit 8c1d75d
* Wed Apr 11 2018 tiwai@suse.de
- Fix kABI breakage due to sound/timer.h inclusion (bsc#1051510).
- commit b419498
* Wed Apr 11 2018 rgoldwyn@suse.com
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-TEXASR-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-XER-SO-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-transactional-memory-b.patch.
- Refresh
  patches.arch/PCI-hotplug-ppc-correct-a-php_slot-usage-after-free.patch.
- Refresh
  patches.arch/cxl-Check-if-PSL-data-cache-is-available-before-issu.patch.
- Refresh
  patches.arch/cxl-Enable-NORST-bit-in-PSL_DEBUG-register-for-PSL9.patch.
- Refresh
  patches.arch/cxl-Fix-possible-deadlock-when-processing-page-fault.patch.
- Refresh
  patches.arch/cxl-Fix-timebase-synchronization-status-on-P9.patch.
- Refresh
  patches.arch/cxl-Remove-function-write_timebase_ctrl_psl9-for-PSL.patch.
- Refresh
  patches.arch/cxl-read-PHB-indications-from-the-device-tree.patch.
- Refresh
  patches.arch/powerpc-64-Call-H_REGISTER_PROC_TBL-when-running-as-.patch.
- Refresh
  patches.arch/powerpc-64s-Enhance-the-information-in-cpu_show_melt.patch.
- Refresh patches.arch/powerpc-64s-Move-cpu_show_meltdown.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v1.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v2.patch.
- Refresh
  patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh
  patches.arch/powerpc-Add-security-feature-flags-for-Spectre-Meltd.patch.
- Refresh
  patches.arch/powerpc-Book-E-Remove-unused-CPU_FTR_L2CSR-bit.patch.
- Refresh
  patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- Refresh
  patches.arch/powerpc-Move-default-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-Remove-unused-flush_dcache_phys_range.patch.
- Refresh
  patches.arch/powerpc-Rename-plapr-routines-to-plpar.patch.
- Refresh
  patches.arch/powerpc-Use-feature-bit-for-RTC-presence-rather-than.patch.
- Refresh
  patches.arch/powerpc-kexec_file-Fix-error-code-when-trying-to-loa.patch.
- Refresh
  patches.arch/powerpc-lpar-debug-Initialize-flags-before-printing-.patch.
- Refresh
  patches.arch/powerpc-mm-Drop-the-function-native_register_proc_ta.patch.
- Refresh
  patches.arch/powerpc-mm-slice-Remove-intermediate-bitmap-copy.patch.
- Refresh
  patches.arch/powerpc-powernv-Fix-SMT4-forcing-idle-code.patch.
- Refresh
  patches.arch/powerpc-powernv-Provide-a-way-to-force-a-core-into-S.patch.
- Refresh
  patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-powernv-Use-the-security-flags-in-pnv_setup_.patch.
- Refresh
  patches.arch/powerpc-pseries-Add-new-H_GET_CPU_CHARACTERISTICS-fl.patch.
- Refresh
  patches.arch/powerpc-pseries-Fix-clearing-of-security-feature-fla.patch.
- Refresh
  patches.arch/powerpc-pseries-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-pseries-Use-the-security-flags-in-pseries_se.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
- Refresh
  patches.arch/powerpc-xmon-Clear-all-breakpoints-when-xmon-is-disa.patch.
- Refresh
  patches.arch/powerpc-xmon-Setup-debugger-hooks-when-first-break-p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-2-hang-issues-in-hv_compose_msi_msg.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-a-comment-typo-in-_hv_pcifront_read_confi.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Only-queue-new-work-items-in-hv_pci_devices_p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Remove-the-bogus-test-in-hv_eject_device_work.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Serialize-the-present-and-eject-work-items.patch.
- commit 2d4fe34
* Wed Apr 11 2018 tiwai@suse.de
- mmc: sdhci-pci: Fix voltage switch for some Intel host
  controllers (bsc#1051510).
- commit 4661208
* Wed Apr 11 2018 tiwai@suse.de
- NFC: fix device-allocation error return (bsc#1051510).
- commit 2eaf698
* Wed Apr 11 2018 tiwai@suse.de
- swiotlb: suppress warning when __GFP_NOWARN is set
  (bsc#1051510).
- commit 85b3818
* Wed Apr 11 2018 tiwai@suse.de
- video: fbdev/mmp: add MODULE_LICENSE (bsc#1051510).
- video: fbdev: atmel_lcdfb: fix display-timings lookup
  (bsc#1051510).
- video/hdmi: Allow "empty" HDMI infoframes (bsc#1051510).
- video: fbdev: au1200fb: Release some resources if a memory
  allocation fails (bsc#1051510).
- video: fbdev: au1200fb: Return an error code if a memory
  allocation fails (bsc#1051510).
- video: fbdev: aty: do not leak uninitialized padding in clk
  to userspace (bsc#1051510).
- commit 7d3cb87
* Wed Apr 11 2018 tiwai@suse.de
- Input: i8042 - enable MUX on Sony VAIO VGN-CS series to fix
  touchpad (bsc#1051510).
- Input: ALPS - fix TrackStick detection on Thinkpad L570 and
  Latitude 7370 (bsc#1051510).
- Input: i8042 - add Lenovo ThinkPad L460 to i8042 reset list
  (bsc#1051510).
- commit c7e202c
* Wed Apr 11 2018 tiwai@suse.de
- crypto: ahash - Fix early termination in hash walk
  (bsc#1051510).
- crypto: lrw - Free rctx->ext with kzfree (bsc#1051510).
- crypto: caam - Fix null dereference at error path (bsc#1051510).
- crypto: x86/cast5-avx - fix ECB encryption when long sg follows
  short one (bsc#1051510).
- i2c: ismt: Separate I2C block read from SMBus block read
  (bsc#1051510).
- crypto: AF_ALG - remove SGL terminator indicator when chaining
  (bsc#1051510).
- commit dcd2df3
* Wed Apr 11 2018 tiwai@suse.de
- ALSA: usb-audio: Add native DSD support for TEAC UD-301
  (bsc#1051510).
- commit 544a3cf
* Wed Apr 11 2018 tiwai@suse.de
- media: au0828: add VIDEO_V4L2 dependency (bsc#1051510).
- Refresh patches.drivers/media-au0828-fix-VIDEO_V4L2-dependency.
- commit 3fa947d
* Wed Apr 11 2018 tiwai@suse.de
- crypto: af_alg - fix possible uninit-value in alg_bind()
  (bsc#1051510).
- commit 2c2b1cd
* Wed Apr 11 2018 tiwai@suse.de
- Fix kABI incompatibility by snd_pcm_oss_runtime.rw_ref addition
  (bsc#1051510).
- commit 5677dde
* Wed Apr 11 2018 tiwai@suse.de
- ALSA: pcm: Fix endless loop for XRUN recovery in OSS emulation
  (bsc#1051510).
- ALSA: pcm: Fix UAF at PCM release via PCM timer access
  (bsc#1051510).
- ALSA: pcm: Fix mutex unbalance in OSS emulation ioctls
  (bsc#1051510).
- ALSA: pcm: Return -EBUSY for OSS ioctls changing busy streams
  (bsc#1051510).
- ALSA: pcm: Avoid potential races between OSS ioctls and
  read/write (bsc#1051510).
- ALSA: pcm: potential uninitialized return values (bsc#1051510).
- commit 8b415be
* Wed Apr 11 2018 tiwai@suse.de
- blacklist.conf: Fix merge conflict leftover
- commit 7ce640a
* Wed Apr 11 2018 tiwai@suse.de
- Preliminary patch sort & update
- commit f1cd84a
* Wed Apr 11 2018 acho@suse.com
- ima: Add cgroups2 to the defaults list (bsc#1073915).
- commit aa0be85
* Wed Apr 11 2018 nborisov@suse.com
- Update config files. (fate#321934)
- commit 15c0ffc
* Wed Apr 11 2018 glin@suse.com
- bpf: skip unnecessary capability check (bsc#1083647).
- bpf, x64: increase number of passes (bsc#1083647).
- bpf: fix corruption on concurrent perf_event_output calls
  (bsc#1083647).
- bpf: avoid excessive stack usage for perf_sample_data
  (bsc#1083647).
- commit 22e80bf
* Tue Apr 10 2018 msuchanek@suse.de
- rpm/package-descriptions: fix typo in kernel-azure
- Add azure kernel description.
- commit 6fdfcf9
* Tue Apr 10 2018 tiwai@suse.de
- Update config files: fix for Cherrytrail devices (bsc#1068546)
- commit 365dd85
* Tue Apr 10 2018 jthumshirn@suse.de
- scsi: lpfc: Fix WQ/CQ creation for older asic's (bsc#1085241).
- commit d8f53e9
* Tue Apr 10 2018 jthumshirn@suse.de
- Add mkp's queue to git_sort.py
- commit 96f199e
* Tue Apr 10 2018 jthumshirn@suse.de
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-TEXASR-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-XER-SO-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-transactional-memory-b.patch.
- Refresh
  patches.arch/PCI-hotplug-ppc-correct-a-php_slot-usage-after-free.patch.
- Refresh
  patches.arch/cxl-Check-if-PSL-data-cache-is-available-before-issu.patch.
- Refresh
  patches.arch/cxl-Enable-NORST-bit-in-PSL_DEBUG-register-for-PSL9.patch.
- Refresh
  patches.arch/cxl-Fix-possible-deadlock-when-processing-page-fault.patch.
- Refresh
  patches.arch/cxl-Fix-timebase-synchronization-status-on-P9.patch.
- Refresh
  patches.arch/cxl-Remove-function-write_timebase_ctrl_psl9-for-PSL.patch.
- Refresh
  patches.arch/cxl-read-PHB-indications-from-the-device-tree.patch.
- Refresh
  patches.arch/powerpc-64-Call-H_REGISTER_PROC_TBL-when-running-as-.patch.
- Refresh
  patches.arch/powerpc-64s-Enhance-the-information-in-cpu_show_melt.patch.
- Refresh patches.arch/powerpc-64s-Move-cpu_show_meltdown.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v1.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v2.patch.
- Refresh
  patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh
  patches.arch/powerpc-Add-security-feature-flags-for-Spectre-Meltd.patch.
- Refresh
  patches.arch/powerpc-Book-E-Remove-unused-CPU_FTR_L2CSR-bit.patch.
- Refresh
  patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- Refresh
  patches.arch/powerpc-Move-default-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-Remove-unused-flush_dcache_phys_range.patch.
- Refresh
  patches.arch/powerpc-Rename-plapr-routines-to-plpar.patch.
- Refresh
  patches.arch/powerpc-Use-feature-bit-for-RTC-presence-rather-than.patch.
- Refresh
  patches.arch/powerpc-kexec_file-Fix-error-code-when-trying-to-loa.patch.
- Refresh
  patches.arch/powerpc-lpar-debug-Initialize-flags-before-printing-.patch.
- Refresh
  patches.arch/powerpc-mm-Drop-the-function-native_register_proc_ta.patch.
- Refresh
  patches.arch/powerpc-mm-slice-Remove-intermediate-bitmap-copy.patch.
- Refresh
  patches.arch/powerpc-powernv-Fix-SMT4-forcing-idle-code.patch.
- Refresh
  patches.arch/powerpc-powernv-Provide-a-way-to-force-a-core-into-S.patch.
- Refresh
  patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-powernv-Use-the-security-flags-in-pnv_setup_.patch.
- Refresh
  patches.arch/powerpc-pseries-Add-new-H_GET_CPU_CHARACTERISTICS-fl.patch.
- Refresh
  patches.arch/powerpc-pseries-Fix-clearing-of-security-feature-fla.patch.
- Refresh
  patches.arch/powerpc-pseries-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-pseries-Use-the-security-flags-in-pseries_se.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
- Refresh
  patches.arch/powerpc-xmon-Clear-all-breakpoints-when-xmon-is-disa.patch.
- Refresh
  patches.arch/powerpc-xmon-Setup-debugger-hooks-when-first-break-p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-2-hang-issues-in-hv_compose_msi_msg.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-a-comment-typo-in-_hv_pcifront_read_confi.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Only-queue-new-work-items-in-hv_pci_devices_p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Remove-the-bogus-test-in-hv_eject_device_work.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Serialize-the-present-and-eject-work-items.patch.
- commit d96e797
* Tue Apr 10 2018 msuchanek@suse.de
- KABI: hide ftrace_enabled in paca (bsc#1088804).
- commit 1cab22b
* Tue Apr 10 2018 msuchanek@suse.de
- powerpc64/ftrace: Use the generic version of
  ftrace_replace_code() (bsc#1088804).
- powerpc64/module: Tighten detection of mcount call sites with
  - mprofile-kernel (bsc#1088804).
- powerpc64/kexec: Hard disable ftrace before switching to the
  new kernel (bsc#1088804).
- powerpc64/ftrace: Disable ftrace during hotplug (bsc#1088804).
- powerpc64/ftrace: Delay enabling ftrace on secondary cpus
  (bsc#1088804).
- powerpc64/ftrace: Add helpers to hard disable ftrace
  (bsc#1088804).
- powerpc64/ftrace: Rearrange #ifdef sections in ftrace.h
  (bsc#1088804).
- powerpc64/ftrace: Disable ftrace during kvm guest entry/exit
  (bsc#1088804).
- powerpc64/ftrace: Add a field in paca to disable ftrace in
  unsafe code paths (bsc#1088804).
- commit 31f7f1f
* Tue Apr 10 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix ppc_breakpoint_available compile error
  (bsc#1061840).
- powerpc: Don't write to DABR on >= Power8 if DAWR is disabled
  (bsc#1055117).
- commit a548bd0
* Mon Apr  9 2018 msuchanek@suse.de
- powerpc/hw_breakpoint: Only disable hw breakpoint if cpu
  supports it (bsc#1055117).
- commit e44aa5c
* Mon Apr  9 2018 msuchanek@suse.de
- powerpc/kvm: Fix guest boot failure on Power9 since DAWR changes
  (bsc#1061840).
- KVM: PPC: Book3S HV: Handle migration with POWER9 disabled DAWR
  (bsc#1061840).
- KVM: PPC: Book3S HV: Return error from h_set_dabr() on POWER9
  (bsc#1061840).
- KVM: PPC: Book3S HV: Return error from h_set_mode(SET_DAWR)
  on POWER9 (bsc#1061840).
- powerpc: Disable DAWR in the base POWER9 CPU features
  (bsc#1055117).
- powerpc: Disable DAWR on POWER9 via CPU feature quirk
  (bsc#1055117).
- powerpc: Update xmon to use ppc_breakpoint_available()
  (bsc#1072829).
- powerpc: Update ptrace to use ppc_breakpoint_available()
  (bsc#1056686).
- commit 5f644fa
* Mon Apr  9 2018 rgoldwyn@suse.com
- fs/aio: Use RCU accessors for kioctx_table->table[]
  (bsc#1088722).
- fs/aio: Add explicit RCU grace period when freeing  kioctx
  (bsc#1088722).
- commit a91dfd2
* Mon Apr  9 2018 bp@suse.de
- x86/intel_rdt: Add command line parameter to control L2_CDP
  (fate#325152).
- x86/intel_rdt: Add two new resources for L2 Code and Data
  Prioritization (CDP) (fate#325152).
- x86/intel_rdt: Enable L2 CDP in MSR IA32_L2_QOS_CFG
  (fate#325152).
- x86/intel_rdt: Enumerate L2 Code and Data Prioritization (CDP)
  feature (fate#325152).
- crypto: ccp - Fix sparse, use plain integer as NULL pointer
  (git-fixes 200664d5237f).
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-TEXASR-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-XER-SO-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-transactional-memory-b.patch.
- Refresh
  patches.arch/PCI-hotplug-ppc-correct-a-php_slot-usage-after-free.patch.
- Refresh
  patches.arch/cxl-Check-if-PSL-data-cache-is-available-before-issu.patch.
- Refresh
  patches.arch/cxl-Enable-NORST-bit-in-PSL_DEBUG-register-for-PSL9.patch.
- Refresh
  patches.arch/cxl-Fix-possible-deadlock-when-processing-page-fault.patch.
- Refresh
  patches.arch/cxl-Fix-timebase-synchronization-status-on-P9.patch.
- Refresh
  patches.arch/cxl-Remove-function-write_timebase_ctrl_psl9-for-PSL.patch.
- Refresh
  patches.arch/cxl-read-PHB-indications-from-the-device-tree.patch.
- Refresh
  patches.arch/powerpc-64-Call-H_REGISTER_PROC_TBL-when-running-as-.patch.
- Refresh
  patches.arch/powerpc-64s-Enhance-the-information-in-cpu_show_melt.patch.
- Refresh patches.arch/powerpc-64s-Move-cpu_show_meltdown.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v1.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v2.patch.
- Refresh
  patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh
  patches.arch/powerpc-Add-security-feature-flags-for-Spectre-Meltd.patch.
- Refresh
  patches.arch/powerpc-Book-E-Remove-unused-CPU_FTR_L2CSR-bit.patch.
- Refresh
  patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- Refresh
  patches.arch/powerpc-Move-default-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-Remove-unused-flush_dcache_phys_range.patch.
- Refresh
  patches.arch/powerpc-Rename-plapr-routines-to-plpar.patch.
- Refresh
  patches.arch/powerpc-Use-feature-bit-for-RTC-presence-rather-than.patch.
- Refresh
  patches.arch/powerpc-kexec_file-Fix-error-code-when-trying-to-loa.patch.
- Refresh
  patches.arch/powerpc-lpar-debug-Initialize-flags-before-printing-.patch.
- Refresh
  patches.arch/powerpc-mm-Drop-the-function-native_register_proc_ta.patch.
- Refresh
  patches.arch/powerpc-mm-slice-Remove-intermediate-bitmap-copy.patch.
- Refresh
  patches.arch/powerpc-powernv-Fix-SMT4-forcing-idle-code.patch.
- Refresh
  patches.arch/powerpc-powernv-Provide-a-way-to-force-a-core-into-S.patch.
- Refresh
  patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-powernv-Use-the-security-flags-in-pnv_setup_.patch.
- Refresh
  patches.arch/powerpc-pseries-Add-new-H_GET_CPU_CHARACTERISTICS-fl.patch.
- Refresh
  patches.arch/powerpc-pseries-Fix-clearing-of-security-feature-fla.patch.
- Refresh
  patches.arch/powerpc-pseries-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-pseries-Use-the-security-flags-in-pseries_se.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
- Refresh
  patches.arch/powerpc-xmon-Clear-all-breakpoints-when-xmon-is-disa.patch.
- Refresh
  patches.arch/powerpc-xmon-Setup-debugger-hooks-when-first-break-p.patch.
- Refresh
  patches.arch/x86-cpufeatures-add-cpuid_7_edx-cpuid-leaf.patch.
- Refresh
  patches.arch/x86-cpufeatures-clean-up-spectre-v2-related-cpuid-flags.patch.
- commit 0256417
* Mon Apr  9 2018 rgoldwyn@suse.com
- ovl: Put upperdentry if ovl_check_origin() fails (bsc#1088704).
- commit 810661d
* Mon Apr  9 2018 rgoldwyn@suse.com
- ovl: fix failure to fsync lower dir (bsc#108871).
- commit 271d2b4
* Mon Apr  9 2018 rgoldwyn@suse.com
- fuse: fix READDIRPLUS skipping an entry (bsc#1088690).
- commit c80f4bb
* Mon Apr  9 2018 oneukum@suse.com
- usb: dwc3: Fix lock-up on ID change during system suspend/resume
  (bsc#1087092).
- commit d535713
* Mon Apr  9 2018 oneukum@suse.com
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-TEXASR-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-XER-SO-bug-in-fake-sus.patch.
- Refresh
  patches.arch/KVM-PPC-Book3S-HV-Work-around-transactional-memory-b.patch.
- Refresh
  patches.arch/PCI-hotplug-ppc-correct-a-php_slot-usage-after-free.patch.
- Refresh
  patches.arch/cxl-Check-if-PSL-data-cache-is-available-before-issu.patch.
- Refresh
  patches.arch/cxl-Enable-NORST-bit-in-PSL_DEBUG-register-for-PSL9.patch.
- Refresh
  patches.arch/cxl-Fix-possible-deadlock-when-processing-page-fault.patch.
- Refresh
  patches.arch/cxl-Fix-timebase-synchronization-status-on-P9.patch.
- Refresh
  patches.arch/cxl-Remove-function-write_timebase_ctrl_psl9-for-PSL.patch.
- Refresh
  patches.arch/cxl-read-PHB-indications-from-the-device-tree.patch.
- Refresh
  patches.arch/powerpc-64-Call-H_REGISTER_PROC_TBL-when-running-as-.patch.
- Refresh
  patches.arch/powerpc-64s-Enhance-the-information-in-cpu_show_melt.patch.
- Refresh patches.arch/powerpc-64s-Move-cpu_show_meltdown.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v1.patch.
- Refresh
  patches.arch/powerpc-64s-Wire-up-cpu_show_spectre_v2.patch.
- Refresh
  patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh
  patches.arch/powerpc-Add-security-feature-flags-for-Spectre-Meltd.patch.
- Refresh
  patches.arch/powerpc-Book-E-Remove-unused-CPU_FTR_L2CSR-bit.patch.
- Refresh
  patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- Refresh
  patches.arch/powerpc-Move-default-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-Remove-unused-flush_dcache_phys_range.patch.
- Refresh
  patches.arch/powerpc-Rename-plapr-routines-to-plpar.patch.
- Refresh
  patches.arch/powerpc-Use-feature-bit-for-RTC-presence-rather-than.patch.
- Refresh
  patches.arch/powerpc-kexec_file-Fix-error-code-when-trying-to-loa.patch.
- Refresh
  patches.arch/powerpc-lpar-debug-Initialize-flags-before-printing-.patch.
- Refresh
  patches.arch/powerpc-mm-Drop-the-function-native_register_proc_ta.patch.
- Refresh
  patches.arch/powerpc-mm-slice-Remove-intermediate-bitmap-copy.patch.
- Refresh
  patches.arch/powerpc-powernv-Fix-SMT4-forcing-idle-code.patch.
- Refresh
  patches.arch/powerpc-powernv-Provide-a-way-to-force-a-core-into-S.patch.
- Refresh
  patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-powernv-Use-the-security-flags-in-pnv_setup_.patch.
- Refresh
  patches.arch/powerpc-pseries-Add-new-H_GET_CPU_CHARACTERISTICS-fl.patch.
- Refresh
  patches.arch/powerpc-pseries-Fix-clearing-of-security-feature-fla.patch.
- Refresh
  patches.arch/powerpc-pseries-Set-or-clear-security-feature-flags.patch.
- Refresh
  patches.arch/powerpc-pseries-Use-the-security-flags-in-pseries_se.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch.
- Refresh
  patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
- Refresh
  patches.arch/powerpc-xmon-Clear-all-breakpoints-when-xmon-is-disa.patch.
- Refresh
  patches.arch/powerpc-xmon-Setup-debugger-hooks-when-first-break-p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-2-hang-issues-in-hv_compose_msi_msg.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-a-comment-typo-in-_hv_pcifront_read_confi.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Only-queue-new-work-items-in-hv_pci_devices_p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Remove-the-bogus-test-in-hv_eject_device_work.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Serialize-the-present-and-eject-work-items.patch.
  Linus has pulled. Take over the ordering.
- commit 1ad4e83
* Mon Apr  9 2018 oneukum@suse.com
- blacklist.conf: not a bug fix, optimization
- commit 5e5824b
* Mon Apr  9 2018 oneukum@suse.com
- blacklist.conf: cosmetic issue
- commit 4b47d7a
* Mon Apr  9 2018 jthumshirn@suse.de
- Update config files, enable CONFIG_SMARTPQI on arm64 (bsc#1088634).
- commit fb9aa6d
* Mon Apr  9 2018 msuchanek@suse.de
- ibmvnic: Do not reset CRQ for Mobility driver resets
  (bsc#1088600).
- ibmvnic: Fix failover case for non-redundant configuration
  (bsc#1088600).
- ibmvnic: Fix reset scheduler error handling (bsc#1088600).
- ibmvnic: Zero used TX descriptor counter on reset (bsc#1088600).
- ibmvnic: Fix DMA mapping mistakes (bsc#1088600).
- commit ec5530d
* Mon Apr  9 2018 msuchanek@suse.de
- ibmvnic: Disable irqs before exiting reset from closed state
  (bsc#1084610).
- commit 3658918
* Mon Apr  9 2018 msuchanek@suse.de
- powerpc/perf: Add blacklisted events for Power9 DD2.2
  (bsc1056686).
- powerpc/perf: Add blacklisted events for Power9 DD2.1
  (bsc1056686).
- powerpc/perf: Infrastructure to support addition of blacklisted
  events (bsc1056686).
- powerpc/perf: Prevent kernel address leak via
  perf_get_data_addr() (bsc1056686).
- powerpc/perf: Prevent kernel address leak to userspace via
  BHRB buffer (bsc1056686).
- powerpc/perf: Fix kernel address leak via sampling registers
  (bsc1056686).
- commit 78dc81b
* Mon Apr  9 2018 msuchanek@suse.de
- Remove broken cpu hotplug patch.
  Delete patches.arch/cpu-hotplug-Convert-hotplug-locking-to-percpu-rwsem.patch.
- commit 2a2ffef
* Mon Apr  9 2018 msuchanek@suse.de
- Revert "Remove patces for bug 1087405 due to regression"
  This reverts commit f91a2ea5192d9e933c41600da5d1543155df381c.
- commit c2ecc06
* Mon Apr  9 2018 msuchanek@suse.de
- Update kabi files from RC3 submission.
- commit 43a8c6f
* Mon Apr  9 2018 ohering@suse.de
- add mainline tag to various patches to be able to get further work done
- commit 500958e
* Sat Apr  7 2018 bp@suse.de
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-2-hang-issues-in-hv_compose_msi_msg.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Fix-a-comment-typo-in-_hv_pcifront_read_confi.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Only-queue-new-work-items-in-hv_pci_devices_p.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Remove-the-bogus-test-in-hv_eject_device_work.patch.
- Refresh
  patches.suse/suse-hv-PCI-hv-Serialize-the-present-and-eject-work-items.patch.
- commit 8cb0a2a
* Sat Apr  7 2018 dbueso@suse.de
- futex: Fix OWNER_DEAD fixup (bsc#1067665).
- futex: Avoid violating the 10th rule of futex (bsc#1067665).
- commit 820eb95
* Sat Apr  7 2018 dbueso@suse.de
- run series_sort.py
- commit 9b0b8df
* Fri Apr  6 2018 msuchanek@suse.de
- Update arm kabi files to reflect changes in iProc driver.
- commit 5c17dc1
* Fri Apr  6 2018 msuchanek@suse.de
- Update ppc kabi files to reflect kabi fixes.
- commit d584de6
* Fri Apr  6 2018 msuchanek@suse.de
- Remove patces for bug 1087405 due to regression
- Refresh patches.arch/powerpc-numa-Invalidate-numa_cpu_lookup_table-on-cpu.patch.
- Delete patches.arch/cpu-hotplug-Convert-hotplug-locking-to-percpu-rwsem.patch.
- Delete patches.arch/cpu-hotplug-Provide-cpus_read-write_-un-lock.patch.
- Delete patches.arch/cpu-hotplug-Provide-lockdep_assert_cpus_held.patch.
- Delete patches.arch/powerpc-Don-t-call-lockdep_assert_cpus_held-from-arc.patch.
- Delete patches.arch/powerpc-Only-obtain-cpu_hotplug_lock-if-called-by-rt.patch.
- Delete patches.arch/stop_machine-Provide-stop_machine_cpuslocked.patch.
- Delete patches.arch/workqueue-Work-around-edge-cases-for-calc-of-pool-s-.patch.
- Delete patches.suse/KABI-cpu-hotplug-provide-the-old-get-put_online_cpus.patch.
- commit f91a2ea
* Fri Apr  6 2018 msuchanek@suse.de
- Update ppc kabi files.
  A change in mm_context_t
- commit 4e5f64a
* Fri Apr  6 2018 mhocko@suse.com
- mm, sparse: do not swamp log with huge vmemmap allocation (bnc#1082184, bnc#1087928).
- commit 080516f
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/mm: Fixup tlbie vs store ordering issue on POWER9
  (bsc#1087908).
- powerpc/mm/radix: Move the functions that does the actual tlbie closer (bsc#1087908).
- Refresh patches.arch/powerpc-Add-CPU-feature-bits-for-TM-bug-workarounds-.patch.
- Refresh patches.arch/powerpc-Free-up-CPU-feature-bits-on-64-bit-machines.patch.
- commit 9f17cf2
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/mm: Workaround Nest MMU bug with TLB invalidations
  (bsc#1087908).
- commit 2dc45cc
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/64s/radix: Optimize TLB range flush barriers
  (bsc#1087908).
- commit ab0534b
* Fri Apr  6 2018 duwe@suse.de
- powerpc/kprobes: Fix warnings from __this_cpu_read() on preempt
  kernels (bsc#1088321).
- powerpc/kprobes: Clean up jprobe detection in livepatch handler
  (bsc#1088321).
- commit de980ac
* Fri Apr  6 2018 duwe@suse.de
- powerpc/modules: Don't try to restore r2 after a sibling call
  (bsc#1088321).
- powerpc/modules: Add REL24 relocation support of livepatch
  symbols (bsc#1088321).
- commit 2e9366a
* Fri Apr  6 2018 tiwai@suse.de
- Fix kABI for musb flush_irq_work field addition (bsc#1085536).
- commit bd7d8c7
* Fri Apr  6 2018 jkosina@suse.cz
- kABI: protect struct mlx5_core_srq (bsc#1046305 FATE#322943).
- Delete
  patches.suse/kabi-IB-mlx5-Fix-integer-overflows-in-mlx5_ib_create_srq.patch.
  Move kABI workaround to patches.kabi/
- commit 8b4c573
* Fri Apr  6 2018 tbogendoerfer@suse.de
- kABI: protect struct mlx5_core_srq (bsc#1046305 FATE#322943).
- commit 722e1e3
* Fri Apr  6 2018 mbenes@suse.cz
- kabi/severities: Ignore livepatching kABI changes
  Namely klp_*_patch symbols (enable, disable, (un)register).
- commit 1162b94
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc/lib/xor_vmx: Ensure no altivec code executes before
  enable_kernel_altivec() (bsc#1065729).
- commit a384ead
* Fri Apr  6 2018 msuchanek@suse.de
- powerpc: Fix check for copy/paste instructions in alignment
  handler (bsc#1055117).
- commit d9df9cc
* Fri Apr  6 2018 mbenes@suse.cz
- livepatch: Add an extra flag to distinguish registered patches
  (bsc#1071995 fate#323487).
- livepatch: Remove Nop structures when unused (bsc#1071995
  fate#323487).
- livepatch: Remove replaced patches from the stack (bsc#1071995
  fate#323487).
- Refresh patches.suse/livepatch-add-atomic-replace.patch.
- Refresh
  patches.suse/livepatch-allow-to-replace-even-disabled-patches.patch.
- Refresh
  patches.suse/livepatch-atomic-replace-and-cumulative-patches-documentation.patch.
- Refresh
  patches.suse/livepatch-free-only-structures-with-initialized-kobject.patch.
- Refresh
  patches.suse/livepatch-use-lists-to-manage-patches-objects-and-functions.patch.
- Delete
  patches.suse/livepatch-allow-to-unpatch-only-functions-of-the-given-type.patch.
- Delete
  patches.suse/livepatch-correctly-handle-atomic-replace-for-not-yet-loaded-modules.patch.
- Delete
  patches.suse/livepatch-improve-dynamic-struct-klp_object-detection-and-manipulation.patch.
- Delete
  patches.suse/livepatch-initial-support-for-dynamic-structures.patch.
- Delete
  patches.suse/livepatch-support-separate-list-for-replaced-patches.patch.
  Atomic replace, update to v11.
- commit 25ee7a3
* Fri Apr  6 2018 jkosina@suse.cz
- Delete kabi/arm64/symtypes-default.
- Delete kabi/arm64/symvers-default.
- Delete kabi/ppc64le/symtypes-default.
- Delete kabi/ppc64le/symvers-default.
- Delete kabi/s390x/symtypes-default.
- Delete kabi/s390x/symvers-default.
- Delete kabi/x86_64/symtypes-default.
- Delete kabi/x86_64/symvers-default.
  Disable imported kABI for now for openSUSE-15.0 branch.
- commit 460eb3a
* Fri Apr  6 2018 mbenes@suse.cz
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- Refresh
  patches.drivers/scsi-csiostor-add-support-for-32-bit-port-capabiliti.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-64G-link-speed-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-PCI-Ids-for-if_type-6-hardware.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-SLI-4-if_type-6-support-to-the-code-ba.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-WQ-Full-Logic-for-NVME-Target.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-embedded-data-pointers-for-enhanced-pe.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-if_type-6-support-for-cycling-valid-bi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-push-to-adapter-support-to-sli4.patch.
- Refresh
  patches.drivers/scsi-lpfc-Allow-set-of-maximum-outstanding-SCSI-cmd-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Change-Copyright-of-12.0.0.0-modified-file.patch.
- Refresh
  patches.drivers/scsi-lpfc-Enable-fw-download-on-if_type-6-devices.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-IO-failure-during-hba-reset-testing-wi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-PRLI-handling-when-topology-type-chang.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-SCSI-io-host-reset-causing-kernel-cras.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-frequency-of-Release-WQE-CQEs.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-header-inclusion-in-lpfc_nvmet.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-issue_lip-if-link-is-disabled.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nonrecovery-of-NVME-controller-after-c.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nvme-embedded-io-length-on-new-hardwar.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-soft-lockup-in-lpfc-worker-thread-duri.patch.
- Refresh
  patches.drivers/scsi-lpfc-Increase-CQ-and-WQ-sizes-for-SCSI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Indicate-CONF-support-in-NVMe-PRLI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-lpfc-to-allow-different-sli4-cq-and.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-sli4-doorbell-infrastructure.patch.
- Refresh
  patches.drivers/scsi-lpfc-Treat-SCSI-Write-operation-Underruns-as-an.patch.
- Refresh
  patches.drivers/scsi-lpfc-Update-11.4.0.7-modified-files-for-2018-Co.patch.
- Refresh
  patches.drivers/scsi-lpfc-Validate-adapter-support-for-SRIU-option.patch.
- Refresh
  patches.drivers/scsi-lpfc-Work-around-NVME-cmd-iu-SGL-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-debug-counters-for-abort.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-make-several-unions-static-fix-non-ansi.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-move-placement-of-target-destroy-on-driver.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-11.4.0.7.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.0.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
  Move patches to the sorted section.
- commit fbb5005
* Fri Apr  6 2018 tiwai@suse.de
- intel_th: Use correct method of finding hub (FATE#325099).
- commit 0af4c94
* Fri Apr  6 2018 tiwai@suse.de
- Preliminary patch sort & update
- commit 1073359
* Fri Apr  6 2018 jthumshirn@suse.de
- scsi: lpfc: Add missing unlock in WQ full logic (bsc#1077989).
- scsi: lpfc: use __raw_writeX on DPP copies (bsc#1077989).
- commit 62cee1d
* Fri Apr  6 2018 jthumshirn@suse.de
- s390/qeth: on channel error, reject further cmd requests
  (bnc#1088343, LTC#165985).
- commit 5b6cf5f
* Fri Apr  6 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-csiostor-add-support-for-32-bit-port-capabiliti.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-64G-link-speed-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-PCI-Ids-for-if_type-6-hardware.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-SLI-4-if_type-6-support-to-the-code-ba.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-WQ-Full-Logic-for-NVME-Target.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-embedded-data-pointers-for-enhanced-pe.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-if_type-6-support-for-cycling-valid-bi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Add-push-to-adapter-support-to-sli4.patch.
- Refresh
  patches.drivers/scsi-lpfc-Allow-set-of-maximum-outstanding-SCSI-cmd-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Change-Copyright-of-12.0.0.0-modified-file.patch.
- Refresh
  patches.drivers/scsi-lpfc-Enable-fw-download-on-if_type-6-devices.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-IO-failure-during-hba-reset-testing-wi.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-PRLI-handling-when-topology-type-chang.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-SCSI-io-host-reset-causing-kernel-cras.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-frequency-of-Release-WQE-CQEs.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-header-inclusion-in-lpfc_nvmet.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-issue_lip-if-link-is-disabled.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nonrecovery-of-NVME-controller-after-c.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-nvme-embedded-io-length-on-new-hardwar.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-soft-lockup-in-lpfc-worker-thread-duri.patch.
- Refresh
  patches.drivers/scsi-lpfc-Increase-CQ-and-WQ-sizes-for-SCSI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Indicate-CONF-support-in-NVMe-PRLI.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-lpfc-to-allow-different-sli4-cq-and.patch.
- Refresh
  patches.drivers/scsi-lpfc-Rework-sli4-doorbell-infrastructure.patch.
- Refresh
  patches.drivers/scsi-lpfc-Treat-SCSI-Write-operation-Underruns-as-an.patch.
- Refresh
  patches.drivers/scsi-lpfc-Update-11.4.0.7-modified-files-for-2018-Co.patch.
- Refresh
  patches.drivers/scsi-lpfc-Validate-adapter-support-for-SRIU-option.patch.
- Refresh
  patches.drivers/scsi-lpfc-Work-around-NVME-cmd-iu-SGL-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-debug-counters-for-abort.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-make-several-unions-static-fix-non-ansi.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-move-placement-of-target-destroy-on-driver.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-11.4.0.7.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.0.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
- commit 78112c4
* Fri Apr  6 2018 ohering@suse.de
- hv_balloon: fix bugs in num_pages_onlined accounting
  (fate#323887).
- hv_balloon: simplify hv_online_page()/hv_page_online_one()
  (fate#323887).
- hv_balloon: fix printk loglevel (fate#323887).
- commit 0be921f
* Fri Apr  6 2018 ohering@suse.de
- PCI: hv: Only queue new work items in hv_pci_devices_present()
  if necessary (fate#323887, bsc#1087659).
- PCI: hv: Remove the bogus test in hv_eject_device_work()
  (fate#323887, bsc#1087659).
- PCI: hv: Fix a comment typo in _hv_pcifront_read_config()
  (fate#323887, bsc#1087659).
- PCI: hv: Fix 2 hang issues in hv_compose_msi_msg() (fate#323887,
  bsc#1087659, bsc#1087906).
- PCI: hv: Serialize the present and eject work items
  (fate#323887, bsc#1087659).
- commit ae18380
* Fri Apr  6 2018 ohering@suse.de
- add mainline tag to various patches to be able to get further work done
- commit 6ad1ff6
* Fri Apr  6 2018 lduncan@suse.com
- iscsi-target: Fix non-immediate TMR reference leak
  (bsc#1088381).
- iscsi-target: Make TASK_REASSIGN use proper se_cmd->cmd_kref
  (bsc#1088381).
- iscsi-target: fix memory leak in lio_target_tiqn_addtpg()
  (bsc#1088381).
- commit 34e6573
* Thu Apr  5 2018 lduncan@suse.com
- Ran series_sort.py prior to adding my patches.
- commit da61622
* Thu Apr  5 2018 msuchanek@suse.de
- kabi/severities: ignore PPC KVM
- commit 7d22756
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/traps: Use SRR1 defines for program check reasons
  (bsc#1061840).
- commit ea11890
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc: Add PPC_FEATURE2_HTM_NO_SUSPEND (bsc#1055117).
- commit 7ef8218
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/xive: prepare all hcalls to support long busy delays
  (bsc#1088273).
- powerpc/xive: shutdown XIVE when kexec or kdump is performed
  (bsc#1088273).
- powerpc/xive: fix hcall H_INT_RESET to support long busy delays
  (bsc#1088273).
- powerpc/64/kexec: fix race in kexec when XIVE is shutdowned
  (bsc#1088273).
- commit 61f67a6
* Thu Apr  5 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Work around TEXASR bug in fake suspend
  state (bsc#1061840).
- KVM: PPC: Book3S HV: Work around XER[SO] bug in fake suspend
  mode (bsc#1061840).
- KVM: PPC: Book3S HV: Work around transactional memory bugs in
  POWER9 (bsc#1061840).
- powerpc/powernv: Provide a way to force a core into SMT4 mode
  (bsc#1061840).
- powerpc: Add CPU feature bits for TM bug workarounds on POWER9
  v2.2 (bsc#1061840).
- powerpc: Free up CPU feature bits on 64-bit machines
  (bsc#1061840).
- powerpc: Book E: Remove unused CPU_FTR_L2CSR bit (bsc#1061840).
- powerpc: Use feature bit for RTC presence rather than timebase
  presence (bsc#1061840).
- powerpc/pseries: Fix clearing of security feature flags
  (bsc#1068032).
- commit acbd042
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/powernv: Enable TM without suspend if possible
  (bsc#1055117).
- Refresh patches.arch/powerpc-powernv-Check-device-tree-for-RFI-flush-sett.patch.
- Refresh patches.arch/powerpc-powernv-Set-or-clear-security-feature-flags.patch.
- commit 53035ed
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/tm: Add commandline option to disable hardware
  transactional memory (bsc#1055117).
- commit d4945ad
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: msgclr when handling doorbell exceptions from
  system reset (bsc#1065729).
- commit 920b4d2
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Avoid cpabort in context switch when possible
  (bsc#1055117).
- Refresh patches.arch/powerpc-64s-Replace-CONFIG_PPC_STD_MMU_64-with-CONFI.patch.
- Refresh patches.arch/powerpc-store-and-restore-the-pkey-state-across-cont.patch.
- commit 4153120
* Thu Apr  5 2018 brogers@suse.com
- fw_cfg: write vmcoreinfo details (bsc#1077919).
- crash: export paddr_vmcoreinfo_note() (bsc#1077919).
- fw_cfg: add DMA register (bsc#1077919).
- fw_cfg: add a public uapi header (bsc#1077919).
- fw_cfg: handle fw_cfg_read_blob() error (bsc#1077919).
- fw_cfg: remove inline from fw_cfg_read_blob() (bsc#1077919).
- fw_cfg: fix sparse warnings around FW_CFG_FILE_DIR read
  (bsc#1077919).
- fw_cfg: fix sparse warning reading FW_CFG_ID (bsc#1077919).
- fw_cfg: fix sparse warnings with fw_cfg_file (bsc#1077919).
- fw_cfg: fix sparse warnings in fw_cfg_sel_endianness()
  (bsc#1077919).
- commit d4b3f19
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64: Drop explicit hwsync in context switch
  (bsc#1065729).
- Refresh patches.arch/powerpc-64s-Add-support-for-ori-barrier_nospec-patch.patch.
- Refresh patches.arch/powerpc-Add-barrier_nospec.patch.
- commit e5a5881
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64: Drop reservation-clearing ldarx in context switch
  (bsc#1065729).
- commit 6038e82
* Thu Apr  5 2018 brogers@suse.com
- fw_cfg: fix driver remove (bsc#1077919).
- fw_cfg: fix the command line module name (bsc#1077919).
- commit e296044
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/powernv: Fix SMT4 forcing idle code (bsc#1061840).
- powerpc/lpar/debug: Initialize flags before printing debug
  message (bsc#1065729).
- powerpc: Move default security feature flags (bsc#1068032).
- commit a13eef9
* Thu Apr  5 2018 brogers@suse.com
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 6ad4507
* Thu Apr  5 2018 jroedel@suse.de
- x86/platform/UV: Fix critical UV MMR address error
  (bsc#1087542).
- x86/platform/UV: Fix GAM Range Table entries less than 1GB
  (bsc#1087542).
- commit 1ed61f7
* Thu Apr  5 2018 jroedel@suse.de
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 8376280
* Thu Apr  5 2018 dbueso@suse.de
- ipc/shm: Fix pid freeing (bsc#1088323).
- ipc/sem: Fix semctl(..., GETPID, ...) between pid namespaces
  (bsc#1088323).
- ipc/msg: Fix msgctl(..., IPC_STAT, ...) between pid namespaces
  (bsc#1088323).
- ipc/shm: Fix shmctl(..., IPC_STAT, ...) between pid namespaces
  (bsc#1088323).
- ipc/util: Helpers for making the sysvipc operations pid
  namespace aware (bsc#1088323).
- commit 834881a
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64: Call H_REGISTER_PROC_TBL when running as a HPT
  guest on POWER9 (bsc#1055117).
- commit d22d56e
* Thu Apr  5 2018 msuchanek@suse.de
- cxl: Fix possible deadlock when processing page faults from
  cxllib (bsc#1055014).
- cxl: Fix timebase synchronization status on P9 (bsc#1055014).
- commit 97da1b3
* Thu Apr  5 2018 dbueso@suse.de
- run series_sort.py
- commit dcd8dad
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Wire up cpu_show_spectre_v2() (bsc#1068032).
- powerpc/64s: Wire up cpu_show_spectre_v1() (bsc#1068032).
- powerpc/64s: Enhance the information in cpu_show_meltdown()
  (bsc#1068032).
- commit 63a2f99
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Move cpu_show_meltdown() (bsc#1068032).
  Refresh patches.arch/powerpc-64-barrier_nospec-Add-debugfs-trigger.patch.
- commit e6621ab
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/powernv: Use the security flags in pnv_setup_rfi_flush()
  (bsc#1068032).
- powerpc/powernv: Set or clear security feature flags
  (bsc#1068032).
- commit 88dba39
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/pseries: Set or clear security feature flags
  (bsc#1068032).
- powerpc/pseries: Use the security flags in
  pseries_setup_rfi_flush() (bsc#1068032).
- Refresh
  patches.arch/powerpc-64s-barrier_nospec-Add-hcall-trigger.patch.
- commit a943584
* Thu Apr  5 2018 jack@suse.cz
- FS-Cache: fix dereference of NULL user_key_payload
  (bsc#1052766).
- commit 55e6fcf
* Thu Apr  5 2018 jack@suse.cz
- nilfs2: fix race condition that causes file system corruption
  (bsc#1052766).
- commit a722fb7
* Thu Apr  5 2018 jack@suse.cz
- ocfs2: fix cluster hang after a node dies (bsc#1052766).
- commit 4120511
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc: Add security feature flags for Spectre/Meltdown
  (bsc#1068032).
- commit 5f230fd
* Thu Apr  5 2018 jack@suse.cz
- quota: propagate error from __dquot_initialize (bsc#1052766).
- commit cb9d963
* Thu Apr  5 2018 jack@suse.cz
- fsnotify: fix pinning group in fsnotify_prepare_user_wait()
  (bsc#1052766).
- commit c437982
* Thu Apr  5 2018 jack@suse.cz
- fscrypt: lock mutex before checking for bounce page pool
  (bsc#1052766).
- commit 209ee5e
* Thu Apr  5 2018 jack@suse.cz
- fscrypt: fix dereference of NULL user_key_payload (bsc#1052766).
- commit f373382
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/pseries: Add new H_GET_CPU_CHARACTERISTICS flags
  (bsc#1068032).
- commit b7a53a4
* Thu Apr  5 2018 jack@suse.cz
- isofs: fix timestamps beyond 2027 (bsc#1052766).
- commit a587b63
* Thu Apr  5 2018 msuchanek@suse.de
- Refresh rfi patches
  patches.arch/powerpc-rfi-flush-Always-enable-fallback-flush-on-ps.patch
  patches.arch/powerpc-rfi-flush-Call-setup_rfi_flush-after-LPM-mig.patch
  patches.arch/powerpc-rfi-flush-Differentiate-enabled-and-patched-.patch
- commit d7870ce
* Thu Apr  5 2018 oneukum@suse.com
- NET: usb: qmi_wwan: add support for YUGA CLM920-NC5 PID 0x9625
  (bsc#1085539).
- commit 1d9d091
* Thu Apr  5 2018 jack@suse.cz
- jbd2: fix sphinx kernel-doc build warnings (bsc#1052766).
- commit fc5bd65
* Thu Apr  5 2018 jack@suse.cz
- ext4: correct documentation for grpid mount option
  (bsc#1052766).
- commit 93f8b5b
* Thu Apr  5 2018 jack@suse.cz
- ext4: save error to disk in __ext4_grp_locked_error()
  (bsc#1052766).
- commit 3dda242
* Thu Apr  5 2018 oneukum@suse.com
- net: usb: qmi_wwan: add Telit ME910 PID 0x1101 support
  (bsc#1085539).
- commit c074125
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix a race in the ext4 shutdown path (bsc#1052766).
- commit 51e6374
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix crash when a directory's i_size is too small
  (bsc#1052766).
- commit 7d7ac9f
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix fdatasync(2) after fallocate(2) operation
  (bsc#1052766).
- commit 887455a
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s: Relax PACA address limitations (bsc#1065729).
  Refresh patches.arch/powerpc-rfi-flush-Make-it-possible-to-call-setup_rfi.patch
- commit 16255f0
* Thu Apr  5 2018 oneukum@suse.com
- net: qmi_wwan: add Sierra EM7565 1199:9091 (bsc#1085539).
- commit d8901e2
* Thu Apr  5 2018 msuchanek@suse.de
- powerpc/64s/radix: Remove bolted-SLB address limit for per-cpu
  stacks (bsc#1055186, fate#323286).
- commit 79fc554
* Thu Apr  5 2018 oneukum@suse.com
- net: qmi_wwan: add Quectel BG96 2c7c:0296 (bsc#1085539).
- commit 78209a8
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix interaction between i_size, fallocate, and delalloc
  after a crash (bsc#1052766).
- commit cbe1a44
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix quota inconsistency during orphan cleanup for
  read-only mounts (bsc#1052766).
- commit f8cbe3f
* Thu Apr  5 2018 jack@suse.cz
- ext4: fix incorrect quotaoff if the quota feature is enabled
  (bsc#1052766).
- commit 5e83762
* Thu Apr  5 2018 jack@suse.cz
- run series_sort.py
- commit b8d67c7
* Thu Apr  5 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch
- commit 0f4792f
* Thu Apr  5 2018 msuchanek@suse.de
- lkdtm: fix handle_irq_event symbol for INT_HW_IRQ_EN
  (bsc#1052766).
- cpu/hotplug: Remove unused check_for_tasks() function
  (bsc#1087405).
- commit aff55d7
* Thu Apr  5 2018 jthumshirn@suse.de
- scsi: aacraid: remove redundant setting of variable c
  (bsc#1077989).
- commit 46a3cd8
* Thu Apr  5 2018 msuchanek@suse.de
- eeprom: at24: fix reading from 24MAC402/24MAC602 (bsc#1052766).
- commit e377943
* Thu Apr  5 2018 ohering@suse.de
- scripts/git_sort/git_sort.py: helgas/pci.git
  bsc#1087659
- commit 718b019
* Thu Apr  5 2018 ohering@suse.de
- add mainline tag to one crypto patch to be able to get further work done
- commit ce6483f
* Thu Apr  5 2018 jthumshirn@suse.de
- libata: Modify quirks for MX100 to limit NCQ_TRIM quirk to
  MU01 version (bsc#1077989).
- libata: Make Crucial BX100 500GB LPM quirk apply to all firmware
  versions (bsc#1077989).
- libata: Apply NOLPM quirk to Crucial M500 480 and 960GB SSDs
  (bsc#1077989).
- libata: Enable queued TRIM for Samsung SSD 860 (bsc#1077989).
- ahci: Add PCI-id for the Highpoint Rocketraid 644L card
  (bsc#1077989).
- libata: disable LPM for Crucial BX100 SSD 500GB drive
  (bsc#1077989).
- libata: Apply NOLPM quirk to Crucial MX100 512GB SSDs
  (bsc#1077989).
- libata: don't try to pass through NCQ commands to non-NCQ
  devices (bsc#1077989).
- libata: remove WARN() for DMA or PIO command without data
  (bsc#1077989).
- libata: fix length validation of ATAPI-relayed SCSI commands
  (bsc#1077989).
- libata: apply MAX_SEC_1024 to all LITEON EP1 series devices
  (bsc#1077989).
- commit c6aedf4
* Thu Apr  5 2018 jthumshirn@suse.de
- libnvdimm: passthru functions clear to send (FATE#324636).
- Refresh
  patches.drivers/libnvdimm-fix-integer-overflow-static-analysis-warni.patch.
- commit 9f63ca3
* Thu Apr  5 2018 jthumshirn@suse.de
- scsi: ibmvfc: fix misdefined reserved field in
  ibmvfc_fcp_rsp_info (bsc#1077989).
- scsi: core: scsi_get_device_flags_keyed(): Always return device
  flags (bsc#1077989).
- scsi: core: Fix a scsi_show_rq() NULL pointer dereference
  (bsc#1077989).
- scsi: ufs: ufshcd: fix potential NULL pointer dereference in
  ufshcd_config_vreg (bsc#1077989).
- commit 56f0ee6
* Thu Apr  5 2018 jthumshirn@suse.de
- scsi: aacraid: Fix udev inquiry race condition (bsc#1077989).
- Refresh patches.drivers/scsi-aacraid-Fix-hang-in-kdump.patch.
- commit 2a83436
* Thu Apr  5 2018 hare@suse.de
- scsi: mpt3sas: wait for and flush running commands on
  shutdown/unload (bsc#1081917).
- scsi: mpt3sas: fix oops in error handlers after shutdown/unload
  (bsc#1081917).
- commit a349d88
* Thu Apr  5 2018 hare@suse.de
- scsi: mpt3sas: Do not use 32-bit atomic request descriptor
  for Ventura controllers (bsc#1081917).
- scsi: mpt3sas: make function _get_st_from_smid static
  (bsc#1081917).
- scsi: mpt3sas: lockless command submission (bsc#1081917).
- scsi: mpt3sas: simplify _wait_for_commands_to_complete()
  (bsc#1081917).
- scsi: mpt3sas: simplify mpt3sas_scsi_issue_tm() (bsc#1081917).
- scsi: mpt3sas: simplify task management functions (bsc#1081917).
- scsi: mpt3sas: always use first reserved smid for ioctl
  passthrough (bsc#1081917).
- scsi: mpt3sas: check command status before attempting abort
  (bsc#1081917).
- scsi: mpt3sas: Introduce mpt3sas_get_st_from_smid()
  (bsc#1081917).
- scsi: mpt3sas: open-code _scsih_scsi_lookup_get() (bsc#1081917).
- scsi: mpt3sas: separate out _base_recovery_check()
  (bsc#1081917).
- scsi: mpt3sas: use list_splice_init() (bsc#1081917).
- scsi: mpt3sas: set default value for cb_idx (bsc#1081917).
- scsi: mpt3sas: Remove unused variable requeue_event
  (bsc#1081917).
- scsi: mpt3sas: Replace PCI pool old API (bsc#1081917).
- commit cb50073
* Thu Apr  5 2018 jthumshirn@suse.de
- libnvdimm, {btt, blk}: do integrity setup before add_disk()
  (FATE#323731).
- libnvdimm, btt: Fix an incompatibility in the log layout
  (FATE#323731).
- libnvdimm, namespace: fix label initialization to use valid
  seq numbers (FATE#323731).
- libnvdimm, dimm: clear 'locked' status on successful DIMM enable
  (FATE#323731).
- commit d622fe7
* Thu Apr  5 2018 lhenriques@suse.com
- ceph: only dirty ITER_IOVEC pages for direct read (bsc#1084898).
- commit 39d3e00
* Thu Apr  5 2018 lhenriques@suse.com
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 0eac7e1
* Thu Apr  5 2018 hare@suse.de
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 31ba015
* Thu Apr  5 2018 colyli@suse.de
- dm: bump DM_VERSION_MINOR in response to target method error
  code changes (fate#322738,fate#322919,fate#322950,fate#323773).
- dm ioctl: fix alignment of event number in the device list
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bcache: don't attach backing with duplicate UUID (bsc#1076110).
- bcache: fix crashes in duplicate cache device register
  (bsc#1076110).
- Refresh with patch-mainline info from upstream
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit d9ed9f7
* Thu Apr  5 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/crypto-ccp-add-check-to-get-psp-master-only-when-psp-is-detected.patch.
- commit 3c722f3
* Thu Apr  5 2018 ohering@suse.de
- hv_netvsc: enable multicast if necessary (fate#323887).
- commit 8ac01bc
* Thu Apr  5 2018 bpoirier@suse.com
- i40evf: fix mac filter removal timing issue (bsc#1085952).
- commit 77d77ad
* Thu Apr  5 2018 rgoldwyn@suse.com
- Check all profiles attached to the label (bsc#1085996).
- commit bdb6960
* Wed Apr  4 2018 bp@suse.de
- EDAC, sb_edac: Fix missing DIMM sysfs entries with KNL SNC2/SNC4
  mode (bsc#1087398).
- commit 379aede
* Wed Apr  4 2018 mbrugger@suse.com
- clk: bcm2835: Protect sections updating shared registers
  (bsc#1085535).
- clk: bcm2835: Fix ana->maskX definitions (bsc#1085535).
- clk: migrate the count of orphaned clocks at init (bsc#1085535).
- i2c: bcm2835: Set up the rising/falling edge delays
  (bsc#1085535).
- clk: Don't touch hardware when reparenting during registration
  (bsc#1085535).
- clk: fix a panic error caused by accessing NULL pointer
  (bsc#1085535).
- clk: imx: imx7d: Fix parent clock for OCRAM_CLK (bsc#1085535).
- clocksource/drivers/arm_arch_timer: Validate CNTFRQ after
  enabling frame (bsc#1085535).
- clocksource/drivers/arm_arch_timer: Fix mem frame loop
  initialization (bsc#1085535).
- commit 99eb15b
* Wed Apr  4 2018 bp@suse.de
- perf/x86/intel/uncore: Fix multi-domain PCI CHA enumeration
  bug on Skylake servers (bsc#1086359).
- commit e6b5922
* Wed Apr  4 2018 mbrugger@suse.com
- arm64: Relax ARM_SMCCC_ARCH_WORKAROUND_1 discovery
  (bsc#1088051).
- arm64: mm: fix thinko in non-global page table attribute check
  (bsc#1088049).
- arm64: Remove unimplemented syscall log message (bsc#1085535).
- arm64: cpufeature: Fix CTR_EL0 field definitions (bsc#1085535).
- arm64: proc: Set PTE_NG for table entries to avoid traversing
  them twice (bsc#1085535).
- arm64: fix CONFIG_DEBUG_WX address reporting (bsc#1085535).
- arm64: mm: Fix false positives in set_pte_at access/dirty race
  detection (bsc#1085535).
- arm64: Initialise high_memory global variable earlier
  (bsc#1085535).
- arm64: fpsimd: Prevent registers leaking from dead tasks
  (bsc#1085535).
- arm64: prevent regressions in compressed kernel image size
  when upgrading to binutils 2.27 (bsc#1085535).
- arm64: Implement arch-specific pte_access_permitted()
  (bsc#1085535).
- arm64: ensure __dump_instr() checks addr_limit (bsc#1085535).
- arm64: fault: Route pte translation faults via
  do_translation_fault (bsc#1085535).
- arm64: mm: Use READ_ONCE when dereferencing pointer to pte table
  (bsc#1085535).
- arm64: Make sure SPsel is always set (bsc#1085535).
- commit 9ca6ca7
* Wed Apr  4 2018 tiwai@suse.de
- mmc: block: fix updating ext_csd caches on ioctl call
  (bsc#1051510).
- commit 750d5f5
* Wed Apr  4 2018 tiwai@suse.de
- blacklist.conf: update mmc entry
- commit 2ee5678
* Wed Apr  4 2018 oneukum@suse.com
- usb: usbmon: Read text within supplied buffer size
  (bsc#1087092).
- commit 86b2669
* Wed Apr  4 2018 oneukum@suse.com
- USB: storage: Add JMicron bridge 152d:2567 to unusual_devs.h
  (bsc#1087092).
- commit 1ed8de7
* Wed Apr  4 2018 oneukum@suse.com
- Revert "usb: musb: host: don't start next rx urb if current
  one failed" (bsc#1087092).
- commit b079d8b
* Wed Apr  4 2018 oneukum@suse.com
- usb: ohci: Proper handling of ed_rm_list to handle race
  condition between usb_kill_urb() and finish_unlinks()
  (bsc#1087092).
- commit 5b90439
* Wed Apr  4 2018 oneukum@suse.com
- xhci: Fix front USB ports on ASUS PRIME B350M-A (bsc#1087092).
- commit f61cb1b
* Wed Apr  4 2018 mfleming@suse.de
- nohz: Prevent a timer interrupt storm in
  tick_nohz_stop_sched_tick() (bsc#1051510).
- Refresh
  patches.suse/kernel-add-release-status-to-kernel-build.patch.
- Refresh patches.suse/sched-throttle-nohz.patch.
- commit a31081c
* Wed Apr  4 2018 tiwai@suse.de
- blacklist.conf: Add mac80211 entry
- commit 8a71e13
* Wed Apr  4 2018 tiwai@suse.de
- media: s3c-camif: fix out-of-bounds array access (bsc#1051510).
- media: vivid: fix incorrect capabilities for radio
  (bsc#1051510).
- media: cx25821: prevent out-of-bounds read on array card
  (bsc#1051510).
- media: au0828: fix VIDEO_V4L2 dependency (bsc#1051510).
- ath10k: fix recent bandwidth conversion bug (bsc#1051510).
- ath10k: advertize beacon_int_min_gcd (bsc#1051510).
- iwlwifi: mvm: check if mac80211_queue is valid in
  iwl_mvm_disable_txq (bsc#1051510).
- ath9k: Protect queue draining by rcu_read_lock() (bsc#1051510).
- mac80211: don't WARN on bad WMM parameters from buggy APs
  (bsc#1051510).
- mt7601u: let mac80211 validate rx CCMP PN (bsc#1051510).
- regmap: Format data for raw write in regmap_bulk_write
  (bsc#1051510).
- regmap: Don't use format_val in regmap_bulk_read (bsc#1051510).
- regmap: Correct offset handling in regmap_volatile_range
  (bsc#1051510).
- regmap-i2c: Off by one in regmap_i2c_smbus_i2c_read/write()
  (bsc#1051510).
- regmap: Fix reversed bounds check in regmap_raw_write()
  (bsc#1051510).
- regmap: Correct comparison in regmap_cached (bsc#1051510).
- commit f0366d2
* Wed Apr  4 2018 tiwai@suse.de
- add a cherry-picked id to earlycon fix patch
- commit c41f9b4
* Wed Apr  4 2018 bp@suse.de
- x86/cpu/amd: Derive L3 shared_cpu_map from cpu_llc_shared_mask
  (stable fixes).
- x86/efi: Fix kernel param add_efi_memmap regression (stable
  fixes).
- x86: Make X86_BUG_FXSAVE_LEAK detectable in CPUID on AMD
  (stable fixes).
- x86/microcode/intel: Disable late loading on model 79 (stable
  fixes).
- x86/microcode/intel: Extend BDW late-loading further with LLC
  size check (stable fixes).
- x86/microcode/intel: Extend BDW late-loading with a revision
  check (stable fixes).
- x86/mm, mm/hwpoison: Clear PRESENT bit for kernel 1:1 mappings
  of poison pages (stable fixes).
- x86/mm, mm/hwpoison: Don't unconditionally unmap kernel 1:1
  pages (stable fixes).
- blacklist.conf:
- Refresh
  patches.arch/x86-cpufeatures-add-amd-feature-bits-for-speculation-control.patch.
- Refresh
  patches.arch/x86-cpufeatures-clean-up-spectre-v2-related-cpuid-flags.patch.
- commit 6fad1e8
* Wed Apr  4 2018 oneukum@suse.com
- HID: multitouch: Support PTP Stick and Touchpad device
  (bsc#1085535).
- commit 121a18f
* Wed Apr  4 2018 mbrugger@suse.com
- blacklist.conf: arm64: ignore compiler warning fix
- commit f435aeb
* Wed Apr  4 2018 oneukum@suse.com
- HID: quirks: Fix keyboard + touchpad on Toshiba Click Mini
  not working (bsc#1087092).
- commit c28bdad
* Wed Apr  4 2018 aaptel@suse.com
- Fix encryption labels and lengths for SMB3.1.1 (bsc#1085536).
- commit 1064d6b
* Wed Apr  4 2018 oneukum@suse.com
- HID: multitouch: Only look at non touch fields in first packet
  of a frame (bsc#1087092).
- commit d86f5f8
* Wed Apr  4 2018 aaptel@suse.com
- Fix SMB3.1.1 guest authentication to Samba (bsc#1085536).
- commit 1a6f5eb
* Wed Apr  4 2018 aaptel@suse.com
- SMB3: Don't ignore O_SYNC/O_DSYNC and O_DIRECT flags
  (bsc#1085536).
- commit b7e7367
* Wed Apr  4 2018 aaptel@suse.com
- SMB3: handle new statx fields (bsc#1085536).
- commit 137a353
* Wed Apr  4 2018 aaptel@suse.com
- SMB: Validate negotiate (to protect against downgrade) even
  if signing off (bsc#1085536).
- commit 4cd7fa4
* Wed Apr  4 2018 aaptel@suse.com
- SMB3: Warn user if trying to sign connection that authenticated
  as guest (bsc#1085536).
- commit 17be9ec
* Wed Apr  4 2018 oneukum@suse.com
- PCMCIA / PM: Avoid noirq suspend aborts during suspend-to-idle
  (bsc#1087092).
- commit c4ccc7e
* Wed Apr  4 2018 agraf@suse.de
- Refresh patches.suse/0001-lan78xx-Connect-phy-early.patch.
- commit 1f9e0fb
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: assembler: Change order of macro arguments in
  phys_to_ttbr (bsc#1087414).
- commit 50ba314
* Tue Apr  3 2018 tbogendoerfer@suse.de
- net/mlx4_core: Fix memory leak while delete slave's resources
  (bsc#1046300 FATE#322946).
- net/mlx4_en: Fix mixed PFC and Global pause user control
  requests (bsc#1046299 FATE#322947).
- net/mlx5e: Avoid using the ipv6 stub in the TC offload neigh
  update path (bsc#1046303 FATE#322944).
- net/mlx5e: Fix memory usage issues in offloading TC flows
  (bsc#1046303 FATE#322944).
- net/mlx5e: Fix traffic being dropped on VF representor
  (bsc#1046303 FATE#322944).
- net/mlx5e: Don't override vport admin link state in switchdev
  mode (bsc#1046303 FATE#322944).
- RDMA/ucma: Check that device exists prior to accessing it
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Check that device is connected prior to access it
  (bsc#1046306 FATE#322942).
- RDMA/qedr: Fix QP state initialization race (bsc#1050545
  FATE#322893).
- RDMA/qedr: Fix rc initialization on CNQ allocation failure
  (bsc#1050545 FATE#322893).
- RDMA/qedr: fix QP's ack timeout configuration (bsc#1050545
  FATE#322893).
- bnxt_en: Check valid VNIC ID in bnxt_hwrm_vnic_set_tpa()
  (bsc#1050242 FATE#322914).
- RDMA/ucma: Ensure that CM_ID exists prior to access it
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Fix use-after-free access in ucma_close (bsc#1046306
  FATE#322942).
- RDMA/ucma: Fix access to non-initialized CM_ID object
  (bsc#1046306 FATE#322942).
- commit bacc3ae
* Tue Apr  3 2018 tbogendoerfer@suse.de
- net/mlx5e: Sync netdev vxlan ports at open (bsc#1046303
  FATE#322944).
- RDMA/core: Do not use invalid destination in determining port
  reuse (bsc#1046306 FATE#322942).
- IB/mlx5: Fix integer overflows in mlx5_ib_create_srq
  (bsc#1046305 FATE#322943).
- IB/mlx5: Fix incorrect size of klms in the memory region
  (bsc#1046305 FATE#322943).
- commit 78a69dd
* Tue Apr  3 2018 tbogendoerfer@suse.de
- net/mlx5: Make eswitch support to depend on switchdev
  (bsc#1046305 FATE#322943).
- RDMA/rdma_cm: Fix use after free race with process_one_req
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Correct option size check using optlen (bsc#1046306
  FATE#322942).
- RDMA/ucma: Check AF family prior resolving address (bsc#1046306
  FATE#322942).
- RDMA/ucma: Don't allow join attempts for unsupported AF family
  (bsc#1046306 FATE#322942).
- IB/mlx5: Fix out-of-bounds read in create_raw_packet_qp_rq
  (bsc#1046305 FATE#322943).
- commit 9a507f9
* Tue Apr  3 2018 tiwai@suse.de
- Move a few upstreamed i915 patches into sorted section
- commit 31b54c4
* Tue Apr  3 2018 tbogendoerfer@suse.de
- Re-sorted sorted section.
- Refresh
  patches.arch/powerpc-64s-Fix-NULL-AT_BASE_PLATFORM-when-using-DT-.patch.
- Refresh
  patches.arch/powerpc-64s-Fix-lost-pending-interrupt-due-to-race-c.patch.
- Refresh
  patches.arch/powerpc-mm-Add-tracking-of-the-number-of-coprocessor.patch.
- Refresh patches.arch/powerpc-mm-radix-Remove-unused-code.patch.
- Refresh
  patches.drivers/drm-i915-Fix-DPLCLKA_CFGCR0-bits-for-Port-F.
- Refresh
  patches.drivers/drm-i915-For-HPD-connected-port-use-hpd_pin-instead-.
- Refresh patches.drivers/drm-i915-cnl-Add-AUX-F-support.
- Refresh
  patches.drivers/drm-i915-cnl-Add-Cannonlake-PCI-IDs-for-another-SKU.
- Refresh patches.drivers/drm-i915-cnl-Add-HPD-support-for-Port-F.
- Refresh patches.drivers/drm-i915-cnl-Add-Port-F-definition.
- Refresh
  patches.drivers/drm-i915-cnl-Add-right-GMBUS-pin-number-for-HDMI-on-.
- Refresh patches.drivers/drm-i915-cnl-Enable-DDI-F-on-Cannonlake.
- Refresh patches.drivers/drm-i915-cnl-Extend-Wa-1178-to-Aux-F.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-DP-max-rate-for-Cannonlake-with-por.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-_CNL_PORT_TX_DW2_LN0_F-definition.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-aux-selection-for-WA-1178.
- Refresh
  patches.drivers/drm-i915-cnl-WaPipeControlBefore3DStateSamplePattern.
- Refresh
  patches.drivers/drm-i915-cnl-apply-Display-WA-1178-to-fix-type-C-don.
- Refresh patches.drivers/drm-i915-dmc-DMC-1.07-for-Cannonlake.
- Refresh
  patches.drivers/drm-i915-dp-abstract-rate-array-length-limiting.
- Refresh
  patches.drivers/drm-i915-dp-clean-up-source-rate-limiting-for-cnl.
- Refresh
  patches.drivers/drm-i915-dp-limit-DP-link-rate-based-on-VBT-on-CNL.
- commit 7eebb19
* Tue Apr  3 2018 msuchanek@suse.de
- powerpc/kexec_file: Fix error code when trying to load kdump
  kernel (bsc#1065729).
- powerpc: Fix invalid use of register expressions (bsc#1065729).
- commit 7f76cbc
* Tue Apr  3 2018 tiwai@suse.de
- drm/i915: Fix hibernation with ACPI S0 target state
  (bsc#1051510).
- drm/i915/execlists: Use a locked clear_bit() for synchronisation
  with interrupt (bsc#1051510).
- drm/i915: Wrap engine->schedule in RCU locks for set-wedge
  protection (bsc#1051510).
- drm/i915/psr: Check for the specific AUX_FRAME_SYNC cap bit
  (bsc#1051510).
- drm/i915: Correctly handle limited range YCbCr data on VLV/CHV
  (bsc#1051510).
- ALSA: pcm: Use dma_bytes as size parameter in
  dma_mmap_coherent() (bsc#1051510).
- ASoC: mt8173-rt5650: fix child-node lookup (bsc#1051510).
- commit 2b920b8
* Tue Apr  3 2018 tiwai@suse.de
- Preliminary patch sort and update
- commit 7e40132
* Tue Apr  3 2018 tiwai@suse.de
- blacklist.conf: Update drm and ath9k blacklist
- commit cd79980
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: mm: ignore memory above supported physical address size (bsc#1087414).
- commit 492164f
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: fix comment above tcr_compute_pa_size (bsc#1087414).
- commit 084a935
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- KVM: arm/arm64: fix HYP ID map extension to 52 bits (bsc#1087414).
- commit 816eb92
* Tue Apr  3 2018 yousaf.kaukab@suse.com
- arm64: fix ID map extension to 52 bits (bsc#1087414).
- commit 08c26ef
* Mon Apr  2 2018 jslaby@suse.cz
- objtool: Fix 32-bit build (bnc#1058115 git-fixes).
- commit 17df039
* Mon Apr  2 2018 jlee@suse.com
- acpi, numa: fix pxm to online numa node associations
  (bsc#1087144).
- commit cc55a09
* Mon Apr  2 2018 jlee@suse.com
- Refresh
  patches.arch/powerpc-64s-Fix-NULL-AT_BASE_PLATFORM-when-using-DT-.patch.
- Refresh
  patches.arch/powerpc-64s-Fix-lost-pending-interrupt-due-to-race-c.patch.
- Refresh
  patches.arch/powerpc-mm-Add-tracking-of-the-number-of-coprocessor.patch.
- Refresh patches.arch/powerpc-mm-radix-Remove-unused-code.patch.
- commit 8e8e208
* Sun Apr  1 2018 nstange@suse.de
- ppc64le: reliable stacktrace: fix .text check (bsc#1087458).
- commit 1aa954a
* Sat Mar 31 2018 nstange@suse.de
- ppc64le: reliable stacktrace: fix stacktrace for idle tasks (bsc#1087458).
- commit 5938588
* Thu Mar 29 2018 bp@suse.de
- x86/entry/64: Don't use IST entry for #BP stack (bsc#1087088).
- commit 10d3c90
* Thu Mar 29 2018 jslaby@suse.cz
- posix-timers: Protect posix clock array access against
  speculation (bnc#1081358 CVE-2017-5715).
- commit 5a1acc8
* Thu Mar 29 2018 msuchanek@suse.de
- KABI: cpu/hotplug: provide the old get|put_online_cpus()
  (bsc#1087405).
- commit f687c6d
* Thu Mar 29 2018 msuchanek@suse.de
- Import kabi files from RC2
- commit 3f5879f
* Thu Mar 29 2018 aaptel@suse.com
- run series_sort.py
- commit d353f7c
* Thu Mar 29 2018 msuchanek@suse.de
- powerpc: Don't call lockdep_assert_cpus_held() from
  arch_update_cpu_topology() (bsc#1087405).
- workqueue: Work around edge cases for calc of pool's cpumask
  (bsc#1087405).
- powerpc: Only obtain cpu_hotplug_lock if called by rtasd
  (bsc#1087405).
  Refresh patches.arch/powerpc-numa-Invalidate-numa_cpu_lookup_table-on-cpu.patch.
- cpu/hotplug: Convert hotplug locking to percpu rwsem
  (bsc#1087405).
- stop_machine: Provide stop_machine_cpuslocked() (bsc#1087405).
- cpu/hotplug: Provide lockdep_assert_cpus_held() (bsc#1087405).
- cpu/hotplug: Provide cpus_read|write_[un]lock() (bsc#1087405).
- commit 47384e4
* Thu Mar 29 2018 jack@suse.cz
- ipc/shm.c: add split function to shm_vm_ops (bsc#1052766).
- commit 4d132c0
* Thu Mar 29 2018 jack@suse.cz
- dax: fix vma_is_fsdax() helper (bsc#1052766).
- commit b56bd6f
* Thu Mar 29 2018 jack@suse.cz
- Run series_sort.py:
  patches.arch/powerpc-64s-Fix-NULL-AT_BASE_PLATFORM-when-using-DT-.patch.
  patches.arch/powerpc-64s-Fix-lost-pending-interrupt-due-to-race-c.patch.
  patches.arch/powerpc-mm-Add-tracking-of-the-number-of-coprocessor.patch.
  patches.arch/powerpc-mm-radix-Remove-unused-code.patch.
- commit d6d2551
* Thu Mar 29 2018 oneukum@suse.com
- blacklist.conf: config only
- commit 80e80db
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: generic: Recognize WACOM_HID_WD_PEN as a type of
  pen collection (bsc#1085539).
- commit 45e56be
* Thu Mar 29 2018 oneukum@suse.com
- HID: hid-elecom: extend to fix descriptor for HUGE trackball
  (bsc#1085536).
- commit 31aa2e9
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- Update config files.
- commit f6b4573
* Thu Mar 29 2018 oneukum@suse.com
- HID: usbhid: fix out-of-bounds bug (bsc#1085536).
- commit 8c5a469
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: Fix TTBR + PAN + 52-bit PA logic in cpu_do_switch_mm (bsc#1087414).
- commit 78c2b65
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: Always increment hdev refcount within
  wacom_get_hdev_data (bsc#1085536).
- commit 928bfef
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: enable 52-bit physical address support (bsc#1087414).
- commit 19c75f1
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: generic: Clear ABS_MISC when tool leaves proximity
  (bsc#1085536).
- commit 52ce6f1
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: generic: Send MSC_SERIAL and ABS_MISC when leaving
  prox (bsc#1085536).
- commit 7d14c4c
* Thu Mar 29 2018 oneukum@suse.com
- HID: i2c-hid: allocate hid buffers for real worst case
  (bsc#1085536).
- commit 8469205
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: Correct coordinate system of touchring and pen twist
  (bsc#1085536).
- HID: wacom: Properly report negative values from Intuos Pro
  2 Bluetooth (bsc#1085536).
- commit 3415c32
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: leds: Don't try to control the EKR's read-only LEDs
  (bsc#1085536).
- commit 9dd7e47
* Thu Mar 29 2018 oneukum@suse.com
- HID: wacom: bits shifted too much for 9th and 10th buttons
  (bsc#1085536).
- commit 981162e
* Thu Mar 29 2018 oneukum@suse.com
- isdn/i4l: fetch the ppp_write buffer in one shot (bsc#1085536).
- commit b48a9e9
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: allow ID map to be extended to 52 bits (bsc#1087414).
- commit 6c68c5d
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: handle 52-bit physical addresses in page table entries (bsc#1087414).
- commit b24364b
* Thu Mar 29 2018 oneukum@suse.com
- ohci-hcd: Fix race condition caused by ohci_urb_enqueue()
  and io_watchdog_func() (bsc#1087092).
- commit 9648543
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: don't open code page table entry creation (bsc#1087414).
- commit d140261
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: head.S: handle 52-bit PAs in PTEs in early page table setup (bsc#1087414).
- Delete out-of-tree patch
  patches.suse/arm64-add-PTE_ADDR_MASK.patch
- commit a185a0c
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: handle 52-bit addresses in TTBR (bsc#1087414).
- Refresh
  patches.suse/0010-arm64-Move-post_ttbr_update_workaround-to-C-code.patch.
- Refresh
  patches.suse/0012-arm64-KVM-Use-per-CPU-vector-when-BP-hardening-is-en.patch
- Refresh
  patches.suse/arm64-Add-software-workaround-for-Falkor-erratum-104.patch
- Refresh
  patches.suse/v2-4-9-arm64-kpti-Add---enable-callback-to-remap-swapper-using-nG-mappings.patch.
- commit 2db3dd8
* Thu Mar 29 2018 tiwai@suse.de
- mfd: lpc_ich: Avoton/Rangeley uses SPI_BYT method (bsc#1051510).
- commit 4767d8c
* Thu Mar 29 2018 tiwai@suse.de
- ima/policy: fix parsing of fsuuid (bsc#1051510).
- ima: relax requiring a file signature for new files with zero
  length (bsc#1051510).
- commit 2cdd97f
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: limit PA size to supported range (bsc#1087414).
- commit 70ee670
* Thu Mar 29 2018 yousaf.kaukab@suse.com
- arm64: add kconfig symbol to configure physical address size (bsc#1087414).
- commit d185b34
* Thu Mar 29 2018 tiwai@suse.de
- earlycon: add reg-offset to physical address before mapping
  (bsc#1051510).
- commit 4cbd533
* Thu Mar 29 2018 tiwai@suse.de
- brcmfmac: fix P2P_DEVICE ethernet address generation
  (bsc#1051510).
- commit f59d048
* Thu Mar 29 2018 tiwai@suse.de
- Bluetooth: btusb: Add Dell OptiPlex 3060 to
  btusb_needs_reset_resume_table (bsc#1051510).
- commit f568264
* Thu Mar 29 2018 tiwai@suse.de
- Preliminary series sort / update
- commit 50c4a36
* Thu Mar 29 2018 oneukum@suse.com
- usb: Don't print a warning if interface driver rebind is
  deferred at resume (bsc#1087211).
- commit a2c4fdd
* Thu Mar 29 2018 oneukum@suse.com
- USB: usbip: remove useless call in usbip_recv (bsc#1087092).
- commit 01880ff
* Thu Mar 29 2018 tiwai@suse.de
- Input: matrix_keypad - fix race when disabling interrupts
  (bsc#1051510).
- commit e958019
* Thu Mar 29 2018 ohering@suse.de
- Drivers: hv: vmbus: Fix ring buffer signaling (fate#323887).
- hv_netvsc: common detach logic (fate#323887).
- hv_netvsc: change GPAD teardown order on older versions
  (fate#323887).
- hv_netvsc: use RCU to fix concurrent rx and queue changes
  (fate#323887).
- hv_netvsc: disable NAPI before channel close (fate#323887).
- hv_netvsc: fix locking during VF setup (fate#323887).
- hv_netvsc: fix locking for rx_mode (fate#323887).
- hv_netvsc: avoid repeated updates of packet filter
  (fate#323887).
- hv_netvsc: fix filter flags (fate#323887).
- scsi: storvsc: Spread interrupts when picking a channel for
  I/O requests (fate#323887).
- hv_netvsc: propagate rx filters to VF (fate#323887).
- hv_netvsc: filter multicast/broadcast (fate#323887).
- hv_netvsc: defer queue selection to VF (fate#323887).
- hv_netvsc: use napi_schedule_irqoff (fate#323887).
- hv_netvsc: fix race in napi poll when rescheduling
  (fate#323887).
- hv_netvsc: cancel subchannel setup before halting device
  (fate#323887).
- hv_netvsc: fix error unwind handling if vmbus_open fails
  (fate#323887).
- hv_netvsc: only wake transmit queue if link is up (fate#323887).
- hv_netvsc: avoid retry on send during shutdown (fate#323887).
- scsi: storvsc: Increase cmd_per_lun for higher speed devices
  (fate#323887).
- commit c2c371a
* Wed Mar 28 2018 tiwai@suse.de
- rtlwifi: rtl8723be: Fix loss of signal (bsc#1051510).
- mmc: dw_mmc: fix falling from idmac to PIO mode when
  dw_mci_reset occurs (bsc#1051510).
- mmc: core: Disable HPI for certain Micron (Numonyx) eMMC cards
  (bsc#1051510).
- mmc: dw_mmc: Avoid accessing registers in runtime suspended
  state (bsc#1051510).
- mmc: sdhci-pci: Fix S0i3 for Intel BYT-based controllers
  (bsc#1051510).
- mmc: avoid removing non-removable hosts during suspend
  (bsc#1051510).
- mmc: mmc_test: Ensure command queue is disabled for testing
  (bsc#1051510).
- commit f5a53da
* Wed Mar 28 2018 tiwai@suse.de
- ALSA: aloop: Fix access to not-yet-ready substream via cable
  (bsc#1051510).
- ALSA: aloop: Sync stale timer before release (bsc#1051510).
- ALSA: hda/realtek - Fix speaker no sound after system resume
  (bsc#1051510).
- ALSA: hda/realtek - Fix Dell headset Mic can't record
  (bsc#1051510).
- ALSA: hda - Force polling mode on CFL for fixing codec
  communication (bsc#1051510).
- ALSA: usb-audio: Fix parsing descriptor of UAC2 processing unit
  (bsc#1051510).
- ALSA: hda/realtek - Always immediately update mute LED with
  pin VREF (bsc#1051510).
- drm: udl: Properly check framebuffer mmap offsets (bsc#1051510).
- drm: Reject getfb for multi-plane framebuffers (bsc#1051510).
- drm/vmwgfx: Fix a destoy-while-held mutex problem (bsc#1051510).
- drm/vmwgfx: Fix black screen and device errors when running
  without fbdev (bsc#1051510).
- drm/radeon: Don't turn off DP sink when disconnected
  (bsc#1051510).
- commit f5e4005
* Wed Mar 28 2018 enadolski@suse.com
- btrfs: add missing initialization in btrfs_check_shared
  (bsc#1087185).
- commit 0dc4dff
* Wed Mar 28 2018 tiwai@suse.de
- mei: me: allow runtime pm for platform with D0i3 (bsc#1087204).
- commit 91f0e9a
* Wed Mar 28 2018 oneukum@suse.com
- usbip: keep usbip_device sockfd state in sync with tcp_socket
  (bsc#1087092).
- commit a9c0193
* Wed Mar 28 2018 aaptel@suse.com
- CIFS: zero sensitive data when freeing (bsc#1087092).
- commit 342e490
* Wed Mar 28 2018 oneukum@suse.com
- usbip: list: don't list devices attached to vhci_hcd
  (bsc#1087092).
- commit 80e4e06
* Wed Mar 28 2018 oneukum@suse.com
- usbip: prevent bind loops on devices attached to vhci_hcd
  (bsc#1087092).
- commit 1b1531b
* Wed Mar 28 2018 aaptel@suse.com
- cifs: Fix autonegotiate security settings mismatch (bsc#1087092).
- commit 7bd8fc2
* Wed Mar 28 2018 aaptel@suse.com
- cifs: Fix missing put_xid in cifs_file_strict_mmap (bsc#1087092).
- commit 15a395c
* Wed Mar 28 2018 aaptel@suse.com
- cifs: fix NULL deref in SMB2_read (bsc#1085539).
- commit a05b05d
* Wed Mar 28 2018 aaptel@suse.com
- cifs: check MaxPathNameComponentLength != 0 before using it
  (bsc#1085536).
- commit 5af1893
* Wed Mar 28 2018 oneukum@suse.com
- usbip: vudc_tx: fix v_send_ret_submit() vulnerability to null
  xfer buffer (bsc#1085539).
- commit cba3218
* Wed Mar 28 2018 aaptel@suse.com
- cifs: Select all required crypto modules (bsc#1085536).
- commit 23399f9
* Wed Mar 28 2018 aaptel@suse.com
- cifs: release auth_key.response for reconnect (bsc#1085536).
- commit 0221ea3
* Wed Mar 28 2018 aaptel@suse.com
- cifs: release cifs root_cred after exit_cifs (bsc#1085536).
- commit 5fcee93
* Wed Mar 28 2018 aaptel@suse.com
- cifs: check rsp for NULL before dereferencing in SMB2_open
  (bsc#1085536).
- commit bb4352e
* Wed Mar 28 2018 oneukum@suse.com
- usbip: remove kernel addresses from usb device and urb debug
  msgs (bsc#1085539).
- usbip: fix vudc_rx: harden CMD_SUBMIT path to handle malicious
  input (bsc#1085539).
- commit 6015ddb
* Wed Mar 28 2018 oneukum@suse.com
- usbip: fix usbip bind writing random string after command in
  match_busid (bsc#1085539).
- commit 251451b
* Wed Mar 28 2018 msuchanek@suse.de
- powerpc/64s: Fix i-side SLB miss bad address handler saving
  nonvolatile GPRs (bsc#1065729).
- commit 5dca109
* Wed Mar 28 2018 oneukum@suse.com
- usbip: prevent leaking socket pointer address in messages
  (bsc#1085539).
- commit c149b42
* Wed Mar 28 2018 lpechacek@suse.com
- powerpc/livepatch: Fix livepatch stack access (bsc#1086660).
- commit 37df8c9
* Wed Mar 28 2018 oneukum@suse.com
- usbip: stub: stop printing kernel pointer addresses in messages
  (bsc#1085539).
- commit 9f24363
* Wed Mar 28 2018 oneukum@suse.com
- usbip: vhci: stop printing kernel pointer addresses in messages
  (bsc#1085539).
- commit dbda174
* Wed Mar 28 2018 oneukum@suse.com
- blacklist.conf: we do not build the tools
- commit 24b7f9c
* Wed Mar 28 2018 msuchanek@suse.de
- Update patches.arch/powerpc-tm-Flush-TM-only-if-CPU-has-TM-feature.patch
  (bsc#1075746, bsc#1087231, CVE-2018-1091).
- commit 7102e9a
* Wed Mar 28 2018 oneukum@suse.com
- blacklist.conf: false positive
- commit d595303
* Wed Mar 28 2018 oneukum@suse.com
- usbnet: fix alignment for frames with no ethernet header
  (bsc#1085539).
- Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
- commit 45660b1
* Wed Mar 28 2018 oneukum@suse.com
- uwb: properly check kthread_run return value (bsc#1085536).
- commit f546456
* Wed Mar 28 2018 oneukum@suse.com
- uwb: ensure that endpoint is interrupt (bsc#1085536).
- commit 5aba24e
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Don't add a virt_dev to the devs array before it's fully
  allocated (bsc#1085539).
- commit df88c42
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Cleanup current_cmd in xhci_cleanup_command_queue()
  (bsc#1085536).
- commit b7e5b94
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Identify USB 3.1 capable hosts by their port protocol
  capability (bsc#1085536).
- commit bd7eec8
* Wed Mar 28 2018 oneukum@suse.com
- Revert "xhci: Limit USB2 port wake support for AMD Promontory
  hosts" (bsc#1085536).
- commit 6bc0fd3
* Wed Mar 28 2018 oneukum@suse.com
- xhci: Fix sleeping with spin_lock_irq() held in ASmedia 1042A
  workaround (bsc#1085536).
- commit bb7b728
* Wed Mar 28 2018 neilb@suse.com
- staging: ncpfs: memory corruption in ncp_read_kernel()
  (bsc#1086162, CVE-2018-8822).
- commit 4da6eb3
* Tue Mar 27 2018 jgross@suse.com
- /pirq: fix error path cleanup when binding MSIs (bnc#1065600).
- commit 01219ee
* Tue Mar 27 2018 jgross@suse.com
- x86/mm: Fix {pmd,pud}_{set,clear}_flags() (bnc#1065600).
- commit f6df79c
* Tue Mar 27 2018 jgross@suse.com
- xen/balloon: Mark unallocated host memory as UNUSABLE
  (bnc#1065600).
- commit d2ace39
* Tue Mar 27 2018 jgross@suse.com
- x86-64/Xen: eliminate W+X mappings (bnc#1065600).
- commit df523b5
* Tue Mar 27 2018 oneukum@suse.com
- xhci: fix wrong endpoint ESIT value shown in tracing
  (bsc#1085536).
- commit 33411cf
* Tue Mar 27 2018 oneukum@suse.com
- xhci: fix finding correct bus_state structure for USB 3.1 hosts
  (bsc#1085536).
- commit 85ca58c
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: we do not buil the tools
- commit a686bd3
* Tue Mar 27 2018 oneukum@suse.com
- uas: fix comparison for error code (bsc#1051943).
- commit 3e3561a
* Tue Mar 27 2018 oneukum@suse.com
- usb: uas: unconditionally bring back host after reset
  (bsc#1051943).
- commit 323a206
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: patch changes only logging
- commit ac5efdb
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf:subsystem not used
- commit 695a5dd
* Tue Mar 27 2018 msuchanek@suse.de
- net: ibm: ibmveth: constify vio_device_id (bsc#1061843).
- ibmveth: properly unwind on init errors (bsc#1061843).
- net: ibm: ibmveth: constify dev_pm_ops structures (bsc#1061843).
- commit da73308
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: io_edgeport: fix possible sleep-in-atomic
  (bsc#1085539).
- usb: misc: usb3503: make sure reset is low for at least 100us
  (bsc#1085539).
- commit 4030478
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: cp210x: add new device ID ELV ALC 8xxx
  (bsc#1085539).
- commit 885cc1c
* Tue Mar 27 2018 jthumshirn@suse.de
- Update
  patches.drivers/nvmet_fc-prevent-new-io-rqsts-in-possible-isr-comple.patch
  (bsc#1083575).
- commit 44b0542
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: cp210x: add IDs for LifeScan OneTouch Verio IQ
  (bsc#1085539).
- commit de14177
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 0406ef2
* Tue Mar 27 2018 oneukum@suse.com
- USB: fix usbmon BUG trigger (bsc#1085539).
- commit 4896206
* Tue Mar 27 2018 oneukum@suse.com
- usb: xhci: Add XHCI_TRUST_TX_LENGTH for Renesas uPD720201
  (bsc#1085539).
- commit 4a1b6e3
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: ftdi_sio: add id for Airbus DS P8GR (bsc#10855539).
- commit 8912afa
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: option: adding support for YUGA CLM920-NC5
  (bsc#1085539).
- commit 651ceb3
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: qcserial: add Sierra Wireless EM7565 (bsc#1085539).
- commit 814b845
* Tue Mar 27 2018 oneukum@suse.com
- USB: serial: option: add support for Telit ME910 PID 0x1101
  (bsc#1085539).
- commit ccecbba
* Tue Mar 27 2018 oneukum@suse.com
- blacklist.conf: not needed in our configuration
- commit 192f439
* Tue Mar 27 2018 oneukum@suse.com
- usb: Add device quirk for Logitech HD Pro Webcam C925e
  (bsc#1085539).
- commit 2db4499
* Tue Mar 27 2018 oneukum@suse.com
- usb: add RESET_RESUME for ELSA MicroLink 56K (bsc#1085539).
- commit fdc4f36
* Tue Mar 27 2018 mgorman@suse.de
- sched/numa: avoid trapping faults and attempting migration
  of file-backed dirty pages (bnc#1064414 reduce unnecessary
  migrations and numab conflicts).
- commit ca8fdbf
* Tue Mar 27 2018 jeffm@suse.com
- audit: fix memleak in auditd_send_unicast_skb (bsc#1086997).
- commit a70d9a2
* Tue Mar 27 2018 jeffm@suse.com
- crypto: dh - fix memleak in setkey (bsc#1086994).
- commit e6b64ce
* Mon Mar 26 2018 tiwai@suse.de
- sched/sysctl: Check user input value of sysctl_sched_time_avg
  (bsc#1086946).
- commit b6afd97
* Mon Mar 26 2018 tiwai@suse.de
- brcmsmac: allocate ucode with GFP_KERNEL (bsc#1085174).
- commit f82808c
* Mon Mar 26 2018 bp@suse.de
- crypto: ccp - add check to get PSP master only when PSP is
  detected (bsc#1063068).
- KVM: x86: Fix device passthrough when SME is active
  (bsc#1084912).
- x86/efi: Free efi_pgd with free_pages() (git-fixes
  d9e9a6418065).
- x86/vsyscall/64: Use proper accessor to update P4D entry
  (git-fixes 49275fef986a).
- scripts/git_sort/git_sort.py:
- commit 0188aa6
* Mon Mar 26 2018 msuchanek@suse.de
- blacklist
  c179ea270100 powerpc/kprobes: Fix warnings from __this_cpu_read() on preempt kernels
  94d3084a0f8c powerpc/32s: Fix compile error with CONFIG_PPC_PTDUMP
- commit f6243d1
* Mon Mar 26 2018 msuchanek@suse.de
- powerpc/bpf/jit: Fix 32-bit JIT for seccomp_data access
  (bsc#1065729).
- commit b6d0e6a
* Mon Mar 26 2018 oneukum@suse.com
- usb: dwc3: of-simple: fix missing clk_disable_unprepare
  (bsc#1085539).
- commit c383569
* Mon Mar 26 2018 oneukum@suse.com
- usb: dwc3: gadget: Wait longer for controller to end command
  processing (bsc#1085539).
- commit ccd154d
* Mon Mar 26 2018 oneukum@suse.com
- usb: xhci: fix TDS for MTK xHCI1.1 (bsc#1085539).
- commit 9eac7a6
* Mon Mar 26 2018 oneukum@suse.com
- USB: uas and storage: Add US_FL_BROKEN_FUA for another JMicron
  JMS567 ID (bsc#1085539).
- commit 23cc14b
* Mon Mar 26 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-Potential-NULL-dereference-in-clean_one_tx_p.patch.
- commit c83e9b6
* Mon Mar 26 2018 oneukum@suse.com
- usb: musb: da8xx: fix babble condition handling (bsc#1085539).
- commit 1be976d
* Mon Mar 26 2018 tiwai@suse.de
- drm/amdgpu: fix prime teardown order (bsc#1051510).
- watchdog: hpwdt: Remove legacy NMI sourcing (bsc#1051510).
- Revert "drm/radeon/pm: autoswitch power state when in balanced
  mode" (bsc#1051510).
- PM / runtime: Update links_count also if !CONFIG_SRCU
  (bsc#1051510).
- watchdog: imx2_wdt: restore previous timeout after
  suspend+resume (bsc#1051510).
- watchdog: hpwdt: fix unused variable warning (bsc#1051510).
- watchdog: hpwdt: Check source of NMI (bsc#1051510).
- watchdog: hpwdt: SMBIOS check (bsc#1051510).
- watchdog: Fix potential kref imbalance when opening watchdog
  (bsc#1051510).
- media: [RESEND] media: dvb-frontends: Add delay to Si2168
  restart (bsc#1051510).
- media: bt8xx: Fix err 'bt878_probe()' (bsc#1051510).
- PCI: designware-ep: Fix ->get_msi() to check MSI_EN bit
  (bsc#1051510).
- PCI: endpoint: Fix find_first_zero_bit() usage (bsc#1051510).
- vgacon: Set VGA struct resource types (bsc#1051510).
- pinctrl: Really force states during suspend/resume
  (bsc#1051510).
- pinctrl: intel: Initialize GPIO properly when used through
  irqchip (bsc#1051510).
- agp/intel: Flush all chipset writes after updating the GGTT
  (bsc#1051510).
- ath10k: handling qos at STA side based on AP WMM enable/disable
  (bsc#1051510).
- rtlwifi: rtl_pci: Fix the bug when inactiveps is enabled
  (bsc#1051510).
- Bluetooth: btqcomsmd: Fix skb double free corruption
  (bsc#1051510).
- Bluetooth: hci_qca: Avoid setup failure on missing rampatch
  (bsc#1051510).
- crypto: cavium - fix memory leak on info (bsc#1051510).
- PM / devfreq: Propagate error from devfreq_add_device()
  (bsc#1051510).
- pinctrl: cherryview: Mask all interrupts on Intel_Strago based
  systems (bsc#1051510).
- drm/exynos: gem: Drop NONCONTIG flag for buffers allocated
  without IOMMU (bsc#1051510).
- PM / runtime: Fix handling of suppliers with disabled runtime PM
  (bsc#1051510).
- crypto: brcm - Explicity ACK mailbox message (bsc#1051510).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_disassoc_cmd (bsc#1051510).
- PM: core: Fix device_pm_check_callbacks() (bsc#1051510).
- commit 6b1c180
* Mon Mar 26 2018 oneukum@suse.com
- usb: xhci: fix panic in xhci_free_virt_devices_depth_first
  (bsc#1085539).
- commit 821249d
* Mon Mar 26 2018 tbogendoerfer@suse.de
- qed: Fix MPA unalign flow in case header is split across two
  packets (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- bnxt_en: Return standard Linux error codes for hwrm flow cmds
  (bsc#1050242 FATE#32291).
- bnxt_en: Remove unwanted ovs-offload messages in some conditions
  (bsc#1050242 FATE#32291).
- infiniband: bnxt_re: use BIT_ULL() for 64-bit bit masks
  (bsc#1050244 FATE#322915).
- infiniband: qplib_fp: fix pointer cast (bsc#1050244
  FATE#322915).
- commit 72c0fdb
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit c778a11
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 11379a6
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 1fab475
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 506214b
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 5d07732
* Mon Mar 26 2018 oneukum@suse.com
- USB: serial: usb_debug: add new USB device id (bsc#1085539).
- USB: serial: option: add Quectel BG96 id (bsc#1085539).
- commit c98442a
* Mon Mar 26 2018 tbogendoerfer@suse.de
- svcrdma: Estimate Send Queue depth properly (bsc#1081515).
- svcrdma: Limit RQ depth (bsc#1081515).
- commit 8eb6546
* Mon Mar 26 2018 oneukum@suse.com
- usb: quirks: Add no-lpm quirk for KY-688 USB 3.1 Type-C Hub
  (bsc#1085539).
- commit 4176e03
* Mon Mar 26 2018 oneukum@suse.com
- blacklist.conf: not applicable change to Makefiles
- commit a0544d1
* Mon Mar 26 2018 oneukum@suse.com
- usb: hub: Cycle HUB power when initialization fails
  (bsc#1085539).
- commit d1a83ef
* Mon Mar 26 2018 jroedel@suse.de
- PCI/DPC: Enable DPC only if AER is available (bsc#1082368).
- commit 654d5a4
* Mon Mar 26 2018 msuchanek@suse.de
- powerpc: System reset avoid interleaving oops using die
  synchronisation (bsc#1086791).
- commit 715df69
* Mon Mar 26 2018 msuchanek@suse.de
- powerpc/crash: Remove the test for cpu_online in the IPI
  callback (bsc#1086791).
- powerpc: Do not send system reset request through the oops path
  (bsc#1086791).
- commit fe60432
* Mon Mar 26 2018 msuchanek@suse.de
- get_fs_type: Validate fs type string argument (bsc#1082943).
- commit 709e045
* Mon Mar 26 2018 nborisov@suse.com
- dcache: Add cond_resched in shrink_dentry_list (bsc#1086194).
- commit 413a765
* Mon Mar 26 2018 bpoirier@suse.com
- net: phy: mdio-bcm-unimac: fix potential NULL dereference in
  unimac_mdio_probe() (bsc#1084829 CVE-2018-8043).
- commit 4836f39
* Mon Mar 26 2018 bpoirier@suse.com
- Fix whitespace breakage in series.conf
  Commit ceb4998ac05a ("s390: scrub registers on kernel entry and KVM exit
  (LTC#164304, bsc#1084911).") changed the first line of series.conf.
  Incidentally, the scripts in scripts/git_sort/quilt-mode.sh rely on this
  line being present for the replacement (via the modified quilt) of the
  simple series file in the expanded tree with a link to series.conf.
- commit d49c5e2
* Fri Mar 23 2018 mcgrof@suse.com
- Refresh patches.drivers/0001-module-warn-if-module-init-probe-takes-long.patch.
- commit caebf3e
* Fri Mar 23 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Disable tb_offset (bsc#1086196).
- commit 529e36c
* Fri Mar 23 2018 agraf@suse.de
- armv7hl: Disable uacces with memcpy (boo#1080435)
- commit 4e513aa
* Fri Mar 23 2018 tiwai@suse.de
- drm/amdgpu/dce: Don't turn off DP sink when disconnected
  (bsc#1051510).
- commit 15ae848
* Fri Mar 23 2018 tiwai@suse.de
- drm/i915: Disable tv output on i9x5gm (bsc#1086657).
- drm/i915: Specify which engines to reset following
  semaphore/event lockups (FATE#322643 bsc#1055900).
- commit 0838c05
* Fri Mar 23 2018 msuchanek@suse.de
- powerpc: Remove unused flush_dcache_phys_range() (bsc#1065729).
- powerpc/mm/radix: Remove unused code (bsc#1055186, fate#323286,
  git-fixes).
- powerpc/mm: Add tracking of the number of coprocessors using
  a context (bsc#1055014).
- powerpc/64s: Fix lost pending interrupt due to race causing
  lost update to irq_happened (bsc#1065729).
- commit ff3617a
* Fri Mar 23 2018 tiwai@suse.de
- drm/i915/dp: Write to SET_POWER dpcd to enable MST hub
  (bsc#1051510).
- ACPI / watchdog: Fix off-by-one error at resource assignment
  (bsc#1073960).
- Bluetooth: btusb: Fix quirk for Atheros 1525/QCA6174
  (bsc#1082504).
- Bluetooth: btusb: Remove Yoga 920 from the
  btusb_needs_reset_resume_table (bsc#1051510).
- commit ce5f883
* Fri Mar 23 2018 tiwai@suse.de
- Preliminary patch sort / update (again)
- commit 805d5d7
* Fri Mar 23 2018 msuchanek@suse.de
- ibmvnic: Potential NULL dereference in clean_one_tx_pool()
  (bsc#1085224, git-fixes).
- commit 7acb565
* Fri Mar 23 2018 tiwai@suse.de
- supported.conf: Add AMDGPU driver (bsc#1069343)
- commit 591ff59
* Fri Mar 23 2018 mhocko@suse.com
- hugetlbfs: check for pgoff value overflow (bnc#1084353,
  CVE-2018-7740).
- commit 621f100
* Fri Mar 23 2018 glin@suse.com
- test_bpf: Fix testing with CONFIG_BPF_JIT_ALWAYS_ON=y on other
  arches (bsc#1083647).
- commit 4714d41
* Fri Mar 23 2018 glin@suse.com
- Move bpf-introduce-ARG_PTR_TO_MEM_OR_NULL.patch to the sorted section
  The patch was added to the KABI section mistakenly.
- commit 638bcf0
* Fri Mar 23 2018 oneukum@suse.com
- USB: Fix off by one in type-specific length check of BOS SSP
  capability (bsc#1085539).
- commit f57a20f
* Thu Mar 22 2018 mcgrof@suse.com
- xfs: disable per-inode DAX flag (bsc#1085535).
- commit 30f0d9f
* Thu Mar 22 2018 jeffm@suse.com
- Btrfs: fix blk_status_t/errno confusion (bsc#1086457).
- commit 25d99b4
* Thu Mar 22 2018 jeffm@suse.com
- build: fix incompatible pointer warnings with PROVE_RCU=y (bsc#1086527).
- Refresh
  patches.fixes/tcp-dccp-fix-lockdep-splat-in-inet_csk_route_req.patch.
- Refresh
  patches.fixes/tcp-dccp-fix-other-lockdep-splats-accessing-ireq_opt.patch.
- commit 956c819
* Thu Mar 22 2018 oneukum@suse.com
- uas: ignore UAS for Norelsys NS1068(X) chips (bsc#1085539).
- commit e48778e
* Thu Mar 22 2018 oneukum@suse.com
- uas: Always apply US_FL_NO_ATA_1X quirk to Seagate devices
  (bsc#1085539).
- commit 20d01c9
* Thu Mar 22 2018 oneukum@suse.com
- USB: core: Add type-specific length check of BOS descriptors
  (bsc#1085539).
- commit 4eca3f0
* Thu Mar 22 2018 oneukum@suse.com
- usb: host: fix incorrect updating of offset (bsc#1085539).
- commit 1c87c04
* Thu Mar 22 2018 oneukum@suse.com
- USB: ulpi: fix bus-node lookup (bsc#1085539).
- commit 4dc623a
* Thu Mar 22 2018 jeffm@suse.com
- config: update product ID and supported state for openSUSE Leap 15.0
- SUSE_PRODUCT_OPENSUSE_LEAP=y
- SUSE_KERNEL_SUPPORTED=n
- commit 48e5be3
* Thu Mar 22 2018 oneukum@suse.com
- USB: usbfs: Filter flags passed in from user space
  (bsc#1085539).
- commit 489cccb
* Thu Mar 22 2018 oneukum@suse.com
- blacklist.conf: subsystem not used
- commit 371489f
* Thu Mar 22 2018 oneukum@suse.com
- USB: usbfs: compute urb->actual_length for isochronous
  (bsc#1085539).
- commit 5677c73
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: Change DbC debug device binding ID (bsc#1085539).
- commit 2d8a16d
* Thu Mar 22 2018 oneukum@suse.com
- USB: early: Use new USB product ID and strings for DbC device
  (bsc#1085539).
- commit 6d94237
* Thu Mar 22 2018 oneukum@suse.com
- USB: Add delay-init quirk for Corsair K70 LUX keyboards
  (bsc#1085539).
- commit 8a8f7d0
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: qcserial: add pid/vid for Sierra Wireless EM7355
  fw update (bsc#1085539).
- commit d2e8e71
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: metro-usb: stop I/O after failed open
  (bsc#1085539).
- commit 1ee3a90
* Thu Mar 22 2018 tiwai@suse.de
- ath10k: fix invalid STS_CAP_OFFSET_MASK (bsc#1051510).
- ath10k: update tdls teardown state to target (bsc#1051510).
- commit 76d759a
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: garmin_gps: fix memory leak on probe errors
  (bsc#1085539).
- commit 313cabb
* Thu Mar 22 2018 tiwai@suse.de
- ASoC: wm_adsp: For TLV controls only register TLV get/set
  (bsc#1051510).
- ASoC: sgtl5000: Fix suspend/resume (bsc#1051510).
- ASoC: rt5651: Fix regcache sync errors on resume (bsc#1051510).
- ASoC: nau8825: fix issue that pop noise when start capture
  (bsc#1051510).
- ASoC: rsnd: fixup ADG register mask (bsc#1051510).
- commit 775374f
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: garmin_gps: fix I/O after failed probe and remove
  (bsc#1085539).
- commit 687813c
* Thu Mar 22 2018 oneukum@suse.com
- usb: phy: tahvo: fix error handling in tahvo_usb_probe()
  (bsc#1085539).
- commit 72163b1
* Thu Mar 22 2018 tiwai@suse.de
- drm/nouveau/kms: remove call to drm_crtc_vblank_off() during
  unload/suspend (FATE#322643,bsc#1055900).
- commit 7187702
* Thu Mar 22 2018 tiwai@suse.de
- drm/nouveau/kms/nv50: update vblank state in response to
  modeset actions (FATE#322643,bsc#1055900).
- Refresh patches.drivers/drm-vblank-Consistent-drm_crtc_-prefix.
- commit d257cff
* Thu Mar 22 2018 tiwai@suse.de
- Preliminary sort/update
- commit edc6792
* Thu Mar 22 2018 oneukum@suse.com
- usb: mtu3: fix error return code in ssusb_gadget_init()
  (bsc#1085539).
- commit 122a412
* Thu Mar 22 2018 oneukum@suse.com
- usb: xhci: Return error when host is dead in xhci_disable_slot()
  (bsc#1085539).
- commit 191f47b
* Thu Mar 22 2018 oneukum@suse.com
- usb: hub: Allow reset retry for USB2 devices on connect bounce
  (bsc#1085536).
- commit 94358bf
* Thu Mar 22 2018 oneukum@suse.com
- USB: serial: metro-usb: add MS7820 device id (bsc#1085536).
- commit 5244c71
* Thu Mar 22 2018 oneukum@suse.com
- usb: quirks: add quirk for WORLDE MINI MIDI keyboard
  (bsc#1085536).
- commit 65b36d5
* Thu Mar 22 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-FC_NO_LOOP_ID-for-FCP-and-FC-NVM.patch.
- commit 5dec0d7
* Thu Mar 22 2018 mcgrof@suse.com
- vfs: Return -ENXIO for negative SEEK_HOLE / SEEK_DATA offsets
  (bsc#1085535).
- commit 9c22a97
* Wed Mar 21 2018 jeffm@suse.com
- btrfs: minimal conversion to errseq_t writeback error reporting
  on fsync (bsc#1086149 bsc#1086285).
- xfs: minimal conversion to errseq_t writeback error reporting
  (bsc#1086285).
- ext4: use errseq_t based error handling for reporting data
  writeback errors (bsc#1086285).
- fs: convert __generic_file_fsync to use errseq_t based reporting
  (bsc#1086149 bsc#1086285).
- block: convert to errseq_t based writeback error tracking
  (bsc#1086285).
- dax: set errors in mapping when writeback fails (bsc#1086149
  bsc#1086285).
- Documentation: flesh out the section in vfs.txt on storing
  and reporting writeback errors (bsc#1086285).
- mm: set both AS_EIO/AS_ENOSPC and errseq_t in mapping_set_error
  (bsc#1086149 bsc#1086285).
- commit 12c97b8
* Wed Mar 21 2018 jeffm@suse.com
- mm: don't TestClearPageError in __filemap_fdatawait_range
  (bsc#1086149 bsc#1086285).
- commit 328af1b
* Wed Mar 21 2018 jeffm@suse.com
- mm: clear AS_EIO/AS_ENOSPC when writeback initiation fails
  (bsc#1086149 bsc#1086285).
- jbd2: don't clear and reset errors after waiting on writeback
  (bsc#1086285).
- buffer: set errors in mapping at the time that the error occurs
  (bsc#1086149 bsc#1086285).
- fs: check for writeback errors after syncing out buffers in
  generic_file_fsync (bsc#1086149 bsc#1086285).
- buffer: use mapping_set_error instead of setting the flag
  (bsc#1086149 bsc#1086285).
- mm: fix mapping_set_error call in me_pagecache_dirty
  (bsc#1086149 bsc#1086285).
- commit 09f9abc
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: sunxi: Explicitly release USB PHY on exit
  (bsc#1085536).
- commit 04fa959
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: Check for host-mode using is_host_active() on reset
  interrupt (bsc#1085536).
- commit 3803e19
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: musb_cppi41: Configure the number of channels for
  DA8xx (bsc#1085536).
- commit 3bbded4
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: musb_cppi41: Fix cppi41_set_dma_mode() for DA8xx
  (bsc#1085536).
- commit e037007
* Wed Mar 21 2018 oneukum@suse.com
- usb: musb: musb_cppi41: Fix the address of teardown and autoreq
  registers (bsc#1085536).
- commit cd326ce
* Wed Mar 21 2018 oneukum@suse.com
- USB: musb: fix late external abort on suspend (bsc#1085536).
- commit 76b398a
* Wed Mar 21 2018 tiwai@suse.de
- drm/nouveau: Merge pre/postclose hooks (FATE#322643
  bsc#1055900).
- commit 4be949d
* Wed Mar 21 2018 oneukum@suse.com
- USB: musb: fix session-bit runtime-PM quirk (bsc#1085536).
- commit 83d81a2
* Wed Mar 21 2018 oneukum@suse.com
- usb: cdc_acm: Add quirk for Elatec TWN3 (bsc#1085536).
- commit db32900
* Wed Mar 21 2018 oneukum@suse.com
- USB: devio: Revert "USB: devio: Don't corrupt user memory"
  (bsc#1085536).
- commit b735c95
* Wed Mar 21 2018 oneukum@suse.com
- usb: xhci: Handle error condition in xhci_stop_device()
  (bsc#1085536).
- commit 9884645
* Wed Mar 21 2018 oneukum@suse.com
- usb: xhci: Reset halted endpoint if trb is noop (bsc#1085536).
- commit 2b4bd6f
* Wed Mar 21 2018 oneukum@suse.com
- usb: usbtest: fix NULL pointer dereference (bsc#1085536).
- commit ddf19a6
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit f6c209c
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit c1380cf
* Wed Mar 21 2018 oneukum@suse.com
- usb: renesas_usbhs: Fix DMAC sequence for receiving zero-length
  packet (bsc#1085536).
- commit 08c1674
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit 609c138
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: qcserial: add Dell DW5818, DW5819 (bsc#1085536).
- commit 572bd85
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: cp210x: add support for ELV TFD500 (bsc#1085536).
- commit 36d66d3
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: cp210x: fix partnum regression (bsc#1085536).
- commit ef7a186
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: option: add support for TP-Link LTE module
  (bsc#1085536).
- commit 7e4d166
* Wed Mar 21 2018 oneukum@suse.com
- USB: serial: ftdi_sio: add id for Cypress WICED dev board
  (bsc#1085536).
- commit 60faefa
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit 66cadf8
* Wed Mar 21 2018 oneukum@suse.com
- blacklist.conf:
  we do not compiler the driver these patches are for
- commit 3dd4c55
* Wed Mar 21 2018 glin@suse.com
- blacklist.conf: update for minor bpf selftest Makefile change
- commit 2b3dbb0
* Wed Mar 21 2018 ptesarik@suse.cz
- supported.conf: Enable s390-trng (bsc#1085820)
- commit 5ced6c1
* Wed Mar 21 2018 glin@suse.com
- bpf: allow xadd only on aligned memory (bsc#1083647).
- commit e79d0c8
* Wed Mar 21 2018 glin@suse.com
- bpf, arm64: fix out of bounds access in tail call (bsc#1083647).
- commit 4b4e122
* Wed Mar 21 2018 glin@suse.com
- bpf: fix rcu lockdep warning for lpm_trie map_free callback
  (bsc#1083647).
- commit 5acee86
* Wed Mar 21 2018 glin@suse.com
- bpf: fix memory leak in lpm_trie map_free callback function
  (bsc#1083647).
- commit 22440c4
* Wed Mar 21 2018 jeffm@suse.com
- Btrfs: fix log replay failure after unlink and link combination
  (bsc#1086151).
- Btrfs: fix log replay failure after linking special file and
  fsync (bsc#1086150).
- commit 8ea5a6a
* Wed Mar 21 2018 neilb@suse.com
- autofs: revert "autofs: take more care to not update last_used
  on path walk" (git-fixes).
- commit 68bbdc6
* Wed Mar 21 2018 neilb@suse.com
- blacklist.conf:
  Add some unwanted fixes.
- commit 5c4df93
* Tue Mar 20 2018 jeffm@suse.com
- btrfs: fix error handling in free_log_tree (bsc#1086116).
- commit 094871b
* Tue Mar 20 2018 jeffm@suse.com
- btrfs: defer adding raid type kobject until after chunk relocation
  (bsc#1086086).
- btrfs: remove dead create_space_info calls (bsc#1086086).
- btrfs: Remove redundant argument of __link_block_group
  (bsc#1086086).
- btrfs: Refactor update_space_info (bsc#1086086).
- btrfs: Separate space_info create/update (bsc#1086086).
- commit 375db74
* Tue Mar 20 2018 jeffm@suse.com
- REVERT: btrfs: qgroup: Move half of the qgroup accounting time
  out of commit trans (bsc#1083684).
- commit 0442bf4
* Tue Mar 20 2018 tiwai@suse.de
- seccomp: make function __get_seccomp_filter static
  (bsc#1051510).
- commit 0b7ff10
* Tue Mar 20 2018 tiwai@suse.de
- rtc: set the alarm to the next expiring timer (bsc#1051510).
- seccomp: fix the usage of get/put_seccomp_filter() in
  seccomp_get_filter() (bsc#1051510).
- commit 9202bc2
* Tue Mar 20 2018 tiwai@suse.de
- PCI: dwc: Fix enumeration end when reaching root subordinate
  (bsc#1051510).
- PCI: keystone: Fix interrupt-controller-node lookup
  (bsc#1051510).
- PCI: iproc: Fix NULL pointer dereference for BCMA (bsc#1051510).
- PCI: Disable MSI for HiSilicon Hip06/Hip07 only in Root Port
  mode (bsc#1051510).
- mac80211: remove BUG() when interface type is invalid
  (bsc#1051510).
- mac80211_hwsim: enforce PS_MANUAL_POLL to be set after
  PS_ENABLED (bsc#1051510).
- iwlwifi: mvm: avoid dumping assert log when device is stopped
  (bsc#1051510).
- mwifiex: cfg80211: do not change virtual interface during scan
  processing (bsc#1051510).
- iwlwifi: mvm: rs: don't override the rate history in the search
  cycle (bsc#1051510).
- PCI / PM: Force devices to D0 in pci_pm_thaw_noirq()
  (bsc#1051510).
- PCI/ASPM: Use correct capability pointer to program
  LTR_L1.2_THRESHOLD (bsc#1051510).
- PCI/ASPM: Account for downstream device's Port
  Common_Mode_Restore_Time (bsc#1051510).
- PCI/ASPM: Deal with missing root ports in link state handling
  (bsc#1051510).
- PCI/AER: Report non-fatal errors only to the affected endpoint
  (bsc#1051510).
- PCI: Fix race condition with driver_override (bsc#1051510).
- commit 9f73db8
* Tue Mar 20 2018 tiwai@suse.de
- drm/amdgpu:Always save uvd vcpu_bo in VM Mode (bsc#1051510).
- drm/amdgpu:Correct max uvd handles (bsc#1051510).
- drm/amdgpu: Notify sbios device ready before send request
  (bsc#1051510).
- drm/amdgpu: fix KV harvesting (bsc#1051510).
- drm/amdgpu: used cached pcie gen info for SI (v2) (bsc#1051510).
- drm/amd/powerplay: fix power over limit on Fiji (bsc#1051510).
- drm/nouveau: prefer XBGR2101010 for addfb ioctl (bsc#1051510).
- drm/radeon: insist on 32-bit DMA for Cedar on PPC64/PPC64LE
  (bsc#1051510).
- drm/amd/powerplay/smu7: allow mclk switching with no displays
  (bsc#1051510).
- drm/amd/powerplay/vega10: allow mclk switching with no displays
  (bsc#1051510).
- drm/amdkfd: Fix memory leaks in kfd topology (bsc#1051510).
- drm/amdgpu: fix get_max_engine_clock_in_mhz (bsc#1051510).
- drm/amdgpu: always cancel uvd idle handler in uvd suspend
  (bsc#1051510).
- drm/amdgpu:fix virtual dce bug (bsc#1051510).
- drm/edid: set ELD connector type in drm_edid_to_eld()
  (bsc#1051510).
- drm/amdgpu: rename rdev to adev (bsc#1051510).
- commit b85f5b3
* Tue Mar 20 2018 jslaby@suse.cz
- x86/speculation: Remove Skylake C2 from Speculation Control
  microcode blacklist (bnc#1068032 bnc#1085823 CVE-2017-5715).
- x86/spectre_v2: Don't check microcode versions when running
  under hypervisors (bnc#1068032 bnc#1085823 CVE-2017-5715).
- x86/speculation: Correct Speculation Control microcode blacklist
  again (bnc#1068032 bnc#1085823 CVE-2017-5715).
- x86/speculation: Update Speculation Control microcode blacklist
  (bnc#1068032 bnc#1085823 CVE-2017-5715).
- commit 1b63bae
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf:
  subsystem not used
- commit ab9f3ef
* Tue Mar 20 2018 oneukum@suse.com
- USB: cdc-wdm: ignore -EPIPE from GetEncapsulatedResponse
  (bsc#1085536).
- commit 8f1dae7
* Tue Mar 20 2018 jslaby@suse.cz
- x86/enter: Use IBRS on syscall and interrupts (bsc#1068032
  CVE-2017-5753).
- x86/enter: Create macros to restrict/unrestrict Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/idle: Control Indirect Branch Speculation in idle
  (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add inlines to control Indirect Branch
  Speculation (bsc#1068032 CVE-2017-5753).
- x86/speculation: Add basic IBRS support infrastructure
  (bsc#1068032 CVE-2017-5753).
- x86/spectre: Check CONFIG_RETPOLINE in command line parser
  (bnc#1068032 bnc#1085823 CVE-2017-5715).
- commit d36b0df
* Tue Mar 20 2018 oneukum@suse.com
- USB: devio: Don't corrupt user memory (bsc#1085536).
- commit b67cff4
* Tue Mar 20 2018 oneukum@suse.com
- USB: devio: Prevent integer overflow in proc_do_submiturb()
  (bnc#1085536).
- commit 05a6bea
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf: driver is not used
- commit 9e98cbf
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf: driver is not used
- commit 5ab00b7
* Tue Mar 20 2018 oneukum@suse.com
- usb-storage: unusual_devs entry to fix write-access regression
  for Seagate external drives (bsc#1085536).
- commit 978c2cc
* Tue Mar 20 2018 oneukum@suse.com
- usb-storage: fix bogus hardware error messages for ATA pass-thru
  devices (bsc#1085536).
- commit b53e42c
* Tue Mar 20 2018 oneukum@suse.com
- blacklist.conf: driver is not compiled
- commit d28686d
* Tue Mar 20 2018 oneukum@suse.com
- usb: dwc3: ep0: fix DMA starvation by assigning req->trb on ep0
  (bsc#1085536).
- commit 3bc98c7
* Tue Mar 20 2018 oneukum@suse.com
- usb: host: xhci-plat: allow sysdev to inherit from ACPI
  (bsc#1085536).
- commit f97459a
* Tue Mar 20 2018 jslaby@suse.cz
- x86/speculation: Move firmware_restrict_branch_speculation_*()
  from C to CPP (bnc#1068032 bnc#1085823 CVE-2017-5715).
- commit 0e9f8e3
* Tue Mar 20 2018 oneukum@suse.com
- usb: pci-quirks.c: Corrected timeout values used in handshake
  (bsc#1085536).
- commit dd7714b
* Tue Mar 20 2018 oneukum@suse.com
- usb: xhci: Free the right ring in xhci_add_endpoint()
  (bsc#1085336).
- commit a4d34c5
* Tue Mar 20 2018 jslaby@suse.cz
- x86/cpu/bugs: Make retpoline module warning conditional
  (bnc#1068032 CVE-2017-5715).
- x86/speculation: Use IBRS if available before calling into
  firmware (bnc#1068032 CVE-2017-5715).
- Refresh
  patches.arch/x86-cpufeatures-clean-up-spectre-v2-related-cpuid-flags.patch.
  This is only IBRS_FW from upstream. The out-of-tree IBRS proper will
  come as a separate PR later. (bnc#1085823)
- commit 04d2542
* Tue Mar 20 2018 oneukum@suse.com
- usb: Increase quirk delay for USB devices (bsc#1085536).
- commit 5e12030
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: provide only a single function for setting the tod
  (fix SCK) (bsc#1085269).
- commit 8b5d3bf
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: consider epoch index on TOD clock syncs
  (bsc#1085269).
- commit a15ff18
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: consider epoch index on hotplugged CPUs
  (bsc#1085269).
- commit 9a02e48
* Tue Mar 20 2018 ptesarik@suse.cz
- KVM: s390: take care of clock-comparator sign control
  (bsc#1085269).
- commit 6c10fe8
* Tue Mar 20 2018 jkosina@suse.cz
- series.conf: re-sort after script bugfix
- commit 91f9daf
* Tue Mar 20 2018 mbrugger@suse.com
- arm64: Run enable method for errata work arounds on late CPUs
  (bsc#1068032).
- arm64: cpufeature: __this_cpu_has_cap() shouldn't stop early
  (bsc#1068032).
- arm64: capabilities: Handle duplicate entries for a capability
  (bsc#1068032).
- commit c010a8c
* Tue Mar 20 2018 bpoirier@suse.com
- rpm/config.sh: Enable checking the sorted patches section of series.conf in pre-commit hook
- commit f9b47cc
* Tue Mar 20 2018 bpoirier@suse.com
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
- commit e04e333
* Mon Mar 19 2018 tiwai@suse.de
- Input: mms114 - fix license module information (bsc#1051510).
- platform/x86: mlx-platform: fix module aliases (bsc#1051510).
- media: c8sectpfe: fix potential NULL pointer dereference in
  c8sectpfe_timer_interrupt (bsc#1051510).
- Input: psmouse - fix Synaptics detection when protocol is
  disabled (bsc#1051510).
- crypto: seqiv - Remove unused alg/spawn variable (bsc#1051510).
- crypto: caam/qi - use correct print specifier for size_t
  (bsc#1051510).
- PM / runtime: Drop children check from __pm_runtime_set_status()
  (bsc#1051510).
- Input: adxl34x - do not treat FIFO_MODE() as boolean
  (bsc#1051510).
- media: coda: disable BWB only while decoding on CODA 960
  (bsc#1051510).
- crypto: caam/qi - fix AD length endianness in S/G entry
  (bsc#1051510).
- crypto: caam/qi - handle large number of S/Gs case
  (bsc#1051510).
- ACPI / PM / EC: Flush all EC work in acpi_freeze_sync()
  (bsc#1051510).
- crypto: testmgr - Reenable sha1/aes in FIPS mode (bsc#1051510).
- commit 49cf21e
* Mon Mar 19 2018 mkubecek@suse.cz
- netfilter: ebtables: fix erroneous reject of last rule
  (CVE-2018-1068 bsc#1085107).
- netfilter: ebtables: CONFIG_COMPAT: don't trust userland offsets
  (CVE-2018-1068 bsc#1085107).
- commit caa60e7
* Mon Mar 19 2018 mkubecek@suse.cz
- series.conf: refresh
  Ran series_sort.py (no effect on expanded tree).
- commit c5e3798
* Mon Mar 19 2018 msuchanek@suse.de
- kernel-*.spec: remove remaining occurences of %%release from dependencies
  There is a mix of %%release and %%source_rel in manually added
  dependencies and the %%release dependencies tend to fail due to rebuild
  sync issues. So get rid of them.
- commit b4ec514
* Mon Mar 19 2018 msuchanek@suse.de
- ibmvnic: Remove unused TSO resources in TX pool structure
  (bsc#1085224).
- commit c081465
* Mon Mar 19 2018 msuchanek@suse.de
- ibmvnic: Update TX pool cleaning routine (bsc#1085224).
- commit 9804de0
* Mon Mar 19 2018 msuchanek@suse.de
- Refresh metadata of ibmvnic patches
  Refresh patches.drivers/ibmvnic-Generalize-TX-pool-structure.patch.
  Refresh patches.drivers/ibmvnic-Update-and-clean-up-reset-TX-pool-routine.patch.
  Refresh patches.drivers/ibmvnic-Update-release-TX-pool-routine.patch
  Refresh patches.drivers/ibmvnic-Update-TX-pool-initialization-routine.patch.
  Refresh patches.drivers/ibmvnic-Update-TX-and-TX-completion-routines.patch.
  Refresh patches.drivers/ibmvnic-Improve-TX-buffer-accounting.patch.
- commit 36929d0
* Mon Mar 19 2018 yousaf.kaukab@suse.com
- PCI: Remove redundant probes for device reset support
  (bsc#1084889).
- PCI: Probe for device reset support during enumeration
  (bsc#1084889).
- ACPI / CPPC: Use 64-bit arithmetic instead of 32-bit
  (bsc#1084771).
- ACPI: CPPC: remove initial assignment of pcc_ss_data
  (bsc#1084771).
- ACPI / CPPC: Fix KASAN global out of bounds warning
  (bsc#1084771).
- PCI: Avoid slot reset if bridge itself is broken (bsc#1084918).
- PCI: Avoid bus reset if bridge itself is broken (bsc#1084918).
- ACPI / CPPC: Make CPPC ACPI driver aware of PCC subspace IDs
  (bsc#1084771).
- mailbox: PCC: Move the MAX_PCC_SUBSPACES definition to header
  file (bsc#1084771).
- mailbox: pcc: Drop uninformative output during boot
  (bsc#1084771).
- ACPI: processor: use dev_dbg() instead of dev_warn() when CPPC
  probe failed (bsc#1084771).
- mailbox: pcc: Fix crash when request PCC channel 0
  (bsc#1084771).
- ACPICA: Add support for new PCCT subtables (bsc#1084771).
- commit 7fecb4d
* Sun Mar 18 2018 mbrugger@suse.com
- Refresh patches.drivers/net-hns-Fix-ethtool-private-flags.patch.
- commit 30b4cfe
* Sat Mar 17 2018 tiwai@suse.de
- ALSA: hda: add dock and led support for HP ProBook 640 G2
  (bsc#1052235).
- ALSA: hda: add dock and led support for HP EliteBook 820 G3
  (bsc#1052235).
- commit d23a5b8
* Sat Mar 17 2018 tiwai@suse.de
- drm/radeon: fix prime teardown order (bsc#1051510).
- drm/radeon: fix KV harvesting (bsc#1051510).
- commit dbeae71
* Sat Mar 17 2018 tiwai@suse.de
- drm/i915/gvt: Correct the privilege shadow batch buffer address
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: keep oa config in shadow ctx (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add runtime_pm_get/put into gvt_switch_mmio
  (FATE#322643 bsc#1055900).
- drm/nouveau/bl: Fix oops on driver unbind (bsc#1051510).
- drm/i915: Kick the rps worker when changing the boost frequency
  (FATE#322643 bsc#1055900).
- drm/i915: Only prune fences after wait-for-all (FATE#322643
  bsc#1055900).
- drm/i915: Enable VBT based BL control for DP (FATE#322643
  bsc#1055900).
- drm/i915: Suspend submission tasklets around wedging
  (FATE#322643 bsc#1055900).
- drm/i915/perf: fix perf stream opening lock (FATE#322643
  bsc#1055900).
- commit 7928411
* Sat Mar 17 2018 mcgrof@suse.com
- buffer: use mapping_set_error instead of setting the flag (bsc#1085535).
- commit e58067e
* Sat Mar 17 2018 mcgrof@suse.com
- buffer: set errors in mapping at the time that the error occurs (bsc#1085535).
- commit 98a5540
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: Properly retry failed dquot items in case of error during buffer writeback (bsc#1085535, bsc#1085737).
- commit bd133bd
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fortify xfs_alloc_buftarg error handling (bsc#1085535).
- commit 6d33267
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fix forgotten rcu read unlock when skipping inode reclaim (bsc#1085535).
- commit 045fde2
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: check if an inode is cached and allocated (bsc#1085535).
- commit 4678d27
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: return a distinct error code value for IGET_INCORE cache misses (bsc#1085535)
- commit d7b171e
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: move two more RT specific functions into CONFIG_XFS_RT (bsc#1085535, bsc#1073411).
- commit 92df594
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: trim writepage mapping to within eof (bsc#1085535, bsc#1073411).
- commit e28559b
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: cancel dirty pages on invalidation (bsc#1085535, bsc#1073406).
- commit 459af78
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't change inode mode if ACL update fails (bsc#1085535, bsc#1073406).
- commit a513898
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: move more RT specific code under CONFIG_XFS_RT (bsc#1085535).
- commit d9135ff
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: Don't log uninitialised fields in inode structures (bsc#1085535). - Refresh patches.fixes/xfs-convert-to-new-i_version-API.patch.
- commit ab8d0ef
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: handle racy AIO in xfs_reflink_end_cow (bsc#1085535).
- commit 928bee7
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: always swap the cow forks when swapping extents (bsc#1085535)
- commit 900bc36
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: Capture state of the right inode in xfs_iflush_done (bsc#1085535, bsc#1070682).
- commit b235462
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: perag initialization should only touch m_ag_max_usable for AG 0 (bsc#1085535).
- commit 16cf407
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: update i_size after unwritten conversion in dio completion (bsc#1085535).
- commit 93c9c20
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: validate bdev support for DAX inode flag (bsc#1085535).
- commit eb71679
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: report zeroed or not correctly in xfs_zero_range() (bsc#1085535).
- commit 6298786
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: evict CoW fork extents when performing finsert/fcollapse (bsc#1085535).
- commit dc06c2e
* Fri Mar 16 2018 jeffm@suse.com
- iomap_dio_rw: Allocate AIO completion queue before submitting
  dio (bsc#1085711).
- commit 3211750
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't unconditionally clear the reflink flag on zero-block files (bsc#1085535).
- commit bcb1820
* Fri Mar 16 2018 jeffm@suse.com
- btrfs: fix lockdep splat in btrfs_alloc_subvolume_writers
  (bsc#1085699).
- commit 73b177a
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: use kmem_free to free return value of kmem_zalloc (bsc#1085535).
- commit 8d1ab0c
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: open code end_buffer_async_write in xfs_finish_page_writeback (bsc#1085535).
- commit 5dc9796
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't set v3 xflags for v2 inodes (bsc#1085535).
- commit 2e1a433
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fix compiler warnings (bsc#1085535).
- commit 231ac4b
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: fix incorrect log_flushed on fsync (bsc#1085535).
- commit 55862a4
* Fri Mar 16 2018 jeffm@suse.com
- btrfs: propagate error to btrfs_cmp_data_prepare caller
  (bsc#1076088).
- commit 20a82e4
* Fri Mar 16 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-64-Use-barrier_nospec-in-syscall-entry.patch.
- Refresh patches.arch/powerpc-Use-barrier_nospec-in-copy_from_user.patch.
  move barrier after branch
- commit bace443
* Fri Mar 16 2018 jthumshirn@suse.de
- scsi: sg: Re-fix off by one in sg_fill_request_table()
  (bsc#1085654).
- scsi: sg: fixup infoleak when using SG_GET_REQUEST_TABLE
  (bsc#1085654).
- scsi: sg: factor out sg_fill_request_table() (bsc#1085654).
- commit d70aad9
* Fri Mar 16 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-lpfc-change-copyright-of-12.0.0.1-modified-files-to.patch.
- Refresh
  patches.drivers/scsi-lpfc-code-cleanup-for-128byte-wqe-data-type.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-mailbox-wait-for-post_sgl-mbox-command.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-scsi-lun-discovery-when-port-configured-for.patch.
- Refresh
  patches.drivers/scsi-lpfc-memory-allocation-error-during-driver-start-up-on.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-initiator-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-streamline-nvme-targe6t-wqe-setup.patch.
- Refresh
  patches.drivers/scsi-lpfc-update-driver-version-to-12.0.0.1.patch.
- commit 7b6b825
* Fri Mar 16 2018 jthumshirn@suse.de
- loop: fix concurrent lo_open/lo_release (bsc#1085643).
- commit ec3edfb
* Fri Mar 16 2018 hare@suse.de
- nvmet_fc: prevent new io rqsts in possible isr completions
  (FATE#323952, FATE#322506).
- commit 03750dd
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: on remoteport reuse, set new nport_id and role
  (bsc#1076760).
- commit 18875d5
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: fix abort race on teardown with lld reject
  (bsc#1083750).
- nvme_fc: io timeout should defer abort to ctrl reset
  (bsc#1085054).
- commit fcde440
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: fix ctrl create failures racing with workq items
  (bsc#1083750).
- commit 9b8dc65
* Fri Mar 16 2018 hare@suse.de
- scripts/git_sort/git_sort.py: Update nvme tree to 4.17
- commit 99db2a2
* Fri Mar 16 2018 jthumshirn@suse.de
- virtio_blk: Fix an SG_IO regression (bsc#1085636).
- commit 2954f97
* Fri Mar 16 2018 jthumshirn@suse.de
- scsi: scsi_transport_fc: fix NULL pointer dereference in
  fc_bsg_job_timeout (bsc#1085634).
- commit 68473f0
* Fri Mar 16 2018 hare@suse.de
- nvme_fc: rework sqsize handling (bsc#1083750).
- nvme-pci: Fix EEH failure on ppc (bsc#1085342).
- commit e100d7e
* Fri Mar 16 2018 hare@suse.de
- nvmet: fix PSDT field check in command format (FATE#323952,
  FATE#322506).
- nvme-pci: Fix nvme queue cleanup if IRQ setup fails
  (FATE#323952, FATE#322506).
- nvmet-loop: use blk_rq_payload_bytes for sgl selection
  (FATE#323952, FATE#322506).
- nvme-rdma: use blk_rq_payload_bytes instead of blk_rq_bytes
  (FATE#323952, FATE#322506).
- nvme-fabrics: don't check for non-NULL module in
  nvmf_register_transport (FATE#323952, FATE#322506).
- nvme-rdma: fix sysfs invoked reset_ctrl error flow (FATE#323952,
  FATE#322506).
- nvmet: Change return code of discard command if not supported
  (FATE#323952, FATE#322506).
- nvme: fix the deadlock in nvme_update_formats (bsc#1083750).
- nvme: Don't use a stack buffer for keep-alive command
  (FATE#323952, FATE#322506).
- nvme: Fix discard buffer overrun (FATE#323952, FATE#322506).
- nvme: delete NVME_CTRL_LIVE --> NVME_CTRL_CONNECTING transition
  (FATE#323952, FATE#322506).
- nvme-rdma: use NVME_CTRL_CONNECTING state to mark init process
  (FATE#323952, FATE#322506).
- commit 5a5189c
* Fri Mar 16 2018 jthumshirn@suse.de
- bsg-lib: don't free job in bsg_prepare_job (bsc#1085630).
- commit 5645dd9
* Fri Mar 16 2018 tiwai@suse.de
- supported.conf: Enable pinctrl/intel modules (FATE#325095,FATE#325124,FATE#322647,FATE#321356)
- commit 34f89b2
* Fri Mar 16 2018 tiwai@suse.de
- Update config files: Enable CONFIG_PINCTRL_DENVERTON for x86_64 (FATE#325124)
- commit 32e2f2c
* Fri Mar 16 2018 tiwai@suse.de
- pinctrl: intel: Add Intel Denverton pin controller support
  (FATE#325124).
- commit 63c5269
* Fri Mar 16 2018 msuchanek@suse.de
- ibmvnic: Fix reset return from closed state (bsc#1084610).
- commit 07460ad
* Fri Mar 16 2018 hare@suse.de
- kabi/severities: Do not blacklist drivers/message/fusion
- commit f791f8f
* Fri Mar 16 2018 hare@suse.de
- block: kyber: fix domain token leak during requeue
  (bsc#1077989).
- blk-mq: don't call io sched's .requeue_request when requeueing
  rq to ->dispatch (bsc#1077989).
- blk-wbt: account flush requests correctly (bsc#1077989).
- blk_rq_map_user_iov: fix error override (bsc#1077989).
- blk-mq: quiesce queue before freeing queue (bsc#1077989).
- block: drain queue before waiting for q_usage_counter becoming
  zero (bsc#1077989).
- block-throttle: avoid double charge (bsc#1077989).
- block: don't let passthrough IO go into .make_request_fn()
  (bsc#1077989).
- ata: fixes kernel crash while tracing ata_eh_link_autopsy event
  (bsc#1077989).
- blk-mq-sched: dispatch from scheduler IFF progress is made in
  - >dispatch (bsc#1077989).
- block,bfq: Disable writeback throttling (bsc#1077989).
- bio_copy_user_iov(): don't ignore ->iov_offset (bsc#1077989).
- more bio_map_user_iov() leak fixes (bsc#1077989).
- block: directly insert blk-mq request from
  blk_insert_cloned_request() (bsc#1077989).
- commit 755e323
* Fri Mar 16 2018 tbogendoerfer@suse.de
- scsi: csiostor: add support for 32 bit port capabilities
  (bsc#1084463).
- commit 2a6691d
* Fri Mar 16 2018 hare@suse.de
- Update config files.
- commit 8f7bcb9
* Fri Mar 16 2018 jthumshirn@suse.de
- dm mpath: fix passing integrity data (bsc#1085599).
- commit 079d71d
* Fri Mar 16 2018 hare@suse.de
- ahci: Add PCI ids for Intel Bay Trail, Cherry Trail and Apollo Lake AHCI (bsc#1077989). - ahci: Allow setting a default LPM policy for mobile chipsets (bsc#1079088). - ahci: Annotate PCI ids for mobile Intel chipsets as such (bsc#1077989). - ata: ahci_brcm: Avoid writing to read-only registers (1079088). - libata: Add the AHCI_HFLAG_NO_WRITE_TO_RO flag (1079088). - libata: Add the AHCI_HFLAG_YES_ALPM flag (1079088). - libata: sata_down_spd_limit should return if driver has not recorded sstatus speed (bsc#1079088). - Refresh patches.fixes/0001-ahci-Add-Intel-Cannon-Lake-PCH-H-PCI-ID.patch.
- commit 20e9c8c
* Fri Mar 16 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-crashes-in-qla2x00_probe_one-on-pro.patch.
  Refresh Patch-mainline
- commit 83e7885
* Fri Mar 16 2018 tiwai@suse.de
- Move sound patches into the sorted section
- commit 9e5a89a
* Fri Mar 16 2018 neilb@suse.com
- NFSv4: handle EINVAL from EXCHANGE_ID better (bsc#1074661).
- commit 328ecd0
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: remove double-underscore integer types (bsc#1085535).
- commit bad7273
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: relog dirty buffers during swapext bmbt owner change (bsc#1085535).
- commit d182840
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: disallow marking previously dirty buffers as ordered (bsc#1085535).
- commit fbe5afe
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: move bmbt owner change to last step of extent swap (bsc#1085535).
- commit b1ccefc
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: don't log dirty ranges for ordered buffers (bsc#1085535).
- commit 1059f79
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: refactor buffer logging into buffer dirtying helper (bsc#1085535).
- commit c4ad563
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: ordered buffer log items are never formatted (bsc#1085535).
- commit bf9d73a
* Fri Mar 16 2018 mcgrof@suse.com
- xfs: remove bli from AIL before release on transaction abort (bsc#1085400).
- commit fe017ba
* Thu Mar 15 2018 brogers@suse.com
- KVM: nVMX: Fix bug of injecting L2 exception into L1
  (bsc#1082743).
- commit c911389
* Thu Mar 15 2018 msuchanek@suse.de
- powerpc/64: barrier_nospec: Add commandline trigger
  (bsc#1068032, bsc#1080157).
- powerpc/64s: barrier_nospec: Add hcall trigger (bsc#1068032,
  bsc#1080157).
- powerpc/64: barrier_nospec: Add debugfs trigger (bsc#1068032,
  bsc#1080157).
- powerpc/64: Patch barrier_nospec in modules (bsc#1068032,
  bsc#1080157).
- powerpc/64s: Add support for ori barrier_nospec patching
  (bsc#1068032, bsc#1080157).
- powerpc/64s: Use barrier_nospec in RFI_FLUSH_SLOT (bsc#1068032,
  bsc#1080157).
- powerpc/64: Use barrier_nospec in syscall entry (bsc#1068032,
  bsc#1080157).
- powerpc: Use barrier_nospec in copy_from_user (bsc#1068032,
  bsc#1080157).
- powerpc: Add barrier_nospec (bsc#1068032, bsc#1080157).
- commit 61e5a68
* Thu Mar 15 2018 msuchanek@suse.de
- rfi-flush: Always enable fallback flush on pseries
  (bsc#1068032).
- rfi-flush: Call setup_rfi_flush() after LPM migration
  (bsc#1068032).
- rfi-flush: Differentiate enabled and patched flush types
  (bsc#1068032).
- rfi-flush: Make it possible to call setup_rfi_flush() again
  (bsc#1068032).
- Delete
  patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- commit bedae0a
* Thu Mar 15 2018 oneukum@suse.com
- Refresh
  patches.suse/0001-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
  Refresh
  patches.suse/0002-Add-a-void-suse_kabi_padding-placeholder-to-some-USB.patch.
  Added placeholders to new structures and structures likely to see
  additions with USB 3.2
- commit 2e13f72
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: remove unnecessary dirty bli format check for ordered bufs (bsc#1085535, bsc#1085400).
- commit 878b923
* Thu Mar 15 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch
- commit 15d094c
* Thu Mar 15 2018 msuchanek@suse.de
- Delete patches.arch/powerpc-rfi-flush-Add-DEBUG_RFI-config-option.patch.
- commit c144715
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: release bli from transaction properly on fs shutdown (bsc#1085400).
- commit d1eb889
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: open-code xfs_buf_item_dirty() (bsc#1085535, bsc#1085400).
- commit 0219f88
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: check for race with xfs_reclaim_inode() in xfs_ifree_cluster() (bsc#1085535).
- commit 63625ee
* Thu Mar 15 2018 ptesarik@suse.cz
- s390/entry.S: fix spurious zeroing of r0 (LTC#164304,
  bsc#1084911).
- commit 385e43e
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: do not bypass BPENTER for interrupt system calls
  (LTC#164304, bsc#1084911).
- commit ed1afdf
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: handle -EFSCORRUPTED during head/tail verification (bsc#1085535).
- commit adcbd09
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: Replace IS_ENABLED(EXPOLINE_*) with
  IS_ENABLED(CONFIG_EXPOLINE_*) (LTC#164304, bsc#1084911).
- commit 8bea736
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix log recovery corruption error due to tail overwrite (bsc#1085535).
- commit 504e04b
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: introduce execute-trampolines for branches (LTC#164304,
  bsc#1084911).
- commit 8b70679
* Thu Mar 15 2018 oneukum@suse.com
- Thunderbolt: kABI paddings added (bsc#1070681).
- commit 211b2ae
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: always verify the log tail during recovery (bsc#1085535).
- commit 24a67e9
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: run user space and KVM guests with modified branch
  prediction (LTC#164304, bsc#1084911).
- commit 2450b20
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: add optimized array_index_mask_nospec (LTC#164304,
  bsc#1084911).
- commit b8c619a
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix recovery failure when log record header wraps log end (bsc#1085535).
- commit 7ffd57a
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: scrub registers on kernel entry and KVM exit (LTC#164304,
  bsc#1084911).
- commit ceb4998
* Thu Mar 15 2018 oneukum@suse.com
- PCI: pciehp: Do not clear Presence Detect Changed during
  initialization (bsc#1070681).
- PCI: pciehp: Fix race condition handling surprise link down
  (bsc#1070681).
- commit c6224de
* Thu Mar 15 2018 ptesarik@suse.cz
- s390: add options to change branch prediction behaviour for
  the kernel (LTC#164304, bsc#1068032, bsc#1084911).
- Delete patches.arch/s390-sles15-99-02-nobp.patch.
- commit ab35499
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Distribute available resources to hotplug-capable bridges
  (bsc#1070681).
- commit c7a131a
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Distribute available buses to hotplug-capable bridges
  (bsc#1070681).
- commit f245576
* Thu Mar 15 2018 mbrugger@suse.com
- watchdog: sbsa: use 32-bit read for WCV (bsc#1083411).
- commit 95be6a2
* Thu Mar 15 2018 mbrugger@suse.com
- scsi: hisi_sas: directly attached disk LED feature for v2 hw
  (bsc#1083411).
- commit 82b07af
* Thu Mar 15 2018 ptesarik@suse.cz
- s390/alternative: use a copy of the facility bit mask
  (LTC#164304, bsc#1084911).
- commit a6eeafb
* Thu Mar 15 2018 mbrugger@suse.com
- net: hns: Fix ethtool private flags (bsc#1085511).
- commit db6e0ea
* Thu Mar 15 2018 ptesarik@suse.cz
- s390/spinlock: add gmb memory barrier (LTC#164304, bsc#1084911).
- commit 60f06f8
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Open-code the two pass loop when scanning bridges
  (bsc#1070681).
- PCI: Add for_each_pci_bridge() helper (bsc#1070681).
- commit 7ef9727
* Thu Mar 15 2018 hare@suse.de
- loop: Fix lost writes caused by missing flag (bsc#1077989).
- block: fix a typo (bsc#1077989).
- block: display the correct diskname for bio (bsc#1077989).
- block: fix the count of PGPGOUT for WRITE_SAME (bsc#1077989).
- genhd: Fix leaked module reference for NVME devices (bsc#1077989).
- scsi: mpt3sas: fix an out of bound write (bsc#1077989).
- scsi: libsas: fix memory leak in sas_smp_get_phy_events() (bsc#1077989).
- block: only bdi_unregister() in del_gendisk() if !GENHD_FL_HIDDEN (bsc#1077989).
- block: wake up all tasks blocked in get_request() (bsc#1077989).
- commit 11bfaef
* Thu Mar 15 2018 jthumshirn@suse.de
- scsi: lpfc: make several unions static, fix non-ANSI prototype
  (bsc#1085387).
- scsi: lpfc: Change Copyright of 12.0.0.1 modified files to 2018
  (bsc#1085387).
- scsi: lpfc: update driver version to 12.0.0.1 (bsc#1085387).
- scsi: lpfc: Memory allocation error during driver start-up on
  power8 (bsc#1085387).
- scsi: lpfc: Fix mailbox wait for POST_SGL mbox command
  (bsc#1085387).
- scsi: lpfc: Fix SCSI lun discovery when port configured for
  both SCSI and NVME (bsc#1085387).
- scsi: lpfc: Streamline NVME Targe6t WQE setup (bsc#1085387).
- scsi: lpfc: Streamline NVME Initiator WQE setup (bsc#1085387).
- scsi: lpfc: Code cleanup for 128byte wqe data type
  (bsc#1085387).
- commit 1cb568e
* Thu Mar 15 2018 yousaf.kaukab@suse.com
- Update config files.
- commit c93abb9
* Thu Mar 15 2018 oneukum@suse.com
- PCI: Move pci_hp_add_bridge() to drivers/pci/probe.c
  (bsc#1070681).
- commit 1eea5d4
* Thu Mar 15 2018 hare@suse.de
- scsi: libsas: notify event PORTE_BROADCAST_RCVD in
  sas_enable_revalidation() (bsc#1085000).
- scsi: libsas: direct call probe and destruct (bsc#1085000).
- scsi: libsas: use flush_workqueue to process disco events
  synchronously (bsc#1085000).
- scsi: libsas: Use new workqueue to run sas event and disco event
  (bsc#1085000).
- scsi: libsas: make the event threshold configurable
  (bsc#1085000).
- scsi: libsas: shut down the PHY if events reached the threshold
  (bsc#1085000).
- scsi: libsas: Use dynamic alloced work to avoid sas event lost
  (bsc#1085000).
- commit 23a9718
* Thu Mar 15 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix crashes in qla2x00_probe_one on probe failure
  (bsc#1077338).
- commit faf79cf
* Thu Mar 15 2018 rgoldwyn@suse.com
- Correct placement of apparmor-next patches
  This needed a new section for jj/linux-apparmor for apparmor-next
  branch.
- commit 70d2dc4
* Thu Mar 15 2018 hare@suse.de
- qla2xxx: Update driver version to 10.00.00.06-k (bsc#1084570).
- qla2xxx: Fix Async GPN_FT for FCP and FC-NVMe scan
  (bsc#1084570).
- qla2xxx: Cleanup code to improve FC-NVMe error handling
  (bsc#1084570).
- qla2xxx: Fix FC-NVMe IO abort during driver reset (bsc#1084570).
- qla2xxx: Fix retry for PRLI RJT with reason of BUSY
  (bsc#1084570).
- qla2xxx: Remove nvme_done_list (bsc#1084570).
- qla2xxx: Return busy if rport going away (bsc#1084570).
- qla2xxx: Fix n2n_ae flag to prevent dev_loss on PDB change
  (bsc#1084570).
- qla2xxx: Add FC-NVMe abort processing (bsc#1084570).
- qla2xxx: Restore ZIO threshold setting (bsc#1084570).
- qla2xxx: Add changes for devloss timeout in driver
  (bsc#1084570).
- qla2xxx: Set IIDMA and fcport state before
  qla_nvme_register_remote() (bsc#1084570).
- qla2xxx: Remove unneeded message and minor cleanup for FC-NVMe
  (bsc#1084570).
- scsi: qla2xxx: Remove FC_NO_LOOP_ID for FCP and FC-NVMe
  Discovery (bsc#1084569).
- scsi: qla2xxx: Fix NULL pointer crash due to active timer for
  ABTS (bsc#1082979).
- commit b0e8cae
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Mask ring interrupt properly when polling starts
  (bsc#1070681).
- commit 3a626f5
* Thu Mar 15 2018 jthumshirn@suse.de
- s390/qeth: fix IP address lookup for L3 devices (bsc#1085486).
- s390/qeth: fix double-free on IP add/remove race (bsc#1085486).
- s390/qeth: fix IP removal on offline cards (bsc#1085486).
- s390/qeth: improve error reporting on IP add/removal
  (bsc#1085486).
- commit 7ed1eb8
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Allocate ring HopID automatically if requested
  (bsc#1070681).
- commit 70ae42d
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Add polling mode for rings (bsc#1070681).
- commit 3c69806
* Thu Mar 15 2018 tiwai@suse.de
- security/keys: BIG_KEY requires CONFIG_CRYPTO (bsc#1051510).
- commit 1e8d44b
* Thu Mar 15 2018 jthumshirn@suse.de
- Fix sorting
- commit 0515713
* Thu Mar 15 2018 hare@suse.de
- Update patch-header with upstream commit ID
- Refresh
  patches.drivers/qla2xxx-Fixup-locking-for-session-deletion.patch.
- Refresh
  patches.drivers/qla2xxx-do-not-check-login_state-if-no-loop-id-is-as.patch.
- Refresh
  patches.drivers/qla2xxx-ensure-async-flags-are-reset-correctly.patch.
- commit 6ceddbd
* Thu Mar 15 2018 tiwai@suse.de
- staging: rtl8188eu: Fix incorrect response to SIOCGIWESSID
  (bsc#1051510).
- ima: do not update security.ima if appraisal status is not
  INTEGRITY_PASS (bsc#1051510).
- staging: rtl8188eu: avoid a null dereference on pmlmepriv
  (bsc#1051510).
- ima: fix hash algorithm initialization (bsc#1051510).
- staging: bcm2835-audio: Fix memory corruption (bsc#1051510).
- security/keys: rewrite all of big_key crypto (bsc#1051510).
- security/keys: properly zero out sensitive key material in
  big_key (bsc#1051510).
- commit 6649606
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Use spinlock in NHI serialization (bsc#1070681).
- thunderbolt: Use spinlock in ring serialization (bsc#1070681).
- thunderbolt: Move ring descriptor flags to thunderbolt.h
  (bsc#1070681).
- commit a02064a
* Thu Mar 15 2018 msuchanek@suse.de
- ipmi: use dynamic memory for DMI driver override (bsc#1085477).
- workqueue: avoid hard lockups in show_workqueue_state()
  (bsc#1085474).
- kdump: write correct address of mem_section into vmcoreinfo
  (bsc#1052766).
- genirq: Guard handle_bad_irq log messages (bsc#1070194).
- ipmi: Stop timers before cleaning up the module (bsc#1085477).
- kdb: Fix handling of kallsyms_symbol_next() return value
  (bsc#1052766).
- smp/hotplug: Move step CPUHP_AP_SMPCFD_DYING to the correct
  place (bsc#1052766).
- workqueue: Fix NULL pointer dereference (bsc#1085474).
- workqueue: replace pool->manager_arb mutex with a flag
  (bsc#1085474).
- irq/generic-chip: Don't replace domain's name (bsc#1070194).
- smp/hotplug: Handle removal correctly in cpuhp_store_callbacks()
  (bsc#1052766).
- commit 2d0ceb8
* Thu Mar 15 2018 msuchanek@suse.de
- Sort apparmor patch.
- commit 1285305
* Thu Mar 15 2018 tbogendoerfer@suse.de
- RDMA/rxe: Fix rxe_qp_cleanup() (bsc#1050662 FATE#323951).
- RDMA/rxe: Fix a race condition in rxe_requester() (bsc#1050662
  FATE#323951).
- RDMA/rxe: Fix a race condition related to the QP error state
  (bsc#1050662 FATE#323951).
- i40e: don't remove netdev->dev_addr when syncing uc list
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: Account for frags split over multiple descriptors
  in check linearize (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- IB/srpt: Disable RDMA access by the initiator (bsc#1046306
  FATE#322942).
- IB/core: Init subsys if compiled to vmlinuz-core (bsc#1046306
  FATE#322942).
- RDMA/cma: Make sure that PSN is not over max allowed
  (bsc#1046306 FATE#322942).
- i40evf: Use smp_rmb rather than read_barrier_depends
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: Use smp_rmb rather than read_barrier_depends (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- Ib/hfi1: Return actual operational VLs in port info query
  (bsc#1060463 FATE#323043).
- RDMA/cma: Avoid triggering undefined behavior (bsc#1046306
  FATE#322942).
- IB/opa_vnic: Properly clear Mac Table Digest (bsc#1060463
  FATE#323043).
- IB/opa_vnic: Properly return the total MACs in UC MAC list
  (bsc#1060463 FATE#323043).
- i40e: use the safe hash table iterator when deleting mac filters
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: spread CPU affinity hints across online CPUs only
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix client notify of VF reset (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- commit be14663
* Thu Mar 15 2018 tbogendoerfer@suse.de
- Fix sorting
- commit 99f04f6
* Thu Mar 15 2018 jroedel@suse.de
- PCI: Mark AMD Stoney GPU ATS as broken (bsc#1085438).
- x86/platform/uv/BAU: Disable BAU on single hub configurations
  (bsc#1085438).
- x86/platform/uv/BAU: Fix congested_response_us not taking effect
  (bsc#1085438).
- commit f016967
* Thu Mar 15 2018 jroedel@suse.de
- Refresh patches.fixes/x86-mm-pkeys-fix-fill_sig_info_pkey.patch.
- commit be26314
* Thu Mar 15 2018 msuchanek@suse.de
- ibmvfc: Avoid unnecessary port relogin (bsc#1085404).
- commit 0423e5a
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Export ring handling functions to modules
  (bsc#1070681).
- commit 0c97603
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Add support for frame mode (bsc#1070681).
- commit 78125e0
* Thu Mar 15 2018 oneukum@suse.com
- thunderbolt: Configure interrupt throttling for all interrupts
  (bsc#1070681).
- commit c6505dc
* Thu Mar 15 2018 jkosina@suse.cz
- Update config files: run oldconfig on arm64, ppc64le, s390x
- commit 92d9f93
* Thu Mar 15 2018 bpoirier@suse.com
- e1000e: Fix link check race condition (bsc#1056664 FATE#322185).
- Revert "e1000e: Separate signaling for link check/link up"
  (bsc#1056664 FATE#322185).
- e1000e: allocate ring descriptors with dma_zalloc_coherent
  (bsc#1056664 FATE#322185).
- e1000e: Fix check_for_link return value with autoneg off
  (bsc#1056664 FATE#322185).
- e1000e: Avoid missed interrupts following ICR read (bsc#1056664
  FATE#322185).
- e1000e: Fix queue interrupt re-raising in Other interrupt
  (bsc#1056664 FATE#322185).
- Partial revert "e1000e: Avoid receiver overrun interrupt bursts"
  (bsc#1056664 FATE#322185).
- e1000e: Remove Other from EIAC (bsc#1056664 FATE#322185).
- e1000e: Alert the user that C-states will be disabled by
  enabling jumbo frames (bsc#1056664 FATE#322185).
- e1000e: Set HTHRESH when PTHRESH is used (bsc#1056664
  FATE#322185).
- e1000e: Be drop monitor friendly (bsc#1056664 FATE#322185).
- e1000e: apply burst mode settings only on default (bsc#1056664
  FATE#322185).
- drivers: net: e1000e: use setup_timer() helper (bsc#1056664
  FATE#322185).
- commit fd1dad2
* Thu Mar 15 2018 gqjiang@suse.com
- md-cluster: fix wrong condition check in raid1_write_request
  (bsc#1085402).
- commit de51b30
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: quota: fix missed destroy of qi_tree_lock (bnc#1012382, bsc#1085525).
- commit 64fa650
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: ubsan fixes (bnc#1012382, bsc#1085525).
- commit d7cba96
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: quota: check result of register_shrinker() (bnc#1012382, bsc#1085525).
- commit 98da9d7
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix log block underflow during recovery cycle verification (bnc#1012382, bsc#1085525).
- commit 967d992
* Thu Mar 15 2018 mcgrof@suse.com
- xfs: fix incorrect extent state in xfs_bmap_add_extent_unwritten_real (bsc#1085525, bnc#1012382).
- commit e1a9c24
* Thu Mar 15 2018 mcgrof@suse.com
- iomap: report collisions between directio and buffered writes
  to userspace (bsc#1074275).
- commit 065d584
* Thu Mar 15 2018 mcgrof@suse.com
- errseq: rename __errseq_set to errseq_set (bsc#1074275).
- commit 76c35ea
* Thu Mar 15 2018 mcgrof@suse.com
- fs: new infrastructure for writeback error handling and
  reporting (bsc#1074275).
- commit 592f3a3
* Thu Mar 15 2018 mcgrof@suse.com
- lib: add errseq_t type and infrastructure for handling it
  (bsc#1074275).
- commit 2949364
* Wed Mar 14 2018 jkosina@suse.cz
- Update config files: qcom=m
- commit 2552aaa
* Wed Mar 14 2018 rgoldwyn@suse.com
- git-sort: correct branch of apparmor repository
  Change branch name from v4.8-aa2.8-out-of-tree to apparmor-next.
- commit d8d3200
* Wed Mar 14 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Drop locks before reading guest memory
  (bsc#1061840).
- KVM: PPC: Book3S HV: Make sure we don't re-enter guest without
  XIVE loaded (bsc#1061840).
- commit f67f69d
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/kernel: Change retrieval of pci_dn (bsc#1078720).
- commit 5779938
* Wed Mar 14 2018 msuchanek@suse.de
- tpm: fix potential buffer overruns caused by bit glitches on
  the bus (bsc#1082555).
- tpm: st33zp24: fix potential buffer overruns caused by bit
  glitches on the bus (bsc#1082555).
- tpm_i2c_infineon: fix potential buffer overruns caused by bit
  glitches on the bus (bsc#1082555).
- tpm_i2c_nuvoton: fix potential buffer overruns caused by bit
  glitches on the bus (bsc#1082555).
- tpm_tis: fix potential buffer overruns caused by bit glitches
  on the bus (bsc#1082555).
- tpm-dev-common: Reject too short writes (bsc#1082555).
- commit e071d12
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/mm/radix: Split linear mapping on hot-unplug
  (bsc#1065729).
- proc: fix coredump vs read /proc/*/stat race (bsc#1052766).
- powerpc/perf: Fix oops when grouping different pmu events
  (bsc#1065729).
- powerpc/perf: Fix pmu_count to count only nest imc pmus
  (bsc#1065729).
- powerpc/64s: Fix masking of SRR1 bits on instruction fault
  (bsc#1065729).
- powerpc/powernv/idle: Round up latency and residency values
  (bsc#1065729).
- powerpc/kprobes: Disable preemption before invoking probe
  handler for optprobes (bsc#1065729).
- powerpc/ipic: Fix status get and status clear (bsc#1065729).
- powerpc/perf/hv-24x7: Fix incorrect comparison in memord
  (bsc#1065729).
- powerpc/xmon: Avoid tripping SMP hardlockup watchdog
  (bsc#1065729).
- powerpc: Fix DAR reporting when alignment handler faults
  (bsc#1065729).
- powerpc/mm: Use symbolic constants for filtering SRR1 bits on
  ISIs (bsc#1065729).
- commit e8616ce
* Wed Mar 14 2018 tiwai@suse.de
- Re-enable patches.suse/tpm-Downgrade-error-level (bsc#1042535)
  False-positive errors still appear on many machines
- commit 3708692
* Wed Mar 14 2018 tiwai@suse.de
- Move shpinx fix patch into the sorted section
- commit 49924e7
* Wed Mar 14 2018 tiwai@suse.de
- crypto: s5p-sss - Fix kernel Oops in AES-ECB mode (bsc#1051510).
- crypto: caam - fix endless loop when DECO acquire fails
  (bsc#1051510).
- crypto: talitos - fix Kernel Oops on hashing an empty file
  (bsc#1051510).
- crypto: sha512-mb - initialize pending lengths correctly
  (bsc#1051510).
- crypto: aesni - handle zero length dst buffer (bsc#1051510).
- crypto: hash - prevent using keyed hashes without setting key
  (bsc#1051510).
- crypto: hash - annotate algorithms taking optional key
  (bsc#1051510).
- crypto: poly1305 - remove ->setkey() method (bsc#1051510).
- crypto: mcryptd - pass through absence of ->setkey()
  (bsc#1051510).
- crypto: cryptd - pass through absence of ->setkey()
  (bsc#1051510).
- crypto: hash - introduce crypto_hash_alg_has_setkey()
  (bsc#1051510).
- crypto: af_alg - whitelist mask and type (bsc#1051510).
- crypto: x86/twofish-3way - Fix %%rbp usage (bsc#1051510).
- crypto: tcrypt - fix S/G table for test_aead_speed()
  (bsc#1051510).
- crypto: algapi - fix NULL dereference in crypto_remove_spawns()
  (bsc#1051510).
- crypto: n2 - cure use after free (bsc#1051510).
- crypto: mcryptd - protect the per-CPU queue with a lock
  (bsc#1051510).
- crypto: dh - Fix double free of ctx->p (bsc#1051510).
- crypto: tcrypt - fix buffer lengths in test_aead_speed()
  (bsc#1051510).
- crypto: talitos - fix ctr-aes-talitos (bsc#1051510).
- crypto: talitos - fix use of sg_link_tbl_len (bsc#1051510).
- crypto: talitos - fix AEAD for sha224 on non sha224 capable
  chips (bsc#1051510).
- crypto: talitos - fix setkey to check key weakness
  (bsc#1051510).
- crypto: talitos - fix memory corruption on SEC2 (bsc#1051510).
- crypto: talitos - fix AEAD test failures (bsc#1051510).
- crypto: crypto4xx - increase context and scatter ring buffer
  elements (bsc#1051510).
- crypto: aesni - Use GCM IV size constant (bsc#1051510).
- crypto: gcm - add GCM IV size constant (bsc#1051510).
- crypto: ccm - preserve the IV buffer (bsc#1051510).
- crypto: x86/sha1-mb - fix panic due to unaligned access
  (bsc#1051510).
- crypto: x86/sha256-mb - fix panic due to unaligned access
  (bsc#1051510).
- crypto: shash - Fix zero-length shash ahash digest crash
  (bsc#1051510).
- crypto: talitos - Don't provide setkey for non hmac hashing algs
  (bsc#1051510).
- crypto: talitos - fix hashing (bsc#1051510).
- crypto: talitos - fix sha224 (bsc#1051510).
- crypto: drbg - fix freeing of resources (bsc#1051510).
- crypto: ccp - Fix XTS-AES-128 support on v5 CCPs (bsc#1051510).
- crypto: scompress - don't sleep with preemption disabled
  (bsc#1051510).
- crypto: caam/qi - properly set IV after {en,de}crypt
  (bsc#1051510).
- crypto: caam/qi - fix typo in authenc alg driver name
  (bsc#1051510).
- commit 72727a1
* Wed Mar 14 2018 yousaf.kaukab@suse.com
- Update config files.
- commit 36b5fce
* Wed Mar 14 2018 yousaf.kaukab@suse.com
- phy: qcom-ufs: add MODULE_LICENSE tag (bsc#1085301).
- power: reset: zx-reboot: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bsc#1085301).
- cpufreq: mediatek: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bsc#1085301).
- commit cfc93a7
* Wed Mar 14 2018 yousaf.kaukab@suse.com
- mmc: mmci: stop building qcom dml as module (bsc#1085301).
- supported.conf:
- commit 5a9b68a
* Wed Mar 14 2018 msuchanek@suse.de
- hwmon: (pmbus) Use 64bit math for DIRECT format values
  (bsc#1052766).
- hwmon: (pmbus/core) Prevent unintentional setting of page to
  0xFF (bsc#1052766).
- commit 54a3243
* Wed Mar 14 2018 msuchanek@suse.de
- cpufreq: powernv: Dont assume distinct pstate values for
  nominal and pmin (bsc#1065729).
- backlight: pwm_bl: Fix overflow condition (bsc#1052766).
- device property: Track owner device of device property
  (bsc#1052766).
- auxdisplay: charlcd: properly restore atomic counter on error
  path (bsc#1052766).
- commit 96648fb
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Move tb_switch_phy_port_from_link() to
  thunderbolt.h (bsc#1070681).
- commit e0e498b
* Wed Mar 14 2018 agraf@suse.de
- lan78xx: Connect phy early (bsc#1085262).
- commit 7b14d88
* Wed Mar 14 2018 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix guest time accounting with
  VIRT_CPU_ACCOUNTING_GEN (bsc#1061840).
- KVM: PPC: Book3S PR: Fix broken select due to misspelling
  (bsc#1061840).
- commit 31b626e
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Move thunderbolt domain structure to thunderbolt.h
  (bsc#1070681).
- thunderbolt: Move enum tb_cfg_pkg_type to thunderbolt.h
  (bsc#1070681).
- commit 7ab081a
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Add support for XDomain properties (bsc#1070681).
- commit 30b5374
* Wed Mar 14 2018 oneukum@suse.com
- thunderbolt: Remove __packed from ICM message structures
  (bsc#1070681).
- commit 9d00945
* Wed Mar 14 2018 oneukum@suse.com
- byteorder: Move {cpu_to_be32, be32_to_cpu}_array() from
  Thunderbolt to core (bsc#1070681).
- commit e4d3505
* Wed Mar 14 2018 jeffm@suse.com
- rpm/kernel-source.spec.in: Add check-module-license to Sources
  The package builds in the build service but the script won't make it
  into the SRPM if it's not in the Sources list.
- commit 031ed9e
* Wed Mar 14 2018 msuchanek@suse.de
- ibmvnic: Improve TX buffer accounting (bsc#1085224).
- ibmvnic: Update TX and TX completion routines (bsc#1085224).
- ibmvnic: Update TX pool initialization routine (bsc#1085224).
- ibmvnic: Update release RX pool routine (bsc#1085224).
- ibmvnic: Update and clean up reset TX pool routine
  (bsc#1085224).
- ibmvnic: Generalize TX pool structure (bsc#1085224).
- ibmvnic: Fix recent errata commit (bsc#1085239).
- ibmvnic: Handle TSO backing device errata (bsc#1085239).
- ibmvnic: Pad small packets to minimum MTU size (bsc#1085239).
- ibmvnic: Account for VLAN header length in TX buffers
  (bsc#1085239).
- ibmvnic: Account for VLAN tag in L2 Header descriptor
  (bsc#1085239).
- powerpc/xive: Use hw CPU ids when configuring the CPU queues
  (bsc#1085030).
- KVM: PPC: Book3S HV: Enable use of the new XIVE "single
  escalation" feature (bsc#1085030).
- powerpc/xive: Add interrupt flag to disable automatic EOI
  (bsc#1085030).
- powerpc/xive: Remove incorrect debug code (bsc#1085030).
- treewide: make "nr_cpu_ids" unsigned (bsc#1085030).
- commit 32f736d
* Wed Mar 14 2018 agraf@suse.de
- supported.conf: Add lan78xx as supported (bsc#1085262)
- commit 315bd24
* Wed Mar 14 2018 msuchanek@suse.de
- cxl: read PHB indications from the device tree (bsc#1055014).
- cxl: Check if PSL data-cache is available before issue flush
  request (bsc#1055014).
- cxl: Remove function write_timebase_ctrl_psl9() for PSL9
  (bsc#1055014).
- cxl: Enable NORST bit in PSL_DEBUG register for PSL9
  (bsc#1055014).
- commit 0894623
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/mm: Drop the function native_register_proc_table()
  (bsc#1065729).
- commit 8669224
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/mm/slice: Remove intermediate bitmap copy (bsc#1065729).
- commit 2120582
* Wed Mar 14 2018 msuchanek@suse.de
- PCI/hotplug: ppc: correct a php_slot usage after free
  (bsc#1065729).
- commit 64ebfbc
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc: Rename plapr routines to plpar (bsc#1065729).
- commit c4bc3eb
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/64s: Fix NULL AT_BASE_PLATFORM when using DT CPU
  features (bsc#1065729).
- commit ea2ff2c
* Wed Mar 14 2018 msuchanek@suse.de
- powerpc/xmon: Clear all breakpoints when xmon is disabled via
  debugfs (bsc#1072829).
- powerpc/xmon: Setup debugger hooks when first break-point is
  set (bsc#1072829).
- commit b18a100
* Wed Mar 14 2018 msuchanek@suse.de
- Delete patches.arch/powerpc-xmon-Dont-register-sysrq-key-when-kernel-param-xmon-off.patch.
- commit 732f3c8
* Wed Mar 14 2018 rgoldwyn@suse.com
- apparmor: fix resource audit messages when auditing peer (bsc#1084839).
- Refresh patches.apparmor/apparmor-basic-networking-rules.patch.
- commit 18e0246
* Wed Mar 14 2018 tiwai@suse.de
- mac80211_hwsim: fix possible memory leak in hwsim_new_radio_nl()
  (CVE-2018-8087,bsc#1085053).
- commit f65296f
* Wed Mar 14 2018 dchang@suse.com
- r8169: fix RTL8168EP take too long to complete driver
  initialization (bsc#1051510).
- r8169: fix memory corruption on retrieval of hardware statistics
  (bsc#1051510).
- commit 7a2625d
* Tue Mar 13 2018 msuchanek@suse.de
- mkspec: fix perl warning
- commit f15670f
* Tue Mar 13 2018 tiwai@suse.de
- drivers/fsi: Add module license to core driver (bsc#1085115).
- commit 3e3aa12
* Tue Mar 13 2018 tbogendoerfer@suse.de
- RDMA/mlx5: Fix integer overflow while resizing CQ (bsc#1046305
  FATE#322943).
- RDMA/ucma: Check that user doesn't overflow QP state
  (bsc#1046306 FATE#322942).
- RDMA/ucma: Limit possible option size (bsc#1046306 FATE#322942).
- IB/core: Fix possible crash to access NULL netdev (bsc#1046306
  FATE#322942).
- IB/mlx5: Fix an error code in __mlx5_ib_modify_qp() (bsc#1046305
  FATE#322943).
- IB/mlx4: Include GID type when deleting GIDs from HW table
  under RoCE (bsc#1046302 FATE#322945).
- IB/mlx4: Fix corruption of RoCEv2 IPv4 GIDs (bsc#1046302
  FATE#322945).
- commit 0097c5e
* Tue Mar 13 2018 tbogendoerfer@suse.de
- IB/core : Add null pointer check in addr_resolve (bsc#1046306
  FATE#322942).
- IB/core: Fix missing RDMA cgroups release in case of failure
  to register device (bsc#1046306 FATE#322942).
- IB/mlx: Set slid to zero in Ethernet completion struct
  (bsc#1046306 FATE#322942).
- IB/mlx5: Avoid passing an invalid QP type to firmware
  (bsc#1046305 FATE#322943).
- commit 8343347
* Tue Mar 13 2018 tiwai@suse.de
- ALSA: hda/realtek - Make dock sound work on ThinkPad L570
  (bsc#1051510).
- ALSA: hda/realtek - Fix dock line-out volume on Dell Precision
  7520 (bsc#1051510).
- ALSA: hda/realtek: Limit mic boost on T480 (bsc#1051510).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bsc#1051510).
- ALSA: hda/realtek - Add support headset mode for DELL WYSE
  (bsc#1051510).
- ALSA: hda - Fix a wrong FIXUP for alc289 on Dell machines
  (bsc#1051510).
- commit 0199631
* Tue Mar 13 2018 tbogendoerfer@suse.de
- RDMA/bnxt_re: Avoid Hard lockup during error CQE processing
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Fix the ib_reg failure cleanup (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Fix incorrect DB offset calculation (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Unconditionly fence non wire memory operations
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Avoid system hang during device un-reg
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Fix system crash during load/unload (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Synchronize destroy_qp with poll_cq (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Unpin SQ and RQ memory if QP create fails
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Disable atomic capability on bnxt_re adapters
  (bsc#1050244 FATE#322915).
- commit a191f43
* Tue Mar 13 2018 tiwai@suse.de
- ALSA: seq: Clear client entry before deleting else at closing
  (CVE-2018-1000004,bsc#1076017).
- ALSA: seq: Fix possible UAF in snd_seq_check_queue()
  (CVE-2018-1000004,bsc#1076017).
- ALSA: hda - Revert power_save option default value
  (bsc#1052235).
- ALSA: seq: Remove superfluous snd_seq_queue_client_leave_cells()
  call (CVE-2018-1000004,bsc#1076017).
- ALSA: seq: More protection for concurrent write and ioctl races
  (CVE-2018-1000004,bsc#1076017).
- ALSA: seq: Don't allow resizing pool in use
  (CVE-2018-1000004,bsc#1076017).
- commit d35b672
* Tue Mar 13 2018 tiwai@suse.de
- i2c: piix4: Fix port number check on release (bsc#1051510).
- commit 0c59e1d
* Tue Mar 13 2018 tiwai@suse.de
- media: m88ds3103: don't call a non-initalized function
  (bsc#1051510).
- mmc: bcm2835: Don't overwrite max frequency unconditionally
  (bsc#1051510).
- ACPI: sbshc: remove raw pointer from printk() message
  (bsc#1051510).
- Revert "apple-gmux: lock iGP IO to protect from vgaarb changes"
  (bsc#1051510).
- media: cxusb, dib0700: ignore XC2028_I2C_FLUSH (bsc#1051510).
- media: dvb-frontends: fix i2c access helpers for KASAN
  (bsc#1051510).
- media: r820t: fix r820t_write_reg for KASAN (bsc#1051510).
- media: pvrusb2: properly check endpoint types (bsc#1051510).
- media: dvb-usb-v2: lmedm04: move ts2020 attach to
  dm04_lme2510_tuner (bsc#1051510).
- media: soc_camera: soc_scale_crop: add missing
  MODULE_DESCRIPTION/AUTHOR/LICENSE (bsc#1051510).
- media: mtk-vcodec: add missing MODULE_LICENSE/DESCRIPTION
  (bsc#1051510).
- gpio: Fix kernel stack leak to userspace (bsc#1051510).
- mac80211: mesh: drop frames appearing to be from us
  (bsc#1051510).
- nl80211: Check for the required netlink attribute presence
  (bsc#1051510).
- leds: core: Fix regression caused by commit 2b83ff96f51d
  (bsc#1051510).
- drm/ttm: check the return value of kzalloc (bsc#1051510).
- led: core: Fix brightness setting when setting delay_off=0
  (bsc#1051510).
- drm/nouveau/pci: do a msi rearm on init (bsc#1051510).
- mac80211_hwsim: Fix a possible sleep-in-atomic bug in
  hwsim_get_radio_nl (bsc#1051510).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bsc#1051510).
- media: s5k6aa: describe some function parameters (bsc#1051510).
- media: usbtv: add a new usbid (bsc#1051510).
- media: rc: sir_ir: detect presence of port (bsc#1051510).
- i2c: i2c-boardinfo: fix memory leaks on devinfo (bsc#1051510).
- i2c: i801: Fix Failed to allocate irq -2147483648 error
  (bsc#1051510).
- mmc: core: Do not leave the block driver in a suspended state
  (bsc#1051510).
- ACPI / EC: Fix regression related to PM ops support in ECDT
  device (bsc#1051510).
- ACPI / bus: Leave modalias empty for devices which are not
  present (bsc#1051510).
- media: Don't do DMA on stack for firmware upload in the AS102
  driver (bsc#1051510).
- media: v4l2-ctrl: Fix flags field on Control events
  (bsc#1051510).
- media: rc: check for integer overflow (bsc#1051510).
- ACPI / EC: Fix regression related to triggering source of EC
  event handling (bsc#1051510).
- ACPI / APEI: remove the unused dead-code for SEA/NMI
  notification type (bsc#1051510).
- ACPI / APEI: adjust a local variable type in
  ghes_ioremap_pfn_irq() (bsc#1051510).
- ACPI / PM: Fix acpi_pm_notifier_lock vs flush_workqueue()
  deadlock (bsc#1051510).
- i2c: piix4: Fix SMBus port selection for AMD Family 17h chips
  (bsc#1051510).
- media: cec: Respond to unregistered initiators, when applicable
  (bsc#1051510).
- media: s5p-cec: add NACK detection support (bsc#1051510).
- media: dvb: i2c transfers over usb cannot be done from stack
  (bsc#1051510).
- nl80211: Define policy for packet pattern attributes
  (bsc#1051510).
- media: uvcvideo: Prevent heap overflow when accessing mapped
  controls (bsc#1051510).
- media: adv7180: add missing adv7180cp, adv7180st i2c device IDs
  (bsc#1051510).
- ACPI: EC: Fix possible issues related to EC initialization order
  (bsc#1051510).
- commit 2fdde9f
* Tue Mar 13 2018 tiwai@suse.de
- Refresh / move APEI ERST fix with upstream version (bsc#1072556).
- commit d6f15a6
* Tue Mar 13 2018 mbenes@suse.cz
- livepatch: Allow to replace even disabled patches (bsc#1071995
  fate#323487).
  Atomic replace, update to v10.
- commit 8ab47ee
* Tue Mar 13 2018 mbenes@suse.cz
- livepatch: Improve dynamic struct klp_object detection and
  manipulation (bsc#1071995 fate#323487).
  Atomic replace, update to v10.
- commit 8dbcd34
* Tue Mar 13 2018 mbenes@suse.cz
- livepatch: Correctly handle atomic replace for not yet loaded
  modules (bsc#1071995 fate#323487).
  Atomic replace, update to v10.
- commit 21d8f42
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
  Move patches to the sorted section.
- commit c676d27
* Tue Mar 13 2018 jlee@suse.com
- Update config files.
  Add CONFIG_IMA_KEYRINGS_PERMIT_SIGNED_BY_BUILTIN_OR_SECONDARY=y
  (bsc#1075517)
- commit f8bf472
* Tue Mar 13 2018 lhenriques@suse.com
- ceph: fix potential memory leak in init_caches() (bsc#1084898).
- ceph: fix dentry leak when failing to init debugfs
  (bsc#1084898).
- libceph, ceph: avoid memory leak when specifying same option
  several times (bsc#1084898).
- ceph: flush dirty caps of unlinked inode ASAP (bsc#1084898).
- commit 0065157
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh patches.suse/livepatch-add-atomic-replace.patch.
  Atomic replace, update to v10.
- commit 01ce0f9
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh
  patches.suse/livepatch-support-separate-list-for-replaced-patches.patch.
  Atomic replace, update to v10.
- commit 4d5d788
* Tue Mar 13 2018 mbenes@suse.cz
- Refresh
  patches.suse/livepatch-initial-support-for-dynamic-structures.patch.
  Atomic replace, update to v10.
- commit 1476fb6
* Tue Mar 13 2018 dchang@suse.com
- e1000e: fix the use of magic numbers for buffer overrun issue
  (bsc#1056664 FATE#322185).
- fm10k: Use smp_rmb rather than read_barrier_depends (bsc#1056660
  FATE#322187).
- ixgbevf: Use smp_rmb rather than read_barrier_depends
  (bsc#1056653 FATE#322190).
- ixgbe: Fix skb list corruption on Power systems (bsc#1056657
  FATE#322189).
- e1000e: fix buffer overrun while the I219 is processing DMA
  transactions (bsc#1056664 FATE#322185).
- e1000e: Avoid receiver overrun interrupt bursts (bsc#1056664
  FATE#322185).
- ixgbe: fix use of uninitialized padding (bsc#1056657
  FATE#322189).
- fm10k: fix mis-ordered parameters in declaration for
  .ndo_set_vf_bw (bsc#1056660 FATE#322187).
- fm10k: ensure we process SM mbx when processing VF mbx
  (bsc#1056660 FATE#322187).
- commit 40b77c1
* Tue Mar 13 2018 dchang@suse.com
- qlcnic: fix deadlock bug (bsc#1050540 FATE#322896).
- e1000: fix disabling already-disabled warning (bsc#1056665
  FATE#322184).
- bnx2x: Improve reliability in case of nested PCI errors
  (bsc#1050319 FATE#322906).
- tg3: Enable PHY reset in MTU change path for 5720 (bsc#1050260
  FATE#322917).
- tg3: Add workaround to restrict 5762 MRRS to 2048 (bsc#1050260
  FATE#322917).
- tg3: Fix rx hang on MTU change with 5717/5719 (bsc#1050260
  FATE#322917).
- igb: Use smp_rmb rather than read_barrier_depends (bsc#1056651
  FATE#322191).
- igbvf: Use smp_rmb rather than read_barrier_depends (bsc#1056643
  FATE#322192).
- sfc: don't warn on successful change of MAC (bsc#1058169
  FATE#322922).
- igb: check memory allocation failure (bsc#1056651 FATE#322191).
- commit cb56e2c
* Tue Mar 13 2018 glin@suse.com
- bpf: one perf event close won't free bpf program attached by
  another perf event (bsc#1083647).
- commit 742d87d
* Mon Mar 12 2018 bp@suse.de
- perf/core: Fix memory leak triggered by perf --namespace
  (git-fixes e422267322cd).
- blacklist.conf:
- commit 049df66
* Mon Mar 12 2018 bp@suse.de
- blacklist.conf:
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
- commit e089071
* Mon Mar 12 2018 rgoldwyn@suse.com
- direct-io: Fix sleep in atomic due to sync AIO (bsc#1084888).
- commit 9abf20b
* Mon Mar 12 2018 jthumshirn@suse.de
- Revert "nvme: create 'slaves' and 'holders' entries for hidden
  controllers" (bsc#1082241).
- commit 7ca03c6
* Sat Mar 10 2018 jeffm@suse.com
- kernel: add release status to kernel build (FATE#325281).
- commit 420b4de
* Sat Mar 10 2018 jeffm@suse.com
- rpm: use %%_sourcedir prefix for release-projects
- rpm: set SUSE_KERNEL_RELEASED based on project name
  Set SUSE_KERNEL_RELEASED in the config only if the project name matches
  a list of projects that are part of official release channels.  This
  list of projects is maintained per-branch.
- commit a391a5b
* Fri Mar  9 2018 jeffm@suse.com
- config: added new 'kvmsmall' flavor
  This flavor is an unreleased internal configuration intended for kernel
  developers to use in simple virtual machines.  It contains only the
  device drivers necessary to use a KVM virtual machine *without* device
  passthrough enabled.  Common local and network file systems are enabled.
  All device mapper targets are enabled.  Only the network and graphics
  drivers for devices that qemu emulates are enabled.  Many subsystems
  enabled in the default kernel are entirely disabled.  This kernel is
  meant to be small and to build very quickly.  There will be no kABI
  stability and its configuration may be changed arbitrarily.
- commit 088f1da
* Fri Mar  9 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
- commit 2532eab
* Fri Mar  9 2018 tiwai@suse.de
- blacklist.conf: Add entries from stable 4.13.x/4.14.x
- commit 2c9c302
* Fri Mar  9 2018 tiwai@suse.de
- iwlwifi: add a new a000 device (bsc#1051510).
- Refresh
  patches.drivers/iwlwifi-add-new-cards-for-a000-series.patch.
- commit 6a92cc7
* Fri Mar  9 2018 tiwai@suse.de
- iwlwifi: mvm: fix the TX queue hang timeout for MONITOR vif type
  (bsc#1051510).
- mac80211: fix the update of path metric for RANN frame
  (bsc#1051510).
- mac80211: use QoS NDP for AP probing (bsc#1051510).
- mac80211: flush hw_roc_start work before cancelling the ROC
  (bsc#1051510).
- mac80211_hwsim: Use proper TX power (bsc#1051510).
- mac80211: fix VLAN handling with TXQs (bsc#1051510).
- commit d44c253
* Fri Mar  9 2018 tiwai@suse.de
- drivers: base: cacheinfo: fix cache type for non-architected
  system cache (bsc#1051510).
- driver core: platform: Don't read past the end of
  "driver_override" buffer (bsc#1051510).
- commit 84a3ffe
* Fri Mar  9 2018 tiwai@suse.de
- Input: synaptics-rmi4 - do not delete interrupt memory too early
  (bsc#1051510).
- Input: trackpoint - force 3 buttons if 0 button is reported
  (bsc#1051510).
- Input: xpad - add support for PDP Xbox One controllers
  (bsc#1051510).
- Input: synaptics-rmi4 - prevent UAF reported by KASAN
  (bsc#1051510).
- Input: ALPS - fix multi-touch decoding on SS4 plus touchpads
  (bsc#1051510).
- Input: elantech - add new icbody type 15 (bsc#1051510).
- dynamic-debug-howto: fix optional/omitted ending line number
  to be LARGE instead of 0 (bsc#1051510).
- Input: elan_i2c - add ELAN060C to the ACPI table (bsc#1051510).
- Input: elan_i2c - add ELAN0611 to the ACPI table (bsc#1051510).
- Input: i8042 - add Gigabyte P57 to the keyboard reset table
  (bsc#1051510).
- Input: xpad - validate USB endpoint type during probe
  (bsc#1051510).
- commit c7a5d22
* Fri Mar  9 2018 tiwai@suse.de
- platform/x86: wmi: Call acpi_wmi_init() later (bsc#1051510).
- platform/x86: asus-wireless: send an EV_SYN/SYN_REPORT between
  state changes (bsc#1051510).
- platform/x86: dell-laptop: Fix keyboard max lighting for Dell
  Latitude E6410 (bsc#1051510).
- platform/x86: intel_punit_ipc: Fix resource ioremap warning
  (bsc#1051510).
- platform/x86: hp_accel: Add quirk for HP ProBook 440 G4
  (bsc#1051510).
- commit 3e187f3
* Fri Mar  9 2018 tiwai@suse.de
- rt2x00usb: mark device removed when get ENOENT usb error
  (bsc#1051510).
- rtlwifi: fix uninitialized rtlhal->last_suspend_sec time
  (bsc#1051510).
- rtlwifi: rtl8192ee: Fix memory leak when loading firmware
  (bsc#1051510).
- rtl8188eu: Fix a possible sleep-in-atomic bug in
  rtw_createbss_cmd (bsc#1051510).
- commit 235d38c
* Fri Mar  9 2018 tiwai@suse.de
- drm/amdgpu: add new device to use atpx quirk (bsc#1051510).
- drm/radeon: adjust tested variable (bsc#1051510).
- drm/amdgpu: Avoid leaking PM domain on driver unbind (v2)
  (bsc#1051510).
- drm/ttm: Don't add swapped BOs to swap-LRU list (bsc#1051510).
- drm/amdgpu: add atpx quirk handling (v2) (bsc#1051510).
- drm/amdgpu: Add dpm quirk for Jet PRO (v2) (bsc#1051510).
- drm/radeon: Add dpm quirk for Jet PRO (v2) (bsc#1051510).
- drm/qxl: unref cursor bo when finished with it (bsc#1051510).
- drm/vmwgfx: Potential off by one in vmw_view_add()
  (bsc#1051510).
- drm/vmwgfx: Don't cache framebuffer maps (bsc#1051510).
- drm/amdgpu: don't try to move pinned BOs (bsc#1051510).
- drm/amdkfd: Fix SDMA oversubsription handling (bsc#1051510).
- drm/amdkfd: Fix SDMA ring buffer size calculation (bsc#1051510).
- drm/amdgpu: Fix SDMA load/unload sequence on HWS disabled mode
  (bsc#1051510).
- drm/amd/pp: fix typecast error in powerplay (bsc#1051510).
- drm/amdgpu: Properly allocate VM invalidate eng v2
  (bsc#1051510).
- drm/amdgpu: Remove check which is not valid for certain VBIOS
  (bsc#1051510).
- drm/vblank: Tune drm_crtc_accurate_vblank_count() WARN down
  to a debug (bsc#1051510).
- drm: Add retries for lspcon mode detection (bsc#1051510).
- commit 3372213
* Fri Mar  9 2018 tiwai@suse.de
- drm/radeon: fix atombios on big endian (bsc#1051510).
- drm/amdgpu: fix error handling in amdgpu_bo_do_create
  (bsc#1051510).
- drm/ttm: once more fix ttm_buffer_object_transfer (bsc#1051510).
- drm/amdgpu: correct reference clock value on vega10
  (bsc#1051510).
- drm/vblank: Fix flip event vblank count (bsc#1051510).
- drm/vmwgfx: Fix Ubuntu 17.10 Wayland black screen issue
  (bsc#1051510).
- drm/amdgpu: allow harvesting check for Polaris VCE
  (bsc#1051510).
- drm/amdgpu: return -ENOENT from uvd 6.0 early init for
  harvesting (bsc#1051510).
- drm/amd/powerplay: fix uninitialized variable (bsc#1051510).
- drm/nouveau/kms/nv50: fix oops during DP IRQ handling on
  non-MST boards (bsc#1051510).
- drm/nouveau/bsp/g92: disable by default (bsc#1051510).
- drm/nouveau/mmu: flush tlbs before deleting page tables
  (bsc#1051510).
- drm/amdgpu: read reg in each iterator of psp_wait_for loop
  (bsc#1051510).
- commit 1358bbc
* Fri Mar  9 2018 tiwai@suse.de
- Bluetooth: btusb: Use DMI matching for QCA reset_resume quirking
  (bsc#1051510).
- Bluetooth: BT_HCIUART now depends on SERIAL_DEV_BUS
  (bsc#1051510).
- commit 8e5482b
* Fri Mar  9 2018 tiwai@suse.de
- console/dummy: leave .con_font_get set to NULL (bsc#1051510).
- Bluetooth: btusb: Restore QCA Rome suspend/resume fix with a
  "rewritten" version (bsc#1051510).
- Bluetooth: btsdio: Do not bind to non-removable BCM43341
  (bsc#1051510).
- brcmfmac: Avoid build error with make W=1 (bsc#1051510).
- brcmfmac: change driver unbind order of the sdio function
  devices (bsc#1051510).
- ath9k: fix tx99 potential info leak (bsc#1051510).
- Bluetooth: hci_ldisc: Fix another race when closing the tty
  (bsc#1051510).
- Bluetooth: btusb: Add new NFA344A entry (bsc#1051510).
- Bluetooth: hci_uart_set_flow_control: Fix NULL deref when
  using serdev (bsc#1051510).
- Bluetooth: btqcomsmd: Add support for BD address setup
  (bsc#1051510).
- cfg80211: fix connect/disconnect edge cases (bsc#1051510).
- brcmsmac: make some local variables 'static const' to reduce
  stack size (bsc#1051510).
- brcmfmac: Add check for short event packets (bsc#1051510).
- brcmfmac: setup passive scan if requested by user-space
  (bsc#1051510).
- brcmfmac: add length check in brcmf_cfg80211_escan_handler()
  (bsc#1051510).
- Bluetooth: btusb: Add support for 0489:e0a2 QCA_ROME device
  (bsc#1051510).
- Bluetooth: hci_ldisc: Use rwlocking to avoid closing proto races
  (bsc#1051510).
- commit f42c236
* Fri Mar  9 2018 msuchanek@suse.de
- ibmvnic: Do not disable device during failover or partition
  migration (bsc#1084610).
- ibmvnic: Reorganize device close (bsc#1084610).
- ibmvnic: Clean up device close (bsc#1084610).
- commit d14516e
* Fri Mar  9 2018 glin@suse.com
- bpf, arm64: fix stack_depth tracking in combination with tail
  calls (bsc#1083647).
- bpf: take advantage of stack_depth tracking in powerpc JIT
  (bsc#1083647).
- s390/bpf: take advantage of stack_depth tracking (bsc#1083647).
- commit 1d58a6a
* Fri Mar  9 2018 glin@suse.com
- x86: bpf_jit: small optimization in emit_bpf_tail_call()
  (bsc#1083647).
- Refresh patches.drivers/bpf-fix-bpf_tail_call-x64-JIT.patch.
- commit 2e51427
* Fri Mar  9 2018 glin@suse.com
- bpf, arm64: take advantage of stack_depth tracking
  (bsc#1083647).
- bpf: take advantage of stack_depth tracking in x64 JIT
  (bsc#1083647).
- bpf: change x86 JITed program stack layout (bsc#1083647).
- commit a045c8c
* Thu Mar  8 2018 msuchanek@suse.de
- mkspec: do not build dtbs for architectures with no kernel.
- commit 8394abf
* Thu Mar  8 2018 tiwai@suse.de
- ASoC: ux500: add MODULE_LICENSE tag (bsc#1051510).
- ASoC: pcm512x: add missing MODULE_DESCRIPTION/AUTHOR/LICENSE
  (bsc#1051510).
- ASoC: skl: Fix kernel warning due to zero NHTL entry
  (bsc#1051510).
- ASoC: codecs: msm8916-wcd-analog: fix module autoload
  (bsc#1051510).
- ASoC: img-parallel-out: Add pm_runtime_get/put to set_fmt
  callback (bsc#1051510).
- ASoC: rsnd: rsnd_ssi_run_mods() needs to care ssi_parent_mod
  (bsc#1051510).
- ASoC: Intel: Skylake: Fix uuid_module memory leak in failure
  case (bsc#1051510).
- commit 0dddbdc
* Thu Mar  8 2018 tiwai@suse.de
- ALSA: usb: add more device quirks for USB DSD devices
  (bsc#1051510).
- ALSA: usb-audio: add implicit fb quirk for Behringer UFX1204
  (bsc#1051510).
- ALSA: line6: Add a sanity check for invalid EPs (bsc#1051510).
- ALSA: caiaq: Add a sanity check for invalid EPs (bsc#1051510).
- ALSA: bcd2000: Add a sanity check for invalid EPs (bsc#1051510).
- usb: core: Add a helper function to check the validity of EP
  type in URB (bsc#1051510).
- commit 4d4a9cb
* Thu Mar  8 2018 duwe@suse.de
- Update config files.
- commit c87ae8c
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- Update config files.
- commit e355af1
* Thu Mar  8 2018 mbrugger@suse.com
- arm64: Update config files. (bsc#1084143)
  Build ARM_MT8173_CPUFREQ as a module
- commit 0db2cc6
* Thu Mar  8 2018 duwe@suse.de
- On ppc64le we HAVE_RELIABLE_STACKTRACE (bsc#1072856).
- commit a4da14c
* Thu Mar  8 2018 oneukum@suse.com
- supported.conf: declared thunderbolt.ko supported
  This used to be an Apple only driver. It has been changed to generic
  thunderbolt support. We want this on SLES, too. (bsc#1084516)
- commit b51cbd2
* Thu Mar  8 2018 tiwai@suse.de
- drm/i915/cnl: Add WaRsDisableCoarsePowerGating (FATE#322643
  bsc#1055900).
- commit 3b71519
* Thu Mar  8 2018 tiwai@suse.de
- drm/i915: Apply headless DMC workaround for CNL (FATE#322643
  bsc#1055900).
- commit 1e7e0de
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- ACPI/IORT: Add msi address regions reservation helper
  (bsc#1084475).
- ACPI/IORT: Enable SMMUv3/PMCG IORT MSI domain set-up
  (bsc#1084475).
- ACPI/IORT: Add SMMUv3 specific special index mapping handling
  (bsc#1084475).
- ACPI/IORT: Enable special index ITS group mappings for IORT
  nodes (bsc#1084475).
- ACPI/IORT: Look up IORT node through struct fwnode_handle
  pointer (bsc#1084475).
- ACPI/IORT: Make platform devices initialization code SMMU
  agnostic (bsc#1084475).
- ACPI/IORT: Improve functions return type/storage class specifier
  indentation (bsc#1084475).
- ACPI/IORT: Remove leftover ACPI_IORT_SMMU_V3_PXM_VALID guard
  (bsc#1084475).
- acpi/arm64: pr_err() strings should end with newlines
  (bsc#1084475).
- ACPI/IORT: Fix PCI ACS enablement (bsc#1084475).
- commit 4f0cd1c
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- ACPI/IORT: Fix build regression without IOMMU (bsc#1084475).
- ACPI/IORT: Handle PCI aliases properly for IOMMUs (bsc#1084475).
- commit a805c57
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- iommu/arm-smmu-v3, acpi: Add temporary Cavium SMMU-V3 IORT
  model number definitions (bsc#1084475).
- Refresh
  patches.suse/iommu-arm-smmu-v3-Enable-ACPI-based-HiSilicon-CMD_PR.patch.
- commit 80781a3
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- ACPI/IORT: Remove iort_node_match() (bsc#1084475).
- commit edbe598
* Thu Mar  8 2018 yousaf.kaukab@suse.com
- i2c: xlp9xx: Add support for SMBAlert (bsc#1084310).
- i2c: xlp9xx: Handle NACK on DATA properly (bsc#1084310).
- i2c: xlp9xx: Check for Bus state before every transfer
  (bsc#1084310).
- i2c: xlp9xx: Handle transactions with I2C_M_RECV_LEN properly
  (bsc#1060799).
- i2c: xlp9xx: return ENXIO on slave address NACK (bsc#1060799).
- ahci: thunderx2: update stop engine errata delay values
  (bsc#1084308).
- arm64: Add missing Falkor part number for branch predictor
  hardening (bsc#1068032).
- ARM64 / cpuidle: Use new cpuidle macro for entering retention
  state (bsc#1084328).
- cpuidle: Add new macro to enter a retention idle state
  (bsc#1084328).
- ipmi: fix unsigned long underflow (bsc#1060799).
- tpm/tpm_crb: Use start method value from ACPI table directly
  (bsc#1084452).
- char: ipmi: constify bmc_dev_attr_group and bmc_device_type
  (bsc#1060799).
- ipmi:ssif: Check dev before setting drvdata (bsc#1060799).
- ipmi: Convert DMI handling over to a platform device
  (bsc#1060799).
- ipmi: Create a platform device for a DMI-specified IPMI
  interface (bsc#1060799).
- ipmi:ssif: Use i2c_adapter_id instead of adapter->nr
  (bsc#1060799).
- ipmi: Use the proper default value for register size in ACPI
  (bsc#1060799).
- ipmi_ssif: remove redundant null check on array
  client->adapter->name (bsc#1060799).
- ACPICA: Add header support for TPM2 table changes (bsc#1084452).
- cpufreq / CPPC: Initialize policy->min to lowest nonlinear
  performance (bsc#1084342).
- commit 9834636
* Thu Mar  8 2018 glin@suse.com
- bpf: introduce ARG_PTR_TO_MEM_OR_NULL (bsc#1083647).
- commit e744b9e
* Thu Mar  8 2018 msuchanek@suse.de
- config.sh: build against SLE-15 in OBS.
- commit e4aa6f4
* Thu Mar  8 2018 tiwai@suse.de
- intel_th: pci: Add Lewisburg PCH support (FATE#325099).
- intel_th: pci: Add Cedar Fork PCH support (FATE#325099).
- intel_th: Perform time resync on capture start (FATE#325099).
- intel_th: Add global activate/deactivate callbacks for the
  glue layers (FATE#325099).
- intel_th: pci: Use drvdata for quirks (FATE#325099).
- intel_th: pti: Support Low Power Path output port type
  (FATE#325099).
- intel_th: Enumerate Low Power Path output port type
  (FATE#325099).
- intel_th: msu: Use the real device in case of IOMMU domain
  allocation (FATE#325099).
- intel_th: Make the switch allocate its subdevices (FATE#325099).
- intel_th: Make SOURCE devices children of the root device
  (FATE#325099).
- intel_th: Streamline the subdevice tree accessors (FATE#325099).
- intel_th: Output devices without ports don't need assigning
  (FATE#325099).
- intel_th: pci: Enable bus mastering (FATE#325099).
- commit e948cb6
* Thu Mar  8 2018 tiwai@suse.de
- Preliminary series.conf sort and update
- commit e372e1c
* Thu Mar  8 2018 glin@suse.com
- bpf: remove explicit handling of 0 for arg2 in bpf_probe_read
  (bsc#1083647).
- bpf: change helper bpf_probe_read arg2 type to
  ARG_CONST_SIZE_OR_ZERO (bsc#1083647).
- commit c81cbaf
* Thu Mar  8 2018 glin@suse.com
- selftests/bpf: add tests for recent bugfixes (bsc#1083647).
- bpf: change bpf_probe_write_user to bpf_trace_printk in
  test_verifier (bsc#1083647).
- bpf: fix and add test cases for ARG_CONST_SIZE_OR_ZERO semantics
  change (bsc#1083647).
- commit 3eadeee
* Wed Mar  7 2018 mbrugger@suse.com
- net: hns: add ACPI mode support for ethtool -p (bsc#1084041).
- commit 1534335
* Wed Mar  7 2018 agraf@suse.de
- lan78xx: Avoid spurious kevent 4 "error" (bsc#1084332).
- lan78xx: Enable LEDs and auto-negotiation (bsc#1084332).
- lan78xx: Correctly indicate invalid OTP (bsc#1084332).
- lan78xx: Read MAC address from DT if present (bsc#1084332).
- lan78xx: Fix failure in USB Full Speed (bsc#1084332).
- lan78xx: Use default values loaded from EEPROM/OTP after reset
  (bsc#1084332).
- lan78xx: Allow EEPROM write for less than MAX_EEPROM_SIZE
  (bsc#1084332).
- lan78xx: Fix for eeprom read/write when device auto suspend
  (bsc#1084332).
- lan78xx: Fix to handle hard_header_len update (bsc#1084332).
- lan78xx: USB fast connect/disconnect crash fix (bsc#1084332).
- commit a355989
* Wed Mar  7 2018 tiwai@suse.de
- rpm/kernel-binary.spec.in: Check module licenses (bsc#1083215,bsc#1083527)
- commit e41de0c
* Wed Mar  7 2018 tiwai@suse.de
- x86/kvm/vmx: do not use vm-exit instruction length for fast
  MMIO when running nested (bsc#1081431).
- commit 0b3a20a
* Wed Mar  7 2018 oneukum@suse.com
- usbip: prevent vhci_hcd driver from leaking a socket pointer address (bsc#1078674 CVE-2017-16911).
- commit d07e5b4
* Wed Mar  7 2018 pmladek@suse.com
- printk: Wake klogd when passing console_lock owner
  (bsc#1084301).
- commit 7dbb932
* Wed Mar  7 2018 dchang@suse.com
- net: dst: move cpu inside ifdef to avoid compilation warning
  (bsc#1083647).
- commit dcdefd8
* Wed Mar  7 2018 dchang@suse.com
- bpf: don't rely on the verifier lock for metadata_dst allocation
  (bsc#1083647).
- commit 4fec793
* Wed Mar  7 2018 dchang@suse.com
- bpf: allow access to skb->len from offloads (bsc#1083647).
- commit 6cb18cc
* Tue Mar  6 2018 tbogendoerfer@suse.de
- ixgbe: fix crash in build_skb Rx code path (bsc#1056657
  FATE#322189).
- RDMA/uverbs: Protect from command mask overflow (bsc#1046306
  FATE#322942).
- IB/uverbs: Improve lockdep_check (bsc#1046306 FATE#322942).
- RDMA/uverbs: Protect from races between lookup and destroy of
  uobjects (bsc#1046306 FATE#322942).
- IB/ipoib: Do not warn if IPoIB debugfs doesn't exist
  (bsc#1046307 FATE#322941).
- net: fix race on decreasing number of TX queues (bsc#1056787).
- s390/qeth: fix SETIP command handling (bsc#1061024 FATE#323301).
- net/mlx5e: Remove timestamp set from netdevice open flow
  (bsc#1046303 FATE#322944).
- commit bbd85ba
* Tue Mar  6 2018 msuchanek@suse.de
- scsi: sr: workaround VMware ESXi cdrom emulation bug
  (bsc#1080813).
- commit d2067fc
* Tue Mar  6 2018 glin@suse.com
- bpf, ppc64: implement jiting of BPF_J{LT, LE, SLT, SLE}
  (bsc#1083647).
- bpf, s390x: implement jiting of BPF_J{LT, LE, SLT, SLE}
  (bsc#1083647).
- bpf, arm64: implement jiting of BPF_J{LT, LE, SLT, SLE}
  (bsc#1083647).
- bpf, x86: implement jiting of BPF_J{LT,LE,SLT,SLE}
  (bsc#1083647).
- commit a245dfe
* Tue Mar  6 2018 tbogendoerfer@suse.de
- net: ethtool: don't ignore return from driver get_fecparam
  method (bsc#1046540 FATE#322930).
- commit 90a64af
* Tue Mar  6 2018 nborisov@suse.com
- btrfs: preserve i_mode if __btrfs_set_acl() fails (bsc#1083000).
- commit 1eddbfd
* Tue Mar  6 2018 nborisov@suse.com
- Btrfs: incremental send, fix wrong unlink path after renaming
  file (bsc#1083000).
- Btrfs: incremental send, fix emission of invalid clone
  operations (bsc#1083000).
- commit 0e8595f
* Tue Mar  6 2018 nborisov@suse.com
- Btrfs: fix unexpected -EEXIST when creating new inode
  (bsc#1083000).
- Btrfs: fix extent state leak from tree log (bsc#1083000).
- Btrfs: fix crash due to not cleaning up tree log block's dirty
  bits (bsc#1083000).
- Btrfs: fix deadlock in run_delalloc_nocow (bsc#1083000).
- Btrfs: avoid losing data raid profile when deleting a device
  (bsc#1083000).
- Btrfs: fix stale entries in readdir (bsc#1083000).
- btrfs: Fix possible off-by-one in btrfs_search_path_in_tree
  (bsc#1083000).
- btrfs: clear ordered flag on cleaning up ordered extents
  (bsc#1083000).
- btrfs: fix readdir deadlock with pagefault (bsc#1083000).
- commit 1e19d87
* Tue Mar  6 2018 jslaby@suse.cz
- x86/speculation: Add <asm/msr-index.h> dependency (bnc#1058115).
- commit 3d60a5f
* Tue Mar  6 2018 tiwai@suse.de
- Update the usptreamed tag for i915 patch
  Also moved to sorted section:
  patches.drivers/drm-i915-cnl-Fix-PORT_TX_DW5-7-register-address
- commit d4f2341
* Tue Mar  6 2018 tiwai@suse.de
- Sort patches / update tags
- commit 8fad596
* Tue Mar  6 2018 jslaby@suse.cz
- objtool: Add module specific retpoline rules (bnc#1058115).
- objtool: Add retpoline validation (bnc#1058115).
- objtool: Use existing global variables for options
  (bnc#1058115).
- x86/mm/sme, objtool: Annotate indirect call in
  sme_encrypt_execute() (bnc#1058115).
- x86/boot, objtool: Annotate indirect jump in
  secondary_startup_64() (bnc#1058115).
- x86/paravirt, objtool: Annotate indirect calls (bnc#1058115).
- x86/speculation, objtool: Annotate indirect calls/jumps for
  objtool (bnc#1058115).
- commit bacb170
* Tue Mar  6 2018 jslaby@suse.cz
- objtool: Fix switch-table detection (bnc#1058115).
- commit deefb76
* Tue Mar  6 2018 jslaby@suse.cz
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-ppp-session-destroy.patch.
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-tunnel-destroy.patch.
- Refresh
  patches.fixes/l2tp-fix-race-in-pppol2tp_release-with-session-objec.patch.
- Refresh
  patches.fixes/l2tp-fix-races-with-tunnel-socket-close.patch.
- Refresh
  patches.fixes/l2tp-fix-tunnel-lookup-use-after-free-race.patch.
  Ran series_sort.
- commit 18a48e4
* Tue Mar  6 2018 nborisov@suse.com
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-ppp-session-destroy.patch.
- Refresh
  patches.fixes/l2tp-don-t-use-inet_shutdown-on-tunnel-destroy.patch.
- Refresh
  patches.fixes/l2tp-fix-race-in-pppol2tp_release-with-session-objec.patch.
- Refresh
  patches.fixes/l2tp-fix-races-with-tunnel-socket-close.patch.
- Refresh
  patches.fixes/l2tp-fix-tunnel-lookup-use-after-free-race.patch.
- commit bd5bc11
* Tue Mar  6 2018 glin@suse.com
- bpf: fix selftests/bpf test_kmod.sh failure when
  CONFIG_BPF_JIT_ALWAYS_ON=y (bsc#1083647).
- selftests/bpf: make 'dubious pointer arithmetic' test useful
  (bsc#1083647).
- bpf: fix stack state printing in verifier log (bsc#1083647).
- commit 9391768
* Mon Mar  5 2018 neilb@suse.com
- dm: fix race between dm_get_from_kobject() and __dm_destroy()
  (bsc#1083242, CVE-2017-18203).
- commit 1b6ebbf
* Mon Mar  5 2018 msuchanek@suse.de
- rpm: provide %%name%%-srchash = <kernel-source commit hash> (FATE#325312).
  - Also use for kernel-obs-build dependency.
- commit b6fccdf
* Mon Mar  5 2018 tbogendoerfer@suse.de
- net: ena: increase ena driver version to 1.5.0 (bsc#1083548).
- net: ena: add detection and recovery mechanism for handling
  missed/misrouted MSI-X (bsc#1083548).
- net: ena: fix error handling in ena_down() sequence
  (bsc#1083548).
- net: ena: unmask MSI-X only after device initialization is
  completed (bsc#1083548).
- net: ena: fix race condition between device reset and link up
  setup (bsc#1083548).
- net: ena: increase ena driver version to 1.3.0 (bsc#1083548).
- net: ena: add new admin define for future support of IPv6 RSS
  (bsc#1083548).
- net: ena: add statistics for missed tx packets (bsc#1083548).
- net: ena: add power management ops to the ENA driver
  (bsc#1083548).
- net: ena: remove legacy suspend suspend/resume support
  (bsc#1083548).
- net: ena: improve ENA driver boot time (bsc#1083548).
- net: ena: Remove redundant unlikely() (bsc#1083548).
- net: ena: fix wrong max Tx/Rx queues on ethtool (bsc#1083548).
- net: ena: fix rare kernel crash when bar memory remap fails
  (bsc#1083548).
- net: ena: reduce the severity of some printouts (bsc#1083548).
- commit 46c382b
* Mon Mar  5 2018 jgross@suse.com
- x86/xen: Zero MSR_IA32_SPEC_CTRL before suspend (bnc#1065600).
- commit 0c69d71
* Mon Mar  5 2018 tbogendoerfer@suse.de
- Drop patches, because new notifier semantic is not in SLE15 (bsc#1082743)
- Delete
  patches.drivers/IB-hfi1-update-to-new-mmu_notifier-semantic.patch.
- Delete
  patches.drivers/IB-umem-update-to-new-mmu_notifier-semantic.patch.
- commit c8f3eed
* Mon Mar  5 2018 glin@suse.com
- selftests/bpf: fix test_align (bsc#1083647).
- selftests/bpf: add test for bogus operations on pointers
  (bsc#1083647).
- selftests/bpf: add a test to test_align (bsc#1083647).
- selftests/bpf: rewrite test_align (bsc#1083647).
- bpf: allow to specify log level and reduce it for test_verifier
  (bsc#1083647).
- selftests/bpf: make correct use of exit codes in bpf selftests
  (bsc#1083647).
- bpf, tests: set rlimit also for test_align, so it doesn't fail
  (bsc#1083647).
- commit 623858a
* Mon Mar  5 2018 mkubecek@suse.cz
- Update
  patches.fixes/netfilter-add-back-stackpointer-size-checks.patch
  references (add CVE-2018-1065 bsc#1083650).
- commit 603dd8a
* Mon Mar  5 2018 mkubecek@suse.cz
- Update
  patches.fixes/net-ipv6-fix-regression-of-no-RTM_DELADDR-sent-after.patch
  references (add bsc#1083557).
- commit 0c85cde
* Mon Mar  5 2018 mkubecek@suse.cz
- doc: Change the min default value of tcp_wmem/tcp_rmem
  (bsc#1076830).
- commit 2dfc414
* Mon Mar  5 2018 mkubecek@suse.cz
- Fix upstream reference:
  patches.drivers/scsi-qla2xxx-Fix-FC-NVMe-LUN-discovery.patch.
- commit 5b6cf57
* Mon Mar  5 2018 gqjiang@suse.com
- raid10: change the size of resync window for clustered raid
  (bsc#1076343).
- commit d4d2d17
* Mon Mar  5 2018 mgalbraith@suse.de
- x86/platform/intel-mid: Handle Intel Edison reboot correctly (Git-fixes).
- blacklist.conf:
- timers: Forward timer base before migrating timers (Git-fixes).
- commit d95fda8
* Mon Mar  5 2018 glin@suse.com
- bpf: mark dst unknown on inconsistent {s, u}bounds adjustments
  (bsc#1083647).
- bpf: reject stores into ctx via st and xadd (bsc#1083647).
- bpf: fix 32-bit divide by zero (bsc#1083647).
- bpf: fix divides by zero (bsc#1083647).
- bpf: arsh is not supported in 32 bit alu thus reject it
  (bsc#1083647).
- bpf: fix spelling mistake: "obusing" -> "abusing" (bsc#1083647).
- bpf: introduce BPF_JIT_ALWAYS_ON config (bsc#1083647).
  Update config files to set CONFIG_BPF_JIT_ALWAYS_ON to y
- bpf: do not allow root to mangle valid pointers (bsc#1083647).
- commit 81ce49e
* Mon Mar  5 2018 glin@suse.com
- bpf: guarantee r1 to be ctx in case of
  bpf_helper_changes_pkt_data (bsc#1083647).
- bpf: add schedule points to map alloc/free (bsc#1083647).
- commit 2ff84f7
* Mon Mar  5 2018 glin@suse.com
- bpf: improve verifier ARG_CONST_SIZE_OR_ZERO semantics
  (bsc#1083647).
- bpf: fix verifier NULL pointer dereference (bsc#1083647).
- bpf: fix out-of-bounds access warning in bpf_check
  (bsc#1083647).
- bpf: fix link error without CONFIG_NET (bsc#1083647).
- bpf: fix verifier memory leaks (bsc#1083647).
- bpf: reduce verifier memory consumption (bsc#1083647).
  Refresh patches.fixes/bpf-fix-branch-pruning-logic.patch.
  Refresh
  patches.fixes/bpf-fix-incorrect-tracking-of-register-size-truncati.patch.
- bpf: move knowledge about post-translation offsets out of
  verifier (bsc#1083647).
- bpf: remove the verifier ops from program structure
  (bsc#1083647).
- bpf: split verifier and program ops (bsc#1083647).
- tracing: bpf: Hide bpf trace events when they are not used
  (bsc#1083647).
- bpf: verifier: set reg_type on context accesses in second pass
  (bsc#1083647).
- bpf: write back the verifier log buffer as it gets filled
  (bsc#1083647).
- bpf: move instruction printing into a separate file
  (bsc#1083647).
- bpf: Optimize lpm trie delete (bsc#1083647).
- bpf: Implement map_delete_elem for BPF_MAP_TYPE_LPM_TRIE
  (bsc#1083647).
- bpf: Allow cgroup sock filters to use get_current_uid_gid helper
  (bsc#1083647).
- selftests/bpf: don't try to access past MAX_PACKET_OFF in
  test_verifier (bsc#1083647).
- selftests/bpf: change test_verifier expectations (bsc#1083647).
  Refresh
  patches.drivers/bpf-verifier-reject-BPF_ALU64-BPF_END.patch.
- commit ea80b65
* Sun Mar  4 2018 msuchanek@suse.de
- arch-symbols: use bash as interpreter since the script uses bashism.
- commit 4cdfb23
* Fri Mar  2 2018 mcgrof@suse.com
- xfs: truncate pagecache before writeback in xfs_setattr_size() (bsc#1073412).
- commit 73496e4
* Fri Mar  2 2018 dbueso@suse.de
- ipc/msg: introduce msgctl(MSG_STAT_ANY) (bsc#1072689).
- ipc/sem: introduce semctl(SEM_STAT_ANY) (bsc#1072689).
- ipc/shm: introduce shmctl(SHM_STAT_ANY) (bsc#1072689).
- commit c31f2e1
* Fri Mar  2 2018 vbabka@suse.cz
- fs/hugetlbfs/inode.c: change put_page/unlock_page order in
  hugetlbfs_fallocate() (git-fixes, bsc#1083745).
- commit 22c8c94
* Fri Mar  2 2018 agraf@suse.de
- Delete
  patches.suse/KVM-update-to-new-mmu_notifier-semantic-v2.patch. (bsc#1082743)
- Delete patches.suse/KVM-x86-fix-APIC-page-invalidation.patch. (bsc#1082743)
- commit 8dfc569
* Fri Mar  2 2018 vbabka@suse.cz
- mm: do not rely on preempt_count in print_vma_addr (git-fixes,
  bsc#1083704).
- commit 6b725d8
* Fri Mar  2 2018 msuchanek@suse.de
- kernel-binary: do not BuildIgnore m4.
  It is actually needed for regenerating zconf when it is not up-to-date
  due to merge.
- commit 967b28b
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: add build requirement for flex
  In addition to bison, we also need flex for "make oldconfig".
- commit 83d831c
* Fri Mar  2 2018 mkubecek@suse.cz
- rpm/kernel-binary.spec.in: remove m4 from BuildIgnore list
  As bison depends on m4, we cannot set !BuildIgnore for it any more.
- commit d7695e1
* Fri Mar  2 2018 tiwai@suse.de
- Documentation/sphinx: Fix Directive import error (bsc#1083694).
- commit 1407e51
* Fri Mar  2 2018 bp@suse.de
- include: psp-sev: Capitalize invalid length enum (bsc#1063068).
- KVM/nVMX: Set the CPU_BASED_USE_MSR_BITMAPS if we have a valid
  L02 MSR bitmap (bsc#1068032 CVE-2017-5754).
- KVM: SVM: Fix SEV LAUNCH_SECRET command (bsc#1063068).
- KVM: SVM: no need to call access_ok() in LAUNCH_MEASURE command
  (bsc#1063068).
- KVM/x86: Reduce retpoline performance impact in
  slot_handle_level_range(), by always inlining iterator helper
  methods (bsc#1068032 CVE-2017-5754).
- KVM/x86: Remove indirect MSR op calls from SPEC_CTRL
  (bsc#1063068).
- nospec: Move array_index_nospec() parameter checking into
  separate macro (bsc#1068032 CVE-2017-5754).
- objtool: Fix segfault in ignore_unreachable_insn() (bsc#1068032
  CVE-2017-5754).
- x86/debug, objtool: Annotate WARN()-related UD2 as reachable
  (bsc#1068032 CVE-2017-5754).
- x86/debug: Use UD2 for WARN() (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Clear extra registers beyond syscall arguments, to
  reduce speculation attack surface (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Clear registers for exceptions/interrupts, to
  reduce speculation attack surface (bsc#1068032 CVE-2017-5754).
- x86/entry/64/compat: Clear registers for compat syscalls, to
  reduce speculation attack surface (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Fix CR3 restore in paranoid_exit() (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Fix paranoid_entry() frame pointer warning
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Get rid of the ALLOC_PT_GPREGS_ON_STACK and
  SAVE_AND_CLEAR_REGS macros (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Indent PUSH_AND_CLEAR_REGS and POP_REGS properly
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Interleave XOR register clearing with PUSH
  instructions (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Introduce the PUSH_AND_CLEAN_REGS macro
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Merge SAVE_C_REGS and SAVE_EXTRA_REGS, remove
  unused extensions (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Merge the POP_C_REGS and POP_EXTRA_REGS macros
  into a single POP_REGS macro (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove the unused 'icebp' macro (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Use PUSH_AND_CLEAN_REGS in more cases (bsc#1068032
  CVE-2017-5754).
- x86/mm: Rename flush_tlb_single() and flush_tlb_one() to
  __flush_tlb_one_[user|kernel]() (bsc#1068032 CVE-2017-5754).
- X86/nVMX: Properly set spec_ctrl and pred_cmd before merging
  MSRs (bsc#1068032 CVE-2017-5754).
- x86/speculation: Clean up various Spectre related details
  (bsc#1068032 CVE-2017-5754).
- x86/speculation: Fix up array_index_nospec_mask() asm constraint
  (bsc#1068032 CVE-2017-5754).
- Refresh
  patches.arch/09.0-x86-spectre-fix-an-error-message.patch.
- commit f83739a
* Fri Mar  2 2018 mgorman@suse.de
- mm/free_pcppages_bulk: prefetch buddy while not holding lock
  (bnc#971975 VM performance -- page allocator).
- mm/free_pcppages_bulk: do not hold lock when picking pages to
  free (bnc#971975 VM performance -- page allocator).
- mm/free_pcppages_bulk: update pcp->count inside (bnc#971975
  VM performance -- page allocator).
- commit b395d98
* Fri Mar  2 2018 mgorman@suse.de
- x86/cpu: Remove unused and undefined __generic_processor_info()
  declaration (bnc#1056230).
- commit 112c00f
* Fri Mar  2 2018 vbabka@suse.cz
- x86/mm/pkeys: Fix fill_sig_info_pkey (git-fixes, bsc#1083529).
- commit 2c7fc72
* Fri Mar  2 2018 tiwai@suse.de
- media: v4l2-compat-ioctl32.c: make ctrl_is_pointer work for
  subdevs (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: refactor compat ioctl32 logic
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: don't copy back the result for
  certain errors (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: drop pr_info for unknown buffer
  type (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: copy clip list in
  put_v4l2_window32 (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: fix ctrl_is_pointer
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: copy m.userptr in put_v4l2_plane32
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: avoid sizeof(type)
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: move 'helper' functions to
  __get/put_v4l2_format32 (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: fix the indentation
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-compat-ioctl32.c: add missing VIDIOC_PREPARE_BUF
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-ioctl.c: don't copy back the result for -ENOTTY
  (CVE-2017-13166,bsc#1072865).
- media: v4l2-ioctl.c: use check_fmt for enum/g/s/try_fmt
  (CVE-2017-13166,bsc#1072865).
- commit 5d9eae0
* Fri Mar  2 2018 tiwai@suse.de
- drm/i915: Make global seqno known in i915_gem_request_execute
  tracepoint (FATE#322643 bsc#1055900).
- drm/i915: Clear the in-use marker on execbuf failure
  (FATE#322643 bsc#1055900).
- drm/i915/audio: fix check for av_enc_map overflow (FATE#322643
  bsc#1055900).
- drm/i915: Fix rsvd2 mask when out-fence is returned (FATE#322643
  bsc#1055900).
- ALSA: hda - Fix pincfg at resume on Lenovo T470 dock
  (bsc#1052235).
- ALSA: usb-audio: Add a quirck for B&W PX headphones
  (bsc#1051510).
- ALSA: hda: Add a power_save blacklist (bsc#1052235).
- commit b784bf6
* Thu Mar  1 2018 mwilck@suse.com
- fs: aio: fix the increment of aio-nr and counting against
  aio-max-nr (bsc#1068075, bsc#1078921).
- commit e2a476e
* Thu Mar  1 2018 tiwai@suse.de
- Update config files: re-enable CONFIG_CRYPTO_FIPS=y (bsc#1083512)
- commit c380188
* Thu Mar  1 2018 tiwai@suse.de
- 9p: add missing module license for xen transport (bsc#1083527).
- commit c36c39b
* Thu Mar  1 2018 hare@suse.de
- supported.conf: Add dm-zoned (FATE#318724)
- commit e97e249
* Thu Mar  1 2018 msuchanek@suse.de
- Include ACPI button driver in base kernel (bsc#1062056).
- commit 412fabd
* Thu Mar  1 2018 hare@suse.de
- Enable dm-zoned (FATE#318724).
- commit 6098432
* Thu Mar  1 2018 mhocko@suse.com
- Update
  patches.fixes/mm-madvise.c-fix-madvise-infinite-loop-under-special.patch
  (bnc#1070964, bnc#1083494, CVE-2017-18208).
- commit b82f489
* Thu Mar  1 2018 bp@suse.de
- Refresh
  patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch.
- commit 9aac42a
* Thu Mar  1 2018 mkubecek@suse.cz
- Delete
  patches.suse/0001-kabi-Lift-ifdefs-for-some-disabled-network-protocols.patch.
  When DCCP was disabled in SLE12-SP2, this patch was added to make it
  possible to build it as a KMP in case it would turn out someone is actually
  using it. As there have been no sign of that since, let's drop the patch.
- commit 285564e
* Thu Mar  1 2018 hare@suse.de
- scsi: qla2xxx: Fix FC-NVMe LUN discovery (bsc#1083224).
- commit 58d375c
* Thu Mar  1 2018 hare@suse.de
- Fixup patch description for patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch
- commit 95e3c32
* Thu Mar  1 2018 tiwai@suse.de
- ALSA: seq: Fix racy pool initializations
  (CVE-2018-7566,bsc#1083483).
- commit c7a35b5
* Thu Mar  1 2018 mkubecek@suse.cz
- l2tp: fix tunnel lookup use-after-free race (bsc#1076830).
- l2tp: fix race in pppol2tp_release with session object destroy
  (bsc#1076830).
- l2tp: fix races with tunnel socket close (bsc#1076830).
- l2tp: don't use inet_shutdown on ppp session destroy
  (bsc#1076830).
- l2tp: don't use inet_shutdown on tunnel destroy (bsc#1076830).
- regulatory: add NUL to request alpha2 (bsc#1076830).
- net: ipv4: Set addr_type in hash_keys for forwarded case
  (bsc#1076830).
- tcp_bbr: better deal with suboptimal GSO (bsc#1076830).
- netfilter: IDLETIMER: be syzkaller friendly (bsc#1076830).
- netfilter: nat: cope with negative port range (bsc#1076830).
- netfilter: x_tables: fix missing timer initialization in xt_LED
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix a refcount bug in
  clusterip_config_find_get() (bsc#1076830).
- netfilter: add back stackpointer size checks (bsc#1076830).
- netfilter: drop outermost socket lock in getsockopt()
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix a race condition of proc file
  creation (bsc#1076830).
- udplite: fix partial checksum initialization (bsc#1076830).
- dn_getsockoptdecnet: move nf_{get/set}sockopt outside sock lock
  (bsc#1076830).
- tcp: Honor the eor bit in tcp_mtu_probe (bsc#1076830).
- sctp: do not pr_err for the duplicated node in transport rhlist
  (bsc#1076830).
- bridge: check brport attr show in brport_show (bsc#1076830).
- ipv6: set all.accept_dad to 0 by default (bsc#1076830).
- l2tp: remove l2tp_tunnel_count and l2tp_session_count
  (bsc#1076830).
  Refresh patches.fixes/l2tp-don-t-close-sessions-in-l2tp_tunnel_destruct.patch
- l2tp: remove ->ref() and ->deref() (bsc#1076830).
- l2tp: initialise PPP sessions before registering them
  (bsc#1076830).
- l2tp: protect sock pointer of struct pppol2tp_session with RCU
  (bsc#1076830).
- ipv6: addrconf: increment ifp refcount before ipv6_del_addr()
  (bsc#1076830).
- l2tp: hold tunnel in pppol2tp_connect() (bsc#1076830).
- ipv6: fix net.ipv6.conf.all.accept_dad behaviour for real
  (bsc#1076830).
  Refresh
  patches.fixes/net-ipv6-send-unsolicited-NA-after-DAD.patch
- l2tp: fix race between l2tp_session_delete() and
  l2tp_tunnel_closeall() (bsc#1076830).
- l2tp: ensure sessions are freed after their PPPOL2TP socket
  (bsc#1076830).
- ipv6: fix net.ipv6.conf.all interface DAD handlers
  (bsc#1076830).
- net: ipv6: fix regression of no RTM_DELADDR sent after DAD
  failure (bsc#1076830).
- net: don't decrement kobj reference count on init failure
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: do not hold dev (bsc#1076830).
- commit 5f23ad9
* Thu Mar  1 2018 mhocko@suse.com
- Remove page cache limit (fate#323778)
- Delete patches.suse/mm-uninline-add-to-page-cache.patch.
- Delete patches.suse/pagecache-limit-dirty.diff.
- Delete patches.suse/pagecache-limit-fix-get_nr_swap_pages.patch.
- Delete patches.suse/pagecache-limit-fix-shmem-deadlock.patch.
- Delete
  patches.suse/pagecache-limit-reduce-zone-lrulock-bouncing.patch.
- Delete patches.suse/pagecache-limit-unmapped.diff.
- Delete patches.suse/pagecache-limit-warn-on-usage.patch.
- Delete patches.suse/pagecache-limit.patch.
- Delete patches.suse/pagecachelimit_batch_huge_nr_to_scan.patch.
- commit d39d94a
* Thu Mar  1 2018 mkubecek@suse.cz
- blacklist.conf: add two commits
  d5902f6d1fbd - a merge commit (we have both commits from the branch)
  fae8b6f4a6be - fixes comments
- commit 9b213a5
* Thu Mar  1 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch.
- commit df1695c
* Thu Mar  1 2018 bpoirier@suse.com
- Refresh
  patches.drivers/ibmvnic-Fix-early-release-of-login-buffer.patch.
- commit 70a1572
* Wed Feb 28 2018 jack@suse.cz
- ocfs2: should wait dio before inode lock in ocfs2_setattr()
  (bsc#1083244 CVE-2017-18204).
- commit f78f4f7
* Wed Feb 28 2018 oneukum@suse.com
- xhci: Don't show incorrect WARN message about events for empty
  rings (bsc#1068674).
- commit 2728c81
* Wed Feb 28 2018 msuchanek@suse.de
- bs-upload-kernel: do not set %%opensuse_bs
  Since SLE15 it is not set in the distribution project so do not set it
  for kernel projects either.
- commit d696aa0
* Wed Feb 28 2018 msuchanek@suse.de
- ibmvnic: Do not attempt to login if RX or TX queues are not
  allocated (bsc#1082993).
- ibmvnic: Report queue stops and restarts as debug output
  (bsc#1082993).
- ibmvnic: Harden TX/RX pool cleaning (bsc#1082993).
- ibmvnic: Allocate statistics buffers during probe (bsc#1082993).
- ibmvnic: Fix TX descriptor tracking again (bsc#1082993).
- commit 953c6c5
* Wed Feb 28 2018 oneukum@suse.com
- media: usbtv: prevent double free in error case (bsc#1074426
  CVE-2017-17975).
- commit b36e4d6
* Wed Feb 28 2018 msuchanek@suse.de
- Move cdrom patches to storage section.
- cdrom: turn off autoclose by default (bsc#1080813).
- commit 3c15342
* Wed Feb 28 2018 jack@suse.cz
- fs/dax.c: release PMD lock even when there is no PMD support
  in DAX (bsc#1052766).
- commit 4806870
* Wed Feb 28 2018 jack@suse.cz
- ocfs2: return error when we attempt to access a dirty bh in jbd2
  (bsc#1052766).
- commit aeb7ce9
* Wed Feb 28 2018 jack@suse.cz
- fscache: Fix the default for fscache_maybe_release_page()
  (bsc#1052766).
- commit 45cac8c
* Wed Feb 28 2018 jack@suse.cz
- orangefs: off by ones in xattr size checks (bsc#1052766).
- commit caf695e
* Wed Feb 28 2018 jack@suse.cz
- f2fs: trigger normal fsync for non-atomic_write file
  (bsc#1052766).
- commit 8f867cc
* Wed Feb 28 2018 oneukum@suse.com
- HID: rmi: Make sure the HID device is opened on resume
  (bsc#1081188).
- commit c315d03
* Wed Feb 28 2018 tbogendoerfer@suse.de
- net: mvneta: eliminate wrong call to handle rx descriptor error
  (fate#319899).
- net: mvneta: use proper rxq_number in loop on rx queues
  (fate#319899).
- net: mvneta: fix handling of the Tx descriptor counter
  (fate#319899).
- commit 24508d7
* Wed Feb 28 2018 tbogendoerfer@suse.de
- ip6_gre: remove the incorrect mtu limit for ipgre tap
  (bsc#1056787).
- ip_gre: remove the incorrect mtu limit for ipgre tap
  (bsc#1056787).
- i40iw: Reinitialize IEQ on MTU change (bsc#1058659 FATE#322535).
- commit 426bcab
* Wed Feb 28 2018 tiwai@suse.de
- drm: fix tainted kernel caused by drm_panel_orientation_quirks.c
  (bsc#1083215).
- commit b67ad61
* Wed Feb 28 2018 jeffm@suse.com
- kernel: add product-identifying information to kernel build (FATE#325281).
- commit b163d4a
* Wed Feb 28 2018 jeffm@suse.com
- kconfig: move SUSE options from init/Kconfig to init/Kconfig.suse
- commit 8aa8057
* Wed Feb 28 2018 bpoirier@suse.com
- Refresh patch order in sorted section
- Refresh
  patches.drivers/ibmvnic-Check-for-NULL-skb-s-in-NAPI-poll-routine.patch.
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit 63c83e7
* Wed Feb 28 2018 lduncan@suse.com
- KEYS: reject NULL restriction string when type is specified
  (bsc#1082623).
- Fix misannotated out-of-line _copy_to_user() (bsc#1082625).
- commit bbdb58c
* Tue Feb 27 2018 neilb@suse.com
- Delete patches.suse/blk-timeout-no-round.
  The flag isn't actually being using, and
  probably isn't needed.
  Bug 768084 has lots of discussion about delays being a little too long,
  but I cannot find anything specific about this patch.
  I suspect the real concern what that the delay
  was longer than expected, and that maybe in different circumstances it
  could end up being much longer.  As the extra unexpected delay is
  limited to 1 second, it is probably safe.
- commit 7adce7e
* Tue Feb 27 2018 jack@suse.cz
- Update tags in
  patches.fixes/ext4-Fix-ENOSPC-handling-in-DAX-page-fault-handler.patch.
- commit 2d083b7
* Tue Feb 27 2018 jbohac@suse.cz
- x86/platform/UV: Add check of TSC state set by UV BIOS
  (bsc#1082579).
- x86/tsc: Add option that TSC on Socket 0 being non-zero is valid
  (bsc#1082579).
- x86/tsc: Drastically reduce the number of firmware bug warnings
  (bsc#1082579).
- x86/tsc: Make CONFIG_X86_TSC=n build work again (bsc#1082579).
- x86/tsc: Provide a means to disable TSC ART (bsc#1082579).
- x86/tsc: Skip TSC test and error messages if already unstable
  (bsc#1082579).
- commit 9667786
* Tue Feb 27 2018 ddiss@suse.de
- target/rbd: use target_configure_unmap_from_queue() helper
  (bsc#1064320).
- target/rbd: handle zero length UNMAP requests early
  (bsc#1064320).
- commit 15a71ab
* Tue Feb 27 2018 ddiss@suse.de
- ceph: fix rebased xattr and cmpext support (bsc#1082443)
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch.
- Refresh
  patches.drivers/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-cmpsetxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-setxattr.patch.
- commit 8add4f9
* Tue Feb 27 2018 msuchanek@suse.de
- ibmvnic: Fix early release of login buffer (bsc#1081134,
  git-fixes).
- commit c7b7dcd
* Tue Feb 27 2018 msuchanek@suse.de
- Revert "rpm/kernel-binary.spec.in: Also require m4 for build."
  This reverts commit 0d7b4b3f948c2efb67b7d1b95b5e1dcae225991c.
- commit f5686d2
* Tue Feb 27 2018 jeffm@suse.com
- btrfs: account for pinned bytes in should_alloc_chunk
  (bsc#1040182).
- commit fc228ad
* Tue Feb 27 2018 jeffm@suse.com
- housekeeping: move suse-only out-of-tree patches after sorted section
- commit 2b8141c
* Tue Feb 27 2018 mhocko@suse.com
- Update
  patches.fixes/mm-oom_reaper-gather-each-vma-to-prevent-leaking-TLB.patch
  (bnc#1073258, bnc#1083088, CVE-2017-18202).
- commit f906298
* Tue Feb 27 2018 jeffm@suse.com
- housekeeping: move kABI fixes after sorted section
- commit ed8c9b1
* Tue Feb 27 2018 jthumshirn@suse.de
- nvme-pci: Fix timeouts in connecting state (FATE#323952,
  FATE#322506).
- commit 10ad0a0
* Tue Feb 27 2018 jthumshirn@suse.de
- nvme: rename NVME_CTRL_RECONNECTING state to
  NVME_CTRL_CONNECTING (FATE#323952, FATE#322506).
- Refresh patches.drivers/nvme_fc-cleanup-io-completion.patch.
- Refresh
  patches.drivers/nvme_fc-correct-abort-race-condition-on-resets.patch.
- commit c1726a2
* Tue Feb 27 2018 nborisov@suse.com
- btrfs: finish ordered extent cleaning if no progress is found (bsc#1082964).
- commit d584b06
* Tue Feb 27 2018 tiwai@suse.de
- kernel-binary: do not package extract-cert when not signing modules
  (boo#1080250).
- commit 10a8bc4
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move kbuild/supported patches after sorted section
- commit 20e13fb
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved SUSE-specific performance fixes after sorted section
- commit e4df9c8
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move driver core patch after sorted section
- commit c3bf010
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move cpufreq patches to sorted section
- commit 689ded1
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: remove empty sections
- commit 96041ef
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move scheduler/core patches to sorted section
- commit c8094ad
* Mon Feb 26 2018 tbogendoerfer@suse.de
- net_sched: gen_estimator: fix broken estimators based on percpu
  stats (bsc#1056787).
- net/mlx5: Add header re-write to the checks for conflicting
  actions (bsc#1046305 FATE#322943).
- net/mlx5: Use 128B cacheline size for 128B or larger cachelines
  (bsc#1081944).
- net/mlx5e: Specify numa node when allocating drop rq
  (bsc#1046305 FATE#322943).
- net/mlx5e: Return error if prio is specified when offloading
  eswitch vlan push (bsc#1046305 FATE#322943).
- net/mlx5e: Verify inline header size do not exceed SKB linear
  size (bsc#1046305 FATE#322943).
- net/mlx5e: Fix loopback self test when GRO is off (bsc#1046305
  FATE#322943).
- net/mlx5e: Fix TCP checksum in LRO buffers (bsc#1046305
  FATE#322943).
- RDMA/vmw_pvrdma: Fix usage of user response structures in ABI
  file (bsc#1046306 FATE#322942).
- RDMA/uverbs: Sanitize user entered port numbers prior to access
  it (bsc#1046306 FATE#322942).
- RDMA/uverbs: Fix circular locking dependency (bsc#1046306
  FATE#322942).
- RDMA/uverbs: Fix bad unlock balance in ib_uverbs_close_xrcd
  (bsc#1046306 FATE#322942).
- IB/uverbs: Fix unbalanced unlock on error path for
  rdma_explicit_destroy (bsc#1046306 FATE#322942).
- IB/uverbs: Hold the uobj write lock after allocate (bsc#1046306
  FATE#322942).
- IB/uverbs: Fix method merging in uverbs_ioctl_merge (bsc#1046306
  FATE#322942).
- PCI/cxgb4: Extend T3 PCI quirk to T4+ devices (bsc#1064802
  bsc#1066129).
- cxgb4: fix trailing zero in CIM LA dump (bsc#1064802
  bsc#1066129).
- commit 2727999
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move locking/core patches to sorted section
- commit 023fb41
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved s390 patches to sorted section
- commit fba6ff3
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move x86 patches to sorted section
- commit 484f12c
* Mon Feb 26 2018 tbogendoerfer@suse.de
- Re-sorted series
- Refresh
  patches.drivers/ibmvnic-Check-for-NULL-skb-s-in-NAPI-poll-routine.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit 9b71c59
* Mon Feb 26 2018 tiwai@suse.de
- nl80211: take RCU read lock when calling ieee80211_bss_get_ie()
  (bsc#1051510).
- nl80211: fix nl80211_send_iface() error paths (bsc#1051510).
- commit d8941e6
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move VM/FS patches to sorted section
- commit 1fd8e1f
* Mon Feb 26 2018 tiwai@suse.de
- blacklist.conf: add a media blacklist
- commit a3cbc5c
* Mon Feb 26 2018 tiwai@suse.de
- extcon: int3496: process id-pin first so that we start with
  the right status (bsc#1051510).
- ALSA: usb-audio: Fix UAC2 get_ctl request with a RANGE attribute
  (bsc#1051510).
- media: exynos4-is: properly initialize frame format
  (bsc#1051510).
- media: cpia2: Fix a couple off by one bugs (bsc#1051510).
- Input: 88pm860x-ts - fix child-node lookup (bsc#1051510).
- Input: twl6040-vibra - fix child-node lookup (bsc#1051510).
- Input: twl4030-vibra - fix sibling-node lookup (bsc#1051510).
- cfg80211: fix station info handling bugs (bsc#1051510).
- cfg80211: check dev_set_name() return value (bsc#1051510).
- mfd: twl6040: Fix child-node lookup (bsc#1051510).
- mfd: twl4030-audio: Fix sibling-node lookup (bsc#1051510).
- nl80211: don't expose wdev->ssid for most interfaces
  (bsc#1051510).
- Documentation/sphinx: fix kernel-doc decode for non-utf-8 locale
  (bsc#1051510).
- [media] dvb uapi docs: enums are passed by value, not reference
  (bsc#1051510).
- Docs: Fix breakage with Sphinx 1.5 and upper (bsc#1051510).
- Docs: Include the Latex "ifthen" package (bsc#1051510).
- commit d06484d
* Mon Feb 26 2018 tiwai@suse.de
- drm/vmwgfx: fix memory corruption with legacy/sou connectors
  (bsc#1051510).
- drm/atomic: Unref duplicated drm_atomic_state in
  drm_atomic_helper_resume() (bsc#1051510).
- commit 18be9dc
* Mon Feb 26 2018 tiwai@suse.de
- blacklist.conf: add duplicated (cherry-picked) commits
- commit 4abafa8
* Mon Feb 26 2018 tiwai@suse.de
- blacklist.conf: Update drm blacklists
  They can't be applied because of the lack of some DRM stuff
- commit 92abf6d
* Mon Feb 26 2018 tiwai@suse.de
- mac80211: fix calling sleeping function in atomic context
  (bsc#1051510).
- mac80211: fix a possible leak of station stats (bsc#1051510).
- cfg80211: fix cfg80211_beacon_dup (bsc#1051510).
- PKCS#7: fix direct verification of SignerInfo signature
  (bsc#1051510).
- PKCS#7: fix certificate blacklisting (bsc#1051510).
- PKCS#7: fix certificate chain verification (bsc#1051510).
- i2c: designware: must wait for enable (bsc#1051510).
- drm: Handle unexpected holes in color-eviction (bsc#1051510).
- drm/edid: Add 6 bpc quirk for CPT panel in Asus UX303LA
  (bsc#1051510).
- drm/atomic: Fix memleak on ERESTARTSYS during non-blocking
  commits (bsc#1051510).
- drm/cirrus: Load lut in crtc_commit (bsc#1051510).
- drm: cirrus: remove dead code and pointless local lut storage
  (bsc#1051510).
- commit ff526a9
* Mon Feb 26 2018 tiwai@suse.de
- Preliminary series sort / updates
- commit 91ac254
* Mon Feb 26 2018 msuchanek@suse.de
- powerpc/powernv: Support firmware disable of RFI flush
  (bsc#1068032).
- powerpc/pseries: Support firmware disable of RFI flush
  (bsc#1068032).
- commit cfd8a20
* Mon Feb 26 2018 msuchanek@suse.de
- powerpc/mm/drmem: Fix unexpected flag value in
  ibm,dynamic-memory-v2 (FATE#324825, bsc#1077428).
- commit 2c4ae37
* Mon Feb 26 2018 bp@suse.de
- media: hdpvr: Fix an error handling path in hdpvr_probe()
  (bsc#1067118 CVE-2017-16644).
- commit 487f60d
* Mon Feb 26 2018 jlee@suse.com
- KEYS: prevent creating a different user's keyrings
  (bnc#1065999).
- commit 29ba1a4
* Mon Feb 26 2018 nborisov@suse.com
- f2fs: fix a bug caused by NULL extent tree (bsc#1082478).
- commit 1902646
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move IPC patches to sorted section
- commit 3d6c0d8
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved small misc fixes to sorted section
- commit 2dae190
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: moved ACPI patches to sorted section
- commit 6332c79
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move hyperv patches to sorted section
- commit 0cbd157
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move ocfs2/dlm patches to sorted section
- commit 7a0f77b
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move arm patches into sorted section
  There is a code change here, but it matches what the upstream ordering is.
- commit e55cbe7
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move driver patches to sorted section
- commit 2167086
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move cifs patches to sorted section
- commit 648f4e7
* Mon Feb 26 2018 jeffm@suse.com
- housekeeping: move epoll and lib patches to sorted section
- commit 435924b
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move powerpc patches to sorted section
- commit 5f0255b
* Sun Feb 25 2018 jthumshirn@suse.de
- scsi: lpfc: Change Copyright of 12.0.0.0 modified files to 2018
  (bsc#1082595).
- scsi: lpfc: update driver version to 12.0.0.0 (bsc#1082595).
- scsi: lpfc: Work around NVME cmd iu SGL type (bsc#1082595).
- scsi: lpfc: Fix nvme embedded io length on new hardware
  (bsc#1082595).
- scsi: lpfc: Add embedded data pointers for enhanced performance
  (bsc#1082595).
- scsi: lpfc: Enable fw download on if_type=6 devices
  (bsc#1082595).
- scsi: lpfc: Add if_type=6 support for cycling valid bits
  (bsc#1082595).
- scsi: lpfc: Add 64G link speed support (bsc#1082595).
- scsi: lpfc: Add PCI Ids for if_type=6 hardware (bsc#1082595).
- scsi: lpfc: Add push-to-adapter support to sli4 (bsc#1082595).
- scsi: lpfc: Add SLI-4 if_type=6 support to the code base
  (bsc#1082595).
- scsi: lpfc: Rework sli4 doorbell infrastructure (bsc#1082595).
- scsi: lpfc: Rework lpfc to allow different sli4 cq and eq
  handlers (bsc#1082595).
- scsi: scsi_transport_fc: fix typos on 64/128 GBit define names
  (bsc#1082595).
- commit baa2a7f
* Sun Feb 25 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Check-for-NULL-skb-s-in-NAPI-poll-routine.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit fae1c5f
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move storage patches into sorted section
- commit cab2152
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move v4l patches to sorted section
- commit 5947eb8
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move random patch to sorted section
- commit f7c56ff
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move spectre/meltdown fixes to sorted section
- commit 425c053
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move xen patches to sorted section
- commit 193f238
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move livepatching to sorted section
- commit 32b7773
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: movw sysctl selftests to sorted section
- commit 21d7c50
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move sysctl patches to sorted section
- commit 5453ebc
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move iommu patches to sorted section
- commit 5ed331f
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move perf patches to sorted section
- commit e4f7f31
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move kdump patches to sorted section
- commit 32d312b
* Sun Feb 25 2018 jeffm@suse.com
- housekeeping: move objtool patches to sorted section
- commit cb30180
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move some modsign patches into sorted section
- commit 69f402d
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move crypto patches to sorted section
- commit 2f5e73f
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move security patches to sorted section
- commit 7826f37
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move md patches to sorted section
- commit 0d60c5b
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move suspend/resume patches to sorted section
- commit eb55162
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: moved other drivers to sorted section
- commit d00ddbb
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move printk patches to sorted section
- commit a3b711d
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: moved input patches to sorted section
- commit e6a3294
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move serial patches to sorted section
- commit 7439018
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move I2C patches to sorted section
- commit 81970be
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move PCI patches to sorted section
- commit bc33814
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move thunderbolt patches to sorted section
- commit ceb04da
* Sat Feb 24 2018 jeffm@suse.com
- housekeeping: move USB to sorted section
- commit 6f2b28e
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move intel-drm to sorted section
- commit ad78bb9
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: rename some fs patches
- commit 14854d5
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move other file system patches into sorted section
- commit d6e80d0
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move apparmor to sorted section
- commit eb353f7
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move NFS to sorted section
- commit eb19955
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: move cephfs patches into sorted section
- commit c1e3883
* Fri Feb 23 2018 msuchanek@suse.de
- git_sort: add powerpc/fixes branch.
- commit efaef8c
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: relocate xfs, btrfs, reiserfs, and ext4 patches to sorted
- commit 667c204
* Fri Feb 23 2018 mwilck@suse.com
- Update and enable
  patches.suse/scsi-do-not-print-reservation-conflict-for-TEST-UNIT.patch
  (bsc#1027054, bsc#1082587).
- commit c6ccd44
* Fri Feb 23 2018 mwilck@suse.com
- Enable patches.fixes/sd-always-scan-VPD-pages-if-thin-provisioning-is-ena.patch (bsc#1013792, bsc#1082587).
- commit 83c00c1
* Fri Feb 23 2018 jeffm@suse.com
- housekeeping: update tags and resort series
- commit 1f975c7
* Fri Feb 23 2018 mwilck@suse.com
- Refresh and enable
  patches.fixes/sd-always-retry-READ-CAPACITY-for-ALUA-state-transit.patch (bsc#1082587, bsc#895814).
- commit 426325e
* Fri Feb 23 2018 aaptel@suse.com
- refresh patch to fix build when SMB2 disabled
- commit e54b17e
* Fri Feb 23 2018 mwilck@suse.com
- Refresh and enable
  patches.fixes/scsi-disable-VPD-page-check-on-error.patch (bsc#1082587,
  bsc#981854).
- commit 53727b5
* Fri Feb 23 2018 mwilck@suse.com
- Delete
  patches.suse/scsi-always-retry-internal-target-error.patch (bsc#1082587).
  This one is superseded by
  patches.fixes/scsi-handle-special-return-codes-for-ABORTED-COMM.patch
- commit 62ad20c
* Fri Feb 23 2018 mwilck@suse.com
- Delete patches.suse/aacraid-export-fixed-module-param (bsc#1082587).
  This patch has a comment: "should be dropped in SLES13".
  Thus dropping it.
- commit 5794c6c
* Fri Feb 23 2018 mwilck@suse.com
- Refresh and enable
  patches.fixes/scsi_scan-Send-TEST-UNIT-READY-to-LUN0-before-LUN-sc.patch (bnc#843236, bnc#893377, bsc#1063043).
- commit 1972fc8
* Fri Feb 23 2018 msuchanek@suse.de
- blacklist
  171360d7800c tpm: fix type of a local variable in tpm2_get_cc_attrs_tbl()
  1a7a9b26c69d tpm: fix type of a local variables in tpm_tis_spi.c
  4557d4bedc9c tpm: fix type of a local variable in tpm2_map_command()
  These only add endian annotation to variables.
- commit 5804018
* Fri Feb 23 2018 msuchanek@suse.de
- tpm_tis_spi: Use DMA-safe memory for SPI transfers
  (bsc#1082555).
- tpm: constify transmit data pointers (bsc#1082555).
- tpm/tpm_crb: fix priv->cmd_size initialisation (bsc#1082555).
- tpm_tis: Use platform_get_irq (bsc#1082555).
- tpm_tis: Fix IRQ autoprobing when using platform_device
  (bsc#1082555).
- commit 8ed9550
* Fri Feb 23 2018 mwilck@suse.com
- scsi: handle special return codes for ABORTED COMMAND
  (bsc#1069138, bnc#745640, bnc#825227).
- commit 291f96e
* Fri Feb 23 2018 mwilck@suse.com
- Refresh
  patches.drivers/scsi-megaraid_sas-Do-not-use-32-bit-atomic-request-d.patch.
- commit d3bb77b
* Fri Feb 23 2018 mbrugger@suse.com
- drivers/fbdev/efifb: Allow BAR to be moved instead of claiming
  it (fate#323912).
- IB/hns: checking for IS_ERR() instead of NULL (fate#323912).
- arm64: sysreg: Fix unprotected macro argmuent in write_sysreg
  (fate#323912).
- efi/fb: Correct PCI_STD_RESOURCE_END usage (fate#323912).
- commit 8bc4586
* Fri Feb 23 2018 jthumshirn@suse.de
- nfit_test Make private definitions to command emulation
  (bsc#1082491).
- commit 05aa73b
* Fri Feb 23 2018 jthumshirn@suse.de
- Re-sort series.conf
- commit 5d633e1
* Fri Feb 23 2018 jkosina@suse.cz
- Update config files: KEXEC_VERIFY_SIG=n for x86 vanilla
- commit c240e03
* Fri Feb 23 2018 mkubecek@suse.cz
- bpf: fix stack_depth usage by test_bpf.ko (bsc#1081174
  bsc#1081380).
- bpf: track stack depth of classic bpf programs (bsc#1081174
  bsc#1081380).
- commit 78f0fd9
* Fri Feb 23 2018 mkubecek@suse.cz
- series.conf: refresh
  Ran series_sort.py (no effect on expanded tree).
- commit 8f7ddd5
* Fri Feb 23 2018 bp@suse.de
- EDAC, thunderx: Fix error handling path in thunderx_lmc_probe()
  (bsc#1057038).
- blacklist.conf:
- EDAC, thunderx: Fix a warning during l2c debugfs node creation
  (bsc#1057038).
- EDAC, sb_edac: Don't create a second memory controller if HA1
  is not present (bsc#1061721).
- EDAC, sb_edac: Classify memory mirroring modes (bsc#1061721).
- EDAC, sb_edac: Avoid creating SOCK memory controller
  (bsc#1061721).
- EDAC, sb_edac: Bump driver version and do some cleanups
  (bsc#1061721).
- EDAC, sb_edac: Check if ECC enabled when at least one DIMM is
  present (bsc#1061721).
- EDAC, sb_edac: Carve out dimm-populating loop (bsc#1061721).
- EDAC, sb_edac: Assign EDAC memory controller per h/w controller
  (bsc#1061721).
- EDAC, sb_edac: Don't use "Socket#" in the memory controller name
  (bsc#1061721).
- EDAC, sb_edac: Classify PCI-IDs by topology (bsc#1061721).
- EDAC, skx_edac: Handle systems with segmented PCI busses
  (bsc#1076447).
- EDAC, skx_edac: Fix detection of single-rank DIMMs
  (bsc#1076447).
- x86/cpu/amd: Limit cpu_core_id fixup to families older than F17h
  (bsc#1060229).
- commit 8fc298f
* Fri Feb 23 2018 hare@suse.de
- dm mpath: remove annoying message of 'blk_get_request()
  returned -11' (bsc#1077989).
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit a7c32d7
* Fri Feb 23 2018 jthumshirn@suse.de
- acpi, nfit: fix register dimm error handling (bsc#1082491).
- acpi, nfit: fix health event notification (bsc#1082491).
- acpi/nfit: Issue Start ARS to retrieve existing records
  (bsc#1082491).
- acpi/nfit: Add support of NVDIMM memory error notification in
  ACPI 6.2 (bsc#1082491).
- commit 1a9ab53
* Fri Feb 23 2018 hare@suse.de
- scsi: bnx2fc: Simplify CPU hotplug code (bsc#1077989). - Refresh patches.drivers/scsi-bnx2i-simplify-cpu-hotplug-code.
- commit c6b20e3
* Fri Feb 23 2018 hare@suse.de
- scsi: scsi_dh: suppress errors from unsupported devices (bsc#1077989).
- scsi: scsi_dh: Return SCSI_DH_XX error code from ->attach() (bsc#1077989).
- scsi: fc: check for rport presence in fc_block_scsi_eh (bsc#1077989).
- scsi: scsi_transport_fc: Also check for NOTPRESENT in fc_remote_port_add() (bsc#1077989).
- scsi: scsi_transport_fc: set scsi_target_id upon rescan (bsc#1077989).
- commit ca27253
* Fri Feb 23 2018 jthumshirn@suse.de
- scsi: aacraid: Fix hang in kdump (bsc#1077989).
- scsi: aacraid: Check for PCI state of device in a generic way
  (bsc#1077989).
- commit 9736167
* Fri Feb 23 2018 hare@suse.de
- Drop superseded SUSE-specific patches
- Delete
  patches.drivers/qla2xxx-0040-Add-module-parameter-for-interrupt-mode.patch.
- Delete patches.fixes/scsi-Add-AIX-VDASD-to-blacklist.patch.
- Delete
  patches.fixes/scsi-Handle-power-on-reset-unit-attention.patch.
- Delete patches.fixes/scsi-Modify-HITACHI-OPEN-V-blacklist.patch.
- Delete
  patches.fixes/scsi-do-not-retry-invalid-function-error.patch.
- commit 2f21950
* Fri Feb 23 2018 jthumshirn@suse.de
- scsi: lpfc: Use after free in lpfc_rq_buf_free() (bsc#1077989).
- Refresh
  patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- commit dba777c
* Fri Feb 23 2018 hare@suse.de
- scsi: qedf: Fix error return code in __qedf_probe()
  (bsc#1077989).
- scsi: mpt3sas: Proper handling of set/clear of "ATA command
  pending" flag (bsc#1077989).
- scsi: fnic: add a space after %%p in printf format (bsc#1077989).
- scsi: devinfo: replace "Dell PV 650F" with "EMC CLARiiON"
  (bsc#1077989).
- scsi: dh: add new rdac devices (bsc#1077989).
- scsi: devinfo: apply to HP XP the same flags as Hitachi VSP
  (bsc#1077989).
- scsi: devinfo: Apply to HP-rebranded the same flags as Hitachi
  (bsc#1077989).
- scsi: pmcraid: use correct size unit when calling
  find_first_zero_bit() (bsc#1077989).
- scsi: ibmvscsis: add DRC indices to debug statements
  (bsc#1077989).
- block: fix blk_rq_append_bio (bsc#1077989).
- scsi: aacraid: Fix I/O drop during reset (bsc#1077989).
- scsi: aacraid: Prevent crash in case of free interrupt during
  scsi EH path (bsc#1077989).
- scsi: aacraid: Perform initialization reset only once
  (bsc#1077989).
- scsi: aacraid: Check for PCI state of device in a generic way
  (bsc#1077989).
- scsi: bnx2fc: Fix hung task messages when a cleanup response
  is not received during abort (bsc#1077989).
- cxlflash: get rid of pointless access_ok() (bsc#1077989).
- scsi: scsi_error: DID_SOFT_ERROR comment clean up (bsc#1077989).
- scsi: cxlflash: Derive pid through accessors (bsc#1077989).
- scsi: cxlflash: Allow cards without WWPN VPD to configure
  (bsc#1077989).
- scsi: cxlflash: Use derived maximum write same length
  (bsc#1077989).
- scsi: scsi_devinfo: Add scsi_devinfo_tbl.c (bsc#1077989).
- scsi: hpsa: bump driver version (bsc#1077989).
- scsi: hpsa: add enclosure logical identifier (bsc#1077989).
- scsi: hpsa: correct logical volume removal (bsc#1077989).
- scsi: hpsa: reduce warning messages on device removal
  (bsc#1077989).
- scsi: hpsa: update queue depth for externals (bsc#1077989).
- scsi: hpsa: correct smart path enabled (bsc#1077989).
- scsi: hpsa: change timeout for internal cmds (bsc#1077989).
- scsi: hpsa: update discovery polling (bsc#1077989).
- scsi: hpsa: add controller checkpoint (bsc#1077989).
- scsi: hpsa: clear tmpdevice in scan thread (bsc#1077989).
- scsi: hpsa: cleanup sas_phy structures in sysfs when unloading
  (bsc#1077989).
- scsi: hpsa: destroy sas transport properties before scsi_host
  (bsc#1077989).
- scsi: scsi_error: Handle power-on reset unit attention
  (bsc#1077989).
- scsi: scsi_error: Do not retry illegal function error
  (bsc#1077989).
- scsi: sd: change manage_start_stop to bool in sysfs interface
  (bsc#1077989).
- scsi: sd: change allow_restart to bool in sysfs interface
  (bsc#1077989).
- scsi: scsi: Export blacklist flags to sysfs (bsc#1077989).
- scsi: sd_zbc: Fix sd_zbc_read_zoned_characteristics()
  (bsc#1077989).
- scsi: sd_zbc: Use well defined macros (bsc#1077989).
- scsi: sd_zbc: Rearrange code (bsc#1077989).
- scsi: sd_zbc: Fix comments and indentation (bsc#1077989).
- scsi: sd_zbc: Move ZBC declarations to scsi_proto.h
  (bsc#1077989).
- scsi: libcxgbi: in case of vlan pass 0 as ifindex to find route
  (bsc#1077989).
- scsi: sd: Align maximum write same blocks to physical block size
  (bsc#1077989).
- scsi: csiostor: enable PCIe relaxed ordering if supported
  (bsc#1077989).
- scsi: libcxgbi: remove redundant check and close on csk
  (bsc#1077989).
- scsi: fcoe: open-code fcoe_destroy_work() for NETDEV_UNREGISTER
  (bsc#1077989).
- scsi: fcoe: separate out fcoe_vport_remove() (bsc#1077989).
- scsi: fcoe: move fcoe_interface_remove() out of
  fcoe_interface_cleanup() (bsc#1077989).
- scsi: bnx2i: Clean up unused pointers in bnx2i_hwi
  (bsc#1077989).
- block: Make q_usage_counter also track legacy requests
  (bsc#1077989).
- =?UTF-8?q?scsi:=20hpsa:=20Fix=20configured=5Flogical=5Fdr?=
  =?UTF-8?q?ive=5Fcount=C2=B7check?= (bsc#1077989).
- scsi: ibmvscsis: Fix write_pending failure path (bsc#1077989).
- scsi: libiscsi: Remove iscsi_destroy_session (bsc#1077989).
- scsi: libiscsi: Fix use-after-free race during
  iscsi_session_teardown (bsc#1077989).
- scsi: sd: Implement blacklist option for WRITE SAME w/ UNMAP
  (bsc#1077989).
- scsi: ILLEGAL REQUEST + ASC==27 => target failure (bsc#1077989).
- scsi: aacraid: Fix 2T+ drives on SmartIOC-2000 (bsc#1077989).
- scsi: Fix the kerneldoc for scsi_initialize_rq() (bsc#1077989).
- scsi: Use blk_mq_rq_to_pdu() to convert a request to a SCSI
  command pointer (bsc#1077989).
- scsi: Document which queue type a function is intended for
  (bsc#1077989).
- scsi: Convert a strncmp() call into a strcmp() call
  (bsc#1077989).
- scsi: Suppress gcc 7 fall-through warnings reported with W=1
  (bsc#1077989).
- scsi: ufs: reqs and tasks were put in the wrong order
  (bsc#1077989).
- scsi: pmcraid: fix duplicated code for different branches
  (bsc#1077989).
- scsi: sym53c8xx: Avoid undefined behaviour (bsc#1077989).
- scsi: virtio: virtio_scsi: Set can_queue to the length of the
  virtqueue (bsc#1077989).
- scsi: mvsas: replace kfree with scsi_host_put (bsc#1077989).
- scsi: esp_scsi: Always clear msg_out_len after MESSAGE OUT phase
  (bsc#1077989).
- scsi: esp_scsi: Avoid sending ABORT TASK SET messages
  (bsc#1077989).
- scsi: esp_scsi: Clean up control flow and dead code
  (bsc#1077989).
- scsi: libcxgbi: use ndev->ifindex to find route (bsc#1077989).
- scsi: mpt3sas: Fix memory allocation failure test in
  'mpt3sas_base_attach()' (bsc#1077989).
- scsi: mpt3sas: fix format overflow warning (bsc#1077989).
- scsi: sg: off by one in sg_ioctl() (bsc#1077989).
- scsi: cxgb4i: call neigh_event_send() to update MAC address
  (bsc#1077989).
- scsi: bnx2fc: Prevent recursive cpuhotplug locking
  (bsc#1077989).
- scsi: bnx2fc: Plug CPU hotplug race (bsc#1077989).
- ibmvscsis: Use tpgt passed in by user (bsc#1077989).
- ibmvscsis: Enable Logical Partition Migration Support
  (bsc#1077989).
- scsi: hpsa: fix spelling mistake: "encrypytion" -> "encryption"
  (bsc#1077989).
- scsi: hptiop: make function hptiop_iop_request_callback_itl
  static (bsc#1077989).
- scsi: esas2r: Replace semaphore fs_api_semaphore with mutex
  (bsc#1077989).
- scsi: esas2r: Replace semaphore fm_api_semaphore with mutex
  (bsc#1077989).
- scsi: libiscsi: use kvzalloc for iscsi_pool_init (bsc#1077989).
- scsi: ibmvscsi_tgt: remove use of class_attrs (bsc#1077989).
- commit eb5e851
* Fri Feb 23 2018 jslaby@suse.cz
- blacklist.conf: add some fixes from 12SP3
- commit 3559625
* Fri Feb 23 2018 ddiss@suse.de
- Update config files (bsc#1082443).
- commit ae8d93d
* Fri Feb 23 2018 ddiss@suse.de
- target/rbd: rebase and reapply LIO+RBD patch set (bsc#1082443).
- Refresh
  patches.drivers/ceph-osd_client-add-support-for-CEPH_OSD_OP_GETXATTR.patch.
- Refresh
  patches.drivers/libceph-add-scatterlist-messenger-data-type.patch.
- Refresh
  patches.drivers/libceph-add-support-for-CMPEXT-compare-extent-reques.patch.
- Refresh
  patches.drivers/libceph-add-support-for-write-same-requests.patch.
- Refresh patches.drivers/libceph-fix-pr_fmt-compile-issues.patch.
- Refresh
  patches.drivers/rbd-add-cmpsetattr-device-attribute-for-debugging.patch.
- Refresh
  patches.drivers/rbd-add-getxattr-device-attribute-for-debugging.patch.
- Refresh patches.drivers/rbd-add-lio-specific-data-area.patch.
- Refresh patches.drivers/rbd-add-num-ops-calculator-helper.patch.
- Refresh
  patches.drivers/rbd-add-rbd_dev_cmpsetxattr-helper.patch.
- Refresh patches.drivers/rbd-add-rbd_dev_getxattr-helper.patch.
- Refresh patches.drivers/rbd-add-rbd_dev_setxattr-helper.patch.
- Refresh
  patches.drivers/rbd-add-setxattr-device-attribute-for-debugging.patch.
- Refresh
  patches.drivers/rbd-add-support-for-COMPARE_AND_WRITE-CMPEXT.patch.
- Refresh
  patches.drivers/rbd-add-support-for-scatterlist-obj_request_type.patch.
- Refresh
  patches.drivers/rbd-add-support-for-writesame-requests.patch.
- Refresh patches.drivers/rbd-add-write-test-helper.patch.
- Refresh
  patches.drivers/rbd-export-some-functions-used-by-lio-rbd-backend.patch.
- Refresh
  patches.drivers/rbd-move-structs-used-by-lio-rbd-to-new-header.patch.
- Refresh
  patches.drivers/target-add-COMPARE_AND_WRITE-sg-creation-helper.patch.
- Refresh
  patches.drivers/target-add-compare-and-write-callback.patch.
- Refresh
  patches.drivers/target-add-lio-rbd-to-makefile-Kconfig.patch.
- Refresh patches.drivers/target-add-rbd-backend.patch.
- Refresh
  patches.drivers/target-compare-and-write-backend-driver-sense-handli.patch.
- Refresh
  patches.drivers/target-configfs-add-device-vendor_id-attribute.patch.
- Refresh
  patches.drivers/target-pr-add-backend-API-for-reservation-handling.patch.
- Refresh
  patches.drivers/target-pr-fix-core_scsi3_pr_seq_non-caller.patch.
- Refresh
  patches.drivers/target-pr-split-out-and-export-core_scsi3_pr_seq_non.patch.
- Refresh
  patches.drivers/target-rbd-SCSI3-check-conflict-support.patch.
- Refresh
  patches.drivers/target-rbd-add-SCSI2-reservation-entry-to-PR-info.patch.
- Refresh patches.drivers/target-rbd-add-pr_clear-support.patch.
- Refresh patches.drivers/target-rbd-add-pr_preempt-support.patch.
- Refresh
  patches.drivers/target-rbd-add-pr_read_reservation-support.patch.
- Refresh patches.drivers/target-rbd-add-pr_release-support.patch.
- Refresh
  patches.drivers/target-rbd-add-pr_report_capabilities-support.patch.
- Refresh patches.drivers/target-rbd-add-pr_reserve-support.patch.
- Refresh
  patches.drivers/target-rbd-add-stubbed-out-pr_read_full_status.patch.
- Refresh
  patches.drivers/target-rbd-add-stubbed-out-pr_register_and_move.patch.
- Refresh
  patches.drivers/target-rbd-add-support-for-PR-register-read-keys.patch.
- Refresh
  patches.drivers/target-rbd-fix-PR-info-memory-leaks.patch.
- Refresh
  patches.drivers/target-rbd-handle-SCSI2-reservation-release-on-reset.patch.
- Refresh
  patches.drivers/target-rbd-implement-SCSI2-reservation-handling.patch.
- Refresh
  patches.fixes/0001-rbd-drop-extra-rbd_img_request_get.patch.
- Refresh
  patches.fixes/0002-rbd-make-sure-pages-are-freed-by-libceph.patch.
- Refresh
  patches.fixes/libceph-fix-scatterlist-last_piece-calculation.patch.
- Refresh
  patches.fixes/libceph-use-upstream-write-same-opcode.patch.
- Refresh
  patches.fixes/rbd-copy-compare-and-write-osd-requests-before-resub.patch.
- Refresh
  patches.fixes/rbd-don-t-log-miscompare-as-an-error.patch.
- Refresh
  patches.fixes/rbd-handle-OBJ_REQUEST_SG-types-for-copyup.patch.
- Refresh
  patches.fixes/rbd-helper-to-copy-compare-and-write-osd-requests.patch.
- Refresh
  patches.fixes/rbd-truncate-objects-on-cmpext-short-reads.patch.
- Refresh
  patches.fixes/target-fix-tcm_rbd_gen_it_nexus-for-emulated-XCOPY-s.patch.
- Refresh
  patches.fixes/target-rbd-don-t-put-snap_context-twice.patch.
- Refresh patches.fixes/target-rbd-remove-caw_mutex-usage.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-cmpsetxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-getxattr.patch.
- Refresh
  patches.suse/rbd-do-away-with-obj_request-in-setxattr.patch.
- Delete
  patches.drivers/libceph-support-bidirectional-requests.patch.
- Delete
  patches.drivers/target-rbd-fix-COMPARE-AND-WRITE-page-vector-leak.patch.
- Delete
  patches.fixes/ceph-memory-leak-in-ceph_direct_read_write-callback.patch.
- Delete
  patches.fixes/rbd-ensure-r_request-is-allocated-for-creatrunc.patch.
- Delete
  patches.fixes/rbd-fix-and-simplify-rbd_osd_req_format_rw.patch.
- Delete
  patches.suse/libceph-handle-writefull-for-OSD-op-extent-init.patch.
- commit 813747a
* Fri Feb 23 2018 neilb@suse.com
- seq_file: fix incomplete reset on read from zero offset
  (git-fixes).
- kernfs: fix regression in kernfs_fop_write caused by wrong type
  (git-fixes).
- jffs2: Fix use-after-free bug in jffs2_iget()'s error handling
  path (git-fixes).
- xprtrdma: Fix BUG after a device removal (git-fixes).
- xprtrdma: Fix calculation of ri_max_send_sges (git-fixes).
- xprtrdma: Fix "bytes registered" accounting (git-fixes).
- xprtrdma: Fix backchannel allocation of extra rpcrdma_reps
  (git-fixes).
- NFS: Fix a race between mmap() and O_DIRECT (git-fixes).
- NFS: reject request for id_legacy key without auxdata
  (git-fixes).
- nfs: Do not convert nfs_idmap_cache_timeout to jiffies
  (git-fixes).
- nfsd: fix panic in posix_unblock_lock called from
  nfs4_laundromat (git-fixes).
- lockd: lost rollback of set_grace_period() in lockd_down_net()
  (git-fixes).
- lockd: double unregister of inetaddr notifiers (git-fixes).
- nfs: Fix ugly referral attributes (git-fixes).
- NFS: Optimize fallocate by refreshing mapping when needed
  (bsc#1033587).
- commit 3cc1a0a
* Fri Feb 23 2018 mcgrof@suse.com
- kernel/sysctl_binary.c: check name array length in
  deprecated_sysctl_warning() (FATE#323821).
- commit da77fbb
* Fri Feb 23 2018 mcgrof@suse.com
- Refresh
  patches.drivers/0006-test_sysctl-add-simple-proc_dointvec-case.patch.
- commit 9426899
* Fri Feb 23 2018 jbohac@suse.cz
- x86/gart: Exclude GART aperture from vmcore (bsc#1046513).
- commit 3a49197
* Thu Feb 22 2018 mcgrof@suse.com
- scripts/sequence-patch.sh: bump patch version req to v2.7
  While at it also update the way we compute the version so a way
  which is much more easier to read and maintain. We borrow the
  kernel's scripts/ld-version.sh which has been in use for ages.
- commit 8fe4408
* Thu Feb 22 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-Split-counters-for-scrq-pools-napi.patch.
  Add upstream commit hash
- commit 9eac9cb
* Thu Feb 22 2018 msuchanek@suse.de
- ibmvnic: Fix TX descriptor tracking (bsc#1081491).
- commit 87f9261
* Thu Feb 22 2018 jbohac@suse.cz
- kexec_file: Restrict at runtime if the kernel is locked down
  (fate#314486).
- kexec_file: split KEXEC_VERIFY_SIG into KEXEC_SIG and
  KEXEC_SIG_FORCE (fate#314486).
- Update config files.
- normalize return values of load_module with kernel lockdown
  patches.suse/0042-Enforce-module-signatures-if-the-kernel-is-locked-do.patch.
- Delete
  patches.suse/0047-kexec_file-Disable-at-runtime-if-securelevel-has-bee.patch.
- commit 61ff520
* Thu Feb 22 2018 rgoldwyn@suse.com
- userfaultfd: non-cooperative: fix fork use after free.
- commit 6637734
* Thu Feb 22 2018 jgross@suse.com
- xen/pvh*: Support > 32 VCPUs at domain restore (bnc#1065600).
- xen/vcpu: Simplify xen_vcpu related code (bnc#1065600).
- commit ed8f926
* Thu Feb 22 2018 msuchanek@suse.de
- mm, x86, powerpc: display pkey in smaps only if arch supports pkeys (FATE#322447, bsc#1078248).
- Refresh to current upstream submit
- Refresh patches.suse/mm-fix-KSM-data-corruption.patch.
- commit 6c82a45
* Thu Feb 22 2018 lpechacek@suse.com
- rpm/kernel-spec-macros: Try harder to detect Build Service environment (bsc#1078788)
- commit a5f1a4a
* Thu Feb 22 2018 hare@suse.de
- qla2xxx: ensure async flags are reset correctly (bsc#1081681).
- qla2xxx: do not check login_state if no loop id is assigned
  (bsc#1081681).
- qla2xxx: Fixup locking for session deletion (bsc#1081681).
- commit 9d633ab
* Thu Feb 22 2018 hare@suse.de
- qla2xxx: Fix incorrect tcm_qla2xxx_free_cmd use during TMR ABORT
  (v2) (bsc#1077989).
- commit eafbfa7
* Thu Feb 22 2018 hare@suse.de
- qla2xxx: Convert QLA_TGT_ABTS to TARGET_SCF_LOOKUP_LUN_FROM_TAG
  (bsc#1077989).
- Refresh
  patches.drivers/0071-scsi-qla2xxx-Fix-task-mgmt-handling-for-NPIV.patch.
- commit 0f758c5
* Thu Feb 22 2018 enadolski@suse.com
- btrfs: remove spurious WARN_ON(ref->count < 0) in
  find_parent_nodes (bsc#1081248).
- commit 8d9dca0
* Thu Feb 22 2018 hare@suse.de
- Refresh mainline tags
- Refresh
  patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh
  patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh
  patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- commit 54182ed
* Thu Feb 22 2018 tiwai@suse.de
- crypto: skcipher - set walk.iv for zero-length inputs
  (bsc#1051510).
- commit fc489a6
* Thu Feb 22 2018 tiwai@suse.de
- rtlwifi: rtl8821ae: Fix connection lost problem correctly
  (bsc#1051510).
- Input: synaptics-rmi4 - unmask F03 interrupts when port is
  opened (bsc#1051510).
- crypto: sha3-generic - fixes for alignment and big endian
  operation (bsc#1051510).
- crypto: echainiv - Remove unused alg/spawn variable
  (bsc#1051510).
- crypto: ecdh - fix typo in KPP dependency of CRYPTO_ECDH
  (bsc#1051510).
- crypto: chacha20poly1305 - validate the digest size
  (bsc#1051510).
- crypto: rsa - fix buffer overread when stripping leading zeroes
  (bsc#1051510).
- pkcs7: return correct error code if pkcs7_check_authattrs()
  fails (bsc#1051510).
- crypto: skcipher - Fix skcipher_walk_aead_common (bsc#1051510).
- crypto: dh - Don't permit 'key' or 'g' size longer than 'p'
  (bsc#1051510).
- crypto: dh - Don't permit 'p' to be 0 (bsc#1051510).
- crypto: lrw - Check for incorrect cipher name (bsc#1051510).
- crypto: lrw - Fix an error handling path in 'create()'
  (bsc#1051510).
- pkcs7: Prevent NULL pointer dereference, since sinfo is not
  always set (bsc#1051510).
- KEYS: Fix the wrong index when checking the existence of second
  id (bsc#1051510).
- crypto: skcipher - Fix crash on zero-length input (bsc#1051510).
- crypto: xts - Fix an error handling path in 'create()'
  (bsc#1051510).
- commit d6282f2
* Thu Feb 22 2018 mbenes@suse.cz
- livepatch: send a fake signal periodically (fate#323487).
- commit 3f8b70f
* Thu Feb 22 2018 jthumshirn@suse.de
- s390/qeth: fix underestimated count of buffer elements
  (bnc#1082087, LTC#164529).
- commit 379f1f8
* Thu Feb 22 2018 mbrugger@suse.com
- arm64: entry: Apply BP hardening for suspicious interrupts
  from EL0 (bsc#1068032).
- arm64: entry: Apply BP hardening for high-priority synchronous
  exceptions (bsc#1068032).
- arm64: futex: Mask __user pointers prior to dereference
  (bsc#1068032).
- arm64: uaccess: Mask __user pointers for __arch_{clear,
  copy_*}_user (bsc#1068032).
- arm64: uaccess: Don't bother eliding access_ok checks in __{get,
  put}_user (bsc#1068032).
- arm64: uaccess: Prevent speculative use of the current
  addr_limit (bsc#1068032).
- arm64: entry: Ensure branch through syscall table is bounded
  under speculation (bsc#1068032).
- arm64: Use pointer masking to limit uaccess speculation
  (bsc#1068032).
- arm64: Make USER_DS an inclusive limit (bsc#1068032).
- arm64: Implement array_index_mask_nospec() (bsc#1068032).
- arm64: barrier: Add CSDB macros to control data-value prediction
  (bsc#1068032).
- arm64: move TASK_* definitions to <asm/processor.h>
  (bsc#1068032).
- commit 679bb40
* Thu Feb 22 2018 aaptel@suse.com
- CIFS: Fix NULL pointer deref on SMB2_tcon() failure
  (bsc#1071009).
- commit 6f343af
* Thu Feb 22 2018 lhenriques@suse.com
- quota: report root dir quota usage in statfs (FATE#323422).
- ceph: quota: add counter for snaprealms with quota
  (FATE#323422).
- ceph: quota: cache inode pointer in ceph_snap_realm
  (FATE#323422).
- ceph: fix root quota realm check (FATE#323422).
- ceph: don't check quota for snap inode (FATE#323422).
- ceph: quota: add quotas to the in-tree cephfs documentation
  (FATE#323422).
- ceph: quota: update MDS when max_bytes is approaching
  (FATE#323422).
- ceph: quota: support for ceph.quota.max_bytes (FATE#323422).
- ceph: quota: don't allow cross-quota renames (FATE#323422).
- ceph: quota: support for ceph.quota.max_files (FATE#323422).
- ceph: quota: add initial infrastructure to support cephfs quotas
  (FATE#323422).
- commit 06ea255
* Thu Feb 22 2018 msuchanek@suse.de
- ibmvnic: Split counters for scrq/pools/napi (bsc#1082223).
- ibmvnic: Correct goto target for tx irq initialization failure
  (bsc#1082223).
- ibmvnic: Allocate max queues stats buffers (bsc#1081498).
- ibmvnic: Make napi usage dynamic (bsc#1081498).
- ibmvnic: Free and re-allocate scrqs when tx/rx scrqs change
  (bsc#1081498).
- ibmvnic: Move active sub-crq count settings (bsc#1081498).
- ibmvnic: Rename active queue count variables (bsc#1081498).
- commit 11616b1
* Thu Feb 22 2018 tiwai@suse.de
- drm/i915/cnl: Sync PCI ID with Spec (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix PORT_TX_DW5/7 register address (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Remove alpha_support protection (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaPipeControlBefore3DStateSamplePattern
  (FATE#322643 bsc#1055900).
- drm/i915/dp: limit DP link rate based on VBT on CNL+
  (FATE#322643 bsc#1055900).
- drm/i915/dp: clean up source rate limiting for cnl (FATE#322643
  bsc#1055900).
- drm/i915/dp: abstract rate array length limiting (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix DP max rate for Cannonlake with port F
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable DDI-F on Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add HPD support for Port F (FATE#322643
  bsc#1055900).
- drm/i915: For HPD connected port use hpd_pin instead of port
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add right GMBUS pin number for HDMI on Port F
  (FATE#322643 bsc#1055900).
- drm/i915: Fix DPLCLKA_CFGCR0 bits for Port F (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix _CNL_PORT_TX_DW2_LN0_F definition (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Extend Wa 1178 to Aux F (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add AUX-F support (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for another SKU
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix aux selection for WA 1178 (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Port F definition (FATE#322643 bsc#1055900).
- drm/i915/cnl: apply Display WA #1178 to fix type C dongles
  (FATE#322643 bsc#1055900).
- drm/i915/dmc: DMC 1.07 for Cannonlake (FATE#322643 bsc#1055900).
- commit 3d0b03e
* Thu Feb 22 2018 tiwai@suse.de
- ALSA: hda/realtek: PCI quirk for Fujitsu U7x7 (bsc#1052235).
- ALSA: hda/realtek - Enable Thinkpad Dock device for ALC298
  platform (bsc#1052235).
- ALSA: hda/realtek - Add headset mode support for Dell laptop
  (bsc#1052235).
- ALSA: hda - Fix headset mic detection problem for two Dell
  machines (bsc#1052235).
- ALSA: hda/realtek - update ALC215 depop optimize (bsc#1052235).
- ALSA: hda/realtek - Support headset mode for
  ALC215/ALC285/ALC289 (bsc#1052235).
- ALSA: hda/realtek - update ALC225 depop optimize (bsc#1052235).
- ALSA: hda - Clean up ALC299 init code (bsc#1052235).
- ALSA: hda - Fix yet remaining issue with vmaster 0dB
  initialization (bsc#1052235).
- ALSA: hda - silence uninitialized variable warning in
  activate_amp_in() (bsc#1052235).
- ALSA: hda - Fix incorrect TLV callback check introduced during
  set_fs() removal (bsc#1052235).
- ALSA: hda - Fix unbalance of i915 module refcount (bsc#1052235).
- ALSA: hda/realtek - Remove GPIO_MASK (bsc#1052235).
- ALSA: hda - Fix doubly initialization of i915 component
  (bsc#1052235).
- ALSA: hda - Minor code refactoring for Intel HDMI codec parsers
  (bsc#1052235).
- ALSA: hda - Bind with i915 component before codec binding
  (bsc#1052235).
- ALSA: hda - Skip card registration when no codec is found
  (bsc#1052235).
- ALSA: hda - Remove superfluous header inclusions (bsc#1052235).
- ALSA: hda - Fix a typo in comment (bsc#1052235).
- ALSA: hda - Remove the use of set_fs() (bsc#1052235).
- ALSA: hda - Remove the generic bind ctl helpers (bsc#1052235).
- ALSA: hda - Move bind-mixer switch codes to generic parser
  (bsc#1052235).
- ALSA: hda - Simplify bound-beep mute control for ALC268
  (bsc#1052235).
- commit d0f912f
* Thu Feb 22 2018 tiwai@suse.de
- ALSA: hda: Abort capability probe on invalid capability
  (bsc#1051510).
- ALSA: hda: Avoid racy recreation of widget kobjects
  (bsc#1051510).
- ALSA: hda: Fix potential race at unregistration and unsol events
  (bsc#1051510).
- commit 34b6b53
* Thu Feb 22 2018 tiwai@suse.de
- spi-nor: intel-spi: Fix broken software sequencing codes
  (bsc#1073836).
- commit ae5adb4
* Thu Feb 22 2018 nborisov@suse.com
- btrfs: Fix quota reservation leak on preallocated files
  (bsc#1079989).
- commit 8af1c31
* Thu Feb 22 2018 tiwai@suse.de
- KEYS: fix key refcount leak in keyctl_read_key() (bsc#1031717).
- KEYS: fix key refcount leak in keyctl_assume_authority()
  (bsc#1031717).
- KEYS: don't revoke uninstantiated key in request_key_auth_new()
  (bsc#1031717).
- KEYS: fix cred refcount leak in request_key_auth_new()
  (bsc#1031717).
- Input: uinput - avoid crash when sending FF request to device
  going away (bsc#1031717).
- r8169: Do not increment tx_dropped in TX ring cleaning
  (bsc#1031717).
- platform/x86: ideapad-laptop: Add several models to no_hw_rfkill
  (bsc#1051022).
- platform/x86: ideapad-laptop: Add IdeaPad V510-15IKB to
  no_hw_rfkill (bsc#1051022).
- platform/x86: ideapad-laptop: Add Y720-15IKBN to no_hw_rfkill
  (bsc#1051022).
- platform/x86: ideapad-laptop: Add Y520-15IKBN to no_hw_rfkill
  (bsc#1051022).
- commit 016b076
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Fix DSI panels with v1 MIPI sequences without a
  DEASSERT sequence v3 (FATE#322643 bsc#1055900).
- drm/i915: Free memdup-ed DSI VBT data structures on
  driver_unload (FATE#322643 bsc#1055900).
- drm/i915: Add intel_bios_cleanup() function (FATE#322643
  bsc#1055900).
- drm/i915/vlv: Add cdclk workaround for DSI (FATE#322643
  bsc#1055900).
- drm/i915/gvt: fix one typo of render_mmio trace (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Support BAR0 8-byte reads/writes (FATE#322643
  bsc#1055900).
- drm/i915/gvt: add 0xe4f0 into gen9 render list (FATE#322643
  bsc#1055900).
- drm/i915: Lock out execlist tasklet while peeking inside for
  busy-stats (FATE#322643 bsc#1055900).
- drm/i915/breadcrumbs: Ignore unsubmitted signalers (FATE#322643
  bsc#1055900).
- drm/i915: Don't wake the device up to check if the engine is
  asleep (FATE#322643 bsc#1055900).
- commit 9b8a688
* Wed Feb 21 2018 tiwai@suse.de
- Add no-fix tags to cherry-picked ids in drm patches
- commit fbe9d22
* Wed Feb 21 2018 msuchanek@suse.de
- kernel-binary undefine unique_debug_names
  Some tools do not understand names like
  usr/lib/debug/boot/vmlinux-4.12.14-11.10-default-4.12.14-11.10.ppc64le.debug
- commit 2b90c1e
* Wed Feb 21 2018 tiwai@suse.de
- supported.conf: add drm_panel_orientation_quirks
- commit e6a774c
* Wed Feb 21 2018 mbrugger@suse.com
- Refresh
  patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh
  patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh
  patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- commit f8e8ff0
* Wed Feb 21 2018 tiwai@suse.de
- Refresh
  patches.drivers/drm-i915-Move-dev_priv-mm.-un-bound_list-to-its-own-.
  Fix the regression with unblanaced list.
- commit 0ae1532
* Wed Feb 21 2018 msuchanek@suse.de
- ibmvnic: Keep track of supplementary TX descriptors
  (bsc#1081491).
- commit 5bf3dc8
* Wed Feb 21 2018 msuchanek@suse.de
- ibmvnic: Check for NULL skb's in NAPI poll routine (bsc#1081134,
  git-fixes).
- commit 092ca14
* Wed Feb 21 2018 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- Refresh patches.drivers/scsi-lpfc-Add-WQ-Full-Logic-for-NVME-Target.patch.
- Refresh patches.drivers/scsi-lpfc-Allow-set-of-maximum-outstanding-SCSI-cmd-.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-IO-failure-during-hba-reset-testing-wi.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-PRLI-handling-when-topology-type-chang.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-RQ-empty-firmware-trap.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-SCSI-io-host-reset-causing-kernel-cras.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-frequency-of-Release-WQE-CQEs.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-header-inclusion-in-lpfc_nvmet.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-issue_lip-if-link-is-disabled.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-nonrecovery-of-NVME-controller-after-c.patch.
- Refresh patches.drivers/scsi-lpfc-Fix-soft-lockup-in-lpfc-worker-thread-duri.patch.
- Refresh patches.drivers/scsi-lpfc-Increase-CQ-and-WQ-sizes-for-SCSI.patch.
- Refresh patches.drivers/scsi-lpfc-Indicate-CONF-support-in-NVMe-PRLI.patch.
- Refresh patches.drivers/scsi-lpfc-Treat-SCSI-Write-operation-Underruns-as-an.patch.
- Refresh patches.drivers/scsi-lpfc-Update-11.4.0.7-modified-files-for-2018-Co.patch.
- Refresh patches.drivers/scsi-lpfc-Validate-adapter-support-for-SRIU-option.patch.
- Refresh patches.drivers/scsi-lpfc-correct-debug-counters-for-abort.patch.
- Refresh patches.drivers/scsi-lpfc-move-placement-of-target-destroy-on-driver.patch.
- Refresh patches.drivers/scsi-lpfc-update-driver-version-to-11.4.0.7.patch.
- commit d2121ce
* Wed Feb 21 2018 mfleming@suse.de
- cpufreq: schedutil: Reset cached_raw_freq when not in sync
  with next_freq (git-fixes).
- commit 45b8f64
* Wed Feb 21 2018 msuchanek@suse.de
- powerpc/eeh: Fix crashes in eeh_report_resume() (FATE#324970,
  bsc#1078720).
- commit a168aa8
* Wed Feb 21 2018 tiwai@suse.de
- blacklist.conf: add drm blacklists
- commit e3024ca
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Avoid truncation before clamping userspace's priority
  value (FATE#322643 bsc#1055900).
- drm/i915/perf: Fix compiler warning for string truncation
  (FATE#322643 bsc#1055900).
- drm/ast: Load lut in crtc_commit (FATE#322643 bsc#1055900).
- commit 81092f7
* Wed Feb 21 2018 tiwai@suse.de
- drm: Fix PANEL_ORIENTATION_QUIRKS breaking the Kconfig DRM
  menuconfig (FATE#322643 bsc#1055900).
- Update config files.
- commit a55f11f
* Wed Feb 21 2018 tiwai@suse.de
- documentation/gpu/i915: fix docs build error after file rename
  (FATE#322643 bsc#1055900).
- drm: rcar-du: Don't set connector DPMS property (FATE#322643
  bsc#1055900).
- drm/fb_helper: Disable all crtc's when initial setup fails
  (FATE#322643 bsc#1055900).
- drm/fsl-dcu: Don't set connector DPMS property (FATE#322643
  bsc#1055900).
- commit 3c20f19
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Hold rcu_read_lock when iterating over the radixtree
  (vma idr) (FATE#322643 bsc#1055900).
- Refresh
  patches.drivers/drm-i915-Reorder-context-close-to-avoid-calling-i915.
- commit dd5076b
* Wed Feb 21 2018 tiwai@suse.de
- drm/atomic: Check for busy planes/connectors before setting
  the commit (FATE#322643 bsc#1055900).
- drm/i915: Don't use BIT() in UAPI section (FATE#322643
  bsc#1055900).
- drm: Make __drm_object_property_get_value() static (FATE#322643
  bsc#1055900).
- drm: Make syncobj import/export functions static (FATE#322643
  bsc#1055900).
- commit 3c66d76
* Wed Feb 21 2018 tiwai@suse.de
- drm: rename u32 in __u32 in uapi (FATE#322643 bsc#1055900).
- drm: Shift wrap bug in create_in_format_blob() (FATE#322643
  bsc#1055900).
- drm: Fix kerneldoc for atomic_async_update (FATE#322643
  bsc#1055900).
- commit a2db442
* Wed Feb 21 2018 tiwai@suse.de
- dma-buf/sync_file: Allow multiple sync_files to wrap a single
  dma-fence (FATE#322643 bsc#1055900).
- commit dbff788
* Wed Feb 21 2018 tiwai@suse.de
- Re-enable downstream DRM patches
  Refresh
  patches.drivers/drm-mgag200-Add-command-line-option-to-specify-preferred-depth.patch.
- commit 61ea818
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/kbl: Change a KBL pci id to GT2 from GT1.5 (FATE#322643
  bsc#1055900).
- commit 46445eb
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/bios: add DP max link rate to VBT child device struct
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Properly handle VBT ddc pin out of bounds
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Ignore VBT request for know invalid DDC pin
  (FATE#322643 bsc#1055900).
- drm/i915/cmdparser: Do not check past the cmd length
  (FATE#322643 bsc#1055900).
- drm/i915/cmdparser: Check reg_table_count before derefencing
  (FATE#322643 bsc#1055900).
- drm/i915/bxt, glk: Increase PCODE timeouts during CDCLK freq
  changing (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use KVM r/w to access guest opregion (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix aperture read/write emulation when enable
  x-no-mmap=on (FATE#322643 bsc#1055900).
- drm/i915/gvt: only reset execlist state of one engine during
  VM engine reset (FATE#322643 bsc#1055900).
- drm/i915/gvt: refine intel_vgpu_submission_ops as per engine
  ops (FATE#322643 bsc#1055900).
- drm/i915/ppgtt: Pin page directories before allocation
  (FATE#322643 bsc#1055900).
- drm/i915: Always run hangcheck while the GPU is busy
  (FATE#322643 bsc#1055900).
- Revert "drm/i915: mark all device info struct with __initconst"
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Do not do link training fallback or prune modes
  on EDP (FATE#322643 bsc#1055900).
- drm/i915: Check for fused or unused pipes (FATE#322643
  bsc#1055900).
- drm/i915: Protect WC stash allocation against direct reclaim
  (FATE#322643 bsc#1055900).
- drm/i915: Always call to intel_display_set_init_power() in
  resume_early (FATE#322643 bsc#1055900).
- drm/i915/gvt: cancel scheduler timer when no vGPU exists
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: cancel virtual vblank timer when no vGPU exists
  (FATE#322643 bsc#1055900).
- drm/i915/pmu: Reconstruct active state on starting busy-stats
  (FATE#322643 bsc#1055900).
- drm/i915: Stop getting the fault address from RING_FAULT_REG
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Add uc_fini_wq in gem_init unwind path
  (FATE#322643 bsc#1055900).
- drm/i915: Fix using BIT_ULL() vs. BIT() for power domain masks
  (FATE#322643 bsc#1055900).
- drm/i915: Try EDID bitbanging on HDMI after failed read
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Disable Guc and HuC on GLK (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Do not use I915_NUM_ENGINES to iterate over the
  mocs regs array (FATE#322643 bsc#1055900).
- drm/i915/gvt: validate gfn before set shadow page entry
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: add PLANE_KEYMAX regs to mmio track list
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix gen8/9_render_mmio_list[0] don't take effect
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171222 (FATE#322643
  bsc#1055900).
- drm/i915: Assert that the request is on the execution queue
  before being removed (FATE#322643 bsc#1055900).
- drm/i915/execlists: Show preemption progress in GEM_TRACE
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: move write protect handler out of mmio emulation
  function (FATE#322643 bsc#1055900).
- drm/i915/gvt: cleanup usage for typed mmio reg vs. offset
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: always use i915_reg_t for MMIO handler definition
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: load host render mocs once in mocs switch
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: refine mocs save restore policy (FATE#322643
  bsc#1055900).
- drm/i915/gvt: optimize for vGPU mmio switch (FATE#322643
  bsc#1055900).
- drm/i915/gvt: refine trace_render_mmio (FATE#322643
  bsc#1055900).
- drm/i915: Disable GMBUS clock gating around GMBUS transfers
  on gen9+ (FATE#322643 bsc#1055900).
- drm/i915: Clean up the PNV bit banging vs. GMBUS clock gating
  w/a (FATE#322643 bsc#1055900).
- drm/i915: No need to power up PG2 for GMBUS on BXT (FATE#322643
  bsc#1055900).
- drm/i915: Do not enable movntdqa optimization in hypervisor
  guest (FATE#322643 bsc#1055900).
- drm/i915: Dump device info at once (FATE#322643 bsc#1055900).
- drm/i915: Add pretty printer for runtime part of
  intel_device_info (FATE#322643 bsc#1055900).
- drm/i915: Update intel_device_info_runtime_init() parameter
  (FATE#322643 bsc#1055900).
- drm/i915: Move intel_device_info definitions to its own header
  (FATE#322643 bsc#1055900).
- drm/i915: Move opregion definitions to dedicated
  intel_opregion.h (FATE#322643 bsc#1055900).
- drm/i915: Move display related definitions to dedicated header
  (FATE#322643 bsc#1055900).
- drm/i915: Move some utility functions to i915_util.h
  (FATE#322643 bsc#1055900).
- drm/i915: Disable all planes for load detection, v2 (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Adding more Coffee Lake PCI IDs (FATE#322643
  bsc#1055900).
- drm/i915: Tidy up GEM_TRACE around execlists (FATE#322643
  bsc#1055900).
- drm/i915: Avoid context dereference inside
  execlists_submission_tasklet (FATE#322643 bsc#1055900).
- drm/i915: Remove pointer indirection for hangcheck_state local
  (FATE#322643 bsc#1055900).
- drm/i915: Show if we consider the engine is idle in the GPU
  error state (FATE#322643 bsc#1055900).
- drm/i915: Implement WaDisableEarlyEOT (FATE#322643 bsc#1055900).
- drm/i915: Implement WaDisableVFclkgate (FATE#322643
  bsc#1055900).
- drm/i915: Add pretty printer for modparams (FATE#322643
  bsc#1055900).
- drm/i915: Convert intel_device_info_dump into pretty printer
  (FATE#322643 bsc#1055900).
- drm/i915: Add pretty printer for device info flags (FATE#322643
  bsc#1055900).
- drm/i915: Fix indentation for intel_ddi_clk_select (FATE#322643
  bsc#1055900).
- drm/i915: Add a strong mb to resetting the has-CS-interrupt bit
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add support for horizontal plane flipping
  (FATE#322643 bsc#1055900).
- drm/i915/trace: add hw_id to gem requests trace points
  (FATE#322643 bsc#1055900).
- drm/i915: reorder field in gem_request tracepoints (FATE#322643
  bsc#1055900).
- drm/i915: Show IPEIR and IPEHR in the engine dump (FATE#322643
  bsc#1055900).
- drm/i915: Re-enable GGTT earlier after GPU reset (FATE#322643
  bsc#1055900).
- drm/i915: Unifying debugfs return codes for unsupported features
  (FATE#322643 bsc#1055900).
- drm/i915: Restore the kernel context after a GPU reset on an
  idle engine (FATE#322643 bsc#1055900).
- drm/i915: Skip an engine reset if it recovered before our
  preparations (FATE#322643 bsc#1055900).
- x86/gpu: add CFL to early quirks (FATE#322643 bsc#1055900).
- drm/i915: Allow internal page allocations to fail (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171214 (FATE#322643
  bsc#1055900).
- drm/i915/gvt/fb_decoder: Fix out-of-bounds read (FATE#322643
  bsc#1055900).
- drm/i915/gvt: refine function emulate_mmio_read/write
  (FATE#322643 bsc#1055900).
- drm/i915/gvt/kvmgt: fill info for ROM/VGA region (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Rename file render.{c, h} to mmio_context.{c, h}
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Remove MMIO barrier in MMIO switch (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Select appropriate mmio list at initialization
  time (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine the ring mmio list definition (FATE#322643
  bsc#1055900).
- drm/i915/gvt: fix off-by-one comparison of ring_id (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add missing breaks in switch statement
  (FATE#322643 bsc#1055900).
- drm/i915: properly init lockdep class (FATE#322643 bsc#1055900).
- drm/i915: make CS frequency read support missing more obvious
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract doorbell verification into a function
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract clients allocation to submission_init
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract doorbell creation from client allocation
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Call invalidate after changing the vfunc
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract guc_init from guc_init_hw (FATE#322643
  bsc#1055900).
- drm/i915/guc: Move GuC workqueue allocations outside of the
  mutex (FATE#322643 bsc#1055900).
- drm/i915/guc: Move shared data allocation away from submission
  path (FATE#322643 bsc#1055900).
- drm/i915: Unwind i915_gem_init() failure (FATE#322643
  bsc#1055900).
- drm/i915: Ratelimit request allocation under oom (FATE#322643
  bsc#1055900).
- drm/i915: Allow fence allocations to fail (FATE#322643
  bsc#1055900).
- drm/i915: Mark up potential allocation paths within
  i915_sw_fence as might_sleep (FATE#322643 bsc#1055900).
- drm/i915: Don't check #active_requests from
  i915_gem_wait_for_idle() (FATE#322643 bsc#1055900).
- drm/i915: Bump timeout for wait_for_engines() (FATE#322643
  bsc#1055900).
- drm/i915: Downgrade misleading "Memory usable" message
  (FATE#322643 bsc#1055900).
- drm/i915: Print an error message for a reset failure on gen2
  (FATE#322643 bsc#1055900).
- drm/i915: prefer resource_size_t for everything stolen
  (FATE#322643 bsc#1055900).
- drm/i915: give stolen_usable_size a more suitable home
  (FATE#322643 bsc#1055900).
- drm/i915: make mappable struct resource centric (FATE#322643
  bsc#1055900).
- drm/i915: make reserved struct resource centric (FATE#322643
  bsc#1055900).
- drm/i915: make dsm struct resource centric (FATE#322643
  bsc#1055900).
- drm/i915: nuke the duplicated stolen discovery (FATE#322643
  bsc#1055900).
- x86/early-quirks: export the stolen region as a resource
  (FATE#322643 bsc#1055900).
- drm/i915: Only report a wakeup if the waiter was truly asleep
  (FATE#322643 bsc#1055900).
- commit cd3b46b
* Wed Feb 21 2018 mhocko@suse.com
- mm: drop migrate type checks from has_unmovable_pages
  (bnc#1074195).
- commit 4ff7604
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Keep a small stash of preallocated WC pages
  (FATE#322643 bsc#1055900).
- Refresh
  patches.drivers/drm-i915-Mark-vm_free_page-as-a-potential-sleeper-ag.
- Refresh
  patches.drivers/drm-i915-Only-free-the-oldest-stale-object-before-a-.
- commit 4f7f6f9
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Use snprintf to avoid line-break when pretty-printing
  engines (FATE#322643 bsc#1055900).
- commit ac105dc
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Add "panel orientation" property to the panel
  connector, v6 (FATE#322643 bsc#1055900).
- commit 71dce14
* Wed Feb 21 2018 tiwai@suse.de
- Update config files: new configs for drm / fb stuff
- commit 4865016
* Wed Feb 21 2018 tiwai@suse.de
- intel/atomic: Stop updating legacy fb parameters (FATE#322643
  bsc#1055900).
- drm/i915: Restore GT performance in headless mode with DMC
  loaded (FATE#322643 bsc#1055900).
- drm/i915/execlists: Cache ELSP register offset (FATE#322643
  bsc#1055900).
- drm/i915: Refactor common list iteration over GGTT vma
  (FATE#322643 bsc#1055900).
- drm/i915: Track GGTT writes on the vma (FATE#322643
  bsc#1055900).
- drm/i915: Remove vma from object on destroy, not close
  (FATE#322643 bsc#1055900).
- drm/i915/huc: Load HuC only if requested (FATE#322643
  bsc#1055900).
- commit e564912
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/guc: Combine enable_guc_loading|submission modparams
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Don't use -EIO to report missing firmware
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Don't fetch GuC firmware if no plan to use GuC
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Introduce USES_GUC_xxx helper macros (FATE#322643
  bsc#1055900).
- drm/i915/guc: Move firmware selection to init_early (FATE#322643
  bsc#1055900).
- drm/i915/huc: Move firmware selection to init_early (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Kick scheduler when new workload queued
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Convert macro queue_workload to a function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add framebuffer decoder support (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add opregion support (FATE#322643 bsc#1055900).
- drm/i915/gvt: Alloc and Init guest opregion at vgpu creation
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix out-of-bounds buffer write into
  opregion->signature[] (FATE#322643 bsc#1055900).
- drm/i915/gvt: Cleanup unwanted public symbols (FATE#322643
  bsc#1055900).
- drm/i915: add platform tag to WA (FATE#322643 bsc#1055900).
- drm/i915: follow single notation for workaround number
  (FATE#322643 bsc#1055900).
- drm/i915: Taint (TAINT_WARN) the kernel if the GPU reset fails
  (FATE#322643 bsc#1055900).
- drm/i915/skl: DMC firmware for skylake v1.27 (FATE#322643
  bsc#1055900).
- drm/i915/cnl: only divide up base frequency with crystal source
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171201 (FATE#322643
  bsc#1055900).
- drm/i915: Remove unsafe i915.enable_rc6 (FATE#322643
  bsc#1055900).
- drm/i915: Sleep and retry a GPU reset if at first we don't
  succeed (FATE#322643 bsc#1055900).
- drm/i915: Interlaced DP output doesn't work on VLV/CHV
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to intel_pipe_{enable,disable}()
  (FATE#322643 bsc#1055900).
- drm/i915: Wait for pipe to start on i830 as well (FATE#322643
  bsc#1055900).
- drm/i915: Fix has_audio readout for DDI A (FATE#322643
  bsc#1055900).
- drm/i915: Don't add the "force audio" property to DP connectors
  that don't support audio (FATE#322643 bsc#1055900).
- drm/i915: Disable DP audio for g4x (FATE#322643 bsc#1055900).
- drm/i915/selftests: Wake the device before executing requests
  on the GPU (FATE#322643 bsc#1055900).
- drm/i915: Set fake_vma.size as well as fake_vma.node.size for
  capture (FATE#322643 bsc#1055900).
- drm/i915: Tidy up signed/unsigned comparison (FATE#322643
  bsc#1055900).
- drm/i915: Enable IPS with only sprite plane visible too, v4
  (FATE#322643 bsc#1055900).
- drm/i915: Make ips_enabled a property depending on whether
  IPS is enabled, v3 (FATE#322643 bsc#1055900).
- drm/i915: Avoid PPS HW/SW state mismatch due to rounding
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Apply WaProgramL3SqcReg1DefaultForPerf for GLK
  too (FATE#322643 bsc#1055900).
- drm/i915/guc: Change default GuC FW for KBL to v9.39
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Change default GuC FW for BXT to v9.29
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Change default GuC FW for SKL to v9.33
  (FATE#322643 bsc#1055900).
- drm/i915: Consolidate checks for engine stats availability
  (FATE#322643 bsc#1055900).
- drm/i915: Move engine->needs_cmd_parser to engine->flags
  (FATE#322643 bsc#1055900).
- drm/i915: Enable hotplug polling after registering the outputs
  (FATE#322643 bsc#1055900).
- drm/i915: Rename i915_gem_timelines_mark_idle (FATE#322643
  bsc#1055900).
- drm/i915: Rename shrinker init/cleanup to match driver
  initialisation phase (FATE#322643 bsc#1055900).
- drm/i915: Record default HW state in the GPU error state
  (FATE#322643 bsc#1055900).
- drm/i915: Flush everything on switching to the kernel_context
  (FATE#322643 bsc#1055900).
- drm/i915: hide unused intel_panel_set_backlight function
  (FATE#322643 bsc#1055900).
- drm/i915/fbdev: Serialise early hotplug events with async
  fbdev config (FATE#322643 bsc#1055900).
- drm/i915/guc: Use consistent name for scratch register count
  (FATE#322643 bsc#1055900).
- drm/i915: Use exponential backoff for wait_for() (FATE#322643
  bsc#1055900).
- drm/i915/guc: Tidy ELSP port assignment (FATE#322643
  bsc#1055900).
- drm/i915/guc: Advance over port[0] if set and not preempting
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename i915_guc_reg.h to intel_guc_reg.h
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Update header guard name of intel_guc_submission.h
  (FATE#322643 bsc#1055900).
- drm/i915: Move mi_set_context() into the legacy ringbuffer
  submission (FATE#322643 bsc#1055900).
- drm/i915: Unwind incomplete legacy context switches (FATE#322643
  bsc#1055900).
- drm/i915: remove stale comment from sanitize_encoder
  (FATE#322643 bsc#1055900).
- drm/i915: sync dp link status checks against atomic commmits
  (FATE#322643 bsc#1055900).
- drm/i915/dmc: DMC 1.04 for Kabylake (FATE#322643 bsc#1055900).
- drm/i915: Save/restore irq state for vlv_residency_raw()
  (FATE#322643 bsc#1055900).
- drm/i915: Remove success dmesg noise for intel_rotate_pages()
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_rc6_residency_us to ns (FATE#322643
  bsc#1055900).
- drm/i915: Engine busy time tracking (FATE#322643 bsc#1055900).
- drm/i915: Wrap context schedule notification (FATE#322643
  bsc#1055900).
- drm/i915: Extract intel_get_cagf (FATE#322643 bsc#1055900).
- drm/i915/selftests: Avoid drm_gem_handle_create under
  struct_mutex (FATE#322643 bsc#1055900).
- drm/i915: Add rudimentary plane state verification (FATE#322643
  bsc#1055900).
- drm/i915: Use plane->get_hw_state() for initial plane fb readout
  (FATE#322643 bsc#1055900).
- drm/i915: Nuke crtc->plane (FATE#322643 bsc#1055900).
- drm/i915: Switch fbc over to for_each_new_intel_plane_in_state()
  (FATE#322643 bsc#1055900).
- drm/i915: Nuke ironlake_get_initial_plane_config() (FATE#322643
  bsc#1055900).
- drm/i915: Cleanup enum pipe/enum plane_id/enum i9xx_plane_id
  in initial fb readout (FATE#322643 bsc#1055900).
- drm/i915: Use enum i9xx_plane_id for the .get_fifo_size()
  hooks (FATE#322643 bsc#1055900).
- drm/i915: s/enum plane/enum i9xx_plane_id/ (FATE#322643
  bsc#1055900).
- drm/i915: Don't use GEN6_RC_VIDEO_FREQ on gen10+ (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Declare we allocated the guc clients
  (FATE#322643 bsc#1055900).
- drm/i915: Remove i915.semaphores modparam (FATE#322643
  bsc#1055900).
- drm/i915: Move debugfs/i915_semaphore_status to i915_engine_info
  (FATE#322643 bsc#1055900).
- drm/i915: Disable semaphores on Sandybridge (FATE#322643
  bsc#1055900).
- drm/i915: Remove obsolete ringbuffer emission for gen8+
  (FATE#322643 bsc#1055900).
- drm/i915: Remove i915.enable_execlists module parameter
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Delay writing to ELSP until HW has processed
  the previous write (FATE#322643 bsc#1055900).
- drm/i915/selftest: Make guc clients static (FATE#322643
  bsc#1055900).
- drm/i915/perf: reuse timestamp frequency from device info
  (FATE#322643 bsc#1055900).
- drm/i915: Automatic i915_switch_context for legacy (FATE#322643
  bsc#1055900).
- drm/i915: Pull the unconditional GPU cache invalidation into
  request construction (FATE#322643 bsc#1055900).
- drm/i915/perf: replace .reg accesses with i915_mmio_reg_offset
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Assert that we don't get mixed IDLE_ACTIVE |
  COMPLETE events (FATE#322643 bsc#1055900).
- drm/i915/execlists: Reduce completed event mask to COMPLETE |
  PREEMPTED (FATE#322643 bsc#1055900).
- drm/i915/execlists: Listen to COMPLETE context event not
  ACTIVE_IDLE (FATE#322643 bsc#1055900).
- drm/fb-helper: Apply panel orientation connector prop to the
  primary plane, v6 (FATE#322643 bsc#1055900).
- drm: Add support for a panel-orientation connector property,
  v6 (FATE#322643 bsc#1055900).
- drm: Add panel orientation quirks, v6 (FATE#322643 bsc#1055900).
- fbcon: Add fbcon_rotate_hint to struct fb_info (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171117 (FATE#322643
  bsc#1055900).
- drm/i915: Add a policy note for removing workarounds
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Report ENOMEM clearly for an allocation
  failure (FATE#322643 bsc#1055900).
- drm/i915: Calculate g4x intermediate watermarks correctly
  (FATE#322643 bsc#1055900).
- drm/i915: Calculate vlv/chv intermediate watermarks correctly,
  v3 (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc_state to ips toggle functions, v2
  (FATE#322643 bsc#1055900).
- drm/i915: Pass idle crtc_state to intel_dp_sink_crc (FATE#322643
  bsc#1055900).
- drm/i915: Enable FIFO underrun reporting after initial fastset,
  v4 (FATE#322643 bsc#1055900).
- commit c55e1d3
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Mark the userptr invalidate workqueue as
  WQ_MEM_RECLAIM (FATE#322643 bsc#1055900).
- drm/i915: Add might_sleep() check to wait_for() (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Add a GuC doorbells selftest (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Let each vgpu has separate opregion memory
  (FATE#322643 bsc#1055900).
- Revert "drm/i915/gvt: Refine broken PPGTT scratch" (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Make gvt_vgpu_err use pr_err (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Don't dump partial state in cmd parser
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Reduce rcs mocs switch latency (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add new debugfs tool mmio_diff (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add mmio iterator
  intel_gvt_for_each_tracked_mmio() (FATE#322643 bsc#1055900).
- drm/i915/gvt: opregion virtualization for win guest (FATE#322643
  bsc#1055900).
- drm/i915/gvt: update CSB and CSB write pointer in virtual HWSP
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine broken PPGTT scratch (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Introduce ops->set_present() (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Introduce page table type of current level in
  GTT type enumerations (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix a bug of unexpectedly clear scratch page table
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Let the caller choose if a shadow page should
  be put into hash table (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use I915_GTT_PAGE_SIZE (FATE#322643 bsc#1055900).
- drm/i915/gvt: Factor intel_vgpu_page_track (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refine shadow batch buffer (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refine find_bb_size() (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use BIT() to make klockwork happy (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add basic debugfs infrastructure (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refactor vGPU type code in kvmgt part (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Move vGPU type related code into gvt file
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move clean_workloads() into scheduler.c
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Introduce intel_vgpu_reset_submission (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Introduce vGPU submission ops (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Remove one extra declaration in scheduler.h
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move common vGPU workload creation into
  scheduler.c (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move common workload preparation into
  prepare_workload() (FATE#322643 bsc#1055900).
- drm/i915/gvt: Factor out prepare_workload() (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Factor out vGPU workload creation/destroy
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use dyndbg for gvt debug info (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add VM healthy check for submit_context
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add VM healthy check for workload_thread
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Change the return type during command scan
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Do not allocate initial ring scan buffer
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move ring scan buffers into intel_vgpu_submission
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Rename reserved ring buffer (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix a memory leak in cmd_parser.c (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Move tlb_handle_pending into intel_vgpu_submission
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Introduce intel_vgpu_submission (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Move workload cache init/clean into
  intel_vgpu_{setup, clean}_submission() (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Rename intel_vgpu_{init, clean}_gvt_context()
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Make elsp_dwords in the right order (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add support for opregion virtualization
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Extend HDMI 2.0 support to CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Simplify dco_fraction calculation (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Don't blindly replace qdiv (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix wrpll math for higher freqs (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix, simplify and unify wrpll variable sizes
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Remove useless conversion (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Remove spurious central_freq (FATE#322643
  bsc#1055900).
- drm/i915/selftests: exercise_ggtt may have nothing to do
  (FATE#322643 bsc#1055900).
- drm/i915: Don't sanitize frame start delay if the pipe is off
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename i915_guc_submission.c|h to
  intel_guc_submission.c|h (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename i915_guc_client struct to intel_guc_client
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Update name and prototype of GuC submission
  interface functions (FATE#322643 bsc#1055900).
- drm/i915/guc: Update names of submission related static
  functions (FATE#322643 bsc#1055900).
- drm/i915: Update execlists tasklet naming (FATE#322643
  bsc#1055900).
- drm/i915: Prevent overflow of execbuf.buffer_count and
  num_cliprects (FATE#322643 bsc#1055900).
- drm/i915: Print the condition causing GEM_BUG_ON (FATE#322643
  bsc#1055900).
- drm/i915: Remove pre-production pooled-EU w/a for Broxton
  (FATE#322643 bsc#1055900).
- drm/i915: Make request's wait-for-space explicit (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Increase size for mock ringbuffer
  (FATE#322643 bsc#1055900).
- drm/i915: Initialise entry in intel_ppat_get() for older
  compilers (FATE#322643 bsc#1055900).
- drm/i915/selftests: Markup __iomem for igt_gem_coherency
  (FATE#322643 bsc#1055900).
- drm/i915: Use ELK stolen memory reserved detection for ILK
  (FATE#322643 bsc#1055900).
- drm/i915: Make the report about a bogus stolen reserved area
  an error (FATE#322643 bsc#1055900).
- drm/i915: Check if the stolen memory "reserved" area is enabled
  or not (FATE#322643 bsc#1055900).
- drm/i915: Fix kerneldocs for intel_audio.c (FATE#322643
  bsc#1055900).
- drm/i915: Call uncore_suspend before platform suspend handlers
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Always initialise err (FATE#322643
  bsc#1055900).
- drm/i915: Resume GuC before using GEM (FATE#322643 bsc#1055900).
- drm/i915: Display WA #1185 WaDisableDARBFClkGating:cnl, glk
  (FATE#322643 bsc#1055900).
- drm/i915: Unconditionally apply the Broxton register workaround
  set (FATE#322643 bsc#1055900).
- drm/i915: Remove pre-production Broxton register workarounds
  (FATE#322643 bsc#1055900).
- drm/i915: Unify SLICE_UNIT_LEVEL_CLKGATE w/a for cnl
  (FATE#322643 bsc#1055900).
- drm/i915: fix 64bit divide (FATE#322643 bsc#1055900).
- drm/i915: Generalize transcoder looping (FATE#322643
  bsc#1055900).
- drm/i915/glk: Refactor handling of PLANE_COLOR_CTL for GLK+
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce GEM proxy (FATE#322643 bsc#1055900).
- drm/i915: Object w/o backing storage is banned by -ENXIO
  (FATE#322643 bsc#1055900).
- drm/i915: Fix function name in comment (FATE#322643
  bsc#1055900).
- drm/i915: There is only one fault register from GEN8 onwards
  (FATE#322643 bsc#1055900).
- drm/i915: Clear per-engine fault register as early as possible
  (FATE#322643 bsc#1055900).
- drm/i915: expose command stream timestamp frequency to userspace
  (FATE#322643 bsc#1055900).
- drm/i915/perf: enable perf support on CNL (FATE#322643
  bsc#1055900).
- drm/i915: fix register naming (FATE#322643 bsc#1055900).
- drm/i915/perf: refactor perf setup (FATE#322643 bsc#1055900).
- drm/i915/perf: add support for Coffeelake GT3 (FATE#322643
  bsc#1055900).
- drm/i915/perf: complete whitelisting for OA programming on HSW
  (FATE#322643 bsc#1055900).
- drm/i915: Handle adjust better in intel_pipe_config_compare
  (FATE#322643 bsc#1055900).
- drm/i915: Check boolean options in intel_pipe_config_compare
  with its own macro (FATE#322643 bsc#1055900).
- drm/i915: Remove bogus ips_enabled check (FATE#322643
  bsc#1055900).
- drm/i915: Remove Gen9 WAs with no effect (FATE#322643
  bsc#1055900).
- drm/i915: Remove redundant intel_autoenable_gt_powersave()
  (FATE#322643 bsc#1055900).
- drm/i915: Update watermark state correctly in
  sanitize_watermarks (FATE#322643 bsc#1055900).
- drm/i915/selftests: Yet another forgotten mock_i915->mm
  initialiser (FATE#322643 bsc#1055900).
- commit ac7993e
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Kerneldoc typo s/rps/rps_client/ (FATE#322643
  bsc#1055900).
- drm/i915: Stop caching the "golden" renderstate (FATE#322643
  bsc#1055900).
- drm/i915: Record the default hw state after reset upon load
  (FATE#322643 bsc#1055900).
- drm/i915: Mark the context state as dirty/written (FATE#322643
  bsc#1055900).
- drm/i915: Inline intel_modeset_gem_init() (FATE#322643
  bsc#1055900).
- drm/i915: Move intel_init_clock_gating() to i915_gem_init()
  (FATE#322643 bsc#1055900).
- drm/i915: Move GT powersaving init to i915_gem_init()
  (FATE#322643 bsc#1055900).
- drm/i915: Force the switch to the i915->kernel_context
  (FATE#322643 bsc#1055900).
- drm/i915: Define an engine class enum for the uABI (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Initialise mock_i915->mm.obj_lock
  (FATE#322643 bsc#1055900).
- drm/i915: Restore the wait for idle engine after flushing
  interrupts (FATE#322643 bsc#1055900).
- drm/i915: Move irqs enabled assertion deeper for mock
  breadcrumbs (FATE#322643 bsc#1055900).
- drm/i915/selftests: Reduce the volume of the timeout message
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171109 (FATE#322643
  bsc#1055900).
- drm/i915: Mark up i915_vma_unbind() as a potential sleeper
  (FATE#322643 bsc#1055900).
- drm/i915: Mark vm_free_page() as a potential sleeper agent
  (FATE#322643 bsc#1055900).
- drm/i915: Use trace_printk to provide a death rattle for GEM
  (FATE#322643 bsc#1055900).
- drm/i915: Clean up DP code local variables and calling
  conventions (FATE#322643 bsc#1055900).
- drm/i915: Clean up PPS code calling conventions (FATE#322643
  bsc#1055900).
- drm/i915: Nuke intel_digital_port->port (FATE#322643
  bsc#1055900).
- drm/i915: Replace dig_port->port with encoder port for BXT
  DPLL selection (FATE#322643 bsc#1055900).
- drm/i915: Eliminate crtc->config usage from CRT code
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to DPIO PHY functions (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from TV code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from SDVO code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from DSI code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate some encoder->crtc usage from DP code
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Simplify programming of GUC_SHIM_CONTROL
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Drop legacy workarounds from guc_prepare_xfer
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Wait for ucode DMA transfer completion
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Split GuC firmware xfer function into clear steps
  (FATE#322643 bsc#1055900).
- drm/i915: Implement ReadHitWriteOnlyDisable (FATE#322643
  bsc#1055900).
- drm/i915: Include intel_engine_is_idle() status in engine
  pretty-printer (FATE#322643 bsc#1055900).
- drm/i915: Read ilk FDI PLL frequency once during initialisation
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Take rpm wakeref around partial tiling tests
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Take rpm wakeref around GGTT lowlevel tests
  (FATE#322643 bsc#1055900).
- drm/i915: Prevent unbounded wm results in g4x_compute_wm()
  (FATE#322643 bsc#1055900).
- drm/i915: Simplify onion for bxt_ddi_phy_init() (FATE#322643
  bsc#1055900).
- drm/i915: Silence compiler for csr_load_work_fn() (FATE#322643
  bsc#1055900).
- drm/i915: Silence smatch for cmdparser (FATE#322643
  bsc#1055900).
- drm/i915: Handle error-state modparams in dedicated functions
  (FATE#322643 bsc#1055900).
- drm/i915: Make GuC log part of the uC error state (FATE#322643
  bsc#1055900).
- drm/i915: Add Guc/HuC firmware details to error state
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Assert ctch->vma is allocated (FATE#322643
  bsc#1055900).
- drm/i915/guc: Assert guc->stage_desc_pool is allocated
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Hide dangerous tests (FATE#322643
  bsc#1055900).
- drm/i915: Assert vma->flags are updated correctly during binding
  (FATE#322643 bsc#1055900).
- drm/i915: Set up mocs tables before restarting the engines
  (FATE#322643 bsc#1055900).
- drm/i915: Warn in debug builds of incorrect usages of
  ptr_pack_bits (FATE#322643 bsc#1055900).
- drm/i915: ensure oa config uuid is null terminated (FATE#322643
  bsc#1055900).
- drm/i915: Flush the irq and tasklets before asserting engine
  is idle (FATE#322643 bsc#1055900).
- drm/i915: Use fallback forcewake if primary ack missing
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Add support for reset engine using GuC commands
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Rename the function that resets the GuC
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Clear terminated attribute bit on GuC preemption
  context (FATE#322643 bsc#1055900).
- drm/i915/cnl: Symmetric scalers for each pipe (FATE#322643
  bsc#1055900).
- drm/i915: Give more details for the active-when-parking warning
  for the engines (FATE#322643 bsc#1055900).
- drm/i915: Move parking-while-active warning to
  intel_engines_park() (FATE#322643 bsc#1055900).
- drm/i915: Check that the breadcrumb wasn't disarmed
  automatically before parking (FATE#322643 bsc#1055900).
- drm/i915/cnl: Remove unnecessary check in cnl_setup_private_ppat
  (FATE#322643 bsc#1055900).
- drm/i915: Remove most encoder->type uses from the audio code
  (FATE#322643 bsc#1055900).
- drm/i915: Pass around crtc and connector states for audio
  (FATE#322643 bsc#1055900).
- drm/i915: Replace "cc-option -Wno-foo" with "cc-disable-warning
  foo" (FATE#322643 bsc#1055900).
- drm/i915: Use intel_ddi_get_config() for MST (FATE#322643
  bsc#1055900).
- drm/i915: Pass a crtc state to ddi post_disable from MST code
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate pll->state usage from bxt_calc_pll_link()
  (FATE#322643 bsc#1055900).
- drm/i915: Nuke intel_ddi_get_encoder_port() (FATE#322643
  bsc#1055900).
- drm/i915: Stop frobbing with DDI encoder->type (FATE#322643
  bsc#1055900).
- drm/i915: Populate output_types from .get_config() (FATE#322643
  bsc#1055900).
- drm/i915: Parse max HDMI TMDS clock from VBT (FATE#322643
  bsc#1055900).
- drm/i915/vbt: Fix HDMI level shifter and max data rate bitfield
  sizes (FATE#322643 bsc#1055900).
- drm/i915: Clean up the mess around hdmi_12bpc_possible()
  (FATE#322643 bsc#1055900).
- drm/i915: Improve DP downstream HPD handling (FATE#322643
  bsc#1055900).
- drm/i915: Fix BXT lane latency optimal setting with MST
  (FATE#322643 bsc#1055900).
- drm/i915: Stop using encoder->type in
  intel_ddi_enable_transcoder_func() (FATE#322643 bsc#1055900).
- drm/i915: Start using output_types for DPLL selection
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to intel_prepare_dp_ddi_buffers()
  (FATE#322643 bsc#1055900).
- drm/i915: Don't use encoder->type in
  intel_ddi_set_pipe_settings() (FATE#322643 bsc#1055900).
- drm/i915: Empty the ring before disabling (FATE#322643
  bsc#1055900).
- drm/i915/edp: clean up code and comments around eDP DPCD read
  (FATE#322643 bsc#1055900).
- drm/i915: Add -Wall -Wextra to our build, set warnings to full
  (FATE#322643 bsc#1055900).
- drm/i915: Include RING_MODE when dumping the engine state
  (FATE#322643 bsc#1055900).
- drm/i915/huc: Use helper function while waiting for DMA
  completion (FATE#322643 bsc#1055900).
- drm/i915/guc: Preemption! With GuC (FATE#322643 bsc#1055900).
- drm/i915: Rename helpers used for unwinding, use macro for
  can_preempt (FATE#322643 bsc#1055900).
- drm/i915/guc: Keep request->priority for its lifetime
  (FATE#322643 bsc#1055900).
- drm/i915: Add information needed to track engine preempt state
  (FATE#322643 bsc#1055900).
- drm/i915: Extract "emit write" part of emit breadcrumb functions
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Split guc_wq_item_append (FATE#322643
  bsc#1055900).
- drm/i915/guc: Add a second client, to be used for preemption
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Add preemption action to GuC firmware interface
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Allocate separate shared data object for GuC
  communication (FATE#322643 bsc#1055900).
- drm/i915/guc: Extract GuC stage desc pool creation into a helper
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Do not use 0 for GuC doorbell cookie (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix SSEU Device Status (FATE#322643 bsc#1055900).
- drm/i915/guc: Initialize GuC before restarting engines
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Always enable the breadcrumbs irq (FATE#322643
  bsc#1055900).
- drm/i915: Add a hook for making the engines idle (parking)
  and unparking (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow 2 pixel per clock on Cannonlake (FATE#322643
  bsc#1055900).
- Revert "drm/i915/selftests: Convert timers to use timer_setup()"
  (FATE#322643 bsc#1055900).
- commit dc0515f
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/selftests: Convert timers to use timer_setup()
  (FATE#322643 bsc#1055900).
- drm/i915: Use same test for eviction and submitting kernel
  context (FATE#322643 bsc#1055900).
- drm/i915: Call cond_resched() before repeating
  i915_gem_evict_something() (FATE#322643 bsc#1055900).
- drm/i915: Perform a central cdclk state sanity check
  (FATE#322643 bsc#1055900).
- drm/i915: Sanity check cdclk in vlv_set_cdclk() (FATE#322643
  bsc#1055900).
- drm/i915: Adjust system agent voltage on CNL if required by
  DDI ports (FATE#322643 bsc#1055900).
- drm/i915: Use cdclk_state->voltage on CNL (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on BXT/GLK (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on SKL/KBL/CFL (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on BDW (FATE#322643
  bsc#1055900).
- drm/i915: Use cdclk_state->voltage on VLV/CHV (FATE#322643
  bsc#1055900).
- drm/i915: Start tracking voltage level in the cdclk state
  (FATE#322643 bsc#1055900).
- drm/i915: Clean up some cdclk switch statements (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Update the DMC version on CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Get RC6 working (FATE#322643 bsc#1055900).
- drm/i915/cnl: Force DDI_A_4_LANES when needed (FATE#322643
  bsc#1055900).
- drm/i915: Synchronize irq before parking each engine
  (FATE#322643 bsc#1055900).
- drm/i915: Bump wait-times for the final CS interrupt before
  parking (FATE#322643 bsc#1055900).
- drm/i915: Fix deadlock in i830_disable_pipe() (FATE#322643
  bsc#1055900).
- drm/i915: Redo plane sanitation during readout (FATE#322643
  bsc#1055900).
- drm/i915: Add .get_hw_state() method for planes (FATE#322643
  bsc#1055900).
- drm/i915: Don't adjust priority on an already signaled fence
  (FATE#322643 bsc#1055900).
- drm/i915: Whitelist SLICE_COMMON_ECO_CHICKEN1 on Geminilake
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix stack-out-of-bounds bug in cmd parser
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Clear the shadow page table entry after post-sync
  (FATE#322643 bsc#1055900).
- drm/i915: Apply Display WA #1183 on skl, kbl, and cfl
  (FATE#322643 bsc#1055900).
- drm/i915: Put all non-blocking modesets onto an ordered wq
  (FATE#322643 bsc#1055900).
- drm/i915: Disable DC states around GMBUS on GLK (FATE#322643
  bsc#1055900).
- drm/i915/psr: Fix register name mess up (FATE#322643
  bsc#1055900).
- i915: Reject CCS modifiers for pipe C on Geminilake (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix pipe A enable as default for vgpu (FATE#322643
  bsc#1055900).
- drm/i915: Protect DDI port to DPLL map from theoretical race
  (FATE#322643 bsc#1055900).
- drm/i915/lpe: Remove double-encapsulation of info string
  (FATE#322643 bsc#1055900).
- drm/i915/fence: Use rcu to defer freeing of irq_work
  (FATE#322643 bsc#1055900).
- drm/i915: Stop listening to request resubmission from the
  signaler kthread (FATE#322643 bsc#1055900).
- drm/i915: Drop fb reference on load_detect_pipe failure path
  (FATE#322643 bsc#1055900).
- drm/i915: Flush pending GTT writes before unbinding (FATE#322643
  bsc#1055900).
- drm: rework delayed connector cleanup in connector_iter
  (bsc#1051510).
- drm/i915/gvt: set max priority for gvt context (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Don't mark vgpu context as inactive when preempted
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Limit read hw reg to active vgpu (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Export intel_gvt_render_mmio_to_ring_id()
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Emulate PCI expansion ROM base address register
  (FATE#322643 bsc#1055900).
- Revert "drm/i915: Display WA #1133 WaFbcSkipSegments:cnl, glk"
  (FATE#322643 bsc#1055900).
- drm/i915: Call i915_gem_init_userptr() before taking
  struct_mutex (FATE#322643 bsc#1055900).
- drm/i915/cnl: Mask previous DDI - PLL mapping (FATE#322643
  bsc#1055900).
- drm/i915: Fix vblank timestamp/frame counter jumps on gen2
  (FATE#322643 bsc#1055900).
- drm/i915: Skip switch-to-kernel-context on suspend when wedged
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Correct ADDR_4K/2M/1G_MASK definition (FATE#322643
  bsc#1055900).
- drm/i915/gvt: enabled pipe A default on creating vgpu
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Move request alloc to dispatch_workload path only
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: remove skl_misc_ctl_write handler (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix unsafe locking caused by spin_unlock_bh
  (FATE#322643 bsc#1055900).
- drm/i915: fix intel_backlight_device_register declaration
  (FATE#322643 bsc#1055900).
- drm/i915: Prevent zero length "index" write (FATE#322643
  bsc#1055900).
- drm/i915: Don't try indexed reads to alternate slave addresses
  (FATE#322643 bsc#1055900).
- drm/edid: Don't send non-zero YQ in AVI infoframe for HDMI
  1.x sinks (bsc#1051510).
- drm/i915: Fix init_clock_gating for resume (FATE#322643
  bsc#1055900).
- drm/i915: Clear breadcrumb node when cancelling signaling
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: ensure -ve return value is handled correctly
  (FATE#322643 bsc#1055900).
- drm/i915: Re-register PMIC bus access notifier on runtime resume
  (FATE#322643 bsc#1055900).
- drm/i915: Fix false-positive assert_rpm_wakelock_held in
  i915_pmic_bus_access_notifier v2 (FATE#322643 bsc#1055900).
- drm/i915: Reorder context-close to avoid calling
  i915_vma_close() under RCU (FATE#322643 bsc#1055900).
- drm/i915: Move init_clock_gating() back to where it was
  (FATE#322643 bsc#1055900).
- drm/i915: Prune the reservation shared fence array (FATE#322643
  bsc#1055900).
- drm/i915: Idle the GPU before shinking everything (FATE#322643
  bsc#1055900).
- drm/i915: Lock llist_del_first() vs llist_del_all() (FATE#322643
  bsc#1055900).
- drm/i915: Calculate ironlake intermediate watermarks correctly,
  v2 (FATE#322643 bsc#1055900).
- drm/i915: Disable lazy PPGTT page table optimization for vGPU
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Remove the priority "optimisation"
  (FATE#322643 bsc#1055900).
- drm/i915: Filter out spurious execlists context-switch
  interrupts (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171023 (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Map VBT DDC Pin to BSpec DDC Pin (FATE#322643
  bsc#1055900).
- drm/i915: Let's use more enum intel_dpll_id pll_id (FATE#322643
  bsc#1055900).
- drm/i915: Use existing DSI backlight ports info (FATE#322643
  bsc#1055900).
- drm/i915: Parse DSI backlight/cabc ports (FATE#322643
  bsc#1055900).
- drm/i915: Skip waking the device to service pwrite (FATE#322643
  bsc#1055900).
- drm/i915/crt: split compute_config hook by platforms
  (FATE#322643 bsc#1055900).
- drm/i915: remove g4x lowfreq_avail and has_pipe_cxsr
  (FATE#322643 bsc#1055900).
- drm/i915: Drop the redundant hdmi prefix/suffix from a lot of
  variables (FATE#322643 bsc#1055900).
- drm/i915: Unify error handling for missing DDI buf trans tables
  (FATE#322643 bsc#1055900).
- drm/i915: Centralize the SKL DDI A/E vs. B/C/D buf trans
  handling (FATE#322643 bsc#1055900).
- drm/i915: Kill off the BXT buf_trans default_index (FATE#322643
  bsc#1055900).
- drm/i915: Pass encoder type to cnl_ddi_vswing_sequence()
  explicitly (FATE#322643 bsc#1055900).
- drm/i915: Integrate BXT into intel_ddi_dp_voltage_max()
  (FATE#322643 bsc#1055900).
- drm/i915: Pass the level to intel_prepare_hdmi_ddi_buffers()
  (FATE#322643 bsc#1055900).
- drm/i915: Pass the encoder type explicitly to skl_set_iboost()
  (FATE#322643 bsc#1055900).
- drm/i915: Extract intel_ddi_get_buf_trans_hdmi() (FATE#322643
  bsc#1055900).
- drm/i915: Relocate intel_ddi_get_buf_trans_*() functions
  (FATE#322643 bsc#1055900).
- drm/i915: Flush the idle-worker for debugfs/i915_drop_caches
  (FATE#322643 bsc#1055900).
- drm/i915: adjust get_crtc_fence_y_offset() to use base.y
  instead of crtc.y (FATE#322643 bsc#1055900).
- drm/i915: Unify skylake plane disable (FATE#322643 bsc#1055900).
- drm/i915: Unify skylake plane update (FATE#322643 bsc#1055900).
- drm/i915: dspaddr_offset doesn't need to be more than local
  variable (FATE#322643 bsc#1055900).
- drm/i915: move adjusted_x/y from crtc to cache (FATE#322643
  bsc#1055900).
- drm/i915: Fixup userptr mmu notifier registration error handling
  (FATE#322643 bsc#1055900).
- drm/i915: No need for RING_MAX_NONPRIV_SLOTS space (FATE#322643
  bsc#1055900).
- drm/i915/uc: Add pretty printer for uc firmware (FATE#322643
  bsc#1055900).
- drm/i915: Handle drm-layer errors in intel_dp_add_mst_connector
  (FATE#322643 bsc#1055900).
- drm/i915: Remove mostly duplicated video DIP handling from
  PSR code (FATE#322643 bsc#1055900).
- commit 7e86bee
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Add in-flight request details to intel_engine_dump()
  (FATE#322643 bsc#1055900).
- drm/i915: Skip HW reinitialisation on resume if still wedged
  (FATE#322643 bsc#1055900).
- drm/i915: Trim struct_mutex hold duration for
  i915_gem_free_objects (FATE#322643 bsc#1055900).
- drm/i915: Only free the oldest stale object before a fresh
  allocation (FATE#322643 bsc#1055900).
- drm/i915: Set our shrinker->batch to 4096 (~16MiB) (FATE#322643
  bsc#1055900).
- drm/i915: Move dev_priv->mm.[un]bound_list to its own lock
  (FATE#322643 bsc#1055900).
- drm/i915: Remove walk over obj->vma_list for the shrinker
  (FATE#322643 bsc#1055900).
- drm/i915: Drop debugfs/i915_gem_pin_display (FATE#322643
  bsc#1055900).
- drm/i915: Rename obj->pin_display to obj->pin_global
  (FATE#322643 bsc#1055900).
- drm/i915: Refactor testing obj->mm.pages (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaRsUseTimeoutMode (FATE#322643 bsc#1055900).
- drm/i915/huc: Move fw select function (FATE#322643 bsc#1055900).
- drm/i915/guc: Update Guc messages on load failure (FATE#322643
  bsc#1055900).
- drm/i915/uc: Unify firmware loading (FATE#322643 bsc#1055900).
- drm/i915: Update DMC firmware load error messages (FATE#322643
  bsc#1055900).
- drm/i915/uc: Add message with firmware url (FATE#322643
  bsc#1055900).
- drm/i915/uc: Improve debug messages in firmware fetch
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Pick better place for Guc final status message
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Check all firmwares against WOPCM size (FATE#322643
  bsc#1055900).
- drm/i915/guc: Reorder functions in intel_guc_fw.c (FATE#322643
  bsc#1055900).
- drm/i915/guc: Rename intel_guc_loader.c to intel_guc_fw.c
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move doc near related definitions (FATE#322643
  bsc#1055900).
- drm/i915/guc: Small fixups post code move (FATE#322643
  bsc#1055900).
- drm/i915/guc: Move GuC boot param initialization out of xfer
  (FATE#322643 bsc#1055900).
- drm/i915: Move intel_guc_wopcm_size to intel_guc.c (FATE#322643
  bsc#1055900).
- drm/i915: enable to read CSB and CSB write pointer from HWSP
  in GVT-g VM (FATE#322643 bsc#1055900).
- drm/i915: Always stop the rings before a missing GPU reset
  (FATE#322643 bsc#1055900).
- drm/i915: Keep the rings stopped until they have been
  re-initialized (FATE#322643 bsc#1055900).
- drm/i915: Stop asserting on set-wedged vs nop_submit_request
  ordering (FATE#322643 bsc#1055900).
- drm/i915: Split intel_enable_ddi() into DP and HDMI variants
  (FATE#322643 bsc#1055900).
- drm/i915: Plumb crtc_state etc. directly to
  intel_ddi_pre_enable_{dp,hdmi}() (FATE#322643 bsc#1055900).
- drm/i915: Split intel_disable_ddi() into DP vs. HDMI variants
  (FATE#322643 bsc#1055900).
- drm/i915: Remove useless eDP check from
  intel_ddi_pre_enable_dp() (FATE#322643 bsc#1055900).
- drm/i915: Split intel_ddi_post_disable() into DP vs. HDMI
  variants (FATE#322643 bsc#1055900).
- drm/i915: Inline the required bits of intel_ddi_post_disable()
  into intel_ddi_fdi_post_disable() (FATE#322643 bsc#1055900).
- drm/i915: Extract intel_disable_ddi_buf() (FATE#322643
  bsc#1055900).
- drm/i915: Extract intel_ddi_clk_disable() (FATE#322643
  bsc#1055900).
- drm/i915: Dump 'output_types' in crtc state dump (FATE#322643
  bsc#1055900).
- drm/i915: Replace *_reference/unreference() or *_ref/unref
  with _get/put() (FATE#322643 bsc#1055900).
- drm/i915: Get rid of hardcoded pipes (FATE#322643 bsc#1055900).
- drm/i915: Add retries for LSPCON detection (FATE#322643
  bsc#1055900).
- drm/i915: Don't give up waiting on INVALID_MODE (FATE#322643
  bsc#1055900).
- drm/i915/bdw: Fix DP_AUX_CH_CTL_TIME_OUT setting (FATE#322643
  bsc#1055900).
- drm/i915: Fix DP_AUX_CH_CTL_TIME_OUT naming (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Wrap a timer into a i915_sw_fence
  (FATE#322643 bsc#1055900).
- drm/i915: Start tracking PSR state in crtc state (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20171012 (FATE#322643
  bsc#1055900).
- drm/i915: Simplify intel_sanitize_enable_ppgtt (FATE#322643
  bsc#1055900).
- drm/i915/userptr: Drop struct_mutex before cleanup (FATE#322643
  bsc#1055900).
- drm/i915/dp: limit sink rates based on rate (FATE#322643
  bsc#1055900).
- drm/i915/dp: centralize max source rate conditions more
  (FATE#322643 bsc#1055900).
- drm/i915: Allow PCH platforms fall back to BIOS LVDS mode
  (FATE#322643 bsc#1055900).
- drm/i915: Reuse normal state readout for LVDS/DVO fixed mode
  (FATE#322643 bsc#1055900).
- drm/i915: Use rcu instead of stop_machine in set_wedged
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce separate status variable for RC6 and LLC
  ring frequency setup (FATE#322643 bsc#1055900).
- drm/i915: Create generic functions to control RC6, RPS
  (FATE#322643 bsc#1055900).
- drm/i915: Create generic function to setup LLC ring frequency
  table (FATE#322643 bsc#1055900).
- drm/i915: Rename intel_enable_rc6 to intel_rc6_enabled
  (FATE#322643 bsc#1055900).
- drm/i915: Name structure in dev_priv that contains RPS/RC6
  state as "gt_pm" (FATE#322643 bsc#1055900).
- drm/i915: Move rps.hw_lock to dev_priv and s/hw_lock/pcu_lock
  (FATE#322643 bsc#1055900).
- drm/i915: Name i915_runtime_pm structure in dev_priv as
  "runtime_pm" (FATE#322643 bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for CHV (FATE#322643
  bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for VLV (FATE#322643
  bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for BDW (FATE#322643
  bsc#1055900).
- drm/i915: Remove superfluous IS_BDW checks and non-BDW changes
  from gen8_enable_rps (FATE#322643 bsc#1055900).
- drm/i915: Separate RPS and RC6 handling for gen6+ (FATE#322643
  bsc#1055900).
- drm/i915: Cleanup South Error Interrupts (FATE#322643
  bsc#1055900).
- drm/i915: Favor for_each_pipe() macro (FATE#322643 bsc#1055900).
- drm/i915: Fold IRQ pipe masks (FATE#322643 bsc#1055900).
- drm/i915: Remove I915_MAX_PIPES dependency for DDB allocation
  (FATE#322643 bsc#1055900).
- drm/i915: Don't relay on I915_MAX_PIPES (FATE#322643
  bsc#1055900).
- drm/i915: Nuke the bogus kernel doc for i9xx_disable_pll()
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc state to i9xx_enable_pll() (FATE#322643
  bsc#1055900).
- drm/i915: Parametrize CBR_DPLLBMD_PIPE defines (FATE#322643
  bsc#1055900).
- drm/i915: Use enum pipe for PCH transcoders (FATE#322643
  bsc#1055900).
- drm/i915: Increase atomic update vblank evasion time with
  lockdep (FATE#322643 bsc#1055900).
- drm/i915: Use execlists_num_ports instead of size of array
  (FATE#322643 bsc#1055900).
- drm/i915: Preallocate our mmu notifier workequeu to unbreak
  cpu hotplug deadlock (FATE#322643 bsc#1055900).
- drm/i915/bios: don't pass bdb to parsers that don't parse VBT
  directly (FATE#322643 bsc#1055900).
- drm/i915/bios: parse SDVO device mapping from pre-parsed child
  devices (FATE#322643 bsc#1055900).
- drm/i915/bios: merge parse_device_mapping() into
  parse_general_definitions() (FATE#322643 bsc#1055900).
- drm/i915/bios: cleanup comments and useless return (FATE#322643
  bsc#1055900).
- drm/i915/bios: remove an unnecessary temp variable (FATE#322643
  bsc#1055900).
- drm/i915/bios: don't initialize fields based on vbt version
  (FATE#322643 bsc#1055900).
- drm/i915/bios: refactor parse general definitions (FATE#322643
  bsc#1055900).
- drm/i915: avoid division by zero on cnl_calc_wrpll_link
  (FATE#322643 bsc#1055900).
- drm/i915: add the BXT and CNL DPLL registers to
  pipe_config_compare (FATE#322643 bsc#1055900).
- drm/i915: Early rejection of mappable GGTT pin attempts for
  large bo (FATE#322643 bsc#1055900).
- drm/i915: Avoid evicting user fault mappable vma for
  pread/pwrite (FATE#322643 bsc#1055900).
- drm/i915: Try a minimal attempt to insert the whole object
  for relocations (FATE#322643 bsc#1055900).
- drm/i915: Check PIN_NONFAULT overlaps in evict_for_node
  (FATE#322643 bsc#1055900).
- drm/i915: Track user GTT faulting per-vma (FATE#322643
  bsc#1055900).
- drm/i915: Consolidate get_fence with pin_fence (FATE#322643
  bsc#1055900).
- drm/i915: Pin fence for iomap (FATE#322643 bsc#1055900).
- drm/i915: Provide an assert for when we expect forcewake to
  be held (FATE#322643 bsc#1055900).
- drm/i915/selftests: Hold the rpm wakeref for the reset tests
  (FATE#322643 bsc#1055900).
- drm/i915: Hold forcewake for the duration of reset+restart
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Pretty print engine state when requests
  fail to start (FATE#322643 bsc#1055900).
- drm/i915: Make i915_engine_info pretty printer to standalone
  (FATE#322643 bsc#1055900).
- drm/i915: Use intel_get_pipe_timings() and
  intel_mode_from_pipe_config() in intel_crtc_mode_get()
  (FATE#322643 bsc#1055900).
- commit 128dfbb
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/execlists: Add a comment for the extra MI_ARB_ENABLE
  (FATE#322643 bsc#1055900).
- drm/i915: Try harder to finish the idle-worker (FATE#322643
  bsc#1055900).
- drm/i915: Fix pointer-to-int conversion (FATE#322643
  bsc#1055900).
- drm/i915/huc: Fix includes in intel_huc.c (FATE#322643
  bsc#1055900).
- drm/i915: Unify uC variable types to avoid flooding
  checkpatch.pl (FATE#322643 bsc#1055900).
- drm/i915/crt: clean up encoder hook assignment (FATE#322643
  bsc#1055900).
- drm/i915: push DDI FDI link training on enable to CRT encoder
  (FATE#322643 bsc#1055900).
- drm/i915: push DDI and DSI underrun reporting on enable to
  encoder (FATE#322643 bsc#1055900).
- drm/i915: push DDI CRT underrun reporting on disable to encoder
  (FATE#322643 bsc#1055900).
- drm/i915: push DDI CRT underrun reporting on enable to encoder
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Unify initialization of the uC firmware helper
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Fix includes order (FATE#322643 bsc#1055900).
- drm/i915/guc: Move GuC core definitions into dedicated files
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move GuC submission declarations into dedicated
  header (FATE#322643 bsc#1055900).
- drm/i915/guc: Move GuC log declarations into dedicated header
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Do not add an extra page for precaution in the
  Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915: avoid potential uninitialized variable use
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: fix check for intel IOMMU (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Remember to create the fake preempt context
  (FATE#322643 bsc#1055900).
- drm/i915/mst: Use MST sideband message transactions for dpms
  control (FATE#322643 bsc#1055900).
- drm/i915/scheduler: Support user-defined priorities (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Preemption! (FATE#322643 bsc#1055900).
- drm/i915: Expand I915_PARAM_HAS_SCHEDULER into a capability
  bitmask (FATE#322643 bsc#1055900).
- drm/i915/execlists: Keep request->priority for its lifetime
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Move bdw GPGPU w/a to emit_bb (FATE#322643
  bsc#1055900).
- drm/i915: Introduce a preempt context (FATE#322643 bsc#1055900).
- drm/i915/execlists: Distinguish the incomplete context notifies
  (FATE#322643 bsc#1055900).
- drm/i915/preempt: Default to disabled mid-command preemption
  levels (FATE#322643 bsc#1055900).
- drm/i915/preempt: Fix WaEnablePreemptionGranularityControlByUMD
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move Guc early init into own function (FATE#322643
  bsc#1055900).
- drm/i915/huc: Move HuC declarations into dedicated header
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Move uC fw helper code into dedicated files
  (FATE#322643 bsc#1055900).
- drm/i915/uc: Create intel_uc_init_mmio (FATE#322643
  bsc#1055900).
- drm/i915/uc: Drop unnecessary forward declaration (FATE#322643
  bsc#1055900).
- drm/i915: Make intel_uncore.h header self-contained (FATE#322643
  bsc#1055900).
- drm/i915: Remove defunct trace points (FATE#322643 bsc#1055900).
- drm/i915: Fix some tracepoints to capture full 64b (FATE#322643
  bsc#1055900).
- drm/i915: Remove WA_(SET|CLR)_BIT (FATE#322643 bsc#1055900).
- drm/i915: Move MMCD_MISC_CTRL from context w/a to standard
  (FATE#322643 bsc#1055900).
- drm/i915: Transform whitelisting WAs into a simple reg write
  (FATE#322643 bsc#1055900).
- drm/i915: Remove use_mmio_flip modparm, v2 (FATE#322643
  bsc#1055900).
- drm/i915: Skip vblank waits for cursor updates when watermarks
  dont need updating (FATE#322643 bsc#1055900).
- drm/i915: Unset legacy_cursor_update early in
  intel_atomic_commit, v3 (FATE#322643 bsc#1055900).
- drm/i915: Organize GLK_COLORS (FATE#322643 bsc#1055900).
- drm/i915: Organize GEN features inheritance (FATE#322643
  bsc#1055900).
- drm/i915/skl: Fix has_ipc on skl and document WaDisableIPC
  (FATE#322643 bsc#1055900).
- drm/i915/glk, cnl: Implement WaDisableScalarClockGating
  (FATE#322643 bsc#1055900).
- drm/i915: Add has_psr-flag to gen9lp (FATE#322643 bsc#1055900).
- drm/i915/gen8+: Init/reset display interrupts only if i915
  IRQs are enabled (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Set same power state before hibernation image
  save/restore (FATE#322643 bsc#1055900).
- drm/i915/execlists: Cache the last priolist lookup (FATE#322643
  bsc#1055900).
- drm/i915: Give the invalid priority a magic name (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Move request unwinding to a separate
  function (FATE#322643 bsc#1055900).
- drm/i915: Move i915_gem_restore_fences to i915_gem_resume
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Replace wmb() with i915_gem_chipset_flush()
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170929 (FATE#322643
  bsc#1055900).
- drm/i915: Also discard second CRC on gen8+ platforms
  (FATE#322643 bsc#1055900).
- drm/i915/psr: Set frames before SU entry for psr2 (FATE#322643
  bsc#1055900).
- drm/dp: Add defines for latency in sink (FATE#322643
  bsc#1055900).
- drm/i915: Allow optimized platform checks (FATE#322643
  bsc#1055900).
- drm/i915: Avoid using dev_priv->info.gen directly (FATE#322643
  bsc#1055900).
- i915: Use %%pS printk format for direct addresses (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Notify context-out for lost requests
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add support slice/subslice/eu configs (FATE#322643
  bsc#1055900).
- drm/i915: Compact device info access by a small re-ordering
  (FATE#322643 bsc#1055900).
- drm/i915: Add IS_PLATFORM macro (FATE#322643 bsc#1055900).
- drm/i915/selftests: Try to recover from a wedged GPU during
  reset tests (FATE#322643 bsc#1055900).
- drm/i915/huc: Reorganize HuC authentication (FATE#322643
  bsc#1055900).
- drm/i915: Fix default values of some modparams (FATE#322643
  bsc#1055900).
- drm/i915: Extend I915_PARAMS_FOR_EACH with default member value
  (FATE#322643 bsc#1055900).
- drm/i915: Make I915_PARAMS_FOR_EACH macro more flexible
  (FATE#322643 bsc#1055900).
- drm/i915: Enable scanline read based on frame timestamps
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Microoptimise
  execlists_cancel_port_request() (FATE#322643 bsc#1055900).
- drm/i915: Don't rmw PIPESTAT enable bits (FATE#322643
  bsc#1055900).
- drm/i915: Speed up DMC firmware loading (FATE#322643
  bsc#1055900).
- drm/i915/dp: Remove useless debug about TPS3 support
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Fix buffer size for sink_irq_esi read (FATE#322643
  bsc#1055900).
- drm/i915/mst: Print active mst links after update (FATE#322643
  bsc#1055900).
- drm/i915/mst: Debug log connector name in destroy_connector()
  (FATE#322643 bsc#1055900).
- drm/i915/lrc: Skip no-op per-bb buffer on gen9 (FATE#322643
  bsc#1055900).
- drm/i915/lrc: Only enable per-context and per-bb buffers if set
  (FATE#322643 bsc#1055900).
- drm/i915: Make execlist port count variable (FATE#322643
  bsc#1055900).
- drm/i915: Add execlist_port_complete (FATE#322643 bsc#1055900).
- drm/i915: Wrap port cancellation into a function (FATE#322643
  bsc#1055900).
- drm/i915: Move execlist initialization into intel_engine_cs.c
  (FATE#322643 bsc#1055900).
- drm/i915: Make own struct for execlist items (FATE#322643
  bsc#1055900).
- drm/i915: Make i915_spin_request() static (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915: Rename global i915 to i915_modparams (FATE#322643
  bsc#1055900).
- drm/i915: Confirm request->global_seqno after spin completion
  (FATE#322643 bsc#1055900).
- drm/i915: Check waiter->seqno carefully in case of preemption
  (FATE#322643 bsc#1055900).
- drm/i915: Only wake the waiter from the interrupt if passed
  (FATE#322643 bsc#1055900).
- drm/i915: Document the split in internal and public execbuf
  flags (FATE#322643 bsc#1055900).
- drm/i915: Reorganize .disable hooks for pre-DDI DP (FATE#322643
  bsc#1055900).
- drm/i915: Drop useless HAS_PSR() check (FATE#322643
  bsc#1055900).
- drm/i915: Stop engines before reset (FATE#322643 bsc#1055900).
- drm/i915/cfl: Remove alpha support protection (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Display Wa #1179: WaHardHangonHotPlug (FATE#322643
  bsc#1055900).
- drm/i915: Shrink cnl_ddi_buf_trans (FATE#322643 bsc#1055900).
- drm/i915: Shrink bxt_ddi_buf_trans (FATE#322643 bsc#1055900).
- commit 50db074
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Replace some spaces with tabs (FATE#322643
  bsc#1055900).
- drm/i915/fence: Avoid del_timer_sync() from inside a timer
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Only touch archdata.iommu when it exists
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Don't touch other PCH clock gating bits
  (FATE#322643 bsc#1055900).
- drm/i915: Do not enable DRRS when PSR is enabled (FATE#322643
  bsc#1055900).
- drm/i915/perf: add support for Coffeelake GT2 (FATE#322643
  bsc#1055900).
- drm/i915/perf: disable clk ratio reports on gen9 (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Disable iommu for the mock device
  (FATE#322643 bsc#1055900).
- drm/i915: Return the correct score in i915_ppat_get()
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Cleanup adding GuC work items (FATE#322643
  bsc#1055900).
- drm/i915/guc: Simplify GuC doorbell logic (FATE#322643
  bsc#1055900).
- drm/i915/guc: Submit GuC workitems containing coalesced requests
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Remove obsolete comments and remove unused
  variable (FATE#322643 bsc#1055900).
- drm/i915/execlists: Unwind incomplete requests on resets
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Split insert_request() (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Move insert_request() (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Kick start request processing after a reset
  (FATE#322643 bsc#1055900).
- drm/i915: Cancel all ready but queued requests when wedging
  (FATE#322643 bsc#1055900).
- drm/i915: Reinstate GMBUS and AUX interrupts on gen4/g4x
  (FATE#322643 bsc#1055900).
- drm/i915: Remove duplicated irq_preinstall/uninstall hooks
  (FATE#322643 bsc#1055900).
- drm/i915: Clean up the HWSTAM mess (FATE#322643 bsc#1055900).
- drm/i915: Mask everything in ring HWSTAM on gen6+ in ringbuffer
  mode (FATE#322643 bsc#1055900).
- drm/i915: Extend private i915_param_named macro with description
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce custom variant of module_param_named macro
  (FATE#322643 bsc#1055900).
- drm/i915: Rename lvds_use_ssc modparam to panel_use_ssc
  (FATE#322643 bsc#1055900).
- drm/i915: Mark the userptr invalidate workqueue as
  WQ_MEM_RECLAIM (FATE#322643 bsc#1055900).
- drm/i915/cnl: Change the macro name to
  DPLL_CFGCR0_DCO_FRACTION_SHIFT (FATE#322643 bsc#1055900).
- drm/i915: Gen3 HWSTAM is actually 32 bits (FATE#322643
  bsc#1055900).
- drm/i915: Rewrite GMCH irq handlers to avoid loops (FATE#322643
  bsc#1055900).
- drm/i915: Extract PIPESTAT irq handling into separate functions
  (FATE#322643 bsc#1055900).
- drm/i915: Remove NULL dev_priv checks from irq_uninstall
  (FATE#322643 bsc#1055900).
- drm/i915: Unify the appearance of gen3/4 irq_postistall hooks
  (FATE#322643 bsc#1055900).
- drm/i915: Eliminate PORT_HOTPLUG_EN setup from gen3/4
  irq_postinstall (FATE#322643 bsc#1055900).
- drm/i915: Setup EMR first on all gen2-4 (FATE#322643
  bsc#1055900).
- drm/i915: Introduce GEN2_IRQ_RESET/INIT (FATE#322643
  bsc#1055900).
- drm/i915: Use GEN3_IRQ_RESET/INIT on gen3/4 (FATE#322643
  bsc#1055900).
- drm/i915: s/GEN5/GEN3/ (FATE#322643 bsc#1055900).
- drm/i915: Clear pipestat consistently (FATE#322643 bsc#1055900).
- drm/i915: Don't enable/unmask flip interrupts (FATE#322643
  bsc#1055900).
- drm/i915: Remove the "INDEX" suffix from PPAT marcos
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce private PAT management (FATE#322643
  bsc#1055900).
- drm/i915: Switch over to the LLC/eLLC hotspot avoidance hash
  mode for CCS (FATE#322643 bsc#1055900).
- drm/i915: Simplify i915_reg_read_ioctl (FATE#322643
  bsc#1055900).
- drm/i915: Introduce INTEL_GEN_MASK (FATE#322643 bsc#1055900).
- drm/i915: Refresh VLV/CHV PSR comments on HW PSR_state machine
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Read the context-status HEAD from the HWSP
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Read the context-status buffer from the HWSP
  (FATE#322643 bsc#1055900).
- drm/i915: Allow HW status page to be bound high (FATE#322643
  bsc#1055900).
- drm/i915/lrc: allocate separate page for HWSP (FATE#322643
  bsc#1055900).
- drm/i915/guc: Don't make assumptions while getting the lrca
  offset (FATE#322643 bsc#1055900).
- drm/i915/lrc: Clarify the format of the context image
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Use mul_u32_u32() for 32b x 32b -> 64b
  result (FATE#322643 bsc#1055900).
- drm/i915: Use mul_u32_u32() for 32b x 32b -> 64b result
  (FATE#322643 bsc#1055900).
- drm/i915: Squelch smatch warning for statement with no effect
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Small improvements to guc_wq_item_append
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Remove WQ_WORKLOAD_SHIFT define (FATE#322643
  bsc#1055900).
- drm/i915/guc: Name the default GuC scheduling policy
  (FATE#322643 bsc#1055900).
- drm/i915: Move the context descriptor to an inline helper
  (FATE#322643 bsc#1055900).
- drm/i915/dsi: Replace MIPI command error message with debug
  message (FATE#322643 bsc#1055900).
- drm/i915: Cleanup error paths through eb_lookup_vma()
  (FATE#322643 bsc#1055900).
- drm/i915/spt+: Don't reset invalid AUX channel interrupt bits
  in SDEIMR (FATE#322643 bsc#1055900).
- drm/i915: Name the IPS_PCODE_CONTROL bit (FATE#322643
  bsc#1055900).
- drm/i915: Nuke some bogus tabs from the pcode defines
  (FATE#322643 bsc#1055900).
- drm/i915: Factor out setup_private_pat() (FATE#322643
  bsc#1055900).
- drm/i915: Increase poll time for BDW FCLK_DONE (FATE#322643
  bsc#1055900).
- drm/i915/psr: Add enable_source vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: Add enable_sink vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: Add setup VSC vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: Re-org Activate after enable (FATE#322643
  bsc#1055900).
- drm/i915/psr: Move hsw_enable_source after enabling sink
  (FATE#322643 bsc#1055900).
- drm/i915/psr: Re-create a hsw_psr_enable_source (FATE#322643
  bsc#1055900).
- drm/i915/psr: Unify VSC setup functions (FATE#322643
  bsc#1055900).
- drm/i915/psr: Add activate vfunc (FATE#322643 bsc#1055900).
- drm/i915/psr: hsw_psr_activate (FATE#322643 bsc#1055900).
- drm/i915/psr: vfunc for disabling source (FATE#322643
  bsc#1055900).
- drm/i915/psr: Avoid any PSR stuff on platforms without support
  (FATE#322643 bsc#1055900).
- drm/i915: Only initialize partially filled pagetables
  (FATE#322643 bsc#1055900).
- drm/i915: Make PAT macros more robust (FATE#322643 bsc#1055900).
- drm/i915: Add a default case in gen7 hwsp switch-case
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add support for PCIe extended configuration space
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling for perform_bb_shadow
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling in dispatch_workload
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling for intel_vgpu_pin_mm
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine error handling for
  prepare_execlist_workload (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add error handling for
  intel_gvt_scan_and_shadow_workload (FATE#322643 bsc#1055900).
- drm/i915/gvt: Separate cmd scan from request allocation
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add emulation for BAR2 (aperture) with normal
  file RW approach (FATE#322643 bsc#1055900).
- drm/i915/kvmgt: Sanitize PCI bar emulation (FATE#322643
  bsc#1055900).
- drm/i915: Transform WaDisablePooledEuLoadBalancingFix into a
  simple register write (FATE#322643 bsc#1055900).
- drm/i915: Transform WaDisableDynamicCreditSharing into a simple
  register write (FATE#322643 bsc#1055900).
- drm/i915: Transform WaDisableGafsUnitClkGating into a simple
  reg write (FATE#322643 bsc#1055900).
- drm/i915: WaPushConstantDereferenceHoldDisable needs to modify
  a masked register (FATE#322643 bsc#1055900).
- drm/i915: Transform WaDisableI2mCycleOnWRPort into a simple
  reg write (FATE#322643 bsc#1055900).
- drm/i915: Transform WaInPlaceDecompressionHang into a simple
  reg write (FATE#322643 bsc#1055900).
- drm/i915: Apply the GTT write flush for all !llc machines
  (FATE#322643 bsc#1055900).
- i915: Fix obj size vs. alignment for drm_pci_alloc()
  (FATE#322643 bsc#1055900).
- drm/i915: Disable mmio debugging during user access (FATE#322643
  bsc#1055900).
- drm/i915/skl+: debugfs entry to control IPC (FATE#322643
  bsc#1055900).
- drm/i915/bxt+: Enable IPC support (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Add has_ipc flag in device info structure
  (FATE#322643 bsc#1055900).
- commit 77f9c1e
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/cnl: Extend WM workaround with IPC for CNL (FATE#322643
  bsc#1055900).
- drm/i915/glk: IPC linetime watermark workaround for GLK
  (FATE#322643 bsc#1055900).
- drm/i915/gen10: Calculate and enable transition WM (FATE#322643
  bsc#1055900).
- drm/i915/skl+: Optimize WM calculation (FATE#322643
  bsc#1055900).
- drm/i915: Fixed point fixed16 wrapper cleanup (FATE#322643
  bsc#1055900).
- drm/i915: Disable snooping (userptr, set-cache-level) on gen4
  (FATE#322643 bsc#1055900).
- drm: Pass struct drm_file * to __drm_mode_object_find [v2]
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170907 (FATE#322643
  bsc#1055900).
- drm/i915/cnl:
  WaThrottleEUPerfToAvoidTDBackPressure:cnl(pre-prod) (FATE#322643
  bsc#1055900).
- drm/i915: Lift has-pinned-pages assert to caller of
  ____i915_gem_object_get_pages (FATE#322643 bsc#1055900).
- drm/i915: Display WA #1133 WaFbcSkipSegments:cnl, glk
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow the reg_read ioctl to read the RCS TIMESTAMP
  register (FATE#322643 bsc#1055900).
- drm/i915: Move device_info.has_snoop into the static tables
  (FATE#322643 bsc#1055900).
- drm/i915: Disable MI_STORE_DATA_IMM for i915g/i915gm
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Wa 1181: Fix Backlight issue (FATE#322643
  bsc#1055900).
- drm/i915: Constify load detect mode (FATE#322643 bsc#1055900).
- drm/i915: io unmap functions want __iomem (FATE#322643
  bsc#1055900).
- drm/i915: Wake up the device for the fbdev setup (FATE#322643
  bsc#1055900).
- drm/i915: Add interface to reserve fence registers for vGPU
  (FATE#322643 bsc#1055900).
- drm/i915: Use correct path to trace include (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate crtc->state usage from
  intel_atomic_commit_tail and .crtc_update() (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate crtc->state usage from
  intel_update_pipe_config() (FATE#322643 bsc#1055900).
- drm/i915: Eliminate obj->state usage from pre/post plane update
  (FATE#322643 bsc#1055900).
- drm/i915: Pass proper old/new states to
  intel_plane_atomic_check_with_state() (FATE#322643 bsc#1055900).
- drm/i915: rework IS_*_GT* macros (FATE#322643 bsc#1055900).
- drm/i915: mark all device info struct with __initconst
  (FATE#322643 bsc#1055900).
- drm/i915: add GT number to intel_device_info (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate obj->state usage in g4x/vlv/chv wm
  computation (FATE#322643 bsc#1055900).
- drm/i915: Pass the crtc state explicitly to
  intel_pipe_update_start/end() (FATE#322643 bsc#1055900).
- drm/i915: Pass the new crtc state to color management code
  (FATE#322643 bsc#1055900).
- drm/i915: Consolidate max_cdclk_freq check in
  intel_crtc_compute_min_cdclk() (FATE#322643 bsc#1055900).
- drm/i915: Track minimum acceptable cdclk instead of "minimum
  dotclock" (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DP max voltage (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DDI hdmi level selection (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Move ddi buf trans related functions up
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Move voltage check into ddi buf trans functions
  (FATE#322643 bsc#1055900).
- drm/i915: Enable voltage swing before enabling DDI_BUF_CTL
  (FATE#322643 bsc#1055900).
- drm/i915: Align vswing sequences with old ddi buffer registers
  (FATE#322643 bsc#1055900).
- drm/i915: decouple gen9 and gen10 dp signal levels (FATE#322643
  bsc#1055900).
- drm/i915: Introduce intel_ddi_dp_level (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Avoid ioremap_wc on Cannonlake as well
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: WaDisableI2mCycleOnWRPort (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WA FtrEnableFastAnisoL1BankingFix (FATE#322643
  bsc#1055900).
- drm/i915: Stop using long platform names on clock gating
  functions (FATE#322643 bsc#1055900).
- drm/i915: Discard the request queue if we fail to sleep before
  suspend (FATE#322643 bsc#1055900).
- drm/i915: Clear wedged status upon resume (FATE#322643
  bsc#1055900).
- drm/i915: Always sanity check engine state upon idling
  (FATE#322643 bsc#1055900).
- drm/i915: Don't use GPU relocations prior to cmdparser stalls
  (FATE#322643 bsc#1055900).
- drm/i915: Remove excess indent in intel_finish_reset() caught
  by sparse (FATE#322643 bsc#1055900).
- drm/i915: Beef up of Beef up the IPS vs. CRC workaround
  (FATE#322643 bsc#1055900).
- drm/i915/bios: amend edp block based on intel_vbt_decode
  (FATE#322643 bsc#1055900).
- drm/i915/bios: amend child device flags based on
  intel_vbt_decode (FATE#322643 bsc#1055900).
- drm/i915/bios: amend bdb_general_features (FATE#322643
  bsc#1055900).
- drm/i915/bios: split up iboost to hdmi and dp bitfields
  (FATE#322643 bsc#1055900).
- drm/i915: Fix FBC cfb stride programming for non X-tiled FB
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: don't hardcode DPCLKA_CFGCR0_DDI_CLK_SEL_SHIFT
  (FATE#322643 bsc#1055900).
- drm/i915/bios: drop the rest of the p_ prefixes from pointers
  (FATE#322643 bsc#1055900).
- drm/i915/bios: throw away unused DVO_* macros (FATE#322643
  bsc#1055900).
- drm/i915/bios: group device type definitions together
  (FATE#322643 bsc#1055900).
- drm/i915/bios: document child device config dvo_port values
  a bit better (FATE#322643 bsc#1055900).
- drm/i915/bios: throw away struct old_child_dev_config
  (FATE#322643 bsc#1055900).
- drm/i915/bios: throw away high level child device union
  (FATE#322643 bsc#1055900).
- drm/i915/bios: add legacy contents to common child device config
  (FATE#322643 bsc#1055900).
- drm/i915/bios: remove the raw version of child device config
  (FATE#322643 bsc#1055900).
- drm/i915/bios: document BDB versions of child device config
  fields (FATE#322643 bsc#1055900).
- drm/i915/bios: amend child device config parameters (FATE#322643
  bsc#1055900).
- drm/i915: Beef up the IPS vs. CRC workaround (FATE#322643
  bsc#1055900).
- drm/i915: Make some RPS functions static (FATE#322643
  bsc#1055900).
- drm/i915: Assert that the handle->vma lut is empty on object
  close (FATE#322643 bsc#1055900).
- drm/i915/cnl: WaForceContextSaveRestoreNonCoherent (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaPushConstantDereferenceHoldDisable (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Coffee Lake works on Kaby Lake PCH (FATE#322643
  bsc#1055900).
- drm/i915/cnl: extract cnl_set_procmon_ref_values (FATE#322643
  bsc#1055900).
- drm/i915/cnl: simplify cnl_procmon_values handling (FATE#322643
  bsc#1055900).
- drm/i915: Boost GPU clocks if we miss the pageflip's vblank
  (FATE#322643 bsc#1055900).
- drm/i915: Constify states passed to enable/disable/etc. encoder
  hooks (FATE#322643 bsc#1055900).
- drm/i915: Plumb crtc_state to PSR enable/disable (FATE#322643
  bsc#1055900).
- drm/i915: Init infoframe vfuncs for DP encoders as well
  (FATE#322643 bsc#1055900).
- drm/i915: Move infoframe vfuncs into intel_digital_port
  (FATE#322643 bsc#1055900).
- drm/i915: Disable infoframes when shutting down DDI HDMI
  (FATE#322643 bsc#1055900).
- drm/i915: Check has_infoframes when enabling infoframes
  (FATE#322643 bsc#1055900).
- drm/i915: Re-enable per-engine reset for Broxton (FATE#322643
  bsc#1055900).
- drm/i915/dp: make is_edp non-static and rename to
  intel_dp_is_edp (FATE#322643 bsc#1055900).
- drm/i915/dp: rename intel_dp_is_edp to intel_dp_is_port_edp
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Apply large line width optimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaDisableEnhancedSBEVertexCaching (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add
  WaDisableReplayBufferBankArbitrationOptimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Introduce initial Cannonlake Workarounds
  (FATE#322643 bsc#1055900).
- drm/dp/mst: Sideband message transaction to power up/down nodes
  (FATE#322643 bsc#1055900).
- drm/atomic: Fix freeing connector/plane state too early by
  tracking commits, v3 (FATE#322643 bsc#1055900).
- drm/atomic: Move drm_crtc_commit to drm_crtc_state, v4
  (FATE#322643 bsc#1055900).
- drm/atomic: Return commit in drm_crtc_commit_get for better
  annotation (FATE#322643 bsc#1055900).
- drm/i915: Always wait for flip_done, v2 (FATE#322643
  bsc#1055900).
- drm/dp: Add defines for DP SDP types (FATE#322643 bsc#1055900).
- drm/i915: Deconstruct struct sgt_dma initialiser (FATE#322643
  bsc#1055900).
- drm/i915: Reject unknown syncobj flags (FATE#322643
  bsc#1055900).
- drm/i915: Check incoming alignment for unfenced buffers (on
  i915gm) (FATE#322643 bsc#1055900).
- drm/i915: Hold rcu_read_lock when iterating over the radixtree
  (objects) (FATE#322643 bsc#1055900).
- drm/i915/edp: read edp display control registers unconditionally
  (FATE#322643 bsc#1055900).
- drm/i915: Do not rely on wm preservation for ILK watermarks
  (FATE#322643 bsc#1055900).
- commit 1559905
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Cancel the modeset retry work during modeset cleanup
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Adding ACTHD mmio read handler (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Extract mmio_read_from_hw() common function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine MMIO_RING_F() (FATE#322643 bsc#1055900).
- drm/i915/gvt: properly check per_ctx bb valid state (FATE#322643
  bsc#1055900).
- drm/i915/perf: fix perf enable/disable ioctls with 32bits
  userspace (FATE#322643 bsc#1055900).
- drm/i915: Use a mask when applying WaProgramL3SqcReg1Default
  (FATE#322643 bsc#1055900).
- drm/i915: Report -EFAULT before pwrite fast path into shmemfs
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix PLL initialization for HDMI (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix PLL mapping (FATE#322643 bsc#1055900).
- drm/i915: Use bdw_ddi_translations_fdi for Broadwell
  (FATE#322643 bsc#1055900).
- drm/i915: Fix eviction when the GGTT is idle but full
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix GPU hang after reusing vGPU instance across
  different guest OS (FATE#322643 bsc#1055900).
- drm/i915/bios: parse DDI ports also for CHV for HDMI DDC pin
  and DP AUX channel (FATE#322643 bsc#1055900).
- drm/i915: Read timings from the correct transcoder in
  intel_crtc_mode_get() (FATE#322643 bsc#1055900).
- drm/i915: Order two completing nop_submit_request (FATE#322643
  bsc#1055900).
- drm/i915: Silence compiler warning for hsw_power_well_enable()
  (FATE#322643 bsc#1055900).
- drm/i915: Use crtc_state_is_legacy_gamma in intel_color_check
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Increase the T12 delay quirk to 1300ms
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Get the Panel Power Off timestamp after panel
  is off (FATE#322643 bsc#1055900).
- drm/i915/glk: Fix DMC/DC state idleness calculation (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Reprogram DMC firmware after S3/S4 resume
  (FATE#322643 bsc#1055900).
- drm/i915: Fix DDI PHY init if it was already on (FATE#322643
  bsc#1055900).
- drm/i915/bios: ignore HDMI on port A (FATE#322643 bsc#1055900).
- drm/i915: remove redundant variable hw_check (FATE#322643
  bsc#1055900).
- drm/i915: always update ELD connector type after get modes
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unused 'in_vbl' from i915_get_crtc_scanoutpos()
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: set min brightness from VBT (FATE#322643
  bsc#1055900).
- Revert "drm/i915/bxt: Disable device ready before shutdown
  command" (bsc#1051510).
- drm/i915/bxt: set min brightness from VBT (FATE#322643
  bsc#1055900).
- drm/i915: Fix an error handling in 'intel_framebuffer_init()'
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix incorrect PCI BARs reporting (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Remove one duplicated MMIO (FATE#322643
  bsc#1055900).
- drm/i915: Re-enable GTT following a device reset (FATE#322643
  bsc#1055900).
- drm/i915: Annotate user relocs with __user (FATE#322643
  bsc#1055900).
- drm/i915: Silence sparse by using gfp_t (FATE#322643
  bsc#1055900).
- drm/i915: Add __rcu to radix tree slot pointer (FATE#322643
  bsc#1055900).
- drm/i915: Fix the missing PPAT cache attributes on CNL
  (FATE#322643 bsc#1055900).
- drm/i915: Fix enum pipe vs. enum transcoder for the PCH
  transcoder (FATE#322643 bsc#1055900).
- drm/i915: Make i2c lock ops static (FATE#322643 bsc#1055900).
- drm/i915: Make i9xx_load_ycbcr_conversion_matrix() static
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Increase T12 panel delay to 900 ms to fix DP
  AUX CH timeouts (FATE#322643 bsc#1055900).
- drm/i915: Ignore duplicate VMA stored within the per-object
  handle LUT (FATE#322643 bsc#1055900).
- drm/i915: Skip fence alignemnt check for the CCS plane
  (FATE#322643 bsc#1055900).
- drm/i915: Treat fb->offsets[] as a raw byte offset instead of
  a linear offset (FATE#322643 bsc#1055900).
- drm/i915: Always wake the device to flush the GTT (FATE#322643
  bsc#1055900).
- drm/i915: Recreate vmapping even when the object is pinned
  (FATE#322643 bsc#1055900).
- drm/i915: Quietly cancel FBC activation if CRTC is turned off
  before worker (FATE#322643 bsc#1055900).
- i915: Use drm_syncobj_fence_get (FATE#322643 bsc#1055900).
- drm/syncobj: Add a race-free drm_syncobj_fence_get helper (v2)
  (FATE#322643 bsc#1055900).
- drm/syncobj: Rename fence_get to find_fence (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170818 (FATE#322643
  bsc#1055900).
- drm/i915: Mark the GT as busy before idling the previous request
  (FATE#322643 bsc#1055900).
- drm/i915: Trivial grammar fix s/opt of/opt out of/ in comment
  (FATE#322643 bsc#1055900).
- drm/i915: Replace execbuf vma ht with an idr (FATE#322643
  bsc#1055900).
- drm/i915: Simplify eb_lookup_vmas() (FATE#322643 bsc#1055900).
- drm/i915: Convert execbuf to use struct-of-array packing for
  critical fields (FATE#322643 bsc#1055900).
- drm/i915: Check context status before looking up our obj/vma
  (FATE#322643 bsc#1055900).
- drm/i915: Don't use MI_STORE_DWORD_IMM on Sandybridge/vcs
  (FATE#322643 bsc#1055900).
- drm/i915: Stop touching forcewake following a gen6+ engine reset
  (FATE#322643 bsc#1055900).
- drm/i915: Split pin mapping into per platform functions
  (FATE#322643 bsc#1055900).
- drm/i915/opregion: let user specify override VBT via firmware
  load (FATE#322643 bsc#1055900).
- drm/i915/cnl: Reuse skl_wm_get_hw_state on Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/gen10: implement gen 10 watermarks calculations
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Setup PAT Index (FATE#322643 bsc#1055900).
- drm/i915/edp: Allow alternate fixed mode for eDP if available
  (FATE#322643 bsc#1055900).
- drm/i915: Add support for drm syncobjs (FATE#322643
  bsc#1055900).
- drm/i915: Handle full s64 precision for wait-ioctl (FATE#322643
  bsc#1055900).
- drm/i915: Split obj->cache_coherent to track r/w (FATE#322643
  bsc#1055900).
- drm/i915/hsw+: Add support for multiple power well regs
  (FATE#322643 bsc#1055900).
- drm/i915: Work around GCC anonymous union initialization bug
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Fix guest i915 full ppgtt blocking issue
  (FATE#322643 bsc#1055900).
- drm/i915: Enable guest i915 full ppgtt functionality
  (FATE#322643 bsc#1055900).
- drm/i915: Disconnect 32 and 48 bit ppGTT support (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Add shadow context descriptor updating
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: expose vGPU context hw id (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Refine the intel_vgpu_reset_gtt reset function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add carefully checking in GTT walker paths
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Remove duplicated MMIO entries (FATE#322643
  bsc#1055900).
- drm/i915/gvt: take runtime pm when do early scan and shadow
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Replace duplicated code with exist function
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: To check whether workload scan and shadow has
  mutex hold (FATE#322643 bsc#1055900).
- drm/i915/gvt: Audit and shadow workload during ELSP writing
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Factor out scan and shadow from workload dispatch
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Optimize ring siwtch 2x faster again by light
  weight mmio access wrapper (FATE#322643 bsc#1055900).
- drm/i915/gvt: Optimize ring siwtch 2x faster by removing
  unnecessary POSTING_READ (FATE#322643 bsc#1055900).
- drm/i915/gvt: Use gvt_err to print the resource not enough error
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Validate the compliance test link parameters
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Generalize intel_dp_link_params function to accept
  arguments to be validated (FATE#322643 bsc#1055900).
- drm/i915: More surgically unbreak the modeset vs reset deadlock
  (FATE#322643 bsc#1055900).
- drm/i915: Push i915_sw_fence_wait into the nonblocking atomic
  commit (FATE#322643 bsc#1055900).
- drm/i915/gen9: Send all components in VF state (FATE#322643
  bsc#1055900).
- drm/i915/guc: Rename GuC irq trigger function (FATE#322643
  bsc#1055900).
- drm/i915: Add SW_SYNC to our recommend testing Kconfig
  (FATE#322643 bsc#1055900).
- drm/i915: Introduce intel_hpd_pin function (FATE#322643
  bsc#1055900).
- drm/i915: Simplify hpd pin to port (FATE#322643 bsc#1055900).
- drm/i915/cnl: Dump the right pll registers when dumping pipe
  config (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add allowed DP rates for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915: make structure intel_sprite_plane_funcs static
  (FATE#322643 bsc#1055900).
- drm/i915/fbc: only update no_fbc_reason when active (FATE#322643
  bsc#1055900).
- commit bb1995e
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915/gen10: fix WM latency printing (FATE#322643
  bsc#1055900).
- drm/i915/gen10: fix the gen 10 SAGV block time (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Enable SAGV for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/gen10+: use the SKL code for reading WM latencies
  (FATE#322643 bsc#1055900).
- drm/i915: Avoid null dereference if mst_port is unset
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Drop redundant check for perf.initialised on
  reset (FATE#322643 bsc#1055900).
- drm/i915/perf: Drop lockdep assert for i915_oa_init_reg_state()
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Initialise dynamic sysfs group before creation
  (FATE#322643 bsc#1055900).
- drm/i915: enum i915_power_well_id is not proper kernel-doc
  (FATE#322643 bsc#1055900).
- drm/i915: Add format modifiers for Intel (FATE#322643
  bsc#1055900).
- drm/i915: Add render decompression support (FATE#322643
  bsc#1055900).
- drm/i915: Implement .get_format_info() hook for CCS (FATE#322643
  bsc#1055900).
- drm/i915: Supply the engine-id for our mock_engine()
  (FATE#322643 bsc#1055900).
- drm/i915/psr: Preserve SRD_CTL bit 29 on PSR init (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Removing missing DDI_E bits from CNL (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Retarget igt_render_engine_reset_fallback()
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Initialise the dynamic sysfs attr (FATE#322643
  bsc#1055900).
- drm/i915: enable WaDisableDopClkGating for skl (FATE#322643
  bsc#1055900).
- drm/i915: Fix PCH names for KBP and CNP (FATE#322643
  bsc#1055900).
- drm/i915/perf: Implement I915_PERF_ADD/REMOVE_CONFIG interface
  (FATE#322643 bsc#1055900).
- drm/i915: reorder NOA register definition to follow addresses
  (FATE#322643 bsc#1055900).
- drm/i915/perf: disable NOA logic when not used (FATE#322643
  bsc#1055900).
- drm/i915/perf: leave GDT_CHICKEN_BITS programming in configs
  (FATE#322643 bsc#1055900).
- drm/i915/perf: prune OA configs (FATE#322643 bsc#1055900).
- drm/i915: add const to bin_attribute (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170731 (FATE#322643
  bsc#1055900).
- drm/i915: Remove unused i915_err_print_instdone (FATE#322643
  bsc#1055900).
- drm/i915: Include mbox details for pcode read/write failures
  (FATE#322643 bsc#1055900).
- drm/i915/sdvo: Shut up state checker with hdmi cards on gen3
  (FATE#322643 bsc#1055900).
- drm/i915: Rework sdvo proxy i2c locking (FATE#322643
  bsc#1055900).
- drm/i915: Call the unlocked version of
  i915_gem_object_get_pages() (FATE#322643 bsc#1055900).
- drm/i915: Move i915_gem_object_phys_attach() (FATE#322643
  bsc#1055900).
- drm/i915: Pin the pages before acquiring struct_mutex for
  display (FATE#322643 bsc#1055900).
- drm/i915: Make i915_gem_object_phys_attach() use obj->mm.lock
  more appropriately (FATE#322643 bsc#1055900).
- drm/i915: Trim struct_mutex usage for kms (FATE#322643
  bsc#1055900).
- drm/i915: Handle msr read failure gracefully (FATE#322643
  bsc#1055900).
- drm/i915/fbc: add comments to the FBC auxiliary structs
  (FATE#322643 bsc#1055900).
- drm/i915: cleanup the CHICKEN_MISC_2 (re)definitions
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Fix kbuild error (FATE#322643 bsc#1055900).
- drm/i915: Squelch reset messages during selftests (FATE#322643
  bsc#1055900).
- drm/i915/selftest: Refactor reset locking (FATE#322643
  bsc#1055900).
- drm/i915: Don't touch fence->error when resetting an innocent
  request (FATE#322643 bsc#1055900).
- drm/i915: Enforce that CS packets are qword aligned (FATE#322643
  bsc#1055900).
- drm/i915/glk: set HDMI 2.0 identifier (FATE#322643 bsc#1055900).
- drm/i915: set colorspace for YCBCR420 outputs (FATE#322643
  bsc#1055900).
- drm/i915: prepare csc unit for YCBCR420 output (FATE#322643
  bsc#1055900).
- drm/i915: prepare pipe for YCBCR420 output (FATE#322643
  bsc#1055900).
- drm/i915: prepare scaler for YCBCR420 modeset (FATE#322643
  bsc#1055900).
- drm/i915: add config function for YCBCR420 outputs (FATE#322643
  bsc#1055900).
- drm/i915: Gather all the power well->domain mappings to one
  place (FATE#322643 bsc#1055900).
- drm/i915: Move hsw_power_well_enable() next to the rest of
  HSW helpers (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Unify the HSW/BDW and GEN9+ power well helpers
  (FATE#322643 bsc#1055900).
- drm/i915/hsw+: Add has_fuses power well attribute (FATE#322643
  bsc#1055900).
- drm/i915/hsw, bdw: Wait for the power well disabled state
  (FATE#322643 bsc#1055900).
- drm/i915/hsw, bdw: Add irq_pipe_mask, has_vga power well
  attributes (FATE#322643 bsc#1055900).
- drm/i915/hsw+: Unify the hsw/bdw and gen9+ power well req/state
  macros (FATE#322643 bsc#1055900).
- drm/i915/hsw, bdw: Split power well set to enable/disable
  helpers (FATE#322643 bsc#1055900).
- drm/i915/hsw, bdw: Remove redundant state check during power
  well toggling (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Remove redundant state check during power well
  toggling (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Remove redundant power well state assert during
  enabling (FATE#322643 bsc#1055900).
- drm/i915/bxt, glk: Give a proper name to the power well struct
  phy field (FATE#322643 bsc#1055900).
- drm/i915: Check for duplicated power well IDs (FATE#322643
  bsc#1055900).
- drm/i915/hsw, bdw: Add an ID for the global display power well
  (FATE#322643 bsc#1055900).
- drm/i915/gen2: Add an ID for the display pipes power well
  (FATE#322643 bsc#1055900).
- drm/i915: Assign everywhere the always-on power well ID
  (FATE#322643 bsc#1055900).
- drm/i915: Unify power well ID enums (FATE#322643 bsc#1055900).
- drm/i915/chv: Add unique power well ID for the pipe A power well
  (FATE#322643 bsc#1055900).
- drm/i915: Simplify scaler init during CRTC HW readout
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Exercise independence of per-engine resets
  (FATE#322643 bsc#1055900).
- drm/i915: Disable per-engine reset for Broxton (FATE#322643
  bsc#1055900).
- drm/i915: Emit a user level message when resetting the GPU
  (or engine) (FATE#322643 bsc#1055900).
- drm/i915: Make i915_gem_context_mark_guilty() safe for unlocked
  updates (FATE#322643 bsc#1055900).
- drm/i915: Clear engine irq posted following a reset (FATE#322643
  bsc#1055900).
- drm/i915: Assert that machine is wedged for nop_submit_request
  (FATE#322643 bsc#1055900).
- drm/i915: Wake up waiters after setting the WEDGED bit
  (FATE#322643 bsc#1055900).
- drm/i915: Move idle checks before
  intel_engine_init_global_seqno() (FATE#322643 bsc#1055900).
- drm/i915: Clear execlist port[] before updating seqno on wedging
  (FATE#322643 bsc#1055900).
- drm/i915: Check the execlist queue for pending requests before
  declaring idle (FATE#322643 bsc#1055900).
- drm/i915: Check execlist/ring status during hangcheck
  (FATE#322643 bsc#1055900).
- drm/i915: Flush the execlist ports if idle (FATE#322643
  bsc#1055900).
- drm/i915: Serialize per-engine resets against new requests
  (FATE#322643 bsc#1055900).
- drm/i915: Reset context image on engines after triggering the
  reset (FATE#322643 bsc#1055900).
- drm/i915: Report execlists irq bit in debugfs (FATE#322643
  bsc#1055900).
- Revert "drm/i915: Add heuristic to determine better way to
  adjust brightness" (FATE#322643 bsc#1055900).
- Revert "drm/i915: Add option to support dynamic backlight via
  DPCD" (FATE#322643 bsc#1055900).
- drm/i915: Drop unpin stall in atomic_prepare_commit (FATE#322643
  bsc#1055900).
- drm/i915: Remove intel_flip_work infrastructure (FATE#322643
  bsc#1055900).
- drm/i915: adjust has_pending_fb_unpin to atomic (FATE#322643
  bsc#1055900).
- drm/i915: Rip out legacy page_flip completion/irq handling
  (FATE#322643 bsc#1055900).
- drm/i915: s/INTEL_INFO(dev_priv)->gen/INTEL_GEN(dev_priv)
  in i915_irq (FATE#322643 bsc#1055900).
- drm/i915: Nuke legacy flip queueing code (FATE#322643
  bsc#1055900).
- drm/i915: Pass enum pipe to
  intel_set_pch_fifo_underrun_reporting() (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Mark contexts as lost during freeing of
  mock device (FATE#322643 bsc#1055900).
- drm/i915: unregister interfaces first in unload (FATE#322643
  bsc#1055900).
- drm/i915: Fix fbdev unload sequence (FATE#322643 bsc#1055900).
- drm/atomic-helper: Fix leak in disable_all (FATE#322643
  bsc#1055900).
- drm/i915/selftests: Attach a stub pm_domain (FATE#322643
  bsc#1055900).
- drm/i915: Drain the device workqueue on unload (FATE#322643
  bsc#1055900).
- drm/i915: More stolen quirking (FATE#322643 bsc#1055900).
- drm/i915: Explicit the connector name for DP link training
  result (FATE#322643 bsc#1055900).
- commit d7aac3c
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Consistently use enum pipe for PCH transcoders
  (FATE#322643 bsc#1055900).
- drm/i915: Fix error checking/locking in perf/lookup_context()
  (FATE#322643 bsc#1055900).
- drm: Handle properties in the core for atomic drivers
  (FATE#322643 bsc#1055900).
- drm: Don't update property values for atomic drivers
  (FATE#322643 bsc#1055900).
- drm/i915: Use the drm_driver.dumb_destroy default (FATE#322643
  bsc#1055900).
- drm/fb-helper: pass physical dimensions to fbdev (FATE#322643
  bsc#1055900).
- drm: i915: remove dead code and pointless local lut storage
  (FATE#322643 bsc#1055900).
- drm/fb-helper: add new drm_setup_crtcs_fb() function
  (FATE#322643 bsc#1055900).
- drm/fb: Fix pointer dereference before null check (FATE#322643
  bsc#1055900).
- drm: Create a format/modifier blob (FATE#322643 bsc#1055900).
- drm: Plumb modifiers through plane init (FATE#322643
  bsc#1055900).
- drm: Fix warning when building docs for scdc_helper (FATE#322643
  bsc#1055900).
- drm/modes: Fix drm_mode_is_420_only() comment (FATE#322643
  bsc#1055900).
- drm/dumb-buffers: Add defaults for .dumb_map_offset and
  .dumb_destroy (FATE#322643 bsc#1055900).
- drm/gem: Add drm_gem_dumb_map_offset() (FATE#322643
  bsc#1055900).
- drm/atomic: implement drm_atomic_helper_commit_tail for
  runtime_pm users (FATE#322643 bsc#1055900).
- drm: Improve kerneldoc for drm_modeset_lock (FATE#322643
  bsc#1055900).
- drm/fb-helper: Support deferred setup (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170717 (FATE#322643
  bsc#1055900).
- drm/i915: Protect against deferred fbdev setup (FATE#322643
  bsc#1055900).
- drm/i915/fbdev: Always forward hotplug events (FATE#322643
  bsc#1055900).
- drm/i915/skl+: unify cpp value in WM calculation (FATE#322643
  bsc#1055900).
- drm/i915/skl+: WM calculation don't require height (FATE#322643
  bsc#1055900).
- drm/i915: Addition wrapper for fixed16.16 operation (FATE#322643
  bsc#1055900).
- drm/i915: cleanup fixed-point wrappers naming (FATE#322643
  bsc#1055900).
- drm/i915: Always perform internal fixed16 division in 64 bits
  (FATE#322643 bsc#1055900).
- drm/i915: take-out common clamping code of fixed16 wrappers
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add missing type case (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add max allowed Cannonlake DC (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Get DDI clock based on PLLs (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Inherit RPS stuff from previous platforms
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Gen10 render context size (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Don't trust VBT's alternate pin for port D for
  now (FATE#322643 bsc#1055900).
- drm/i915: Fix the kernel panic when using aliasing ppgtt
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake color init (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add force wake for gen10+ (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix comment about AUX IO power well enable/disable
  (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Don't remove secondary power well requests
  (FATE#322643 bsc#1055900).
- drm/i915/bxt, glk: Fix assert on conditions for DC9 enabling
  (FATE#322643 bsc#1055900).
- drm/i915/skl: Don't disable misc IO power well during display
  uninit (FATE#322643 bsc#1055900).
- drm/i915/gen9+: Add 10 us delay after power well 1/AUX IO pw
  disabling (FATE#322643 bsc#1055900).
- drm/i915: Only free the oldest stale context before allocating
  (FATE#322643 bsc#1055900).
- drm/i915: Drop request retirement before reaping stale contexts
  (FATE#322643 bsc#1055900).
- drm/i915: Move stale context reaping to common
  i915_gem_context_create (FATE#322643 bsc#1055900).
- drm/i915: Check new context against kernel_context after
  reporting an error (FATE#322643 bsc#1055900).
- drm/i915: Setting pch_id for HSW/BDW in virtual environment
  (FATE#322643 bsc#1055900).
- drm: i915: sysfs: constify attribute_group structures
  (FATE#322643 bsc#1055900).
- drm/i915/edp: Add a T12 panel delay quirk to fix DP AUX CH
  timeouts (FATE#322643 bsc#1055900).
- drm/i915/skl+: Scaling not supported in IF-ID Interlace mode
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: Check for supported plane configuration in
  Interlace mode (FATE#322643 bsc#1055900).
- drm/i915: Fix use-after-free of context during free_contexts
  (FATE#322643 bsc#1055900).
- drm/i915: Prevent kernel panic when reading/writing compliance
  debugfs files, v2 (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170703 (FATE#322643
  bsc#1055900).
- drm/i915: Avoid keeping waitboost active for signaling threads
  (FATE#322643 bsc#1055900).
- drm/i915: Drop flushing of the object free list/worker from
  i915_gem_suspend (FATE#322643 bsc#1055900).
- drm/i915: Cancel pending execlists irq handler upon idling
  (FATE#322643 bsc#1055900).
- drm/i915/selftests: Fix mutex imbalance for
  igt_render_engine_reset_fallback (FATE#322643 bsc#1055900).
- drm/i915/dp: Remove -1/+1 from t11_t12 for Gen9_LP/CNP case
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Fix the t11_t12 panel power cycle delay from VBT
  read (FATE#322643 bsc#1055900).
- drm/i915: Add option to support dynamic backlight via DPCD
  (FATE#322643 bsc#1055900).
- drm/i915: Add heuristic to determine better way to adjust
  brightness (FATE#322643 bsc#1055900).
- drm/i915: Set PWM divider to match desired frequency in vbt
  (FATE#322643 bsc#1055900).
- drm/i915: Always use 9 bits of the LPC bridge device ID for
  PCH detection (FATE#322643 bsc#1055900).
- drm/i915: Clean up some expressions (FATE#322643 bsc#1055900).
- drm/i915: Document that PPT==CPT and WPT==LPT (FATE#322643
  bsc#1055900).
- drm/i915: s/Couar/Cougar/ (FATE#322643 bsc#1055900).
- drm/i915: Use HAS_PCH_CPT() everywhere (FATE#322643
  bsc#1055900).
- drm/i915: pass the vma to insert_entries (FATE#322643
  bsc#1055900).
- drm/i915: Cancel pending execlist tasklet upon wedging
  (FATE#322643 bsc#1055900).
- drm/i915: Assert the vma's active tracking is clear before free
  (FATE#322643 bsc#1055900).
- drm/i915: select CRC32 (FATE#322643 bsc#1055900).
- drm/i915: Enable Engine reset and recovery support (FATE#322643
  bsc#1055900).
- drm/i915/selftests: reset engine self tests (FATE#322643
  bsc#1055900).
- drm/i915: Export per-engine reset count info to debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Add engine reset count to error state (FATE#322643
  bsc#1055900).
- drm/i915: Add support for per engine reset recovery (FATE#322643
  bsc#1055900).
- drm/i915: Modify error handler for per engine hang recovery
  (FATE#322643 bsc#1055900).
- drm/i915: Update i915.reset to handle engine resets (FATE#322643
  bsc#1055900).
- drm/i915: Look for active requests earlier in the reset path
  (FATE#322643 bsc#1055900).
- drm/i915: Wait for concurrent global resets to complete
  (FATE#322643 bsc#1055900).
- drm/i915: Enable rcu-only context lookups (FATE#322643
  bsc#1055900).
- drm/i915: Allow contexts to be unreferenced locklessly
  (FATE#322643 bsc#1055900).
- drm/i915: Group all the global context information together
  (FATE#322643 bsc#1055900).
- drm/i915: Do not re-calculate num_rings locally (FATE#322643
  bsc#1055900).
- drm/i915: Simplify intel_engines_init (FATE#322643 bsc#1055900).
- drm/i915: Make intel_digital_port_connected() work for any port
  (FATE#322643 bsc#1055900).
- drm/syncobj: Fix kerneldoc (FATE#322643 bsc#1055900).
- drm/atomic: Allow drm_atomic_helper_swap_state to fail
  (FATE#322643 bsc#1055900).
- drm/i915: Handle drm_atomic_helper_swap_state failure
  (FATE#322643 bsc#1055900).
- drm/atomic: Change drm_atomic_helper_swap_state to return an
  error (FATE#322643 bsc#1055900).
- drm: Update docs around gem_free_object (FATE#322643
  bsc#1055900).
- drm: Don't complain too much about struct_mutex (FATE#322643
  bsc#1055900).
- drm: add helper functions for YCBCR420 handling (FATE#322643
  bsc#1055900).
- drm/edid: parse ycbcr 420 deep color information (FATE#322643
  bsc#1055900).
- drm/edid: parse YCBCR420 videomodes from EDID (FATE#322643
  bsc#1055900).
- drm: add helper to validate YCBCR420 modes (FATE#322643
  bsc#1055900).
- drm/edid: cleanup patch for CEA extended-tag macro (FATE#322643
  bsc#1055900).
- drm/edid: parse sink information before CEA blocks (FATE#322643
  bsc#1055900).
- drm/edid: complete CEA modedb(VIC 1-107) (FATE#322643
  bsc#1055900).
- drm/fb-helper: separate the fb_setcmap helper into atomic and
  legacy paths (FATE#322643 bsc#1055900).
- commit 963a693
* Wed Feb 21 2018 tiwai@suse.de
- drm/atomic-helper: update lut props directly in
  ..._legacy_gamma_set (FATE#322643 bsc#1055900).
- drm: rename, adjust and export drm_atomic_replace_property_blob
  (FATE#322643 bsc#1055900).
- drm/dp/mst: Use memchr_inv() instead of memcmp() against a
  zeroed array (FATE#322643 bsc#1055900).
- drm/atomic: Make private objs proper objects (FATE#322643
  bsc#1055900).
- drm/atomic: Remove pointless private object NULL state check
  (FATE#322643 bsc#1055900).
- drm/i915: Use correct iterator macro (FATE#322643 bsc#1055900).
- drm/atomic: Use new iterator macros in
  drm_atomic_helper_wait_for_flip_done (FATE#322643 bsc#1055900).
- drm/atomic: Use the new helpers in
  drm_atomic_helper_disable_all() (FATE#322643 bsc#1055900).
- drm/atomic: Use the correct iterator macro in atomic_remove_fb
  (FATE#322643 bsc#1055900).
- drm: inhibit drm drivers register to uninitialized drm core
  (FATE#322643 bsc#1055900).
- drm/fb-helper: remove drm_fb_helper_save_lut_atomic (FATE#322643
  bsc#1055900).
- drm/fb-helper: keep the .gamma_store updated in
  drm_fb_helper_setcmap (FATE#322643 bsc#1055900).
- drm/fb-helper: factor out pseudo-palette (FATE#322643
  bsc#1055900).
- drm/fb-helper: Split dpms handling into legacy and atomic paths
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Stop using mode_config.mutex for internals
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Push locking into
  restore_fbdev_mode_atomic|legacy (FATE#322643 bsc#1055900).
- drm/fb-helper: Push locking into pan_display_atomic|legacy
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Drop locking from the vsync wait ioctl code
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Push locking in fb_is_bound (FATE#322643
  bsc#1055900).
- drm/fb-helper: Add top-level lock (FATE#322643 bsc#1055900).
- drm/i915: Drop FBDEV #ifdev in mst code (FATE#322643
  bsc#1055900).
- drm/fb-helper: Push down modeset lock into FB helpers
  (FATE#322643 bsc#1055900).
- drm: Remove pending_read_domains and pending_write_domain
  (FATE#322643 bsc#1055900).
- drm/fb-helper: Remove drm_mode_config_fb (FATE#322643
  bsc#1055900).
- drm/atomic: initial support for asynchronous plane update
  (FATE#322643 bsc#1055900).
- drm/core: Fail atomic IOCTL with no CRTC state but with
  signaling (FATE#322643 bsc#1055900).
- drm/atomic-helper: Simplify commit tracking locking (FATE#322643
  bsc#1055900).
- drm/i915: Drop drm_vblank_cleanup (FATE#322643 bsc#1055900).
- drm: Add drm_atomic_helper_wait_for_flip_done() (FATE#322643
  bsc#1055900).
- drm: Check for drm_device->dev in drm_set_busid (FATE#322643
  bsc#1055900).
- drm: Convert CMA fbdev console suspend helpers to use bool
  (FATE#322643 bsc#1055900).
- drm: More links for gamma support helpers (FATE#322643
  bsc#1055900).
- drm/doc: Improve ioctl/fops docs a bit more (FATE#322643
  bsc#1055900).
- drm/pci: Deprecate drm_pci_init/exit completely (FATE#322643
  bsc#1055900).
- drm: Remove drm_driver->set_busid hook (FATE#322643
  bsc#1055900).
- drm/vblank: Consistent drm_crtc_ prefix (FATE#322643
  bsc#1055900).
- drm/vblank: _ioctl posfix for ioctl handler (FATE#322643
  bsc#1055900).
- drm/doc: vblank cleanup (FATE#322643 bsc#1055900).
- drm/i915: Clear lost context-switch interrupts across reset
  (FATE#322643 bsc#1055900).
- drm/i915/bxt: use NULL for GPIO connection ID (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix LSPCON support (FATE#322643 bsc#1055900).
- drm/i915: Initialize 'data' in intel_dsi_dcs_backlight.c
  (FATE#322643 bsc#1055900).
- drm/i915: Avoid the gpu reset vs. modeset deadlock (FATE#322643
  bsc#1055900).
- drm/i915: Suppress switch_mm emission between the same
  aliasing_ppgtt (FATE#322643 bsc#1055900).
- drm/i915: Return correct EDP voltage swing table for 0.85V
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add slice and subslice information to debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: remove unused function declaration (FATE#322643
  bsc#1055900).
- drm/i915: fix backlight invert for non-zero minimum brightness
  (FATE#322643 bsc#1055900).
- drm/i915/shrinker: Wrap need_resched() inside preempt-disable
  (FATE#322643 bsc#1055900).
- drm/i915/perf: fix flex eu registers programming (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Change the max length of mmio_reg_rw from 4 to 8
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Initialize MMIO Block with HW state (FATE#322643
  bsc#1055900).
- drm/i915/gvt: clean workload queue if error happened
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: change resetting to resetting_eng (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Extend KBL platform support in GVT-g (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix the vblank timer close issue after shutdown
  VMs in reverse (FATE#322643 bsc#1055900).
- drm/i915: Fix bad comparison in skl_compute_plane_wm
  (FATE#322643 bsc#1055900).
- drm/i915: Force CPU synchronisation even if userspace requests
  ASYNC (FATE#322643 bsc#1055900).
- drm/i915: Only skip updating execobject.offset after error
  (FATE#322643 bsc#1055900).
- drm/i915: Only mark the execobject as pinned on success
  (FATE#322643 bsc#1055900).
- drm/i915: Remove assertion from raw __i915_vma_unpin()
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix loadgen select programming on ddi vswing
  sequence (FATE#322643 bsc#1055900).
- drm/i915/selftests: Fix an error handling path in
  'mock_gem_device()' (FATE#322643 bsc#1055900).
- drm/i915: Unbreak gpu reset vs. modeset locking (FATE#322643
  bsc#1055900).
- drm/i915: Fix cursor updates on some platforms (FATE#322643
  bsc#1055900).
- drm/i915: Fix user ptr check size in eb_relocate_vma()
  (FATE#322643 bsc#1055900).
- drm: vblank: Fix vblank timestamp update (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Use fence error from GVT request for workload
  status (FATE#322643 bsc#1055900).
- drm/i915/gvt: remove scheduler_mutex in per-engine
  workload_thread (FATE#322643 bsc#1055900).
- drm/i915/gvt: Revert "drm/i915/gvt: Fix possible recursive
  locking issue" (FATE#322643 bsc#1055900).
- drm/i915/gvt: Audit the command buffer address (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix a memory leak in intel_gvt_init_gtt()
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix the CURSOR_COEFF_MASK used in DDI Vswing
  Programming (FATE#322643 bsc#1055900).
- drm/i915/cfl: Fix Workarounds (FATE#322643 bsc#1055900).
- drm/i915: Avoid undefined behaviour of "u32 >> 32" (FATE#322643
  bsc#1055900).
- drm/i915: Fix an error checking test (FATE#322643 bsc#1055900).
- drm/i915/gvt: Make function dpy_reg_mmio_readx safe (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Don't read ADPA_CRT_HOTPLUG_MONITOR from host
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Set initial PORT_CLK_SEL vreg for BDW (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix possible recursive locking issue (FATE#322643
  bsc#1055900).
- drm: Remove unused drm_file parameter to
  drm_syncobj_replace_fence() (FATE#322643 bsc#1055900).
- drm/i915: Clear execbuf's vma backpointer upon release
  (FATE#322643 bsc#1055900).
- drm/i915: Pass the right flags to i915_vma_move_to_active()
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix RMW on ddi vswing sequence (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170619 (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake workarounds (FATE#322643
  bsc#1055900).
- drm/i915: Store 9 bits of PCI Device ID for platforms with a
  LP PCH (FATE#322643 bsc#1055900).
- drm/i915: Stash a pointer to the obj's resv in the vma
  (FATE#322643 bsc#1055900).
- drm/i915: Async GPU relocation processing (FATE#322643
  bsc#1055900).
- drm/i915: Allow execbuffer to use the first object as the batch
  (FATE#322643 bsc#1055900).
- drm/i915: Wait upon userptr get-user-pages within execbuffer
  (FATE#322643 bsc#1055900).
- drm/i915: First try the previous execbuffer location
  (FATE#322643 bsc#1055900).
- drm/i915: Store a persistent reference for an object in the
  execbuffer cache (FATE#322643 bsc#1055900).
- drm/i915: Eliminate lots of iterations over the execobjects
  array (FATE#322643 bsc#1055900).
- drm/i915: Disable EXEC_OBJECT_ASYNC when doing relocations
  (FATE#322643 bsc#1055900).
- drm/i915: Pass vma to relocate entry (FATE#322643 bsc#1055900).
- drm/i915: Store a direct lookup from object handle to vma
  (FATE#322643 bsc#1055900).
- drm/i915: Fix retrieval of hangcheck stats (FATE#322643
  bsc#1055900).
- drm/i915: Store i915_gem_object_is_coherent() as a bit next
  to cache-dirty (FATE#322643 bsc#1055900).
- drm/i915: Mark CPU cache as dirty on every transition for CPU
  writes (FATE#322643 bsc#1055900).
- commit b736327
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Make i915_vma_destroy() static (FATE#322643
  bsc#1055900).
- drm/i915: Actually attach the tv_format property to the SDVO
  connector (FATE#322643 bsc#1055900).
- drm/i915/gvt: Refine virtual reset function (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Fix GDRST vreg state after reset (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Tuning the size of MMIO hash lookup table to 2048
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add helper for tuning MMIO hash table (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Make the MMIO attribute wrappers be inline
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Make mmio_attribute as type u8 to save 1.5MB
  memory (FATE#322643 bsc#1055900).
- drm/i915/gvt: Cleanup struct intel_gvt_mmio_info (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Optimize MMIO register handling for some large
  MMIO blocks (FATE#322643 bsc#1055900).
- drm/i915/gvt: add gtt_invalidate API to flush the GTT TLB
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add runtime_pm get/put to proctect MMIO accessing
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: remove redundant -Wall (FATE#322643 bsc#1055900).
- drm/i915/gvt: Legacy HSW related MMIO handler clean up
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Trigger scheduling after context complete
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Support event based scheduling (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Delete gvt_dbg_cmd() in cmd_parser_exec()
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: Change flood gvt dmesg into trace (FATE#322643
  bsc#1055900).
- drm/i915/gvt: clean up the unused last_ctx_submit_time of
  struct intel_vgpu (FATE#322643 bsc#1055900).
- drm/i915/gvt: add RING_INSTDONE and SC_INSTDONE mmio handler
  in GVT-g (FATE#322643 bsc#1055900).
- drm/i915/gvt: implement per-vm mmio switching optimization
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: refactor function intel_vgpu_submit_execlist
  (FATE#322643 bsc#1055900).
- drm/i915/gvt: rewrite the trace gvt:gvt_command using trace
  style approach (FATE#322643 bsc#1055900).
- Revert "drm/i915/skl: New ddb allocation algorithm" (FATE#322643
  bsc#1055900).
- drm/i915/glk: Add cold boot sequence for GLK DSI (FATE#322643
  bsc#1055900).
- drm/i915/glk: Split GLK DSI device ready functionality
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: make function cnl_ddi_dp_set_dpll_hw_state static
  (FATE#322643 bsc#1055900).
- drm/i915: Remove pipe A quirk remnants (FATE#322643
  bsc#1055900).
- drm/i915: Drop pipe A quirk for Thinkapd T60 (FATE#322643
  bsc#1055900).
- drm/i915: Drop pipe A quirk for Toshiba Protege R205-S209
  (FATE#322643 bsc#1055900).
- drm/i915: Add i830 "pipes power well" (FATE#322643 bsc#1055900).
- drm/i915: Use a loop for the "three times for luck" DPLL
  procedure (FATE#322643 bsc#1055900).
- drm/i915: Split vma exec_link/evict_link (FATE#322643
  bsc#1055900).
- drm/i915: Use vma->exec_entry as our double-entry placeholder
  (FATE#322643 bsc#1055900).
- drm/i915: Amalgamate execbuffer parameter structures
  (FATE#322643 bsc#1055900).
- drm/i915/perf: add GLK support (FATE#322643 bsc#1055900).
- drm/i915/perf: add KBL support (FATE#322643 bsc#1055900).
- drm/i915: add KBL GT2/GT3 check macros (FATE#322643
  bsc#1055900).
- drm/i915/perf: remove perf.hook_lock (FATE#322643 bsc#1055900).
- drm/i915/perf: per-gen timebase for checking sample freq
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Add more OA configs for BDW, CHV, SKL + BXT
  (FATE#322643 bsc#1055900).
- drm/i915/perf: Add OA unit support for Gen 8+ (FATE#322643
  bsc#1055900).
- drm/i915/perf: Add 'render basic' Gen8+ OA unit configs
  (FATE#322643 bsc#1055900).
- drm/i915/perf: rework mux configurations queries (FATE#322643
  bsc#1055900).
- drm/i915: expose _SUBSLICE_MASK GETPARM (FATE#322643
  bsc#1055900).
- drm/i915: expose _SLICE_MASK GETPARM (FATE#322643 bsc#1055900).
- drm/i915: Reinstate reservation_object zapping for batch_pool
  objects (FATE#322643 bsc#1055900).
- drm/i915: Spin for struct_mutex inside shrinker (FATE#322643
  bsc#1055900).
- drm/i915: Only restrict noreclaim in the early shrink passes
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Basic DDI plumbing for Coffee Lake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Enable wrpll computation for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: LSPCON support is gen9+ (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable fifo underrun for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix Cannonlake scaler mode programing (FATE#322643
  bsc#1055900).
- drm/i915: Use HAS_CSR instead of gen number on DMC load
  (FATE#322643 bsc#1055900).
- drm/i915/DMC/CNL: Load DMC on CNL (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable loadgen_select bit for vswing sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement voltage swing sequence (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add DDI Buffer translation tables for Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add registers related to voltage swing sequences
  (FATE#322643 bsc#1055900).
- drm/i915: Add MMIO helper for 6 ports with different offsets
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Initialize PLLs (FATE#322643 bsc#1055900).
- drm/i915: Configure DPLL's for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: DDI - PLL mapping (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow dynamic cdclk changes on CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement CNL display init/unit sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement .set_cdclk() for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement .get_display_clock_speed() for CNL
  (FATE#322643 bsc#1055900).
- drm/i915: Pass atomic state to backlight enable/disable/set
  callbacks (FATE#322643 bsc#1055900).
- drm/i915: Pass connector state to intel_panel_set_backlight_acpi
  (FATE#322643 bsc#1055900).
- drm/i915: Pass crtc_state and connector state to backlight
  enable/disable functions (FATE#322643 bsc#1055900).
- drm/i915/cfl: Coffee Lake reuses Kabylake DMC (FATE#322643
  bsc#1055900).
- drm/i915/huc: Load HuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/guc: Load GuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for U Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for H Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for S Skus (FATE#322643
  bsc#1055900).
- drm/i915/glk: Remove the alpha_support flag (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Display workarounds for Coffee Lake
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Coffee Lake uses CNP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake platform definition
  (FATE#322643 bsc#1055900).
- drm/i915: Remove the spin-request during execbuf await_request
  (FATE#322643 bsc#1055900).
- drm/i915: Skip adding the request to the signal tree is complete
  (FATE#322643 bsc#1055900).
- drm/i915: Report back whether the irq was armed when adding
  the waiter (FATE#322643 bsc#1055900).
- drm/i915: Check signaled state after enabling signaling
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Clear enable_guc_loading in case of init failure
  (FATE#322643 bsc#1055900).
- drm/i915: Move the unclaimed mmio detection into the powerwell
  for KMS (FATE#322643 bsc#1055900).
- drm/i915: Unify GT* and GT3 definitions (FATE#322643
  bsc#1055900).
- drm/i915: Remove unnecessary PORT3 definition (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Also need power well sanitize (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add power wells for CNL (FATE#322643 bsc#1055900).
- drm/i915/gen10: Set value of Indirect Context Offset for gen10
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake has same MOCS table than Skylake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Configure EU slice power gating (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Cannonlake has 4 planes (3 sprites) per pipe
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: add IS_CNL_REVID macro (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for Y-skus (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for U-skus (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Cannonlake uses CNP PCH (FATE#322643 bsc#1055900).
- drm/i915/cnl: Introduce Cannonlake platform defition
  (FATE#322643 bsc#1055900).
- commit 35f6167
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: s/fbc_fc/fbc_false_color/ (FATE#322643 bsc#1055900).
- drm/i915: Implement fbc_status "Compressing" info for all
  platforms (FATE#322643 bsc#1055900).
- drm/i915: Remove dead code from runtime resume handler
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Panel Power sequence changes for CNP PCH
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: add CNP gmbus support (FATE#322643 bsc#1055900).
- drm/i915/cnp: Backlight support for CNP (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Get/set proper Raw clock frequency on CNP
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Add PCI ID for Cannonpoint LP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Introduce Cannonpoint PCH (FATE#322643
  bsc#1055900).
- drm/i915: Allow kswapd to pause the device whilst reaping
  (FATE#322643 bsc#1055900).
- drm/i915: return the correct usable aperture size under gvt
  environment (FATE#322643 bsc#1055900).
- drm/i915: Check the ring is empty when declaring the engines
  are idle (FATE#322643 bsc#1055900).
- drm/i915/guc: Assert that we switch between known
  ggtt->invalidate functions (FATE#322643 bsc#1055900).
- drm/i915/dvo: fix debug logging on unknown DID (FATE#322643
  bsc#1055900).
- drm/i915/ddi: Avoid long delays during system suspend / eDP
  disabling (FATE#322643 bsc#1055900).
- drm/i915/glk: Fix dotclock calculation in
  skl_check_pipe_max_pixel_rate (FATE#322643 bsc#1055900).
- drm/i915/skl+: consider max supported plane pixel rate while
  scaling (FATE#322643 bsc#1055900).
- drm/i915/skl: New ddb allocation algorithm (FATE#322643
  bsc#1055900).
- drm/i915/guc: Fix doorbell id selection (FATE#322643
  bsc#1055900).
- drm/i915/gvt: Return -EIO if host GuC submission is enabled
  when loading GVT-g (FATE#322643 bsc#1055900).
- drm/i915/gvt: Return -EIO if host enable_execlists not enabled
  when loading GVT-g (FATE#322643 bsc#1055900).
- drm/i915/gvt: Add gvt options sanitize function (FATE#322643
  bsc#1055900).
- drm/i915: Remove toplevel struct_mutex locking from
  debugfs/i915_drop_caches (FATE#322643 bsc#1055900).
- drm/i915: Add kerneldoc to describe i915_gem_object.vma_list
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_sdvo connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Handle force_audio correctly in intel_sdvo
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_hdmi connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_dp properties to atomic, v2 (FATE#322643
  bsc#1055900).
- drm/i915: Make intel_dp->has_audio reflect hw state only
  (FATE#322643 bsc#1055900).
- drm/i915: Convert LVDS connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Convert DSI connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Add plumbing for digital connector state, v3
  (FATE#322643 bsc#1055900).
- drm/i915: Use per-connector scaling mode property (FATE#322643
  bsc#1055900).
- drm/i915: Use atomic scaling_mode instead of panel.fitting_mode
  (FATE#322643 bsc#1055900).
- drm/i915: Remove decoupled MMIO code (FATE#322643 bsc#1055900).
- drm: Reduce scope of 'state' variable (FATE#322643 bsc#1055900).
- drm: Remove duplicate forward declaration (FATE#322643
  bsc#1055900).
- drm: Add const to name field declaration in struct
  drm_prop_enum_list (FATE#322643 bsc#1055900).
- drm/syncobj: add sync_file interaction. (v1.2) (FATE#322643
  bsc#1055900).
- drm: introduce sync objects (v4) (FATE#322643 bsc#1055900).
- drm: remove writeq/readq function definitions (FATE#322643
  bsc#1055900).
- drm/doc: Polish irq helper documentation (FATE#322643
  bsc#1055900).
- drm: Extract drm_vblank.[hc] (FATE#322643 bsc#1055900).
- drm/atomic: Consitfy mode parameter to
  drm_atomic_set_mode_for_crtc() (FATE#322643 bsc#1055900).
- drm: better document how to send out the crtc disable event
  (FATE#322643 bsc#1055900).
- drm: Use vsnprintf extension %%ph (FATE#322643 bsc#1055900).
- drm/doc: move printf helpers out of drmP.h (FATE#322643
  bsc#1055900).
- drm: Use mode_valid() in atomic modeset (FATE#322643
  bsc#1055900).
- drm: Use new mode_valid() helpers in connector probe helper
  (FATE#322643 bsc#1055900).
- drm: Introduce drm_bridge_mode_valid() (FATE#322643
  bsc#1055900).
- drm: Add drm_{crtc/encoder/connector}_mode_valid() (FATE#322643
  bsc#1055900).
- drm: Remove drm_device->virtdev (FATE#322643 bsc#1055900).
- drm/i915: use drm_for_each_connector_iter() (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170529 (FATE#322643
  bsc#1055900).
- drm/i915: Keep the forcewake timer alive for 1ms past the most
  recent use (FATE#322643 bsc#1055900).
- drm/i915/guc: capture GuC logs if FW fails to load (FATE#322643
  bsc#1055900).
- drm/i915/guc: Introduce buffer based cmd transport (FATE#322643
  bsc#1055900).
- drm/i915/guc: Disable send function on fini (FATE#322643
  bsc#1055900).
- drm: Add definition for eDP backlight frequency (FATE#322643
  bsc#1055900).
- drm/i915: Drop AUX backlight enable check for backlight control
  (FATE#322643 bsc#1055900).
- drm/i915: Consolidate #ifdef CONFIG_INTEL_IOMMU (FATE#322643
  bsc#1055900).
- drm/i915: Only GGTT vma may be pinned and prevent shrinking
  (FATE#322643 bsc#1055900).
- drm/i915: Convert i915_gem_object_ops->flags values to use BIT()
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Skip port assign on first iteration of GuC dequeue
  (FATE#322643 bsc#1055900).
- drm/i915: Remove misleading comment in request_alloc
  (FATE#322643 bsc#1055900).
- drm/i915/g33: Improve reset reliability (FATE#322643
  bsc#1055900).
- drm/i915/huc: Update GLK HuC version (FATE#322643 bsc#1055900).
- drm/i915: Check for allocation failure (FATE#322643
  bsc#1055900).
- drm/i915/guc: Remove action status and statistics from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915/g4x: Improve gpu reset reliability (FATE#322643
  bsc#1055900).
- drm/i915/guc: Remove last submission result from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Remove failed doorbell stat from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Reorder media/render reset on g4x (FATE#322643
  bsc#1055900).
- drm/i915: Try harder to reset the GPU (FATE#322643 bsc#1055900).
- drm/i915/selftests: Pretend to be a gfx pci device (FATE#322643
  bsc#1055900).
- drm/i915: Check C for null pointer rather than B (FATE#322643
  bsc#1055900).
- drm/i915/skl+: use linetime latency if ddb size is not available
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: Perform wm level calculations in separate
  function (FATE#322643 bsc#1055900).
- drm/i915/skl+: Watermark calculation cleanup (FATE#322643
  bsc#1055900).
- drm/i915/skl+: Fail the flip if ddb min requirement exceeds
  pipe allocation (FATE#322643 bsc#1055900).
- drm/i915/skl+: no need to memset again (FATE#322643
  bsc#1055900).
- drm/i915/skl: Fail the flip if no FB for WM calculation
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: calculate pixel_rate & relative_data_rate in
  fixed point (FATE#322643 bsc#1055900).
- drm/i915: Use fixed_16_16 wrapper for division operation
  (FATE#322643 bsc#1055900).
- drm/i915: Add more wrapper for fixed_point_16_16 operations
  (FATE#322643 bsc#1055900).
- drm/i915: fix naming of fixed_16_16 wrapper (FATE#322643
  bsc#1055900).
- drm/i915: Don't force serialisation on marking up execlists
  irq posted (FATE#322643 bsc#1055900).
- drm/i915: Stop inlining the execlists IRQ handler (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Reduce lock contention between
  schedule/submit_request (FATE#322643 bsc#1055900).
- drm/i915: Create a kmem_cache to allocate struct i915_priolist
  from (FATE#322643 bsc#1055900).
- drm/i915: Split execlist priority queue into rbtree + linked
  list (FATE#322643 bsc#1055900).
- drm/i915: Use a define for the default priority [0] (FATE#322643
  bsc#1055900).
- drm/i915: Don't mark an execlists context-switch when idle
  (FATE#322643 bsc#1055900).
- drm/i915/execlists: Pack the count into the low bits of the
  port.request (FATE#322643 bsc#1055900).
- drm/i915: Redefine ptr_pack_bits() and friends (FATE#322643
  bsc#1055900).
- drm/i915: Make ptr_unpack_bits() more function-like (FATE#322643
  bsc#1055900).
- drm/i915: Import the kfence selftests for i915_sw_fence
  (FATE#322643 bsc#1055900).
- drm/i915: Remove kref from i915_sw_fence (FATE#322643
  bsc#1055900).
- drm/i915/gen9: Reintroduce WaEnableYV12BugFixInHalfSliceChicken7
  (FATE#322643 bsc#1055900).
- gpu: drm: i915: compress logic into one line (FATE#322643
  bsc#1055900).
- commit 8d45858
* Wed Feb 21 2018 tiwai@suse.de
- gpu: drm: i915: remove dead code (FATE#322643 bsc#1055900).
- drm/i915/guc:fix spelling mistake: "adddress" -> "address"
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Calculate high/low switch count for GLK
  (FATE#322643 bsc#1055900).
- drm/i915: Fixup 64bit divides in timelines selftest (FATE#322643
  bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170515 (FATE#322643
  bsc#1055900).
- drm/i915/perf: rate limit spurious oa report notice (FATE#322643
  bsc#1055900).
- drm/i915/perf: better pipeline aged/aging tail updates
  (FATE#322643 bsc#1055900).
- drm/i915/perf: improve invalid OA format debug message
  (FATE#322643 bsc#1055900).
- drm/i915/perf: improve tail race workaround (FATE#322643
  bsc#1055900).
- drm/i915/perf: no head/tail ref in gen7_oa_read (FATE#322643
  bsc#1055900).
- drm/i915/perf: avoid read back of head register (FATE#322643
  bsc#1055900).
- drm/i915/perf: avoid poll, read, EAGAIN busy loops (FATE#322643
  bsc#1055900).
- drm/i915/perf: fix gen7_append_oa_reports comment (FATE#322643
  bsc#1055900).
- drm/i915: Restore brightness level in aux backlight driver
  (FATE#322643 bsc#1055900).
- drm/i915: Set backlight mode before enable backlight
  (FATE#322643 bsc#1055900).
- drm/i915: Correctly enable backlight brightness adjustment
  via DPCD (FATE#322643 bsc#1055900).
- drm/i915: Fix cap check for intel_dp_aux_backlight driver
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Make scratch register base and count flexible
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Move notification code into virtual function
  (FATE#322643 bsc#1055900).
- drm/i915: Remove vma unpin in intel_plane_destroy (FATE#322643
  bsc#1055900).
- drm/i915: Fix hw state verifier access to crtc->state
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Dump the GuC stage descriptor pool in debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Fix __intel_wait_for_register_fw to not sleep in
  atomic (FATE#322643 bsc#1055900).
- drm/i915: Simplify cursor register write sequence (FATE#322643
  bsc#1055900).
- drm/i915: Relax 845/865 CURBASE alignemnt requirement to 32
  bytes (FATE#322643 bsc#1055900).
- drm/i915: Handle fb offset and src coordinates for cursors
  (FATE#322643 bsc#1055900).
- drm/i915: Fix gen3 physical cursor alignment requirements
  (FATE#322643 bsc#1055900).
- drm/i915: Support variable cursor height on ivb+ (FATE#322643
  bsc#1055900).
- drm/i915: Use fb->pitches[0] in cursor code (FATE#322643
  bsc#1055900).
- drm/i915: Generalize cursor size checks a bit (FATE#322643
  bsc#1055900).
- drm/i915: Split cursor check_plane into i845 and i9xx variants
  (FATE#322643 bsc#1055900).
- drm/i915: Drop useless posting reads from cursor commit
  (FATE#322643 bsc#1055900).
- drm/i915: Move cursor position and base handling into the
  platform specific functions (FATE#322643 bsc#1055900).
- drm/i915: Refactor CURPOS calculation (FATE#322643 bsc#1055900).
- drm/i915: Clean up cursor junk from intel_crtc (FATE#322643
  bsc#1055900).
- drm/i915: Refactor CURBASE calculation (FATE#322643
  bsc#1055900).
- drm/i915: Pass intel_plane and intel_crtc to plane hooks
  (FATE#322643 bsc#1055900).
- drm/i915: Parametrize cursor/primary pipe select bits
  (FATE#322643 bsc#1055900).
- drm/i915: Add support for sprites on g4x (FATE#322643
  bsc#1055900).
- drm/i915: Add g4x watermark tracepoint (FATE#322643
  bsc#1055900).
- drm/i915: Enable HPLL watermarks on g4x (FATE#322643
  bsc#1055900).
- drm/i915: Two stage watermarks for g4x (FATE#322643
  bsc#1055900).
- drm/i915: Apply the g4x TLB miss w/a to SR watermarks as well
  (FATE#322643 bsc#1055900).
- drm/i915: Refactor wm calculations (FATE#322643 bsc#1055900).
- drm/i915: Refactor the g4x TLB miss w/a to a helper (FATE#322643
  bsc#1055900).
- drm/i915: Fix the g4x watermark TLB miss workaround (FATE#322643
  bsc#1055900).
- drm/i915: Fix cursor 'cpp' in watermark calculatins for old
  platforms (FATE#322643 bsc#1055900).
- drm/i915: Document CxSR (FATE#322643 bsc#1055900).
- drm/i915: Make vlv/chv watermark debug print less cryptic
  (FATE#322643 bsc#1055900).
- drm/i915: Rename bunch of vlv_ watermark structures to g4x_
  (FATE#322643 bsc#1055900).
- drm/i915: s/vlv_num_wm_levels/intel_wm_num_levels/ (FATE#322643
  bsc#1055900).
- drm/i915: Drop the debug message from vlv_get_fifo_size()
  (FATE#322643 bsc#1055900).
- drm/i915: s/vlv_plane_wm_compute/vlv_raw_plane_wm_compute/
  etc (FATE#322643 bsc#1055900).
- drm/i915/lvds: Remove magic from PLL programming (FATE#322643
  bsc#1055900).
- drm/i915: Sanitize stolen memory size calculation (FATE#322643
  bsc#1055900).
- drm/i915: Check error return when converting pipe to connector
  (FATE#322643 bsc#1055900).
- drm/i915: Check error return when setting DMA mask (FATE#322643
  bsc#1055900).
- drm/i915/sdvo: Check error return from intel_sdvo_get_value()
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Check error return during DPCD capability queries
  (FATE#322643 bsc#1055900).
- drm/i915/vlv: Fix port B PLL opamp initialization (FATE#322643
  bsc#1055900).
- drm/i915: Show dmc debug registers on Kabylake (FATE#322643
  bsc#1055900).
- drm/i915: Move uncore definitions into a separate header
  (FATE#322643 bsc#1055900).
- drm/i915: use memdup_user_nul (FATE#322643 bsc#1055900).
- drm/i915: Micro-optimise hotpath through intel_ring_begin()
  (FATE#322643 bsc#1055900).
- drm/i915: Report the ring->space from intel_ring_update_space()
  (FATE#322643 bsc#1055900).
- drm/i915: Avoid the branch in computing intel_ring_space()
  (FATE#322643 bsc#1055900).
- drm/i915: Use engine->context_pin() to report the intel_ring
  (FATE#322643 bsc#1055900).
- drm/i915: Implement dma_buf_ops->kmap (FATE#322643 bsc#1055900).
- drm/i915: Clean up the LPE audio platform data (FATE#322643
  bsc#1055900).
- drm/i915: Reorganize intel_lpe_audio_notify() arguments
  (FATE#322643 bsc#1055900).
- drm/i915: Remove hdmi_connected from LPE audio pdata
  (FATE#322643 bsc#1055900).
- drm/i915: Replace tmds_clock_speed and link_rate with just
  ls_clock (FATE#322643 bsc#1055900).
- drm/i915: Remove the unused pending_notify from LPE platform
  data (FATE#322643 bsc#1055900).
- drm/i915: Switch the global i915.semaphores check to a local
  predicate (FATE#322643 bsc#1055900).
- drm/i915: Do not record a successful syncpoint for a dma-await
  (FATE#322643 bsc#1055900).
- drm/i915: Rename intel_timeline.sync_seqno[] to .global_sync[]
  (FATE#322643 bsc#1055900).
- drm/i915: Squash repeated awaits on the same fence (FATE#322643
  bsc#1055900).
- drm/i915: Lift timeline ordering to await_dma_fence (FATE#322643
  bsc#1055900).
- drm/i915: Unwrap top level fence-array (FATE#322643
  bsc#1055900).
- drm/i915: Mark up clflushes as belonging to an unordered
  timeline (FATE#322643 bsc#1055900).
- drm/i915: Use wait_for_atomic_us when waiting for gt fifo
  (FATE#322643 bsc#1055900).
- drm/i915: Move the GTFIFODBG to the common mmio dbg framework
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Enable send function only after successful init
  (FATE#322643 bsc#1055900).
- drm/i915: Do not leak dev_priv->l3_parity.remap_info[]
  (FATE#322643 bsc#1055900).
- drm/i915: Update DRIVER_DATE to 20170502 (FATE#322643
  bsc#1055900).
- drm/i915: Capture CCID on ILK (FATE#322643 bsc#1055900).
- drm/i915: Reset ILK during GEM sanitization (FATE#322643
  bsc#1055900).
- drm/i915: Eliminate HAS_HW_CONTEXTS (FATE#322643 bsc#1055900).
- drm/i915: Sanitize engine context sizes (FATE#322643
  bsc#1055900).
- drm/i915/guc: Fix sleep under spinlock during reset (FATE#322643
  bsc#1055900).
- drm/i915: Defer context state allocation for legacy ring
  submission (FATE#322643 bsc#1055900).
- drm/i915: Rename gen8_(un)request_engine_reset to
  gen8_reset_engine_start/cancel (FATE#322643 bsc#1055900).
- drm/i915: Fix stale comment about I915_RESET_IN_PROGRESS flag
  (FATE#322643 bsc#1055900).
- drm/i915/glk: Don't allow 12 bpc when htotal is too big
  (FATE#322643 bsc#1055900).
- drm/i915: Skip waking the signaler when enabling before request
  submission (FATE#322643 bsc#1055900).
- drm/i915: Poison the request before emitting commands
  (FATE#322643 bsc#1055900).
- drm/i915: Report request restarts for both execlists/guc
  (FATE#322643 bsc#1055900).
- drm/i915: Include interesting seqno in the missed breadcrumb
  debug (FATE#322643 bsc#1055900).
- drm/i915: Avoid format string expansion from engine names
  (FATE#322643 bsc#1055900).
- drm/i915: Fix GCC 4.4 build issue with
  __intel_wait_for_register_fw (FATE#322643 bsc#1055900).
- commit 60934e6
* Wed Feb 21 2018 tiwai@suse.de
- drm/i915: Update DRIVER_DATE to 20170418 (FATE#322643
  bsc#1055900).
- drm/i915: Copy user requested buffers into the error state
  (FATE#322643 bsc#1055900).
- drm/i915: set "ret" correctly on error paths (FATE#322643
  bsc#1055900).
- drm/i915: Implement Link Rate fallback on Link training failure
  (FATE#322643 bsc#1055900).
- drm/i915/guc: write wopcm related register once during uc init
  (FATE#322643 bsc#1055900).
- drm/i915/dp: Validate cached link rate and lane count before
  retraining (FATE#322643 bsc#1055900).
- drm/i915: Wake device for emitting request during selftest
  (FATE#322643 bsc#1055900).
- drm/i915: Pretend the engine is always idle when mocking
  (FATE#322643 bsc#1055900).
- drm/i915: Add stub mmio read/write routines to mock device
  (FATE#322643 bsc#1055900).
- drm/i915: Treat WC a separate cache domain (FATE#322643
  bsc#1055900).
- drm/i915: Combine write_domain flushes to a single function
  (FATE#322643 bsc#1055900).
- drm/i915: Do not use lock all in hsw_trans_edp_pipe_A_crc_wa
  (FATE#322643 bsc#1055900).
- Revert "drm/i915: Lock mode_config.mutex in
  intel_display_resume." (FATE#322643 bsc#1055900).
- drm/i915: Convert intel DVO connector to atomic (FATE#322643
  bsc#1055900).
- drm/i915: Convert intel_crt connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Convert intel_dp_mst connector properties to atomic
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unused dp properties for dp-mst (FATE#322643
  bsc#1055900).
- drm/i915: Convert intel_tv connector properties to atomic, v5
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unused members from intel_tv.c (FATE#322643
  bsc#1055900).
- drm/i915/execlists: Document runtime pm for
  intel_lrc_irq_handler() (FATE#322643 bsc#1055900).
- drm/i915: Lie and treat all engines as idle if wedged
  (FATE#322643 bsc#1055900).
- drm/i915: Use the engine class to get the context size
  (FATE#322643 bsc#1055900).
- drm/i915: Bail if we do not setup the RCS engine (FATE#322643
  bsc#1055900).
- drm/i915/dp: read sink count to a temporary variable first
  (FATE#322643 bsc#1055900).
- drm/i915/dp: use readb and writeb calls for single byte DPCD
  access (FATE#322643 bsc#1055900).
- drm/i915/dp: localize link rate index variable more (FATE#322643
  bsc#1055900).
- drm/i915/mst: use max link not sink lane count (FATE#322643
  bsc#1055900).
- drm/i915/dp: add functions for max common link rate and lane
  count (FATE#322643 bsc#1055900).
- drm/i915/dp: don't call the link parameters sink parameters
  (FATE#322643 bsc#1055900).
- drm/i915/dp: do not limit rate seek when not needed (FATE#322643
  bsc#1055900).
- drm/i915/dp: cache common rates with sink rates (FATE#322643
  bsc#1055900).
- drm/i915/dp: use the sink rates array for max sink rates
  (FATE#322643 bsc#1055900).
- drm/i915: Rename intel_engine_cs.exec_id to uabi_id (FATE#322643
  bsc#1055900).
- drm/i915: Split the engine info table in two levels, using
  class + instance (FATE#322643 bsc#1055900).
- drm/i915: Generate the engine name based on the instance number
  (FATE#322643 bsc#1055900).
- drm/i915: Use the same vfunc for BSD2 ring init (FATE#322643
  bsc#1055900).
- drm/i915: Classify the engines in class + instance (FATE#322643
  bsc#1055900).
- drm/i915: Use safer intel_uncore_wait_for_register in ring-init
  (FATE#322643 bsc#1055900).
- drm/i915: Use __intel_uncore_wait_for_register_fw for
  sandybride_pcode_read (FATE#322643 bsc#1055900).
- drm/i915: Acquire uncore.lock over
  intel_uncore_wait_for_register() (FATE#322643 bsc#1055900).
- drm/i915: Stop sleeping from inside gen6_bsd_submit_request()
  (FATE#322643 bsc#1055900).
- drm/i915: Stop second guessing the caller for
  intel_uncore_wait_for_register() (FATE#322643 bsc#1055900).
- drm/i915: Don't allow overuse of __intel_wait_for_register_fw()
  (FATE#322643 bsc#1055900).
- drm/i915: Drop const qualifiers from params in
  wait_for_register() (FATE#322643 bsc#1055900).
- drm/i915: Use drm_i915_private directly from debugfs
  (FATE#322643 bsc#1055900).
- drm/i915/guc: Use wait_for_register_fw() while waiting for
  MMIO response (FATE#322643 bsc#1055900).
- drm/i915: Extend intel_wait_for_register_fw() with fast timeout
  (FATE#322643 bsc#1055900).
- drm/i915: Fix type of timeout_ms parameter in
  intel_wait_for_register_fw() (FATE#322643 bsc#1055900).
- drm/i915: Insert cond_resched() into i915_gem_free_objects
  (FATE#322643 bsc#1055900).
- drm/i915: Break up long runs of freeing objects (FATE#322643
  bsc#1055900).
- drm/i915: Simplify shrinker locking (FATE#322643 bsc#1055900).
- drm/i915: Drain any freed objects prior to hibernation
  (FATE#322643 bsc#1055900).
- drm/i915: The shrinker already acquires struct_mutex, so call
  it unlocked (FATE#322643 bsc#1055900).
- i915: initialize the free_list of the fencing atomic_helper
  (FATE#322643 bsc#1055900).
- drm/i915: Advance ring->head fully when idle (FATE#322643
  bsc#1055900).
- drm/i915: Assert the engine is idle before overwiting the HWS
  (FATE#322643 bsc#1055900).
- drm/i915/GLK/HuC: Load HuC on GLK (FATE#322643 bsc#1055900).
- drm/i915/GuC/GLK: Load GuC on GLK (FATE#322643 bsc#1055900).
- drm/i915/glk: limit pixel clock to 99%% of cdclk workaround
  (FATE#322643 bsc#1055900).
- drm/i915/dp: generate and cache sink rate array for all DP,
  not just eDP 1.4 (FATE#322643 bsc#1055900).
- drm/i915/dp: cache source rates at init (FATE#322643
  bsc#1055900).
- drm/i915/dp: rename rate_to_index() to intel_dp_rate_index()
  and reuse (FATE#322643 bsc#1055900).
- drm/i915/dp: return errors from rate_to_index() (FATE#322643
  bsc#1055900).
- drm/i915/dp: use known correct array size in rate_to_index
  (FATE#322643 bsc#1055900).
- drm/i915: Enable atomic on VLV/CHV (FATE#322643 bsc#1055900).
- drm/i915: Use intel_wm_plane_visible() on VLV/CHV as well
  (FATE#322643 bsc#1055900).
- drm/i915: Check for id==PLANE_CURSOR instead of
  type==DRM_PLANE_TYPE_CURSOR (FATE#322643 bsc#1055900).
- drm/i915/guc: Use GUC prefix for CORE_FAMILY definitions
  (FATE#322643 bsc#1055900).
- drm/i915: Typo fix - 'pipe bpc' to 'pipe bpp' (FATE#322643
  bsc#1055900).
- drm/i915/huc: Simplify intel_huc_init_hw() (FATE#322643
  bsc#1055900).
- drm/i915: Remove user-triggerable WARN from
  i915_gem_object_create (FATE#322643 bsc#1055900).
- drm/i915: Onion unwind for intel_init_ring_common() (FATE#322643
  bsc#1055900).
- drm/i915: intel_ring.engine is unused (FATE#322643 bsc#1055900).
- drm/doc: Clarify mode_fixup vs. atomic_check a bit more
  (FATE#322643 bsc#1055900).
- drm/doc: Document adjusted/request modes a bit better
  (FATE#322643 bsc#1055900).
- drm: Add crtc/encoder/bridge->mode_valid() callbacks
  (FATE#322643 bsc#1055900).
- drm: Add DRM_MODE_ROTATE_ and DRM_MODE_REFLECT_ to UAPI
  (FATE#322643 bsc#1055900).
- drm: trivial documentation fix to drm_for_each_connector_iter
  (FATE#322643 bsc#1055900).
- drm: add missing declaration to drm_blend.h (FATE#322643
  bsc#1055900).
- drm/dp: Wait up all outstanding tx waiters (FATE#322643
  bsc#1055900).
- drm/dp: Read the tx msg state once after checking for an event
  (FATE#322643 bsc#1055900).
- drm/prime: Forward declare struct device (FATE#322643
  bsc#1055900).
- drm/vblank: Lock down vblank->hwmode more (FATE#322643
  bsc#1055900).
- drm/vblank: drop the mode argument from
  drm_calc_vbltimestamp_from_scanoutpos (FATE#322643 bsc#1055900).
- drm/vblank: Add FIXME comments about moving the vblank ts hooks
  (FATE#322643 bsc#1055900).
- drm/vblank: Switch to bool in_vblank_irq in get_vblank_timestamp
  (FATE#322643 bsc#1055900).
- drm/vblank: Switch drm_driver->get_vblank_timestamp to return
  a bool (FATE#322643 bsc#1055900).
- drm: Nerf the preclose callback for modern drivers (FATE#322643
  bsc#1055900).
- drm: Remove redundant NULL check during atomic plane commit
  (FATE#322643 bsc#1055900).
- drm/atomic: Add support for custom scaling mode properties,
  v2 (FATE#322643 bsc#1055900).
- drm/atomic: Handle picture_aspect_ratio in atomic core
  (FATE#322643 bsc#1055900).
- drm/prime: Introduce drm_gem_prime_import_dev (FATE#322643
  bsc#1055900).
- drm/i915: Track MST link bandwidth (FATE#322643 bsc#1055900).
- drm/atomic: fix doc to use new name for commit types
  (FATE#322643 bsc#1055900).
- drm: Make drm_atomic_replace_property_blob_from_id() more
  generic (FATE#322643 bsc#1055900).
- drm: drm_color_mgmt.h needs struct drm_crtc declaration
  (FATE#322643 bsc#1055900).
- drm/cec: Add CEC over Aux register definitions (FATE#322643
  bsc#1055900).
- drm: Add DPCD definitions for DP 1.4 DSC feature (FATE#322643
  bsc#1055900).
- drm/doc: Interlink color manager docs better (FATE#322643
  bsc#1055900).
- drm: fix spelling mistake: "committing" (FATE#322643
  bsc#1055900).
- commit bb6495e
* Wed Feb 21 2018 tiwai@suse.de
- Disable downstream DRM patches temporarily for upgrading the base codes
- commit bc652a8
* Tue Feb 20 2018 msuchanek@suse.de
- blacklist
  7a074fc08389 powerpc/64s: Fix ps3 build error due to tlbiel_all()
  015eb1b89e95 powerpc/mm/radix: Fix build error when RADIX_MMU=n
- commit 5a608da
* Tue Feb 20 2018 msuchanek@suse.de
- powerpc/64s/radix: Boot-time NULL pointer protection using a
  guard-PID (bsc#1055117).
- powerpc/64s: Improve local TLB flush for boot and MCE on POWER9
  (bsc#1055117).
- powerpc/64s: Initialize ISAv3 MMU registers before setting
  partition table (bsc#1055117).
- commit 67f5cce
* Tue Feb 20 2018 jack@suse.cz
- ext4: Fix offset overflow on 32-bit archs in ext4_iomap_begin()
  (bsc#1079747).
- commit bbceb80
* Tue Feb 20 2018 bp@suse.de
- objtool: Improve retpoline alternative handling (bsc#1068032
  CVE-2017-5754).
- objtool: Add support for alternatives at the end of a section
  (bsc#1068032 CVE-2017-5754).
- objtool: Warn on stripped section symbol (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Remove the SYSCALL64 fast path (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Push extra regs right away (bsc#1068032
  CVE-2017-5754).
- x86/asm: Move 'status' from thread_struct to thread_info
  (bsc#1068032 CVE-2017-5754).
- x86/speculation: Use Indirect Branch Prediction Barrier in
  context switch (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Avoid retpolines for built-in __init functions
  (bsc#1068032 CVE-2017-5754).
- x86/spectre: Simplify spectre_v2 command line parsing
  (bsc#1068032 CVE-2017-5754).
- KVM: nVMX: Eliminate vmcs02 pool (bsc#1068032 CVE-2017-5754).
- KVM: VMX: introduce alloc_loaded_vmcs (bsc#1068032
  CVE-2017-5754).
- KVM: VMX: make MSR bitmaps per-VCPU (bsc#1068032 CVE-2017-5754).
- KVM/x86: Update the reverse_cpuid list to include CPUID_7_EDX
  (bsc#1068032 CVE-2017-5754).
- KVM/x86: Add IBPB support (bsc#1068032 CVE-2017-5754).
- KVM/VMX: Emulate MSR_IA32_ARCH_CAPABILITIES (bsc#1068032
  CVE-2017-5754).
- KVM/VMX: Allow direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5754).
- KVM/SVM: Allow direct access to MSR_IA32_SPEC_CTRL (bsc#1068032
  CVE-2017-5754).
- perf/x86/amd/power: Do not load AMD power module on !AMD
  platforms (git-fixes c7ab62bfbe0e).
- blacklist.conf:
- Delete
  patches.arch/x86-retpoline-simplify-vmexit_fill_rsb.patch.
- commit ac25421
* Tue Feb 20 2018 nborisov@suse.com
- Btrfs: fix kernel oops while reading compressed data
  (bsc#1081671).
- Refresh
  patches.suse/0023-block-switch-bios-to-blk_status_t.patch.
- commit 565ea00
* Tue Feb 20 2018 jthumshirn@suse.de
- scsi: megaraid_sas: Do not use 32-bit atomic request descriptor
  for Ventura controllers (bsc#1081737).
- commit 4e60173
* Tue Feb 20 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Clean-RX-pool-buffers-during-device-close.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-NAPI-structures-memory-leak.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-login-buffer-memory-leaks.patch.
- Refresh
  patches.drivers/ibmvnic-Free-RX-socket-buffer-in-case-of-adapter-err.patch.
- Refresh
  patches.drivers/ibmvnic-Wait-until-reset-is-complete-to-set-carrier-.patch.
- commit ba71f73
* Tue Feb 20 2018 npajkovsky@suse.cz
- bsc#1053298 oracleasm
  patches.suse/0001-oracleasm-4.0-compat-changes.patch
- commit def7601
* Tue Feb 20 2018 neilb@suse.com
- nfs: fix a deadlock in nfs client initialization (bsc#1074198).
- commit 913cb84
* Tue Feb 20 2018 jroedel@suse.de
- blacklist.conf: da391d640c528bc5bb227ea5b39c882b75ac3167
  Comment-only fix
- commit be9480e
* Tue Feb 20 2018 jroedel@suse.de
- iommu/exynos: Remove initconst attribute to avoid potential
  kernel oops (bsc#975772).
- commit ad7bb7b
* Mon Feb 19 2018 jroedel@suse.de
- iommu/mediatek: Fix driver name (bsc#975772).
- iommu/vt-d: Use domain instead of cache fetching (bsc#975772).
- iommu/amd: Limit the IOVA page range to the specified addresses
  (bsc#975772).
- iommu/amd: Fix alloc_irq_index() increment (bsc#975772).
- iommu/amd: Enforce alignment for MSI IRQs (bsc#975772).
- iommu/amd: Add align parameter to alloc_irq_index()
  (bsc#975772).
- commit 69050a0
* Mon Feb 19 2018 mkubecek@suse.cz
- netfilter: xt_RATEEST: acquire xt_rateest_mutex for hash insert
  (bsc#1076830).
- netfilter: xt_cgroup: initialize info->priv in
  cgroup_mt_check_v1() (bsc#1076830).
- iscsi-target: make sure to wake up sleeping login worker
  (bsc#1076830).
- sctp: fix dst refcnt leak in sctp_v4_get_dst (bsc#1076830).
- media: ts2020: avoid integer overflows on 32 bit machines
  (bsc#1076830).
- Revert "defer call to mem_cgroup_sk_alloc()" (bsc#1076830).
- net: ipv6: send unsolicited NA after DAD (bsc#1076830).
- xfrm: Add SA to hardware at the end of xfrm_state_construct()
  (bsc#1076830).
- sctp: do not allow the v4 socket to bind a v4mapped v6 address
  (bsc#1076830).
- strparser: Call sock_owned_by_user_nocheck (bsc#1076830).
- sock: Add sock_owned_by_user_nocheck (bsc#1076830).
- sctp: add SCTP_CID_RECONF conversion in sctp_cname
  (bsc#1076830).
- tcp: invalidate rate samples during SACK reneging (bsc#1076830).
- Revert "tcp: must block bh in __inet_twsk_hashdance()"
  (bsc#1076830).
- tcp: add tcp_v4_fill_cb()/tcp_v4_restore_cb() (bsc#1076830).
- tipc: call tipc_rcv() only if bearer is up in tipc_udp_recv()
  (bsc#1076830).
- tcp/dccp: block bh before arming time_wait timer (bsc#1076830).
- sctp: set sender next_tsn for the old result with ctsn_ack_point
  plus 1 (bsc#1076830).
- tcp: when scheduling TLP, time of RTO should account for
  current ACK (bsc#1076830).
- ipvlan: NULL pointer dereference panic in ipvlan_port_destroy
  (bsc#1076830).
- route: update fnhe_expires for redirect when the fnhe exists
  (bsc#1076830).
- Refresh
  patches.fixes/route-also-update-fnhe_genid-when-updating-a-route-c.patch.
- sctp: check stream reset info len before making reconf chunk
  (bsc#1076830).
- l2tp: don't close sessions in l2tp_tunnel_destruct()
  (bsc#1076830).
- l2tp: initialise l2tp_eth sessions before registering them
  (bsc#1076830).
- l2tp: don't register sessions in l2tp_session_create()
  (bsc#1076830).
- sctp: fix a type cast warnings that causes a_rwnd gets the
  wrong value (bsc#1076830).
- sctp: fix some type cast warnings introduced by transport
  rhashtable (bsc#1076830).
- sctp: add the missing sock_owned_by_user check in
  sctp_icmp_redirect (bsc#1076830).
- net: call cgroup_sk_alloc() earlier in sk_clone_lock()
  (bsc#1076830).
- net: memcontrol: defer call to mem_cgroup_sk_alloc()
  (bsc#1076830).
- netfilter: x_tables: avoid stack-out-of-bounds read in
  xt_copy_counters_from_user (bsc#1076830).
- netfilter: ipset: pernet ops must be unregistered last
  (bsc#1076830).
- xfrm: Fix deletion of offloaded SAs on failure (bsc#1076830).
- packet: only test po->has_vnet_hdr once in packet_snd
  (bsc#1076830).
- net: dsa: Fix network device registration order (bsc#1076830).
- net: set tb->fast_sk_family (bsc#1076830).
- net: vrf: avoid gcc-4.6 warning (bsc#1076830).
- tcp/dccp: remove reqsk_put() from inet_child_forget()
  (bsc#1076830).
- tcp: fix a request socket leak (bsc#1076830).
- l2tp: pass tunnel pointer to ->session_create() (bsc#1076830).
- Refresh patches.fixes/l2tp-fix-l2tp_eth-module-loading.patch.
- l2tp: prevent creation of sessions on terminated tunnels
  (bsc#1076830).
  Refresh
  patches.fixes/l2tp-fix-race-condition-in-l2tp_tunnel_delete.patch.
- l2tp: hold tunnel used while creating sessions with netlink
  (bsc#1076830).
- tcp: fix possible deadlock in TCP stack vs BPF filter
  (bsc#1076830).
- tcp: fix xmit timer to only be reset if data ACKed/SACKed
  (bsc#1076830).
- netfilter: nf_ct_dccp/sctp: fix memory leak after netns cleanup
  (bsc#1076830).
- tcp: Add a tcp_filter hook before handle ack packet
  (bsc#1076830).
- vxlan: dont migrate permanent fdb entries during learn
  (bsc#1076830).
- commit f1b2d26
* Mon Feb 19 2018 msuchanek@suse.de
- powerpc/64s: Improve RFI L1-D cache flush fallback (bsc#1068032).
  Update to upstream patch.
- Refresh
  patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- Refresh
  patches.arch/powerpc-xmon-Add-RFI-flush-related-fields-to-paca-du.patch.
- commit deca5e6
* Mon Feb 19 2018 msuchanek@suse.de
- Refresh RFI LPM migration patches with upstream status.
- Refresh patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
- rfi-flush: Move the logic to avoid a redo into the debugfs code
  (bsc#1068032).
- commit 42d34e2
* Mon Feb 19 2018 mbrugger@suse.com
- iommu/io-pgtable-arm-v7s: Need dma-sync while there is no
  QUIRK_NO_DMA (fate#321947).
- iommu/arm-smmu: Reintroduce locking around TLB sync operations
  (fate#321947).
- commit 0427583
* Mon Feb 19 2018 mbrugger@suse.com
- Reorder patches
- commit 0771c78
* Mon Feb 19 2018 msuchanek@suse.de
- powerpc/pseries: Check for zero filled ibm,dynamic-memory
  property (FATE#324825, bsc#1077428, bsc#1080789).
- commit ccf669c
* Mon Feb 19 2018 mfleming@suse.de
- cpumask: Make for_each_cpu_wrap() available on UP as well
  (git-fixes).
- commit e4d0ff0
* Mon Feb 19 2018 msuchanek@suse.de
- blacklist c1e150ceb61e powerpc/pseries: Add empty update_numa_cpu_lookup_table() for NUMA=n
  blacklist 82343484a2d4 powerpc/pseries: Fix build break for SPLPAR=n and CPU hotplug
- commit 2993802
* Mon Feb 19 2018 mgorman@suse.de
- mm: pin address_space before dereferencing it while isolating
  an LRU page (bnc#1081500).
- commit 93762be
* Mon Feb 19 2018 mkubecek@suse.cz
- series.conf: refresh
  Ran series_sort.py (no effect on expanded tree).
- Update upstream reference:
  patches.drivers/nvme_fc-cleanup-io-completion.patch.
  patches.drivers/nvme_fc-correct-abort-race-condition-on-resets.patch.
- Fix patch metadata:
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- commit 24a578f
* Mon Feb 19 2018 lhenriques@suse.com
- ceph: improving efficiency of syncfs (FATE#324714).
- libceph: check kstrndup() return value (FATE#324714).
- ceph: try to allocate enough memory for reserved caps
  (FATE#324714).
- ceph: fix race of queuing delayed caps (FATE#324714).
- ceph: delete unreachable code in ceph_check_caps()
  (FATE#324714).
- ceph: limit rate of cap import/export error messages
  (FATE#324714).
- ceph: fix incorrect snaprealm when adding caps (FATE#324714).
- ceph: fix un-balanced fsc->writeback_count update (FATE#324714).
- ceph: track read contexts in ceph_file_info (FATE#324714).
- ceph: avoid dereferencing invalid pointer during cached readdir
  (FATE#324714).
- ceph: use atomic_t for ceph_inode_info::i_shared_gen
  (FATE#324714).
- ceph: cleanup traceless reply handling for rename (FATE#324714).
- ceph: voluntarily drop Fx cap for readdir request (FATE#324714).
- ceph: properly drop caps for setattr request (FATE#324714).
- ceph: voluntarily drop Lx cap for link/rename requests
  (FATE#324714).
- ceph: voluntarily drop Ax cap for requests that create new inode
  (FATE#324714).
- commit 33131fd
* Mon Feb 19 2018 mgorman@suse.de
- buffer: Avoid setting buffer bits that are already set
  (bnc#971975 VM performance -- buffers).
- commit ca2f72a
* Mon Feb 19 2018 jack@suse.cz
- iversion: Rename make inode_cmp_iversion{+raw} to
  inode_eq_iversion{+raw} (bsc#1081186).
- commit d89d8c5
* Mon Feb 19 2018 jack@suse.cz
- iversion: make inode_cmp_iversion{+raw} return bool instead
  of s64 (bsc#1081186).
- commit 625951e
* Mon Feb 19 2018 jack@suse.cz
- fs: handle inode->i_version more efficiently (bsc#1081186).
- commit b5b1ede
* Mon Feb 19 2018 jack@suse.cz
- btrfs: only dirty the inode in btrfs_update_time if something
  was changed (bsc#1081186).
- commit 509a5c3
* Mon Feb 19 2018 jack@suse.cz
- xfs: avoid setting XFS_ILOG_CORE if i_version doesn't need
  incrementing (bsc#1081186).
- commit f466f92
* Mon Feb 19 2018 jack@suse.cz
- fs: only set S_VERSION when updating times if necessary
  (bsc#1081186).
- commit 2f39cae
* Mon Feb 19 2018 jack@suse.cz
- IMA: switch IMA over to new i_version API (bsc#1081186).
- commit f5c04bb
* Mon Feb 19 2018 jack@suse.cz
- xfs: convert to new i_version API (bsc#1081186).
- commit e0e201b
* Mon Feb 19 2018 jack@suse.cz
- ufs: use new i_version API (bsc#1081186).
- commit bb021c0
* Mon Feb 19 2018 jack@suse.cz
- ocfs2: convert to new i_version API (bsc#1081186).
- commit 5b5fa6e
* Mon Feb 19 2018 jack@suse.cz
- nfsd: convert to new i_version API (bsc#1081186).
- commit ed53100
* Mon Feb 19 2018 jack@suse.cz
- nfs: convert to new i_version API (bsc#1081186).
- commit 55bd438
* Mon Feb 19 2018 jack@suse.cz
- ext4: convert to new i_version API (bsc#1081186).
- commit 437c1ef
* Mon Feb 19 2018 jack@suse.cz
- ext2: convert to new i_version API (bsc#1081186).
- commit 2cd1049
* Mon Feb 19 2018 jack@suse.cz
- exofs: switch to new i_version API (bsc#1081186).
- commit 225c244
* Mon Feb 19 2018 jack@suse.cz
- btrfs: convert to new i_version API (bsc#1081186).
- commit ae27f85
* Mon Feb 19 2018 jack@suse.cz
- afs: convert to new i_version API (bsc#1081186).
- commit 2fa658c
* Mon Feb 19 2018 jack@suse.cz
- affs: convert to new i_version API (bsc#1081186).
- commit 0a73f1a
* Mon Feb 19 2018 jack@suse.cz
- fat: convert to new i_version API (bsc#1081186).
- commit 75908ef
* Mon Feb 19 2018 jack@suse.cz
- fs: don't take the i_lock in inode_inc_iversion (bsc#1081186).
- commit 3ecc67b
* Mon Feb 19 2018 jack@suse.cz
- fs: new API for handling inode->i_version (bsc#1081186).
- commit 4e364de
* Mon Feb 19 2018 jack@suse.cz
- ntfs: remove i_version handling (bsc#1081186).
- commit 3636058
* Mon Feb 19 2018 jack@suse.cz
- lustre: don't set f_version in ll_readdir (bsc#1081186).
- commit 052b4c4
* Mon Feb 19 2018 jack@suse.cz
- ima: Use i_version only when filesystem supports it
  (bsc#1081186).
- commit 5e28e82
* Mon Feb 19 2018 jthumshirn@suse.de
- nvme-pci: Remap CMB SQ entries on every controller reset
  (FATE#323952, FATE#322506).
- commit 37d7f9b
* Mon Feb 19 2018 jack@suse.cz
- Fix up tags in
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- commit 7dc8b66
* Mon Feb 19 2018 jthumshirn@suse.de
- Refresh patches.drivers/nvme_fc-cleanup-io-completion.patch.
- Refresh
  patches.drivers/nvme_fc-correct-abort-race-condition-on-resets.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- commit 54909a8
* Mon Feb 19 2018 mgalbraith@suse.de
- sched/rt: Up the root domain ref count when passing it around
  via IPIs (bnc#1022476).
- sched/rt: Use container_of() to get root domain in
  rto_push_irq_work_func() (bnc#1022476).
- hrtimer: Ensure POSIX compliance (relative CLOCK_REALTIME
  hrtimers) (bnc#1022476).
- hrtimer: Reset hrtimer cpu base proper on CPU hotplug
  (bnc#1022476).
- commit e19e122
* Fri Feb 16 2018 tiwai@suse.de
- blacklist.conf: Remove i915 entries
- commit c8a167f
* Fri Feb 16 2018 mbrugger@suse.com
- arm64: Update config files.
  enable ARCH_PROC_KCORE_TEXT
- commit 5f62bc2
* Fri Feb 16 2018 mbrugger@suse.com
- net: ethernet: cavium: Correct Cavium Thunderx NIC driver
  names accordingly to module name (fate#321947).
- iommu/arm-smmu-v3: Cope with duplicated Stream IDs
  (fate#321947).
- ACPICA: iasl: Update to IORT SMMUv3 disassembling (fate#321947).
- ACPI/IORT: numa: Add numa node mapping for smmuv3 devices
  (fate#321947).
- iommu/arm-smmu-v3: Remove io-pgtable spinlock (fate#321947).
- iommu/arm-smmu: Remove io-pgtable spinlock (fate#321947).
- iommu/io-pgtable-arm-v7s: Support lockless operation
  (fate#321947).
- iommu/io-pgtable-arm: Support lockless operation (fate#321947).
- iommu/io-pgtable: Introduce explicit coherency (fate#321947).
- iommu/io-pgtable-arm-v7s: Refactor split_blk_unmap
  (fate#321947).
- iommu/io-pgtable-arm: Improve split_blk_unmap (fate#321947).
- iommu/io-pgtable-arm-v7s: Check table PTEs more precisely
  (fate#321947).
- arm64: mm: select CONFIG_ARCH_PROC_KCORE_TEXT (fate#321947).
- fs/proc: kcore: use kcore_list type to check for vmalloc/module
  address (fate#321947).
- arm64: kernel: restrict /dev/mem read() calls to linear region
  (bsc#1081310).
- commit 4267f13
* Fri Feb 16 2018 tiwai@suse.de
- Preliminary roll-back of drm/i915 patches for the further updates
- commit dbb70d2
* Fri Feb 16 2018 jeffm@suse.com
- btrfs: use kvzalloc to allocate btrfs_fs_info (bsc#1059336).
- commit 1d89bd7
* Thu Feb 15 2018 mcgrof@suse.com
- xfs: stop searching for free slots in an inode chunk when there are none (bsc#1072739).
- commit 80d1325
* Thu Feb 15 2018 jack@suse.cz
- jfs: remove increment of i_version counter (bsc#1081186).
- commit 5e24fbb
* Thu Feb 15 2018 jack@suse.cz
- reiserfs: remove unneeded i_version bump (bsc#1081186).
- commit 5aba66b
* Thu Feb 15 2018 jack@suse.cz
- hpfs: don't bother with the i_version counter or f_version (bsc#1081186).
- commit 337ee72
* Thu Feb 15 2018 jack@suse.cz
- ecryptfs: remove unnecessary i_version bump (bsc#1081186).
- commit 2a56f3b
* Thu Feb 15 2018 jack@suse.cz
- f2fs: don't bother with inode->i_version (bsc#1081186).
- commit 13fcbd3
* Thu Feb 15 2018 jack@suse.cz
- nilfs2: remove inode->i_version initialization (bsc#1081186).
- commit 17fcbba
* Thu Feb 15 2018 jack@suse.cz
- orangefs: remove initialization of i_version (bsc#1081186).
- commit 5f1d1e2
* Thu Feb 15 2018 jack@suse.cz
- ceph: remove the bump of i_version (bsc#1081186).
- commit ea139ef
* Thu Feb 15 2018 mgorman@suse.de
- writeback: eliminate work item allocation in
  bd_start_writeback() (bnc#1081213).
- writeback: only allow one inflight and pending full flush
  (bnc#1081213).
- writeback: move nr_pages == 0 logic to one location
  (bnc#1081213).
- writeback: make wb_start_writeback() static (bnc#1081213).
- writeback: pass in '0' for nr_pages writeback in laptop mode
  (bnc#1081213).
- writeback: provide a wakeup_flusher_threads_bdi() (bnc#1081213).
- writeback: remove 'range_cyclic' argument for
  wb_start_writeback() (bnc#1081213).
- writeback: switch wakeup_flusher_threads() to cyclic writeback
  (bnc#1081213).
- fs: kill 'nr_pages' argument from wakeup_flusher_threads()
  (bnc#1081213).
- buffer: eliminate the need to call free_more_memory() in
  __getblk_slow() (bnc#971975 VM performance -- memory usage
  during reclaim).
- buffer: grow_dev_page() should use __GFP_NOFAIL for all cases
  (bnc#971975 VM performance -- memory usage during reclaim).
- buffer: have alloc_page_buffers() use __GFP_NOFAIL (bnc#971975
  VM performance -- memory usage during reclaim).
- commit ff7bae7
* Thu Feb 15 2018 mbrugger@suse.com
- Refresh
  patches.suse/arm64-Add-software-workaround-for-Falkor-erratum-104.patch.
- commit 709299d
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/mm/hash64: Zero PGD pages on allocation (FATE#322447,
  bsc#1078248).
- powerpc/mm/hash64: Store the slot information at the right
  offset for hugetlb (FATE#322447, bsc#1078248).
- powerpc/mm/hash64: Allocate larger PMD table if hugetlb config
  is enabled (FATE#322447, bsc#1078248).
- powerpc/mm: Fix crashes with 16G huge pages (FATE#322447,
  bsc#1078248).
- commit c53ee68
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/numa: Invalidate numa_cpu_lookup_table on cpu remove
  (FATE#323746, bsc#1079524).
- commit f1632b3
* Thu Feb 15 2018 agraf@suse.de
- KVM: s390: add vcpu stat counters for many instruction
  (bsc#1081178).
- KVM: s390: diagnoses are instructions as well (bsc#1081178).
- commit 801cf55
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/mm: Flush radix process translations when setting MMU
  type (bsc#1061840).
- commit 6d1b9f9
* Thu Feb 15 2018 msuchanek@suse.de
- powerpc/pseries: Enable RAS hotplug events later (FATE#322022,
  bsc#1065729).
- commit 445a309
* Thu Feb 15 2018 jeffm@suse.com
- btrfs: copy fsid to super_block s_uuid (bsc#1080774).
- commit 8d21561
* Thu Feb 15 2018 jmoreira@suse.de
- Add kernel livepatch-devel package
  Resolving non-exported static symbols in kernel livepatches cannot
  be done implicitly. For such, the relocations of these symbols must
  follow a specially crafted format in the respective elf file. Willing
  to make the task of converting the elf into the right format, a tool
  named klp-convert was proposed. Through a file that maps all kernel
  symbols into their respective kernel object, this tool infers which
  non-exported symbol is relative to a livepatch relocation and
  automatically formats the final elf file.
  Add support to the generation of a map file right after the kernel
  compilation.
  Add the package kernel-<flavour>-livepatch-devel that brings
  the map file.
- commit 0b1b4d3
* Thu Feb 15 2018 jthumshirn@suse.de
- scsi: lpfc: Update 11.4.0.7 modified files for 2018 Copyright
  (bsc#1080657).
- scsi: lpfc: update driver version to 11.4.0.7 (bsc#1080657).
- scsi: lpfc: Fix nonrecovery of NVME controller after cable swap
  (bsc#1080657).
- scsi: lpfc: Treat SCSI Write operation Underruns as an error
  (bsc#1080657).
- scsi: lpfc: Fix header inclusion in lpfc_nvmet (bsc#1080657).
- scsi: lpfc: Validate adapter support for SRIU option
  (bsc#1080657).
- scsi: lpfc: Fix SCSI io host reset causing kernel crash
  (bsc#1080657).
- scsi: lpfc: Indicate CONF support in NVMe PRLI (bsc#1080657).
- scsi: lpfc: Fix issue_lip if link is disabled (bsc#1080657).
- scsi: lpfc: Fix soft lockup in lpfc worker thread during LIP
  testing (bsc#1080657).
- scsi: lpfc: Allow set of maximum outstanding SCSI cmd limit
  for a target (bsc#1080657).
- scsi: lpfc: Fix RQ empty firmware trap (bsc#1080657).
- scsi: lpfc: Fix IO failure during hba reset testing with nvme io
  (bsc#1080657).
- scsi: lpfc: Fix PRLI handling when topology type changes
  (bsc#1080657).
- scsi: lpfc: Add WQ Full Logic for NVME Target (bsc#1080657).
- scsi: lpfc: correct debug counters for abort (bsc#1080657).
- scsi: lpfc: move placement of target destroy on driver detach
  (bsc#1080657).
- scsi: lpfc: Increase CQ and WQ sizes for SCSI (bsc#1080657).
- scsi: lpfc: Fix frequency of Release WQE CQEs (bsc#1080657).
- commit 7226e76
* Thu Feb 15 2018 ohering@suse.de
- hv_netvsc: Use the num_online_cpus() for channel limit
  (fate#323887).
- scsi: storvsc: missing error code in storvsc_probe()
  (fate#323887).
- uio_hv_generic: fix new type mismatch warnings (fate#323887).
- uio_hv_generic: fix type mismatch warnings (fate#323887).
- uio_hv_generic: add rescind support (fate#323887).
- uio_hv_generic: check that host supports monitor page
  (fate#323887).
- uio_hv_generic: create send and receive buffers (fate#323887).
- vmbus: add monitor_id and subchannel_id to sysfs per channel
  (fate#323887).
- uio_hv_generic: use ISR callback method (fate#323887).
- uio_hv_generic: use standard mmap for resources (fate#323887).
- uio_hv_generic: fix configuration comments (fate#323887).
- vmbus: make channel attributes static (fate#323887).
- hv_netvsc: empty current transmit aggregation if flow blocked
  (fate#323887).
- hv_netvsc: remove open_cnt reference count (fate#323887).
- hv_netvsc: pass netvsc_device to receive callback (fate#323887).
- hv_netvsc: simplify function args in receive status path
  (fate#323887).
- hv_netvsc: track memory allocation failures in ethtool stats
  (fate#323887).
- hv_netvsc: copy_to_send buf can be void (fate#323887).
- hv_netvsc: Fix the TX/RX buffer default sizes (fate#323887).
- hv_netvsc: Fix the receive buffer size limit (fate#323887).
- vmbus: make hv_get_ringbuffer_availbytes local (fate#323887).
- hv_netvsc: optimize initialization of RNDIS header
  (fate#323887).
- hv_netvsc: use reciprocal divide to speed up percent calculation
  (fate#323887).
- hv_netvsc: replace divide with mask when computing padding
  (fate#323887).
- hv_netvsc: don't need local xmit_more (fate#323887).
- hv_netvsc: drop unused macros (fate#323887).
- commit 72e1a3c
* Thu Feb 15 2018 ohering@suse.de
- add mainline tag to hv-X86_FEATURE_PCID patch
- commit 258a152
* Thu Feb 15 2018 tiwai@suse.de
- drm/vc4: Flush the caches before the bin jobs, as well
  (bsc#1051510).
- commit 81ad369
* Thu Feb 15 2018 tiwai@suse.de
- drm: rework delayed connector cleanup in connector_iter
  (bsc#1051510).
- commit cc83f2f
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Always call to intel_display_set_init_power() in
  resume_early (bsc#1051510).
- commit f91d13e
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Always run hangcheck while the GPU is busy
  (bsc#1051510).
- commit 09cdfcc
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/cmdparser: Check reg_table_count before derefencing
  (bsc#1051510).
- commit 3a43a70
* Thu Feb 15 2018 tiwai@suse.de
- drm: safely free connectors from connector_iter (bsc#1051510).
- commit 8a5bb42
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/lpe: Remove double-encapsulation of info string
  (bsc#1051510).
- commit c91a5f4
* Thu Feb 15 2018 tiwai@suse.de
- drm/qxl: reapply cursor after resetting primary (bsc#1051510).
- commit 579b46a
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/ppgtt: Pin page directories before allocation
  (bsc#1051510).
- commit ec22aec
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Fix using BIT_ULL() vs. BIT() for power domain masks
  (bsc#1051510).
- commit 2fd6f13
* Thu Feb 15 2018 tiwai@suse.de
- drm/amdgpu: only check mmBIF_IOV_FUNC_IDENTIFIER on tonga/fiji
  (bsc#1051510).
- commit 9861962
* Thu Feb 15 2018 msuchanek@suse.de
- ibmvnic: Clean RX pool buffers during device close
  (bsc#1081134).
- ibmvnic: Free RX socket buffer in case of adapter error
  (bsc#1081134).
- ibmvnic: Fix NAPI structures memory leak (bsc#1081134).
- ibmvnic: Fix login buffer memory leaks (bsc#1081134).
- ibmvnic: Wait until reset is complete to set carrier on
  (bsc#1081134).
- commit 93a2616
* Thu Feb 15 2018 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit 83ae805
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915: Drop fb reference on load_detect_pipe failure path
  (bsc#1051510).
- drm/i915: Replace *_reference/unreference() or *_ref/unref
  with _get/put() (bsc#1051510).
- commit c6b993a
* Thu Feb 15 2018 msuchanek@suse.de
- Refresh patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
  fix commit hash
- commit 94790ed
* Thu Feb 15 2018 tiwai@suse.de
- drm/vc4: Fix NULL pointer dereference in vc4_save_hang_state()
  (bsc#1051510).
- commit 1603569
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/psr: Fix register name mess up (bsc#1051510).
- commit 6ce9707
* Thu Feb 15 2018 tiwai@suse.de
- drm/vc4: Move IRQ enable to PM path (bsc#1051510).
- commit 4fd629c
* Thu Feb 15 2018 tiwai@suse.de
- serial: 8250_uniphier: fix error return code in
  uniphier_uart_probe() (bsc#1051510).
- commit 5b3310e
* Thu Feb 15 2018 tiwai@suse.de
- drm/edid: kerneldoc for is_hdmi2_sink (bsc#1051510).
- commit 072edca
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/cnp: Properly handle VBT ddc pin out of bounds
  (bsc#1051510).
- drm/i915/cnp: Ignore VBT request for know invalid DDC pin
  (bsc#1051510).
- commit 1b039a5
* Thu Feb 15 2018 tiwai@suse.de
- drm/i915/glk: Disable Guc and HuC on GLK (bsc#1051510).
- commit b8eaf51
* Thu Feb 15 2018 tiwai@suse.de
- Add no-fix tag to i915 patches
- commit 1c45058
* Thu Feb 15 2018 tiwai@suse.de
- platform/x86: dell-laptop: Filter out spurious keyboard
  backlight change events (bsc#1051510).
- commit 104f7af
* Thu Feb 15 2018 tiwai@suse.de
- ASoC: au1x: Fix timeout tests in au1xac97c_ac97_read()
  (bsc#1051510).
- ASoC: Intel: sst: Fix the return value of
  'sst_send_byte_stream_mrfld()' (bsc#1051510).
- ASoC: rockchip: i2s: fix playback after runtime resume
  (bsc#1051510).
- ASoC: nuc900: Fix a loop timeout test (bsc#1051510).
- ASoC: amd: Add error checking to probe function (bsc#1051510).
- commit d9748ce
* Thu Feb 15 2018 tiwai@suse.de
- ALSA: hda - Reduce the suspend time consumption for ALC256
  (bsc#1051510).
- commit 6999499
* Thu Feb 15 2018 tiwai@suse.de
- ALSA: hda - Use IS_REACHABLE() for dependency on input
  (bsc#1051510).
- commit 016c820
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Atomic replace and cumulative patches documentation
  (bsc#1071995 fate#323487).
- commit e40f006
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Add atomic replace (bsc#1071995 fate#323487).
- commit bf08cda
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Support separate list for replaced patches
  (bsc#1071995 fate#323487).
- commit 1f2a166
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Allow to unpatch only functions of the given type
  (bsc#1071995 fate#323487).
- commit 9895789
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Initial support for dynamic structures (bsc#1071995
  fate#323487).
- commit c46efc1
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Free only structures with initialized kobject
  (bsc#1071995 fate#323487).
- commit c2ef814
* Thu Feb 15 2018 mbenes@suse.cz
- livepatch: Use lists to manage patches, objects and functions
  (bsc#1071995 fate#323487).
- commit 3385ca3
* Thu Feb 15 2018 bpoirier@suse.com
- Refresh patch order in sorted section
- Refresh
  patches.drivers/scsi-qla2xxx-Avoid-triggering-undefined-behavior-in-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-a-locking-imbalance-in-qlt_24xx_han.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
- commit cea0d55
* Wed Feb 14 2018 mbrugger@suse.com
- arm64: Kill PSCI_GET_VERSION as a variant-2 workaround
  (bsc#1068032).
- arm64: Add ARM_SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bsc#1068032).
- arm/arm64: smccc: Implement SMCCC v1.1 inline primitive
  (bsc#1068032).
- arm/arm64: smccc: Make function identifiers an unsigned quantity
  (bsc#1068032).
- firmware/psci: Expose SMCCC version through psci_ops
  (bsc#1068032).
- firmware/psci: Expose PSCI conduit (bsc#1068032).
- arm64: KVM: Add SMCCC_ARCH_WORKAROUND_1 fast handling
  (bsc#1068032).
- arm64: KVM: Report SMCCC_ARCH_WORKAROUND_1 BP hardening support
  (bsc#1068032).
- arm/arm64: KVM: Turn kvm_psci_version into a static inline
  (bsc#1068032).
- arm/arm64: KVM: Advertise SMCCC v1.1 (bsc#1068032).
- arm/arm64: KVM: Implement PSCI 1.0 support (bsc#1068032).
- arm/arm64: KVM: Add smccc accessors to PSCI code (bsc#1068032).
- arm/arm64: KVM: Add PSCI_VERSION helper (bsc#1068032).
- arm/arm64: KVM: Consolidate the PSCI include files
  (bsc#1068032).
- arm64: KVM: Increment PC after handling an SMC trap
  (bsc#1068032).
- arm: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bsc#1068032).
- commit e769a19
* Wed Feb 14 2018 mbrugger@suse.com
- Refresh
  patches.suse/0019-arm64-KVM-Fix-SMCCC-handling-of-unimplemented-SMC-HV.patch.
- commit a856f51
* Wed Feb 14 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: Add mkp/4.17/scsi-queue
- commit 41390e8
* Wed Feb 14 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-double-free-bug-after-firmware-time.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-incorrect-handle-for-abort-IOCB.patch.
  Upstream Commit IDs have changed due to re-base.
- commit 6cd1846
* Wed Feb 14 2018 jslaby@suse.cz
- pipe: avoid round_pipe_size() nr_pages overflow on 32-bit
  (bnc#1006867).
- commit e550396
* Wed Feb 14 2018 tiwai@suse.de
- futex: Prevent overflow by strengthen input validation
  (CVE-2018-6927,bsc#1080757).
- commit 6fd37c0
* Wed Feb 14 2018 jack@suse.cz
- ext4: reduce lock contention in __ext4_new_inode (bsc#1080989).
- commit bcf743f
* Wed Feb 14 2018 jack@suse.cz
- ext4: do not unnecessarily allocate buffer in recently_deleted()
  (bsc#1080989).
- commit 3ae1700
* Wed Feb 14 2018 jack@suse.cz
- ext4: cleanup goto next group (bsc#1080989).
- commit 13de627
* Wed Feb 14 2018 mbrugger@suse.com
- Fix series.conf sort-order
- commit 6668be5
* Tue Feb 13 2018 msuchanek@suse.de
- ibmvnic: Remove skb->protocol checks in ibmvnic_xmit
  (bsc#1080384).
- ibmvnic: Reset long term map ID counter (bsc#1080364).
- commit 8c6ee76
* Tue Feb 13 2018 msuchanek@suse.de
- powerpc/xmon: Dont register sysrq key when kernel param xmon=off
  (bsc#1072829).
- commit 3e326cd
* Tue Feb 13 2018 jthumshirn@suse.de
- nvme_fc: cleanup io completion (bsc#1079628).
- nvme_fc: correct abort race condition on resets (bsc#1079628).
- commit 3347e8d
* Tue Feb 13 2018 mgorman@suse.de
- sched/numa: Delay retrying placement for automatic NUMA balance
  after wake_affine (bnc#1064414).
- sched/fair: Consider SD_NUMA when selecting the most idle
  group to schedule on (bnc#1064414).
- sched/fair: Do not migrate due to a sync wakeup on exit
  (bnc#1064414).
- sched/fair: Do not migrate on wake_affine_weight if weights
  are equal (bnc#1064414).
- sched/fair: Defer calculation of prev_eff_load in wake_affine
  until needed (bnc#1064414).
- sched/fair: Avoid an unnecessary lookup of current CPU ID
  during wake_affine (bnc#1064414).
- commit 5c70670
* Tue Feb 13 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add nvme/nvme-4.16-rc
- commit 40fc9c6
* Tue Feb 13 2018 msuchanek@suse.de
- KVM: PPC: Book3S PR: Fix svcpu copying with preemption enabled
  (bsc#1077761, git-fixes).
- commit b909d20
* Tue Feb 13 2018 jthumshirn@suse.de
- scsi: libsas: fix error when getting phy events (bsc#1061782).
- commit 7b1f578
* Tue Feb 13 2018 fdmanana@suse.com
- Btrfs: fix space leak after fallocate and zero range operations
  (fate#323233).
- commit 12996c5
* Tue Feb 13 2018 fdmanana@suse.com
- Btrfs: fix missing inode i_size update after zero range
  operation (fate#323233).
- commit a150fc9
* Tue Feb 13 2018 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-add-support-for-fallocate-s-zero-range-operati.patch.
- commit 18b5788
* Tue Feb 13 2018 jthumshirn@suse.de
- scsi: libsas: Disable asynchronous aborts for SATA devices
  (bsc#1061782).
- commit fd6cd11
* Tue Feb 13 2018 jthumshirn@suse.de
- Re-sort series.conf
- commit 3e66481
* Tue Feb 13 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/libnvdimm-fix-integer-overflow-static-analysis-warni.patch.
  Fix compiler warning due to bad backport.
- commit b178056
* Tue Feb 13 2018 mcgrof@suse.com
- xfs: write unmount record for ro mounts (bsc#1073401).
- xfs: toggle readonly state around xfs_log_mount_finish (bsc#1073401).
- commit d6cbdb2
* Mon Feb 12 2018 jthumshirn@suse.de
- libnvdimm, dax: fix 1GB-aligned namespaces vs physical
  misalignment (FATE#323731).
- libnvdimm, pfn: fix start_pad handling for aligned namespaces
  (FATE#323731).
- libnvdimm, pfn: make 'resource' attribute only readable by root
  (FATE#323731).
- libnvdimm, namespace: make 'resource' attribute only readable
  by root (FATE#323731).
- libnvdimm, region : make 'resource' attribute only readable
  by root (FATE#323731).
- libnvdimm: fix integer overflow static analysis warning
  (FATE#323731).
- commit 1f72f5a
* Mon Feb 12 2018 oneukum@suse.com
- usbip: fix stub_send_ret_submit() vulnerability to null
  transfer_buffer (bsc#1078669 CVE-2017-16914).
- commit 55a35d1
* Mon Feb 12 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Ensure-that-buffers-are-NULL-after-free.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-rx-queue-cleanup-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/ibmvnic-queue-reset-when-CRQ-gets-closed-during-rese.patch.
- Refresh
  patches.suse/v2-2-9-arm64-kpti-Make-use-of-nG-dependent-on-arm64_kernel_unmapped_at_el0.patch.
- commit 44586d4
* Mon Feb 12 2018 tbogendoerfer@suse.de
- cxgb4: properly initialize variables (bsc#1064802 bsc#1066129).
- IB/core: Perform modify QP on real one (bsc#1046306
  FATE#322942).
- IB/hfi1: Fix infinite loop in 8051 command error path
  (bsc#1060463 FATE#323043).
- commit bfc5374
* Mon Feb 12 2018 mgorman@suse.de
- x86 / CPU: Avoid unnecessary IPIs in arch_freq_get_on_cpu()
  (bnc#1073583 cpufreq reporting).
- cpufreq: x86: Disable interrupts during MSRs reading
  (bnc#1073583 cpufreq reporting).
- commit f714afd
* Mon Feb 12 2018 jkosina@suse.cz
- README.BRANCH: remove Jeff Mahoney as temporary comaintainer
- commit 718ae6f
* Mon Feb 12 2018 mgorman@suse.de
- cpufreq: x86: Make scaling_cur_freq behave more as expected
  (bnc#1073583 cpufreq reporting).
- commit 7670904
* Mon Feb 12 2018 mgorman@suse.de
- x86: use common aperfmperf_khz_on_cpu() to calculate KHz using
  APERF/MPERF (bnc#1073583 cpufreq reporting).
- commit 529bfe4
* Mon Feb 12 2018 bp@suse.de
- x86/cpuid: Fix up "virtual" IBRS/IBPB/STIBP feature bits on
  Intel (bsc#1068032 CVE-2017-5754).
- x86/pti: Mark constant arrays as __initconst (bsc#1068032
  CVE-2017-5754).
- x86/microcode: Fix again accessing initrd after having been
  freed (git-fixes f26483eaedec).
- x86/tsc: Fix erroneous TSC rate on Skylake Xeon (bsc#1074873).
- commit 8d39e42
* Mon Feb 12 2018 tbogendoerfer@suse.de
- bnx2x: disable GSO where gso_size is too big for hardware
  (bsc#1079384).
- net: create skb_gso_validate_mac_len() (bsc#1079384).
- commit d647fd1
* Mon Feb 12 2018 tbogendoerfer@suse.de
- Re-sorted series.conf
- Refresh
  patches.drivers/ibmvnic-Ensure-that-buffers-are-NULL-after-free.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-rx-queue-cleanup-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/ibmvnic-queue-reset-when-CRQ-gets-closed-during-rese.patch.
- Refresh
  patches.suse/v2-2-9-arm64-kpti-Make-use-of-nG-dependent-on-arm64_kernel_unmapped_at_el0.patch.
- commit d67c239
* Mon Feb 12 2018 jthumshirn@suse.de
- blacklist.conf: Blacklist 007a61ae2f35 ("nvme: fix visibility of "uuid" ns
  attribute")
- commit 94a7b7f
* Sat Feb 10 2018 bp@suse.de
- Documentation/virtual/kvm: Add AMD Secure Encrypted
  Virtualization (SEV) (bsc#1063068).
- x86/CPU/AMD: Add the Secure Encrypted Virtualization CPU feature
  (bsc#1063068).
- kvm: svm: prepare for new bit definition in nested_ctl
  (bsc#1063068).
- kvm: svm: Add SEV feature definitions to KVM (bsc#1063068).
- KVM: SVM: Prepare to reserve asid for SEV guest (bsc#1063068).
- KVM: X86: Extend CPUID range to include new leaf (bsc#1063068).
- KVM: Introduce KVM_MEMORY_ENCRYPT_OP ioctl (bsc#1063068).
- KVM: Introduce KVM_MEMORY_ENCRYPT_{UN,}REG_REGION ioctl
  (bsc#1063068).
- crypto: ccp - Use devres interface to allocate PCI/iomap and
  cleanup (bsc#1063068).
- crypto: ccp - Introduce the AMD Secure Processor device
  (bsc#1063068).
- crypto: ccp - Abstract interrupt registeration (bsc#1063068).
- crypto: ccp - rename ccp driver initialize files as sp device
  (bsc#1063068).
- crypto: ccp - remove ccp_present() check from device initialize
  (bsc#1063068).
- crypto: ccp - remove duplicate module version and author entry
  (bsc#1063068).
- crypto: ccp: Build the AMD secure processor driver only with
  AMD CPU support (bsc#1063068).
- crypto: ccp: Define SEV userspace ioctl and command id
  (bsc#1063068).
- crypto: ccp: Define SEV key management command id (bsc#1063068).
- crypto: ccp: Add Platform Security Processor (PSP) device
  support (bsc#1063068).
- crypto: ccp: Add Secure Encrypted Virtualization (SEV) command
  support (bsc#1063068).
- crypto: ccp: Implement SEV_FACTORY_RESET ioctl command
  (bsc#1063068).
- crypto: ccp: Implement SEV_PLATFORM_STATUS ioctl command
  (bsc#1063068).
- crypto: ccp: Implement SEV_PEK_GEN ioctl command (bsc#1063068).
- crypto: ccp: Implement SEV_PDH_GEN ioctl command (bsc#1063068).
- crypto: ccp: Implement SEV_PEK_CSR ioctl command (bsc#1063068).
- crypto: ccp: Implement SEV_PEK_CERT_IMPORT ioctl command
  (bsc#1063068).
- crypto: ccp: Implement SEV_PDH_CERT_EXPORT ioctl command
  (bsc#1063068).
- KVM: X86: Add CONFIG_KVM_AMD_SEV (bsc#1063068).
- KVM: SVM: Reserve ASID range for SEV guest (bsc#1063068).
- KVM: SVM: Add sev module_param (bsc#1063068).
- KVM: Define SEV key management command id (bsc#1063068).
- KVM: SVM: Add KVM_SEV_INIT command (bsc#1063068).
- KVM: SVM: VMRUN should use associated ASID when SEV is enabled
  (bsc#1063068).
- KVM: SVM: Add support for KVM_SEV_LAUNCH_START command
  (bsc#1063068).
- KVM: SVM: Add support for KVM_SEV_LAUNCH_UPDATE_DATA command
  (bsc#1063068).
- KVM: SVM: Add support for KVM_SEV_LAUNCH_MEASURE command
  (bsc#1063068).
- KVM: SVM: Add support for SEV LAUNCH_FINISH command
  (bsc#1063068).
- KVM: SVM: Add support for SEV GUEST_STATUS command
  (bsc#1063068).
- KVM: SVM: Add support for SEV DEBUG_DECRYPT command
  (bsc#1063068).
- KVM: SVM: Add support for SEV DEBUG_ENCRYPT command
  (bsc#1063068).
- KVM: SVM: Add support for SEV LAUNCH_SECRET command
  (bsc#1063068).
- KVM: SVM: Pin guest memory when SEV is active (bsc#1063068).
- KVM: SVM: Clear C-bit from the page fault address (bsc#1063068).
- KVM: SVM: Do not install #UD intercept when SEV is enabled
  (bsc#1063068).
- KVM: X86: Restart the guest when insn_len is zero and SEV is
  enabled (bsc#1063068).
- Update config files.
- Refresh
  patches.arch/01-x86-retpoline-fill-rsb-on-context-switch-for-affected-cpus.patch.
- Refresh
  patches.arch/x86-cpufeatures-clean-up-spectre-v2-related-cpuid-flags.patch.
- Refresh
  patches.arch/x86-speculation-add-basic-ibpb-indirect-branch-prediction-barrier-support.patch.
- Refresh
  patches.drivers/ibmvnic-Ensure-that-buffers-are-NULL-after-free.patch.
- Refresh
  patches.drivers/ibmvnic-Fix-rx-queue-cleanup-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/ibmvnic-queue-reset-when-CRQ-gets-closed-during-rese.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/v2-2-9-arm64-kpti-Make-use-of-nG-dependent-on-arm64_kernel_unmapped_at_el0.patch.
- scripts/git_sort/git_sort.py:
- commit 9adbb9d
* Sat Feb 10 2018 lduncan@suse.com
- qedi: Cleanup local str variable (bsc#1079977).
- qedi: Fix truncation of CHAP name and secret (bsc#1079977).
- scsi: qedi: Drop cqe response during connection recovery
  (bsc#1079977).
- scsi: qedi: Use zeroing allocator instead of allocator/memset
  (bsc#1079977).
- scsi: qedi: Fix a possible sleep-in-atomic bug in
  qedi_process_tmf_resp (bsc#1079977).
- cxgbit: Abort the TCP connection in case of data out timeout
  (bsc#1080021).
- scsi: qedi: Delete redundant variables (bsc#1079977).
- commit e417c01
* Fri Feb  9 2018 jeffm@suse.com
- config: resync arm64/vanilla
- commit e129956
* Fri Feb  9 2018 jdelvare@suse.de
- x86/acpi: Reduce code duplication in mp_override_legacy_irq()
  (bsc#1061680 bsc#1068984 bsc#1074099).
- x86/acpi: Handle SCI interrupts above legacy space gracefully
  (bsc#1061680 bsc#1068984 bsc#1074099).
- commit d3814df
* Fri Feb  9 2018 duwe@suse.de
- crypto: pcrypt - fix freeing pcrypt instances
  (bsc#1077402,CVE-2017-18075).
- commit 8e9d0d1
* Fri Feb  9 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/scsi-qla2xxx-Add-XCB-counters-to-debugfs.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ability-to-send-PRLO.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ability-to-use-GPNFT-GNNFT-for-RSCN.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-boundary-checks-for-exchanges-to-be.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-lock-protection-around-host-lookup.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-option-for-use-reserve-exch-for-ELS.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-retry-limit-for-fabric-scan-logic.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-switch-command-to-simplify-fabric-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-relogin-and-session-creation-afte.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-target-mode-to-accept-PRLI-in-dua.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Chip-reset-uses-wrong-lock-during-IO-fl.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Clear-loop-id-after-delete.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Defer-processing-of-GS-IOCB-calls.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Delay-loop-id-allocation-at-login.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Don-t-call-dma_free_coherent-with-IRQ-d.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Enable-ATIO-interrupt-handshake-for-ISP.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-Firmware-dump-size-for-Extended-log.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-GPNFT-GNNFT-error-handling.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-NPIV-host-cleanup-in-target-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-NULL-pointer-access-for-fcport-stru.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-NULL-pointer-crash-due-to-probe-fai.patch.
- Refresh patches.drivers/scsi-qla2xxx-Fix-PRLI-state-check.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-Relogin-being-triggered-too-fast.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-abort-command-deadlock-due-to-spinl.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-gpnid-error-processing.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-login-state-machine-freeze.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-login-state-machine-stuck-at-GPDB.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-logo-flag-for-qlt_free_session_done.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-memory-leak-in-dual-target-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-queue-ID-for-async-abort-with-Multi.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-re-login-for-Nport-Handle-in-use.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-scan-state-field-for-fcport.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-session-cleanup-for-N2N.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-smatch-warning-in-qla25xx_delete_-r.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-system-crash-for-Notify-ack-timeout.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-system-crash-in-qlt_plogi_ack_unref.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-warning-during-port_name-debug-prin.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-warning-for-code-intentation-in-__q.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-warning-in-qla2x00_async_iocb_timeo.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Increase-verbosity-of-debug-messages-lo.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Migrate-switch-registration-commands-aw.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Move-session-delete-to-driver-work-queu.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Move-work-element-processing-out-of-DPC.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Prevent-multiple-active-discovery-comma.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Prevent-relogin-trigger-from-sending-to.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Properly-extract-ADISC-error-codes.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reduce-the-use-of-terminate-exchange.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reduce-trace-noise-for-Async-Events.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Relogin-to-target-port-on-a-cable-swap.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-aborting-ELS-IOCB-call-issued-as.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-session-creation-redundant-code.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Remove-unused-argument-from-qlt_schedul.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Replace-GPDB-with-async-ADISC-command.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Replace-fcport-alloc-with-qla2x00_alloc.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Retry-switch-command-on-time-out.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Serialize-GPNID-for-multiple-RSCN.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Serialize-session-deletion-by-using-wor.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Serialize-session-free-in-qlt_free_sess.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Skip-IRQ-affinity-for-Target-QPairs.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Suppress-gcc-7-fall-through-warnings.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Tweak-resource-count-dump.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.03-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.04-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.05-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-IOCB-path-to-submit-Control-VP-MBX-.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-chip-reset-to-bring-down-laser-on-u.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-known-NPort-ID-for-Management-Serve.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-shadow-register-for-ISP27XX.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-zeroing-allocator-rather-than-alloc.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-remove-duplicate-includes.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-remove-redundant-assignment-of-d.patch.
- commit 8ad9d97
* Fri Feb  9 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix incorrect handle for abort IOCB
  (bsc#1077338).
- scsi: qla2xxx: Fix double free bug after firmware timeout
  (bsc#1077338).
- scsi: qla2xxx: Fix a locking imbalance in qlt_24xx_handle_els()
  (bsc#1077338).
- scsi: qla2xxx: Avoid triggering undefined behavior in
  qla2x00_mbx_completion() (bsc#1077338).
- commit 920953f
* Fri Feb  9 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add mkp/scsi.git 4.16/scsi-fixes
- commit db9b61f
* Fri Feb  9 2018 jthumshirn@suse.de
- scsi: qla2xxx: Fix logo flag for qlt_free_session_done()
  (bsc#1077338).
- scsi: qla2xxx: Update driver version to 10.00.00.05-k
  (bsc#1077338).
- scsi: qla2xxx: Add XCB counters to debugfs (bsc#1077338).
- scsi: qla2xxx: Fix queue ID for async abort with Multiqueue
  (bsc#1077338).
- scsi: qla2xxx: Fix warning for code intentation in
  __qla24xx_handle_gpdb_event() (bsc#1077338).
- scsi: qla2xxx: Fix warning during port_name debug print
  (bsc#1077338).
- scsi: qla2xxx: Fix warning in qla2x00_async_iocb_timeout()
  (bsc#1077338).
- scsi: qla2xxx: Fix NULL pointer crash due to probe failure
  (bsc#1077338).
- scsi: qla2xxx: remove redundant assignment of d (bsc#1077338).
- scsi: qla2xxx: Use zeroing allocator rather than
  allocator/memset (bsc#1077338).
- scsi: qla2xxx: Update driver version to 10.00.00.04-k
  (bsc#1077338).
- scsi: qla2xxx: Serialize session free in qlt_free_session_done
  (bsc#1077338).
- scsi: qla2xxx: Serialize session deletion by using work_lock
  (bsc#1077338).
- scsi: qla2xxx: Remove unused argument from
  qlt_schedule_sess_for_deletion() (bsc#1077338).
- scsi: qla2xxx: Prevent relogin trigger from sending too many
  commands (bsc#1077338).
- scsi: qla2xxx: Prevent multiple active discovery commands per
  session (bsc#1077338).
- scsi: qla2xxx: Add retry limit for fabric scan logic
  (bsc#1077338).
- scsi: qla2xxx: Delay loop id allocation at login (bsc#1077338).
- scsi: qla2xxx: Increase verbosity of debug messages logged
  (bsc#1077338).
- scsi: qla2xxx: Allow relogin and session creation after reset
  (bsc#1077338).
- scsi: qla2xxx: Add ability to use GPNFT/GNNFT for RSCN handling
  (bsc#1077338).
- scsi: qla2xxx: Properly extract ADISC error codes (bsc#1077338).
- scsi: qla2xxx: Fix GPNFT/GNNFT error handling (bsc#1077338).
- scsi: qla2xxx: Remove session creation redundant code
  (bsc#1077338).
- scsi: qla2xxx: Migrate switch registration commands away from
  mailbox interface (bsc#1077338).
- scsi: qla2xxx: Fix login state machine freeze (bsc#1077338).
- scsi: qla2xxx: Reduce trace noise for Async Events
  (bsc#1077338).
- scsi: qla2xxx: Reduce the use of terminate exchange
  (bsc#1077338).
- scsi: qla2xxx: Add lock protection around host lookup
  (bsc#1077338).
- scsi: qla2xxx: Add switch command to simplify fabric discovery
  (bsc#1077338).
- scsi: qla2xxx: Use known NPort ID for Management Server login
  (bsc#1077338).
- scsi: qla2xxx: Fix session cleanup for N2N (bsc#1077338).
- scsi: qla2xxx: Tweak resource count dump (bsc#1077338).
- scsi: qla2xxx: Allow target mode to accept PRLI in dual mode
  (bsc#1077338).
- scsi: qla2xxx: Don't call dma_free_coherent with IRQ disabled
  (bsc#1077338).
- scsi: qla2xxx: Add ability to send PRLO (bsc#1077338).
- scsi: qla2xxx: Add option for use reserve exch for ELS
  (bsc#1077338).
- scsi: qla2xxx: Use shadow register for ISP27XX (bsc#1077338).
- scsi: qla2xxx: Enable ATIO interrupt handshake for ISP27XX
  (bsc#1077338).
- scsi: qla2xxx: Move work element processing out of DPC thread
  (bsc#1077338).
- scsi: qla2xxx: Replace GPDB with async ADISC command
  (bsc#1077338).
- scsi: qla2xxx: Fix Firmware dump size for Extended login and
  Exchange Offload (bsc#1077338).
- scsi: qla2xxx: Chip reset uses wrong lock during IO flush
  (bsc#1077338).
- scsi: qla2xxx: Add boundary checks for exchanges to be offloaded
  (bsc#1077338).
- scsi: qla2xxx: Use chip reset to bring down laser on unload
  (bsc#1077338).
- scsi: qla2xxx: Use IOCB path to submit Control VP MBX command
  (bsc#1077338).
- scsi: qla2xxx: Fix NULL pointer access for fcport structure
  (bsc#1077338).
- scsi: qla2xxx: Fix smatch warning in
  qla25xx_delete_{rsp|req}_que (bsc#1077338).
- scsi: qla2xxx: remove duplicate includes (bsc#1077338).
- scsi: qla2xxx: Suppress gcc 7 fall-through warnings
  (bsc#1077338).
- scsi: qla2xxx: Update driver version to 10.00.00.03-k
  (bsc#1077338).
- scsi: qla2xxx: Fix memory leak in dual/target mode
  (bsc#1077338).
- scsi: qla2xxx: Fix system crash in qlt_plogi_ack_unref
  (bsc#1077338).
- scsi: qla2xxx: Remove aborting ELS IOCB call issued as part
  of timeout (bsc#1077338).
- scsi: qla2xxx: Defer processing of GS IOCB calls (bsc#1077338).
- scsi: qla2xxx: Clear loop id after delete (bsc#1077338).
- scsi: qla2xxx: Fix scan state field for fcport (bsc#1077338).
- scsi: qla2xxx: Replace fcport alloc with qla2x00_alloc_fcport
  (bsc#1077338).
- scsi: qla2xxx: Fix abort command deadlock due to spinlock
  (bsc#1077338).
- scsi: qla2xxx: Fix PRLI state check (bsc#1077338).
- scsi: qla2xxx: Fix Relogin being triggered too fast
  (bsc#1077338).
- scsi: qla2xxx: Relogin to target port on a cable swap
  (bsc#1077338).
- scsi: qla2xxx: Fix NPIV host cleanup in target mode
  (bsc#1077338).
- scsi: qla2xxx: Fix login state machine stuck at GPDB
  (bsc#1077338).
- scsi: qla2xxx: Serialize GPNID for multiple RSCN (bsc#1077338).
- scsi: qla2xxx: Retry switch command on time out (bsc#1077338).
- scsi: qla2xxx: Fix re-login for Nport Handle in use
  (bsc#1077338).
- scsi: qla2xxx: Skip IRQ affinity for Target QPairs
  (bsc#1077338).
- scsi: qla2xxx: Move session delete to driver work queue
  (bsc#1077338).
- scsi: qla2xxx: Fix gpnid error processing (bsc#1077338).
- scsi: qla2xxx: Fix system crash for Notify ack timeout handling
  (bsc#1077338).
- scsi: qla2xxx: Fix oops in qla2x00_probe_one error path
  (bsc#1077338).
- scsi: qla2xxx: Fix system crash while triggering FW dump
  (bsc#1077338).
- commit e0a937c
* Fri Feb  9 2018 mkubecek@suse.cz
- tap: fix use-after-free (bsc#1076830).
- l2tp: don't use l2tp_tunnel_find() in l2tp_ip and l2tp_ip6
  (bsc#1076830).
- l2tp: fix l2tp_eth module loading (bsc#1076830).
- tipc: use only positive error codes in messages (bsc#1076830).
- tcp: fastopen: fix on syn-data transmit failure (bsc#1076830).
- sctp: do not mark sk dumped when inet_sctp_diag_fill returns
  err (bsc#1076830).
- media: rc: simplify ir_raw_event_store_edge() (bsc#1076830).
- l2tp: hold tunnel while handling genl tunnel updates
  (bsc#1076830).
- l2tp: hold tunnel while processing genl delete command
  (bsc#1076830).
- l2tp: initialise session's refcount before making it reachable
  (bsc#1076830).
- tcp: enable xmit timer fix by having TLP use time when RTO
  should fire (bsc#1076830).
- tcp: introduce tcp_rto_delta_us() helper for xmit timer fix
  (bsc#1076830).
- ipvlan: Fix 64-bit statistics seqcount initialization
  (bsc#1076830).
- commit 56fda6b
* Fri Feb  9 2018 agraf@suse.de
- Update config files (bsc#1080294)
- commit 54e4b16
* Fri Feb  9 2018 mkubecek@suse.cz
- netfilter: on sockopt() acquire sock lock only in the required
  scope (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix out-of-bounds accesses in
  clusterip_tg_check() (bsc#1076830).
- netfilter: x_tables: fix pointer leaks to userspace
  (bsc#1076830).
- tcp_bbr: fix pacing_gain to always be unity when using lt_bw
  (bsc#1076830).
- ipv6: Fix SO_REUSEPORT UDP socket with implicit sk_ipv6only
  (bsc#1076830).
- bridge: return boolean instead of integer in
  br_multicast_is_router (bsc#1076830).
- vxlan: Fix trailing semicolon (bsc#1076830).
- l2tp: fix missing print session offset info (bsc#1076830).
- xfrm: Fix xfrm_replay_overflow_offload_esn (bsc#1076830).
- rds: tcp: correctly sequence cleanup on netns deletion
  (bsc#1076830).
- rds: tcp: remove redundant function rds_tcp_conn_paths_destroy()
  (bsc#1076830).
- gso: validate gso_type in GSO handlers (bsc#1076830).
- tun: fix a memory leak for tfile->tx_array (bsc#1076830).
- mac80211_hwsim: validate number of different channels
  (bsc#1076830).
- sctp: reinit stream if stream outcnt has been change by sinit
  in sendmsg (bsc#1076830).
- esp: Fix GRO when the headers not fully in the linear part of
  the skb (bsc#1076830).
- xfrm: skip policies marked as dead while rehashing
  (bsc#1076830).
- tcp: remove buggy call to tcp_v6_restore_cb() (bsc#1076830).
- ipvlan: always use the current L2 addr of the master
  (bsc#1076830).
- tcp: do not mangle skb->cb in tcp_make_synack() (bsc#1076830).
- l2tp: check ps->sock before running pppol2tp_session_ioctl()
  (bsc#1076830).
- l2tp: fix race condition in l2tp_tunnel_delete (bsc#1076830).
- net: use inet6_rcv_saddr to compare sockets (bsc#1076830).
- tcp: remove two unused functions (bsc#1076830).
- xfrm_user: fix info leak in copy_user_offload() (bsc#1076830).
- l2tp: hold tunnel while handling genl TUNNEL_GET commands
  (bsc#1076830).
- l2tp: hold tunnel while looking up sessions in l2tp_netlink
  (bsc#1076830).
- tipc: reassign pointers after skb reallocation / linearization
  (bsc#1076830).
- tipc: remove subscription references only for pending timers
  (bsc#1076830).
- bridge: allow ext learned entries to change ports (bsc#1076830).
- net: reflect mark on tcp syn ack packets (bsc#1076830).
- rds: tcp: set linger to 1 when unloading a rds-tcp
  (bsc#1076830).
- rds: tcp: Set linger when rejecting an incoming conn in
  rds_tcp_accept_one (bsc#1076830).
- commit bd4b81f
* Fri Feb  9 2018 agraf@suse.de
- s390/perf: fix problem state detection (bsc#1077761).
- commit da7a2a3
* Fri Feb  9 2018 agraf@suse.de
- Run scripts/series_sort.py.
- commit 22e3d2b
* Fri Feb  9 2018 agraf@suse.de
- Update config files: Enable CONFIG_HISILICON_ERRATUM_161600802 on arm64
- commit cceb161
* Fri Feb  9 2018 msuchanek@suse.de
- ibmvnic: queue reset when CRQ gets closed during reset
  (bsc#1080263).
- commit 75132a4
* Fri Feb  9 2018 mbrugger@suse.com
- arm64: idmap: Use "awx" flags for .idmap.text .pushsection
  directives (bsc#1068032).
- Update config files.
- arm64: entry: Reword comment about post_ttbr_update_workaround
  (bsc#1068032).
- arm64: Force KPTI to be disabled on Cavium ThunderX
  (bsc#1068032).
- patches.suse/arm64-add-PTE_ADDR_MASK.patch: (bsc#1068032).
- arm64: kpti: Add ->enable callback to remap swapper using nG
  mappings (bsc#1068032).
- arm64: mm: Permit transitioning from Global to Non-Global
  without BBM (bsc#1068032).
- arm64: kpti: Make use of nG dependent on
  arm64_kernel_unmapped_at_el0() (bsc#1068032).
- arm64: Add software workaround for Falkor erratum 1041
  (bsc#1068032).
- commit 057a1ba
* Fri Feb  9 2018 agraf@suse.de
- arm64: Use physical counter for in-kernel reads when booted
  in EL2 (bsc#1077761).
- arm64: Implement arch_counter_get_cntpct to read the physical
  counter (bsc#1077761).
- commit 9467ba3
* Fri Feb  9 2018 jthumshirn@suse.de
- fix unbalanced page refcounting in bio_map_user_iov (bsc#1062568
  CVE-2017-12190).
- commit a42b8fb
* Fri Feb  9 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Branch inside feature section
  (bsc#1077761).
- commit 3577581
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v4: Add forward definition of struct irq_domain_ops
  (FATE#323954).
- commit 286a0c1
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3: pr_err() strings should end with newlines
  (FATE#323954).
- commit eac0d6c
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3: Fix ppi-partitions lookup (FATE#323954).
- commit 8fafdca
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v4: Clear IRQ_DISABLE_UNLAZY again if mapping fails
  (FATE#323954).
- commit fe1e3f4
* Fri Feb  9 2018 agraf@suse.de
- KVM: arm/arm64: Check that system supports split eoi/deactivate
  (FATE#323954).
- commit 595c1eb
* Fri Feb  9 2018 agraf@suse.de
- arm64/sve: System register and exception syndrome definitions
  (FATE#323954).
- commit f07e79a
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix VPE activate callback return value
  (FATE#323954).
- commit a04ec1d
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic: Deal with broken firmware exposing only 4kB of
  GICv2 CPU interface (FATE#323954).
- commit 01bd7b0
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Setup VLPI properties at map time
  (FATE#323954).
- commit a21da0f
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Update effective affinity on VPE mapping
  (FATE#323954).
- commit dc3a515
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Only send VINVALL to a single ITS
  (FATE#323954).
- commit 5ecdea0
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Limit scope of VPE mapping to be per ITS
  (FATE#323954).
- commit 413611f
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Make its_send_vmapp operate on a single ITS
  (FATE#323954).
- commit 9941246
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Make its_send_vinvall operate on a single
  ITS (FATE#323954).
- commit 70b8ac8
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Make GICv4_ITS_LIST_MAX globally available
  (FATE#323954).
- commit 23467c3
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Track per-ITS list number (FATE#323954).
- commit 4bd7058
* Fri Feb  9 2018 agraf@suse.de
- irqchip/gic-v3-its: Workaround HiSilicon Hip07 redistributor
  addressing (FATE#323954).
- Refresh
  patches.suse/arm64-Add-software-workaround-for-Falkor-erratum-104.patch.
- commit 0a26906
* Thu Feb  8 2018 brogers@suse.com
- supported.conf: add drivers/firmware/qemu_fw_cfg
  It enables ability for handling of guest crash analysis
  (KVM), along with other uses. (bsc#1077919)
- commit 36c01d0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Pass its_node pointer to each command
  builder (FATE#323954).
- commit d719157
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add support for Range Selector (RS) feature
  (FATE#323954).
- commit 706f089
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add missing changes to support 52bit
  physical address (FATE#323954).
- commit e8e419f
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix the incorrect parsing of VCPU table size
  (FATE#323954).
- commit 511523a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix the incorrect BUG_ON in
  its_init_vpe_domain() (FATE#323954).
- commit f0aa0ed
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Fix building with ancient gcc (FATE#323954).
- commit 1d16c51
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Iterate over possible CPUs by
  for_each_possible_cpu() (FATE#323954).
- commit ebcfbbc
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Make irq_chip const (FATE#323954).
- commit 2d5ac36
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Advertise GICv4 support to KVM (FATE#323954).
- commit 40f9623
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Enable low-level GICv4 operations (FATE#323954).
- commit 84b3f27
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add some basic documentation (FATE#323954).
- commit ec6f959
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add VLPI configuration interface (FATE#323954).
- commit 86e4f8e
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add VPE command interface (FATE#323954).
- commit 73856c3
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add per-VM VPE domain creation (FATE#323954).
- commit 187e199
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Set implementation defined bit to enable
  VLPIs (FATE#323954).
- commit 3df2699
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Allow doorbell interrupts to be
  injected/cleared (FATE#323954).
- commit 4a1320e
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Move pending doorbell after VMOVP
  (FATE#323954).
- commit 7bf8955
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add device proxy for VPE management if
  !DirectLpi (FATE#323954).
- commit 7814bf0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Make LPI allocation optional on device
  creation (FATE#323954).
- commit af01bb0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE interrupt masking (FATE#323954).
- commit 3e0e018
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE affinity changes (FATE#323954).
- commit d562b75
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE invalidation hook (FATE#323954).
- commit 0ab99d4
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE scheduling (FATE#323954).
- commit 886a69b
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPENDBASER/VPROPBASER accessors
  (FATE#323954).
- commit a555020
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE irq domainactivation (FATE#323954).
- commit 1e0a736
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE irq domain allocation/teardown
  (FATE#323954).
- commit 5012fa3
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VPE domain infrastructure (FATE#323954).
- commit b171b80
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VLPI configuration handling
  (FATE#323954).
- commit 1a53a79
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VLPI map/unmap operations (FATE#323954).
- commit 39bdd8c
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add VLPI configuration hook (FATE#323954).
- commit 1df4f9e
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add GICv4 ITS command definitions
  (FATE#323954).
- commit 754bd85
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v4: Add management structure definitions
  (FATE#323954).
- commit 3e4d038
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Generalize LPI configuration (FATE#323954).
- commit c322f9d
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Generalize device table allocation
  (FATE#323954).
- commit d807afe
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Rework LPI freeing (FATE#323954).
- commit f77ae34
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Split out pending table allocation
  (FATE#323954).
- commit 94bff76
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Allow use of indirect VCPU tables
  (FATE#323954).
- commit e7ee4bb
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Split out property table allocation
  (FATE#323954).
- commit af26837
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Implement irq_set_irqchip_state for pending
  state (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-its-Add-post-mortem-info-on-command-t.patch.
- commit 321d3a8
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Macro-ize its_send_single_command
  (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-Add-workaround-for-Synquacer-pre-ITS-558b0165.patch.
- Refresh
  patches.suse/irqchip-gic-v3-its-Add-post-mortem-info-on-command-t.patch.
- commit d80fdde
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add probing for VLPI properties
  (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-Probe-device-ID-space-before-quirks-h.patch.
- Refresh
  patches.suse/irqchip-gic-v3-Add-workaround-for-Synquacer-pre-ITS-558b0165.patch
- commit a385b0d
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Move LPI definitions around (FATE#323954).
- commit 29c36a2
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add VLPI/DirectLPI discovery (FATE#323954).
- commit 6babec0
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add redistributor iterator (FATE#323954).
- commit ee41ab4
* Thu Feb  8 2018 agraf@suse.de
- genirq: Let irq_set_vcpu_affinity() iterate over hierarchy
  (FATE#323954).
- commit bb7657a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Properly handle command queue wrapping
  (FATE#323954).
- commit b883322
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Report that effective affinity is a single
  target (FATE#323954).
- commit 6f8bd53
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Report that effective affinity is a single
  target (FATE#323954).
- commit 8954ba3
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Report that effective affinity is a single target
  (FATE#323954).
- commit 7ca4347
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its-platform-msi: Fix msi-parent parsing loop
  (FATE#323954).
- commit b0e243c
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Allow GIC ITS number more than MAX_NUMNODES
  (FATE#323954).
- commit 36735a4
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Ensure we have an ISB between ack and ->handle_irq
  (FATE#323954).
- commit f7f8f59
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Remove ACPICA version check for ACPI NUMA
  (FATE#323954).
- commit ad1cbf1
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Honor forced affinity setting (FATE#323954).
- commit 76565c7
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Report failures in gic_irq_domain_alloc
  (FATE#323954).
- commit a5ca30a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v2: Report failures in gic_irq_domain_alloc
  (FATE#323954).
- commit cc989f5
* Thu Feb  8 2018 agraf@suse.de
- iommu/arm-smmu-v3: Enable ACPI based HiSilicon CMD_PREFETCH
  quirk(erratum 161010701) (FATE#323954).
- commit c2ed429
* Thu Feb  8 2018 agraf@suse.de
- arm64: Add MIDR values for Cavium cn83XX SoCs (FATE#323954).
- commit 3d86f32
* Thu Feb  8 2018 agraf@suse.de
- arm64: Add a facility to turn an ESR syndrome into a sysreg
  encoding (FATE#323954).
- commit b7a0ad9
* Thu Feb  8 2018 brogers@suse.com
- Update config files.
- commit 038084e
* Thu Feb  8 2018 agraf@suse.de
- ACPICA: Add support for new SRAT subtable (FATE#323954).
- commit 107759b
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Don't assume GICv3 hardware supports 16bit
  INTID (FATE#323954).
- commit 41c997a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add ACPI NUMA node mapping (FATE#323954).
- commit e83e0cc
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its-platform-msi: Make of_device_ids const
  (FATE#323954).
- commit ac4f6c8
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Make of_device_ids const (FATE#323954).
- commit cdca6a2
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gicv3-its: Skip irq affinity setting when target cpu
  is the same as current setting (FATE#323954).
- commit 8566246
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Fix MSI alias accounting (FATE#323954).
- commit 90ccab5
* Thu Feb  8 2018 agraf@suse.de
- genirq/irqdomain: Remove auto-recursive hierarchy support
  (FATE#323954).
- commit b4e692f
* Thu Feb  8 2018 agraf@suse.de
- irqchip/MSI: Use irq_domain_update_bus_token instead of an
  open coded access (FATE#323954).
- Refresh
  patches.suse/irqchip-gic-v3-Add-workaround-for-Synquacer-pre-ITS-558b0165.patch.
- commit c2912d8
* Thu Feb  8 2018 agraf@suse.de
- genirq/irqdomain: Add irq_domain_update_bus_token helper
  (FATE#323954).
- commit bbab0e5
* Thu Feb  8 2018 agraf@suse.de
- s390/mm: remove incorrect _REGION3_ENTRY_ORIGIN define
  (bsc#1077761).
- commit 7a77b31
* Thu Feb  8 2018 agraf@suse.de
- Add stubs to ignore effective IRQ affinity (FATE#323954).
- commit ffd094d
* Thu Feb  8 2018 brogers@suse.com
- s390: fix alloc_pgste check in init_new_context again
  (bsc#1077706).
- s390/kvm: avoid global config of vm.alloc_pgste=1 (bsc#1077706).
- commit 504a71f
* Thu Feb  8 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: Also require m4 for build.
- commit 0d7b4b3
* Thu Feb  8 2018 msuchanek@suse.de
- ibmvnic: Ensure that buffers are NULL after free (bsc#1080014).
- ibmvnic: Fix rx queue cleanup for non-fatal resets
  (bsc#1080014).
- commit 9627b8d
* Thu Feb  8 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-fix-empty-firmware-version-and-errors-cleanu.patch.
- commit 83a5eee
* Thu Feb  8 2018 agraf@suse.de
- Move ARM IOMMU patches to sorted section
- commit 3aa94a7
* Thu Feb  8 2018 jslaby@suse.cz
- Documentation: Document array_index_nospec (bsc#1068032
  CVE-2017-5753).
- array_index_nospec: Sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5753).
- x86: Implement array_index_mask_nospec (bsc#1068032
  CVE-2017-5753).
- x86: Introduce barrier_nospec (bsc#1068032 CVE-2017-5753).
- x86: Introduce __uaccess_begin_nospec() and uaccess_try_nospec
  (bsc#1068032 CVE-2017-5753).
- x86/usercopy: Replace open coded stac/clac with
  __uaccess_{begin, end} (bsc#1068032 CVE-2017-5753).
- x86/syscall: Sanitize syscall table de-references under
  speculation (bsc#1068032 CVE-2017-5753).
- nl80211: Sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5753).
- x86/spectre: Report get_user mitigation for spectre_v1
  (bsc#1068032 CVE-2017-5753).
- Refresh
  patches.arch/23-x86-retpoline-entry-convert-entry-assembler-indirect-jumps.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Delete patches.suse/0001-Documentation-document-array_ptr.patch.
- Delete
  patches.suse/0002-asm-nospec-array_ptr-sanitize-speculative-array-de-r.patch.
- Delete
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Delete patches.suse/0003-x86-implement-array_ptr_mask.patch.
- Delete
  patches.suse/0004-x86-introduce-__uaccess_begin_nospec-and-ifence.patch.
- Delete
  patches.suse/0005-x86-bpf-jit-prevent-speculative-execution-when-JIT-i.patch.
- Delete
  patches.suse/0006-uvcvideo-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-carl9170-prevent-speculative-execution.patch.
- Delete
  patches.suse/0007-x86-narrow-out-of-bounds-syscalls-to-sys_read-under-.patch.
- Delete
  patches.suse/0008-p54-prevent-speculative-execution.patch.
- Delete
  patches.suse/0009-qla2xxx-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-cw1200-prevent-speculative-execution.patch.
- Delete
  patches.suse/0010-nl80211-sanitize-array-index-in-parse_txq_params.patch.
- Delete
  patches.suse/0011-Thermal-int340x-prevent-speculative-execution.patch.
- Delete
  patches.suse/0012-ipv4-prevent-speculative-execution.patch.
- Delete
  patches.suse/0013-ipv6-prevent-speculative-execution.patch.
- Delete patches.suse/0014-fs-prevent-speculative-execution.patch.
- Delete
  patches.suse/0015-net-mpls-prevent-speculative-execution.patch.
- Delete
  patches.suse/0016-udf-prevent-speculative-execution.patch.
- Delete
  patches.suse/0017-userns-prevent-speculative-execution.patch.
  Replace spectre v1 by the upstream solution.
  /sys/devices/system/cpu/vulnerabilities/spectre_v1 now also has the
  proper text.
- commit fa33561
* Thu Feb  8 2018 bp@suse.de
- kprobes/x86: Blacklist indirect thunk functions for kprobes
  (bsc#1068032 CVE-2017-5754).
- kprobes/x86: Disable optimizing on the function jumps to
  indirect thunk (bsc#1068032 CVE-2017-5754).
- KVM: VMX: Make indirect call speculation safe (bsc#1068032
  CVE-2017-5754).
- KVM: x86: Make indirect calls in emulator speculation safe
  (bsc#1068032 CVE-2017-5754).
- module/retpoline: Warn about missing retpoline in module
  (bsc#1068032 CVE-2017-5754).
- retpoline: Introduce start/end markers of indirect thunk
  (bsc#1068032 CVE-2017-5754).
- x86/cpufeature: Blacklist SPEC_CTRL/PRED_CMD on early Spectre
  v2 microcodes (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Add AMD feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Clean up Spectre v2 related CPUID flags
  (bsc#1068032 CVE-2017-5754).
- x86/msr: Add definitions for new speculation control MSRs
  (bsc#1068032 CVE-2017-5754).
- x86/pti: Do not enable PTI on CPUs which are not vulnerable
  to Meltdown (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Optimize inline assembler for vmexit_fill_RSB
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Simplify vmexit_fill_RSB() (bsc#1068032
  CVE-2017-5754).
- x86/speculation: Add basic IBPB (Indirect Branch Prediction
  Barrier) support (bsc#1068032 CVE-2017-5754).
- blacklist.conf:
- Refresh
  patches.arch/x86-bugs-drop-one-mitigation-from-dmesg.patch.
- Refresh
  patches.arch/x86-mce-make-machine-check-speculation-protected.patch.
- commit 4d56a2a
* Thu Feb  8 2018 jthumshirn@suse.de
- kernel: fix rwlock implementation (bnc#1079840, LTC#164371).
- commit bcb7294
* Thu Feb  8 2018 jthumshirn@suse.de
- fs/proc/kcore.c: use probe_kernel_read() instead of memcpy()
  (bsc#1079840).
- commit 45c8725
* Thu Feb  8 2018 hare@suse.de
- KVM: s390: add proper locking for CMMA migration bitmap (bsc#1079840).
- KVM: s390: prevent buffer overrun on memory hotplug during migration (bsc#1079840).
- KVM: s390: fix cmma migration for multiple memory slots (bsc#1079840).
- ata: pata_artop: remove redundant initialization of pio (bsc#1079840).
- blk-mq: attempt to fix atomic flag memory ordering
  (bsc#1079840).
- s390/guarded storage: fix possible memory corruption
  (bsc#1079840).
- s390/runtime instrumention: fix possible memory corruption
  (bsc#1079840).
- s390/mm: make pmdp_invalidate() do invalidation only
  (bsc#1079840).
- s390/perf: fix bug when creating per-thread event (bsc#1079840).
- block: Relax a check in blk_start_queue() (bsc#1079840).
- Documentation: DMA API: fix a typo in a function name
  (bsc#1079840).
- kernel-doc: describe the ``literal`` syntax (bsc#1079840).
- commit 51ba0ad
* Thu Feb  8 2018 jthumshirn@suse.de
- PCI: vmd: Remove IRQ affinity so we can allocate more IRQs
  (bsc#1079887).
- commit 2023869
* Thu Feb  8 2018 oneukum@suse.com
- usbip: fix stub_rx: get_pipe() to validate endpoint number
  (bsc#1078673 CVE-2017-16912).
- commit 32f2c09
* Thu Feb  8 2018 agraf@suse.de
- Update config files.
- commit 68baef6
* Thu Feb  8 2018 hare@suse.de
- scsi: megaraid_sas: NVMe passthrough command support
  (bsc#1077408).
- scsi: megaraid_sas: driver version upgrade (bsc#1077408).
- scsi: megaraid_sas: re-work DCMD refire code (bsc#1077408).
- scsi: megaraid_sas: Expose fw_cmds_outstanding through sysfs
  (bsc#1077408).
- scsi: megaraid_sas: Selectively apply stream detection based
  on IO type (bsc#1077408).
- scsi: megaraid_sas: Update LD map after populating drv_map
  driver map copy (bsc#1077408).
- scsi: megaraid_sas: Use megasas_wait_for_adapter_operational
  to detect controller state in IOCTL path (bsc#1077408).
- scsi: megaraid_sas: Avoid firing DCMDs while OCR is in progress
  (bsc#1077408).
- scsi: megaraid_sas: unload flag should be set after
  scsi_remove_host is called (bsc#1077408).
- scsi: megaraid_sas: Error handling for invalid ldcount provided
  by firmware in RAID map (bsc#1077408).
- scsi: megaraid_sas: Reset ldio_outstanding in megasas_resume
  (bsc#1077408).
- scsi: megaraid_sas: Return the DCMD status from
  megasas_get_seq_num (bsc#1077408).
- scsi: megaraid_sas: memset IOC INIT frame using correct size
  (bsc#1077408).
- scsi: megaraid_sas: zero out IOC INIT and stream detection
  memory (bsc#1077408).
- commit 60410e5
* Thu Feb  8 2018 hare@suse.de
- Drop non-standard megaraid_sas patches
- Delete
  patches.drivers/megaraid_sas-Fallback-to-older-scanning-if-not-disks.patch.
- Delete
  patches.drivers/megaraid_sas-boot-hangs-while-LD-is-offline.patch.
- commit 4400510
* Thu Feb  8 2018 hare@suse.de
- Refresh
  patches.drivers/ibmvnic-fix-empty-firmware-version-and-errors-cleanu.patch.
- commit b3b1ac0
* Thu Feb  8 2018 hare@suse.de
- blacklist.conf: ignore mac_esp patch (bsc#1077989)
- commit efe494e
* Thu Feb  8 2018 hare@suse.de
- Refresh patches.fixes/st-fix-blk_get_queue-usage.patch.
- commit 5541263
* Thu Feb  8 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-fix-empty-firmware-version-and-errors-cleanu.patch.
- commit b3e021a
* Thu Feb  8 2018 hare@suse.de
- scsi: libfc: fix ELS request handling (bsc#1077989).
- scsi: bfa: integer overflow in debugfs (bsc#1077989).
- scsi: aacraid: Fix controller initialization failure
  (bsc#1077989).
- scsi: scsi-mq: Always unprepare before requeuing a request
  (bsc#1077989).
- scsi: zfcp: add handling for FCP_RESID_OVER to the fcp ingress
  path (bsc#1077989).
- scsi: sun_esp: fix device reference leaks (bsc#1077989).
- commit e90d3ec
* Thu Feb  8 2018 neilb@suse.com
- Refresh
  patches.fixes/0003-NFSv4-always-set-NFS_LOCK_LOST-when-a-lock-is-lost.patch.
  Add git-commit tag
- commit 1ef434c
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: add proper locking for CMMA migration bitmap
  (bsc#1077761).
- commit 9a8fac9
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: wire up bpb feature (bsc#1077761).
- commit d14cb22
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S: Provide information about hardware/firmware
  CVE workarounds (bsc#1077761).
- commit 1e687f0
* Thu Feb  8 2018 agraf@suse.de
- KVM/x86: Fix wrong macro references of X86_CR0_PG_BIT and
  X86_CR4_PAE_BIT in kvm_valid_sregs() (bsc#1077761).
- commit 0863a2e
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm64: Fix GICv4 init when called from vgic_its_create
  (bsc#1077761).
- commit 54f74da
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Check pagesize when allocating a hugepage at
  Stage 2 (bsc#1077761).
- commit db3eec9
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Add memory barrier on vmcs field lookup (bsc#1077761).
- commit 973bff3
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: emulate #UD while in guest mode (bsc#1077761).
- commit 9b6aa90
* Thu Feb  8 2018 agraf@suse.de
- x86: kvm: propagate register_shrinker return code (bsc#1077761).
- commit 39dc997
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S PR: Fix WIMG handling under pHyp (bsc#1077761).
- commit d5a5c70
* Thu Feb  8 2018 agraf@suse.de
- KVM MMU: check pending exception before injecting APF
  (bsc#1077761).
- commit dbd1b43
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: prevent buffer overrun on memory hotplug during
  migration (bsc#1077761).
- commit ce5730c
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: fix cmma migration for multiple memory slots
  (bsc#1077761).
- commit 7f0eaab
* Thu Feb  8 2018 agraf@suse.de
- kvm: vmx: Scrub hardware GPRs at VM-exit (bsc#1077761).
- commit 3ae582d
* Thu Feb  8 2018 agraf@suse.de
- kvm: x86: fix RSM when PCID is non-zero (bsc#1077761).
- commit b9c326f
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix timer enable flow (bsc#1077761).
- commit e5afd2e
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Properly handle arch-timer IRQs after
  vtimer_save_state (bsc#1077761).
- commit c3b0312
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: timer: Don't set irq as forwarded if no usable
  GIC (bsc#1077761).
- commit f3c1476
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix HYP unmapping going off limits
  (bsc#1077761).
- commit d158077
* Thu Feb  8 2018 agraf@suse.de
- arm64: kvm: Prevent restoring stale PMSCR_EL1 for vcpu
  (bsc#1077761).
- commit 4363ba1
* Thu Feb  8 2018 agraf@suse.de
- KVM/x86: Check input paging mode when cs.l is set (bsc#1077761).
- commit ccf0181
* Thu Feb  8 2018 agraf@suse.de
- kvm: x86: fix WARN due to uninitialized guest FPU state
  (bsc#1077761).
- commit 35f63bf
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Fix load RFLAGS w/o the fixed bit (bsc#1077761).
- commit 6700cda
* Thu Feb  8 2018 agraf@suse.de
- KVM: MMU: Fix infinite loop when there is no available mmu page
  (bsc#1077761).
- commit 13275e4
* Thu Feb  8 2018 agraf@suse.de
- arm64: Add software workaround for Falkor erratum 1041
  (bsc#1077761).
- commit e4dbbd7
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: fix APIC page invalidation (bsc#1077761).
- commit 4c9f820
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: Fix skey emulation permission check (bsc#1077761).
- commit 2763160
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: mark irq_state.flags as non-usable (bsc#1077761).
- commit d864d9d
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: Remove redundant license text (bsc#1077761).
- commit ed05681
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: add SPDX identifiers to the remaining files
  (bsc#1077761).
- commit 592f87d
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: fix page leak in hardware_setup() (bsc#1077761).
- commit a03952e
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: remove I/O port 0x80 bypass on Intel hosts
  (bsc#1077761).
- commit 2c4af04
* Thu Feb  8 2018 agraf@suse.de
- x86,kvm: remove KVM emulator get_fpu / put_fpu (bsc#1077761).
- commit abbfb8e
* Thu Feb  8 2018 agraf@suse.de
- x86,kvm: move qemu/guest FPU switching out to vcpu_run
  (bsc#1077761).
- commit 473f3e5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix broken GICH_ELRSR big endian conversion
  (bsc#1077761).
- commit 36535a5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: kvm_arch_destroy_vm cleanups (bsc#1077761).
- commit 3ac49a7
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix spinlock acquisition in vgic_set_owner
  (bsc#1077761).
- commit 0be83be
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm: don't treat unavailable HYP mode as an error
  (bsc#1077761).
- commit a44e98a
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Avoid attempting to load timer vgic state
  without a vgic (bsc#1077761).
- commit d6f7f9c
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-step of hyp emulated mmio instructions
  (bsc#1077761).
- commit 3b2c220
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-step during SError exceptions
  (bsc#1077761).
- commit b1b7578
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-step of userspace mmio instructions
  (bsc#1077761).
- commit fd1574f
* Thu Feb  8 2018 agraf@suse.de
- kvm: arm64: handle single-stepping trapped instructions
  (bsc#1077761).
- commit a578072
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: debug: Introduce helper for single-step
  (bsc#1077761).
- commit eedd8be
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-v4: Only perform an unmap for valid vLPIs
  (bsc#1077761).
- commit df09a13
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Check result of allocation before use
  (bsc#1077761).
- commit 62a3243
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Preserve the revious read from the
  pending table (bsc#1077761).
- commit 0f4fbdc
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic: Preserve the revious read from the
  pending table (bsc#1077761).
- commit 4aa2aa4
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-irqfd: Fix MSI entry allocation
  (bsc#1077761).
- commit 901d4a5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: VGIC: extend !vgic_is_initialized guard
  (bsc#1077761).
- commit 0b58110
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Don't enable/disable physical timer access on
  VHE (bsc#1077761).
- commit 3a8bf70
* Thu Feb  8 2018 agraf@suse.de
- KVM: Let KVM_SET_SIGNAL_MASK work as advertised (bsc#1077761).
- commit c9e7305
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Fix vmx->nested freeing when no SMI handler
  (bsc#1077761).
- commit fc76735
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Fix rflags cache during vCPU reset (bsc#1077761).
- commit 0fa5b65
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Fix softlockup when get the current kvmclock
  (bsc#1077761).
- commit ae72d3e
* Thu Feb  8 2018 agraf@suse.de
- KVM: lapic: Fixup LDR on load in x2apic (bsc#1077761).
- commit 6dfe4f7
* Thu Feb  8 2018 agraf@suse.de
- KVM: lapic: Split out x2apic ldr calculation (bsc#1077761).
- commit fbbbd35
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Fix CPUID function for word 6 (80000001_ECX)
  (bsc#1077761).
- commit 77b9fea
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Fix vmx_check_nested_events() return value in case
  an event was reinjected to L2 (bsc#1077761).
- commit 8723e44
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Preserve read-only values in the redirection
  table (bsc#1077761).
- commit 5afc781
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Clear Remote IRR when entry is switched to
  edge-triggered (bsc#1077761).
- commit 42ed301
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Remove redundant check for Remote IRR in
  ioapic_set_irq (bsc#1077761).
- commit e540bbf
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Don't fire level irq when Remote IRR set
  (bsc#1077761).
- commit 76995b3
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: ioapic: Fix level-triggered EOI and IOAPIC reconfigure
  race (bsc#1077761).
- commit 3f52b3a
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: inject exceptions produced by x86_decode_insn
  (bsc#1077761).
- commit 529f2d4
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Allow suppressing prints on RDMSR/WRMSR of unhandled
  MSRs (bsc#1077761).
- commit de7dd6f
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: fix em_fxstor() sleeping while in atomic
  (bsc#1077761).
- commit 7dbd3d6
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Fix mmu context after VMLAUNCH/VMRESUME failure
  (bsc#1077761).
- commit 0ae6cb9
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Validate the IA32_BNDCFGS on nested VM-entry
  (bsc#1077761).
- commit 2fbfa04
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Fix operand/address-size during instruction decoding
  (bsc#1077761).
- commit d6d9f45
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Don't re-execute instruction when not passing CR2
  value (bsc#1077761).
- commit e06fcac
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: emulator: Return to user-mode on L1 CPL=0 emulation
  failure (bsc#1077761).
- commit 25a36b8
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: Exit to user-mode on #UD intercept when emulator
  requires (bsc#1077761).
- commit 7d63739
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX/nSVM: Don't intercept #UD when running L2
  (bsc#1077761).
- commit 2d12ec9
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: pvclock: Handle first-time write to pvclock-page
  contains random junk (bsc#1077761).
- commit a009110
* Thu Feb  8 2018 agraf@suse.de
- kvm: vmx: Allow disabling virtual NMI support (bsc#1077761).
- Refresh
  patches.arch/18-x86-mm-kvm-teach-kvm-s-vmx-code-that-cr3-isn-t-a-constant.patch.
- Refresh
  patches.arch/18.2-kvm-nvmx-fix-host_cr3-host_cr4-cache.patch.
- commit e88d160
* Thu Feb  8 2018 agraf@suse.de
- kvm: vmx: Reinstate support for CPUs without virtual NMI
  (bsc#1077761).
- Refresh
  patches.arch/18-x86-mm-kvm-teach-kvm-s-vmx-code-that-cr3-isn-t-a-constant.patch.
- Refresh
  patches.arch/18.2-kvm-nvmx-fix-host_cr3-host_cr4-cache.patch.
- commit aab882b
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: obey guest PAT (bsc#1077761).
- commit e2a37d5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Don't queue VLPIs on INV/INVALL (bsc#1077761).
- commit 06b20fe
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Fix GICv4 ITS initialization issues
  (bsc#1077761).
- commit 3a973bd
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Theory of operations (bsc#1077761).
- commit 6853074
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Enable VLPI support (bsc#1077761).
- commit b1aeb7c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Prevent userspace from changing doorbell
  affinity (bsc#1077761).
- commit ff6fe51
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Prevent a VM using GICv4 from being saved
  (bsc#1077761).
- commit 72575b0
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Enable virtual cpuif if VLPIs can be
  delivered (bsc#1077761).
- commit 36a8d5b
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Hook vPE scheduling into vgic flush/sync
  (bsc#1077761).
- commit aef44e6
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Use the doorbell interrupt as an
  unblocking source (bsc#1077761).
- commit 2e2478b
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Add doorbell interrupt handling
  (bsc#1077761).
- commit 4a7ec1c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Use pending_last as a scheduling hint
  (bsc#1077761).
- commit ea6aa7c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle INVALL applied to a vPE
  (bsc#1077761).
- commit 81503da
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Propagate property updates to VLPIs
  (bsc#1077761).
- commit e61dccd
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle MOVALL applied to a vPE
  (bsc#1077761).
- commit 87310a5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle CLEAR applied to a VLPI
  (bsc#1077761).
- commit 4d71627
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Propagate affinity changes to the
  physical ITS (bsc#1077761).
- commit bed266d
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Unmap VLPI when freeing an LPI
  (bsc#1077761).
- commit 54f9ab4
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Handle INT command applied to a VLPI
  (bsc#1077761).
- commit dd48bea
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Wire mapping/unmapping of VLPIs in VFIO
  irq bypass (bsc#1077761).
- commit 0df7b76
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Add init/teardown of the per-VM vPE
  irq domain (bsc#1077761).
- commit f3fa7a9
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: GICv4: Add property field and per-VM predicate
  (bsc#1077761).
- commit b3cf419
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vITS: Add a helper to update the affinity of
  an LPI (bsc#1077761).
- commit 67e2fb3
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vITS: Add MSI translation helpers (bsc#1077761).
- commit 2cfbfd2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic: Move kvm_vgic_destroy call around
  (bsc#1077761).
- commit c72e631
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm: Select ARM_GIC_V3 and ARM_GIC_V3_ITS (bsc#1077761).
- commit 60f0eba
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic: restructure kvm_vgic_(un)map_phys_irq
  (bsc#1077761).
- commit 17738e1
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: register irq bypass consumer on ARM/ARM64
  (bsc#1077761).
- commit eef5148
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: provide a capability for AIS state migration
  (bsc#1077761).
- commit a45393d
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: clear_io_irq() requests are not expected for adapter
  interrupts (bsc#1077761).
- commit c161531
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: abstract conversion between isc and enum irq_types
  (bsc#1077761).
- commit 51df92d
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: vsie: use common code functions for pinning
  (bsc#1077761).
- commit 307cbae
* Thu Feb  8 2018 agraf@suse.de
- KVM: s390: document memory ordering for kvm_s390_vcpu_wakeup
  (bsc#1077761).
- commit ebccffe
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Cosmetic post-merge cleanups (bsc#1077761).
- commit 59839b5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Unify 32bit fault injection (bsc#1077761).
- commit 37ff111
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Implement KVM_DEV_ARM_ITS_CTRL_RESET
  (bsc#1077761).
- commit 24e7c77
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Free caches when GITS_BASER Valid
  bit is cleared (bsc#1077761).
- commit 00d0a4f
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: New helper functions to free the
  caches (bsc#1077761).
- commit ef1d37c
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Remove kvm_its_unmap_device
  (bsc#1077761).
- commit 5660535
* Thu Feb  8 2018 agraf@suse.de
- arm/arm64: KVM: Load the timer state when enabling the timer
  (bsc#1077761).
- commit fee14c5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Rework kvm_timer_should_fire (bsc#1077761).
- commit 3f72f82
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Get rid of kvm_timer_flush_hwstate
  (bsc#1077761).
- commit 979f853
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Avoid phys timer emulation in vcpu entry/exit
  (bsc#1077761).
- commit 02b2fcf
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Move phys_timer_emulate function (bsc#1077761).
- commit f3f29b2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Use kvm_arm_timer_set/get_reg for guest register
  traps (bsc#1077761).
- commit 8796db5
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Support EL1 phys timer register access in
  set/get reg (bsc#1077761).
- commit 254a94f
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Avoid timer save/restore in vcpu entry/exit
  (bsc#1077761).
- commit 73ba9e1
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Set VCPU affinity for virt timer irq
  (bsc#1077761).
- commit 9327afa
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Move timer save/restore out of the hyp code
  (bsc#1077761).
- commit 61110ab
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Use separate timer for phys timer emulation
  (bsc#1077761).
- commit f6a35de
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Move timer/vgic flush/sync under disabled irq
  (bsc#1077761).
- commit dc41fde
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Rename soft timer to bg_timer (bsc#1077761).
- commit 9264d9d
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Make timer_arm and timer_disarm helpers more
  generic (bsc#1077761).
- commit 2b2c5a2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Support calling vgic_update_irq_pending from
  irq context (bsc#1077761).
- commit 18a1bd2
* Thu Feb  8 2018 agraf@suse.de
- KVM: arm/arm64: Guard kvm_vgic_map_is_active against
  !vgic_initialized (bsc#1077761).
- commit ba7e655
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Run HPT guests on POWER9 radix hosts
  (bsc#1077761).
- commit 13d7989
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Allow for running POWER9 host in
  single-threaded mode (bsc#1077761).
- commit 04bf875
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S: Fix gas warning due to using r0 as immediate 0
  (bsc#1077761).
- commit 375f419
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S PR: Only install valid SLBs during
  KVM_SET_SREGS (bsc#1077761).
- commit 767b8b7
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S PR: Enable in-kernel TCE handlers for PR KVM
  (bsc#1077761).
- commit 60c4ea7
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Delete an error message for a failed
  memory allocation in kvmppc_allocate_hpt() (bsc#1077761).
- commit 8ad1a63
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: BookE: Use vma_pages function (bsc#1077761).
- commit d6571ba
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Use ARRAY_SIZE macro (bsc#1077761).
- commit 5cbbfdd
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Handle unexpected interrupts better
  (bsc#1077761).
- commit 636eaa8
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: #GP when guest attempts to write MCi_STATUS register
  w/o 0 (bsc#1077761).
- commit 7d66248
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Fix VPID capability detection (bsc#1077761).
- commit d2fac0a
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: Fix EPT switching advertising (bsc#1077761).
- commit f7d3e41
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: detect opening of SMI window using STGI intercept
  (bsc#1077761).
- commit b1d58d1
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: extend usage of RET_MMIO_PF_* constants (bsc#1077761).
- commit f9e03bb
* Thu Feb  8 2018 agraf@suse.de
- KVM: nSVM: fix SMI injection in guest mode (bsc#1077761).
- commit 906e480
* Thu Feb  8 2018 agraf@suse.de
- KVM: nSVM: refactor nested_svm_vmrun (bsc#1077761).
- commit f20f8d1
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: fix SMI injection in guest mode (bsc#1077761).
- commit 864bea5
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: set IDTR and GDTR limits when loading L1 host state
  (bsc#1077761).
- commit 9755543
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: introduce ISA specific smi_allowed callback
  (bsc#1077761).
- commit d5dea7a
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: introduce ISA specific SMM entry/exit callbacks
  (bsc#1077761).
- commit 504d250
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: limit kvm_handle_page_fault to #PF handling
  (bsc#1077761).
- commit 078dc47
* Thu Feb  8 2018 agraf@suse.de
- KVM: SVM: unconditionally wake up VCPU on IOMMU interrupt
  (bsc#1077761).
- commit af2e0bd
* Thu Feb  8 2018 agraf@suse.de
- arch/x86: remove redundant null checks before kmem_cache_destroy
  (bsc#1077761).
- commit 790a8df
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Don't expose unrestricted_guest is enabled if ept
  is disabled (bsc#1077761).
- commit 7b71997
* Thu Feb  8 2018 agraf@suse.de
- KVM: X86: Processor States following Reset or INIT
  (bsc#1077761).
- commit 6a51165
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: thoroughly disarm LAPIC timer around TSC deadline
  switch (bsc#1077761).
- commit eca3693
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: really disarm lapic timer when clearing TMICT
  (bsc#1077761).
- commit 9623514
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: handle 0 write to TSC_DEADLINE MSR (bsc#1077761).
- commit 0be4ae2
* Thu Feb  8 2018 agraf@suse.de
- kvm, mm: account kvm related kmem slabs to kmemcg (bsc#1077761).
- commit a513a0a
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: rename RDSEED and RDRAND vmx ctrls to reflect exiting
  (bsc#1077761).
- commit 8efad65
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: allow setting identity map addr with no vcpus only
  (bsc#1077761).
- commit 87d5593
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: cleanup init_rmode_identity_map() (bsc#1077761).
- commit 4829c2a
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: no need to set ept/vpid caps to 0 (bsc#1077761).
- commit 5bfbc6a
* Thu Feb  8 2018 agraf@suse.de
- KVM: nVMX: no need to set vcpu->cpu when switching vmcs
  (bsc#1077761).
- commit 32ffbc8
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: drop unnecessary function declarations (bsc#1077761).
- commit 724a966
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: require INVEPT GLOBAL for EPT (bsc#1077761).
- commit a44c9d8
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: call ept_sync_global() with enable_ept only
  (bsc#1077761).
- commit 7c47e21
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: drop enable_ept check from ept_sync_context()
  (bsc#1077761).
- commit fbddd95
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: no need to inititalize vcpu members to 0
  (bsc#1077761).
- commit 9d148ad
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: vmx_vcpu_setup() cannot fail (bsc#1077761).
- commit a5cab9a
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: drop BUG_ON(vcpu->kvm) (bsc#1077761).
- commit 6eb942e
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: mmu: free_page can handle NULL (bsc#1077761).
- commit 3f89823
* Thu Feb  8 2018 agraf@suse.de
- KVM: x86: mmu: returning void in a void function is strange
  (bsc#1077761).
- commit 6efd205
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Apply change to TDCR right away to the timer
  (bsc#1077761).
- commit 666609a
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Keep timer running when switching between one-shot
  and periodic mode (bsc#1077761).
- commit 55c6d5a
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Introduce limit_periodic_timer_frequency
  (bsc#1077761).
- commit 7c581b3
* Thu Feb  8 2018 agraf@suse.de
- KVM: LAPIC: Fix lapic timer mode transition (bsc#1077761).
- commit b52714f
* Thu Feb  8 2018 agraf@suse.de
- KVM: VMX: Don't expose PLE enable if there is no hardware
  support (bsc#1077761).
- commit 6186087
* Thu Feb  8 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Handle host system reset in guest mode
  (bsc#1077761).
- commit 1118068
* Thu Feb  8 2018 agraf@suse.de
- Revert "KVM: PPC: Book3S HV: POWER9 does not require secondary
  thread management" (bsc#1077761).
- commit a334af4
* Thu Feb  8 2018 agraf@suse.de
- arm64/sve: KVM: Hide SVE from CPU features exposed to guests
  (bsc#1077761).
- commit de772e4
* Thu Feb  8 2018 agraf@suse.de
- arm64/sve: KVM: Treat guest SVE use as undefined instruction
  execution (bsc#1077761).
- commit 5fb9a5a
* Thu Feb  8 2018 agraf@suse.de
- arm64: KVM: Hide unsupported AArch64 CPU features from guests
  (bsc#1077761).
- commit 8bbe83e
* Thu Feb  8 2018 agraf@suse.de
- arm64: sysreg: Move SPE registers and PSB into common header
  files (bsc#1077761).
- commit c7d961a
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3-its: Add post-mortem info on command timeout
  (bsc#1077761).
- commit b376906
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Add workaround for Synquacer pre-ITS
  (bsc#1077761).
- commit 1ff37f4
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic: Make quirks matching conditional on init return
  value (bsc#1077761).
- commit 9f48672
* Thu Feb  8 2018 agraf@suse.de
- irqchip/gic-v3: Probe device ID space before quirks handling
  (bsc#1077761).
- commit 61afdc5
* Wed Feb  7 2018 mgorman@suse.de
- Refresh
  patches.suse/sched-fair-Do-not-migrate-if-the-prev_cpu-is-idle.patch.
- Refresh
  patches.suse/sched-fair-Remove-unnecessary-parameters-from-wake_affine_idle.patch.
- Refresh
  patches.suse/sched-fair-Restructure-wake_affine-to-return-a-CPU-id.patch.
- Refresh
  patches.suse/sched-fair-Use-a-recently-used-CPU-as-an-idle-candidate-and-the-basis-for-SIS.patch.
- commit 6bb11d2
* Wed Feb  7 2018 rgoldwyn@suse.com
- apparmor: fix possible recursive lock warning in  __aa_create_ns
  (bsc#1079834).
- apparmor: fix ptrace label match when matching stacked labels
  (bsc#1079851).
- apparmor: fix regression in mount mediation when feature  set
  is pinned (bsc#1079828).
- Update
  patches.apparmor/apparmor-fix-oops-in-audit_signal_cb-hook.patch
  (bsc#1070227).
- commit d71c37d
* Wed Feb  7 2018 tbogendoerfer@suse.de
- IB/hfi1: Remove blind constants from 16B update (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove dependence on qp->s_hdrwords (bsc#1060463
  FATE#323043).
- IB/hfi1: Add RQ/SRQ information to QP stats (bsc#1060463
  FATE#323043).
- commit 5e5aecf
* Wed Feb  7 2018 tbogendoerfer@suse.de
- RDMA/cma: Check existence of netdevice during port validation
  (bsc#1046306 FATE#322942).
- RDMA/cma: Introduce API to read GIDs for multiple transports
  (bsc#1046306 FATE#322942).
- RDMA/cma: Fix rdma_cm path querying for RoCE (bsc#1046306
  FATE#322942).
- RDMA/cma: Fix rdma_cm raw IB path setting for RoCE (bsc#1046306
  FATE#322942).
- RDMA/{cma, ucma}: Simplify and rename rdma_set_ib_paths
  (bsc#1046306 FATE#322942).
- RDMA/cma: Provide a function to set RoCE path record L2
  parameters (bsc#1046306 FATE#322942).
- RDMA/cma: Use the right net namespace for the rdma_cm_id
  (bsc#1046306 FATE#322942).
- RDMA/cma: Introduce and use helper functions to init work
  (bsc#1046306 FATE#322942).
- RDMA/cma: Avoid setting path record type twice (bsc#1046306
  FATE#322942).
- RDMA/cma: Simplify netdev check (bsc#1046306 FATE#322942).
- RDMA/cma: Set default GID type as RoCE when resolving RoCE route
  (bsc#1046306 FATE#322942).
- commit 82aa918
* Wed Feb  7 2018 agraf@suse.de
- s390/ctl_reg: move control register definitions to ctl_reg.h
  (bsc#1077761).
- commit 0ecc113
* Wed Feb  7 2018 agraf@suse.de
- s390/runtime_instrumentation: clean up struct runtime_instr_cb
  (bsc#1077761).
- commit 51c2ad5
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Check GITS_BASER Valid bit before
  saving tables (bsc#1077761).
- commit c657664
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Check CBASER/BASER validity before
  enabling the ITS (bsc#1077761).
- commit 3e240a3
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Fix vgic_its_restore_collection_table
  returned value (bsc#1077761).
- commit f6dcef1
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic-its: Fix return value for device table
  restore (bsc#1077761).
- commit e5ec1bc
* Wed Feb  7 2018 agraf@suse.de
- arm/arm64: kvm: Disable branch profiling in HYP code
  (bsc#1077761).
- commit bea11c5
* Wed Feb  7 2018 agraf@suse.de
- arm/arm64: kvm: Move initialization completion message
  (bsc#1077761).
- commit 32dee34
* Wed Feb  7 2018 agraf@suse.de
- arm/arm64: KVM: set right LR register value for 32 bit guest
  when inject abort (bsc#1077761).
- commit 1f9a389
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm64: its: Fix missing dynamic allocation check in
  scan_its_table (bsc#1077761).
- commit b1a2351
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: install ksym-provides tool (bsc#1077692).
- commit 679f5c5
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Update APICv on APIC reset (bsc#1077761).
- commit 81a4412
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: Do not fully reset PI descriptor on vCPU reset
  (bsc#1077761).
- commit 780175d
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: fix guest CR4 loading when emulating L2 to L1 exit
  (bsc#1077761).
- commit 6272cb9
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: always terminate page walks at level 1 (bsc#1077761).
- commit 012351b
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: update last_nonleaf_level when initializing nested
  EPT (bsc#1077761).
- commit fba7c5e
* Wed Feb  7 2018 agraf@suse.de
- KVM: add X86_LOCAL_APIC dependency (bsc#1077761).
- commit b0c57c5
* Wed Feb  7 2018 agraf@suse.de
- kvm/x86: Avoid async PF preempting the kernel incorrectly
  (bsc#1077761).
- commit 33e3762
* Wed Feb  7 2018 agraf@suse.de
- kvm/x86: Handle async PF in RCU read-side critical sections
  (bsc#1077761).
- commit d538f32
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix nested #PF intends to break L1's vmlauch/vmresume
  (bsc#1077761).
- commit e5c273a
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: use cmpxchg64 (bsc#1077761).
- commit ccea3eb
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: simplify and fix vmx_vcpu_pi_load (bsc#1077761).
- commit 9131f7c
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: avoid double list add with VT-d posted interrupts
  (bsc#1077761).
- commit efab819
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: extract __pi_post_block (bsc#1077761).
- commit 6de20b1
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Check for updated HDSISR on P9 HDSI
  exception (bsc#1077761).
- commit 1bf0fea
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Fix the NULL pointer parameter in check_cr_write()
  (bsc#1077761).
- commit ac5bf85
* Wed Feb  7 2018 agraf@suse.de
- Revert "KVM: Don't accept obviously wrong gsi values via
  KVM_IRQFD" (bsc#1077761).
- commit 7ff728f
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Handle deferred early VMLAUNCH/VMRESUME failure
  properly (bsc#1077761).
- commit 3210b1f
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Handle VMLAUNCH/VMRESUME failure properly
  (bsc#1077761).
- commit 23509b2
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Remove nested_vmx_succeed after successful VM-entry
  (bsc#1077761).
- commit 8fb1583
* Wed Feb  7 2018 agraf@suse.de
- KVM: Don't accept obviously wrong gsi values via KVM_IRQFD
  (bsc#1077761).
- commit 9441090
* Wed Feb  7 2018 msuchanek@suse.de
- rpm/kernel-binary.spec.in: require bison for build.
  linux-next tends to have outdated generated files so it needs bison to
  regenerate them.
- commit 4ad1ede
* Wed Feb  7 2018 agraf@suse.de
- KVM: trace events: update list of exit reasons (bsc#1077761).
- commit ebca120
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Don't block vCPU if there is pending exception
  (bsc#1077761).
- commit c6a59bd
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: fix clang build (bsc#1077761).
- commit bde54e4
* Wed Feb  7 2018 agraf@suse.de
- KVM: fix rcu warning on VM_CREATE errors (bsc#1077761).
- commit 8b38d86
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Fix handling of pending signal on uninitialized AP
  (bsc#1077761).
- commit f17cb3c
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Protect updates to spapr_tce_tables list
  (bsc#1077761).
- commit 4fb91d2
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Fix invalid use of register expression
  (bsc#1077761).
- commit 3d56d7a
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Fix H_REGISTER_VPA VPA size validation
  (bsc#1077761).
- commit dd5bcf7
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Fix setting of storage key in H_ENTER
  (bsc#1077761).
- commit 41b5422
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: e500mc: Fix a NULL dereference (bsc#1077761).
- commit ece8d3c
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: e500: Fix some NULL dereferences on error
  (bsc#1077761).
- commit b7887fb
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Support uaccess of GICC_APRn (bsc#1077761).
- commit 9a096e3
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Extract GICv3 max APRn index calculation
  (bsc#1077761).
- commit ebeb5d5
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vITS: Drop its_ite->lpi field (bsc#1077761).
- commit 5cf62bb
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic: constify seq_operations and
  file_operations (bsc#1077761).
- commit dafbaeb
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Fix guest external abort matching (bsc#1077761).
- commit 403db45
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: vsie: cleanup mcck reinjection (bsc#1077761).
- commit a25bb09
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: use WARN_ON_ONCE only for checking (bsc#1077761).
- commit 10b882b
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: guestdbg: fix range check (bsc#1077761).
- commit e525cc4
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: we are always in czam mode (bsc#1077761).
- commit 2e46f1e
* Wed Feb  7 2018 msuchanek@suse.de
- Add ksym-provides tool (bsc#1077692).
- commit ee8ebe0
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: sthyi: remove invalid guest write access
  (bsc#1077761).
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- commit 0a9d7cd
* Wed Feb  7 2018 tbogendoerfer@suse.de
- mlx5: fix mlx5_get_vector_affinity to start from completion
  vector 0 (bsc#1046303 FATE#322944).
- IB/core: Avoid a potential OOPs for an unused optional parameter
  (bsc#1046306 FATE#322942).
- IB/core: Map iWarp AH type to undefined in rdma_ah_find_type
  (bsc#1046306 FATE#322942).
- IB/hfi1: Fix for potential refcount leak in hfi1_open_file()
  (bsc#1060463 FATE#323043).
- RDMA/bnxt_re: Fix an error code in bnxt_qplib_create_srq()
  (bsc#1050244 FATE#322915).
- net_sched: gen_estimator: fix lockdep splat (bsc#1056787).
- i40e: fix reported mask for ntuple filters (bsc#1056658
  FATE#322188).
- igb: Free IRQs when device is hotplugged (bsc#1056651
  FATE#322191).
- net/mlx5: Separate ingress/egress namespaces for each vport
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix ingress/egress naming mistake (bsc#1046303
  FATE#322944).
- net/mlx5e: E-Switch, Use the name of static array instead of
  its address (bsc#1046303 FATE#322944).
- net/mlx4_en: Change default QoS settings (bsc#1046299
  FATE#322947).
- net/mlx4_core: Cleanup FMR unmapping flow (bsc#1046300
  FATE#322946).
- RDMA/mlx5: Avoid memory leak in case of XRCD dealloc failure
  (bsc#1046305 FATE#322943).
- IB/umad: Fix use of unprotected device pointer (bsc#1046306
  FATE#322942).
- i40iw: Free IEQ resources (bsc#1058659 FATE#322535).
- i40iw: Remove limit on re-posting AEQ entries to HW (bsc#1058659
  FATE#322535).
- RDMA/core: Clarify rdma_ah_find_type (bsc#1046306 FATE#322942).
- IB/mlx4: Fix incorrectly releasing steerable UD QPs when have
  only ETH ports (bsc#1046302 FATE#322945).
- IB/srpt: Remove an unused structure member (bsc#1046306
  FATE#322942).
- IB/core: Fix two kernel warnings triggered by rxe registration
  (bsc#1046306 FATE#322942).
- i40iw: Fix the connection ORD value for loopback (bsc#1058659
  FATE#322535).
- i40iw: Validate correct IRD/ORD connection parameters
  (bsc#1058659 FATE#322535).
- i40iw: Fix sequence number for the first partial FPDU
  (bsc#1058659 FATE#322535).
- i40iw: Selectively teardown QPs on IP addr change event
  (bsc#1058659 FATE#322535).
- i40iw: Correct Q1/XF object count equation (bsc#1058659
  FATE#322535).
- IB/SA: Check dlid before SA agent queries for ClassPortInfo
  (bsc#1046306 FATE#322942).
- IB/umem: Fix use of npages/nmap fields (bsc#1046306
  FATE#322942).
- RDMA/cma: Use correct size when writing netlink stats
  (bsc#1046306 FATE#322942).
- RDMA/iwpm: Fix uninitialized error code in iwpm_send_mapinfo()
  (bsc#1046306 FATE#322942).
- IB/mlx5: revisit -Wmaybe-uninitialized warning (bsc#1046305
  FATE#322943).
- commit 5f2318b
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: Multiple Epoch Facility support (bsc#1077761).
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- commit 69d2bea
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Validate the virtual-APIC address on nested VM-entry
  (bsc#1077761).
- commit 02cdfc0
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix trying to cancel vmlauch/vmresume (bsc#1077761).
- commit d7cc599
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Fix loss of exception which has not yet been injected
  (bsc#1077761).
- commit 0c65010
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: use kvm_event_needs_reinjection (bsc#1077761).
- commit c9110ef
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: speedup update_permission_bitmask (bsc#1077761).
- commit 6c779fb
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Expose the LA57 feature to VM (bsc#1077761).
- commit 6626022
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Add 5 level EPT & Shadow page table support
  (bsc#1077761).
- commit 02cce94
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Rename PT64_ROOT_LEVEL to PT64_ROOT_4LEVEL
  (bsc#1077761).
- commit 5957c99
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: check guest CR3 reserved bits based on its physical
  address width (bsc#1077761).
- commit 74530a7
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Add return value to kvm_cpuid() (bsc#1077761).
- commit 2260172
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Raise #UD on unsupported XSAVES/XRSTORS (bsc#1077761).
- commit 1ca81c7
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Raise #UD on unsupported RDSEED (bsc#1077761).
- commit 416b7c0
* Wed Feb  7 2018 agraf@suse.de
- kvm: vmx: Raise #UD on unsupported RDRAND (bsc#1077761).
- commit d990f93
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: cache secondary exec controls (bsc#1077761).
- commit aee234d
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: always require WB memory type for EPT (bsc#1077761).
- commit 004c65c
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: cleanup EPTP definitions (bsc#1077761).
- commit a0416af
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: fix use of L1 MMIO areas in nested guests
  (bsc#1077761).
- commit 5c78d98
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Avoid guest page table walk when gpa_available is set
  (bsc#1077761).
- commit 9101925
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: simplify ept_misconfig (bsc#1077761).
- commit c81e473
* Wed Feb  7 2018 agraf@suse.de
- kvm: avoid uninitialized-variable warnings (bsc#1077761).
- commit 138f617
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: Disallow illegal IA32_APIC_BASE MSR values
  (bsc#1077761).
- commit 41bb0d9
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Bail out immediately if there is no available mmu page
  (bsc#1077761).
- commit a95ac0e
* Wed Feb  7 2018 agraf@suse.de
- KVM: MMU: Fix softlockup due to mmu_lock is held too long
  (bsc#1077761).
- commit 2e9e45e
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: validate eptp pointer (bsc#1077761).
- commit b202868
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: Add support for fast unprotection of nested guest
  page tables (bsc#1077761).
- commit dbe7eff
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Fix residual mmio emulation request to userspace
  (bsc#1077761).
- commit ba3cd5b
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm: implements the kvm_arch_vcpu_in_kernel()
  (bsc#1077761).
- commit bc61a6f
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: implements the kvm_arch_vcpu_in_kernel()
  (bsc#1077761).
- commit ccf0426
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: implement the logic for spinlock optimization
  (bsc#1077761).
- commit cd89a32
* Wed Feb  7 2018 agraf@suse.de
- KVM: add spinlock optimization framework (bsc#1077761).
- commit 9be0d73
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: use general helpers for some cpuid manipulation
  (bsc#1077761).
- commit 7c96559
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: generalize guest_cpuid_has_ helpers (bsc#1077761).
- commit 6253831
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: X86_FEATURE_NRIPS is not scattered anymore
  (bsc#1077761).
- commit 8fc76c4
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Emulate EPTP switching for the L1 hypervisor
  (bsc#1077761).
- commit 41af192
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Enable VMFUNC for the L1 hypervisor (bsc#1077761).
- commit 03e08c3
* Wed Feb  7 2018 agraf@suse.de
- KVM: vmx: Enable VMFUNCs (bsc#1077761).
- commit febad7f
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: get rid of nested_release_page* (bsc#1077761).
- commit 8dfa692
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: get rid of nested_get_page() (bsc#1077761).
- commit 18480de
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: INVPCID support (bsc#1077761).
- commit c42b719
* Wed Feb  7 2018 agraf@suse.de
- KVM: hyperv: support HV_X64_MSR_TSC_FREQUENCY and
  HV_X64_MSR_APIC_FREQUENCY (bsc#1077761).
- commit 3211c0a
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S HV: POWER9 does not require secondary thread
  management (bsc#1077761).
- commit c66a49a
* Wed Feb  7 2018 agraf@suse.de
- powerpc/mm: Update definitions of DSISR bits (bsc#1077761).
- commit 67bca61
* Wed Feb  7 2018 agraf@suse.de
- arm64: Remove the !CONFIG_ARM64_HW_AFDBM alternative code paths
  (bsc#1077761).
- commit 6e5f833
* Wed Feb  7 2018 agraf@suse.de
- kvm/x86: Avoid clearing the C-bit in rsvd_bits() (bsc#1077761).
- commit 420d917
* Wed Feb  7 2018 agraf@suse.de
- KVM: update to new mmu_notifier semantic v2 (bsc#1077761).
- commit 20cbd84
* Wed Feb  7 2018 agraf@suse.de
- KVM: PPC: Book3S: Fix race and leak in
  kvm_vm_ioctl_create_spapr_tce() (bsc#1077761).
- commit 7e876d5
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: vgic: Use READ_ONCE fo cmpxchg (bsc#1077761).
- commit 0963889
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: PMU: Fix overflow interrupt injection
  (bsc#1077761).
- commit 0e13c71
* Wed Feb  7 2018 agraf@suse.de
- KVM: arm/arm64: Fix bug in advertising KVM_CAP_MSI_DEVID
  capability (bsc#1077761).
- commit f588e1d
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix interrupt window request with "Acknowledge
  interrupt on exit" (bsc#1077761).
- commit 96a9aa1
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: mark vmcs12 pages dirty on L2 exit (bsc#1077761).
- commit d690017
* Wed Feb  7 2018 agraf@suse.de
- kvm: nVMX: don't flush VMCS12 during VMXOFF or VCPU teardown
  (bsc#1077761).
- commit 7f92ce5
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: do not pin the VMCS12 (bsc#1077761).
- commit 9c1a723
* Wed Feb  7 2018 agraf@suse.de
- KVM: avoid using rcu_dereference_protected (bsc#1077761).
- commit d8f2f42
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: init irq->level in kvm_pv_kick_cpu_op (bsc#1077761).
- commit daa60bc
* Wed Feb  7 2018 agraf@suse.de
- KVM: X86: Fix loss of pending INIT due to race (bsc#1077761).
- commit 0c6ceeb
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: fixes to nested virt interrupt injection
  (bsc#1077761).
- commit a1131d2
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: do not fill vm_exit_intr_error_code in prepare_vmcs12
  (bsc#1077761).
- commit 483e7f3
* Wed Feb  7 2018 agraf@suse.de
- KVM: LAPIC: Fix reentrancy issues with preempt notifiers
  (bsc#1077761).
- commit 1f7a6ad
* Wed Feb  7 2018 agraf@suse.de
- KVM: s390: take srcu lock when getting/setting storage keys
  (bsc#1077761).
- commit 4f1fa14
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix loss of L2's NMI blocking state (bsc#1077761).
- commit b30d4e0
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Fix posted intr delivery when vcpu is in guest mode
  (bsc#1077761).
- Refresh
  patches.arch/0002-kvm-vmx-remove-warn_on_once-in-kvm_vcpu_trigger_posted_interrupt.
- commit 1d74271
* Wed Feb  7 2018 agraf@suse.de
- x86: irq: Define a global vector for nested posted interrupts
  (bsc#1077761).
- commit 1a7d98c
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: do mask out upper bits of PAE CR3 (bsc#1077761).
- commit 2851b3a
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: remove unused field (bsc#1077761).
- commit c2fa409
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: hyperv: avoid livelock in oneshot SynIC timers
  (bsc#1077761).
- commit e399bf8
* Wed Feb  7 2018 agraf@suse.de
- KVM: VMX: Fix invalid guest state detection after task-switch
  emulation (bsc#1077761).
- commit 2f44a61
* Wed Feb  7 2018 agraf@suse.de
- x86: add MULTIUSER dependency for KVM (bsc#1077761).
- commit 12a5533
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: Disallow VM-entry in MOV-SS shadow (bsc#1077761).
- commit 77d8ab1
* Wed Feb  7 2018 agraf@suse.de
- KVM: nVMX: track NMI blocking state separately for each VMCS
  (bsc#1077761).
- Refresh
  patches.arch/18.2-kvm-nvmx-fix-host_cr3-host_cr4-cache.patch.
- commit 080adef
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: masking out upper bits (bsc#1077761).
- commit 78f98d2
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: hyperv: make VP_INDEX managed by userspace
  (bsc#1077761).
- commit b7577ef
* Wed Feb  7 2018 agraf@suse.de
- KVM: async_pf: Let guest support delivery of async_pf from
  guest mode (bsc#1077761).
- Refresh
  patches.arch/0003-kvm-async_pf-fix-df-due-to-inject-page-not-present-and-page-ready-exceptions-simultaneously.
- commit 421024f
* Wed Feb  7 2018 agraf@suse.de
- KVM: async_pf: Force a nested vmexit if the injected #PF is
  async_pf (bsc#1077761).
  Refresh
  patches.arch/0003-kvm-async_pf-fix-df-due-to-inject-page-not-present-and-page-ready-exceptions-simultaneously.
- commit 0c8c65c
* Wed Feb  7 2018 agraf@suse.de
- KVM: async_pf: Add L1 guest async_pf #PF vmexit handler
  (bsc#1077761).
- commit 05fcb6b
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: Simplify kvm_x86_ops->queue_exception parameter list
  (bsc#1077761).
- commit b0fb424
* Wed Feb  7 2018 agraf@suse.de
- kvm: x86: hyperv: add KVM_CAP_HYPERV_SYNIC2 (bsc#1077761).
- commit 56fe2cc
* Wed Feb  7 2018 agraf@suse.de
- KVM: x86: make backwards_tsc_observed a per-VM variable
  (bsc#1077761).
- commit c612bf5
* Wed Feb  7 2018 agraf@suse.de
- KVM: SVM: handle singlestep exception when skipping emulated
  instructions (bsc#1077761).
- Refresh patches.arch/0007-kvm-svm-enable-virtual-gif-feature.
- Refresh
  patches.arch/kvm-svm-delete-avic_vm_id_bitmap-2-megabyte-static-array.
- commit 77f3e25
* Wed Feb  7 2018 msuchanek@suse.de
- blacklist acb1feab320e powerpc/64: Don't trace irqs-off at interrupt
  return to soft-disabled context
- commit ef64ee1
* Wed Feb  7 2018 jslaby@suse.cz
- Refresh
  patches.suse/0002-futex-futex_wake_op-fix-sign_extend32-sign-bits.patch.
  Update upstream status.
- commit a44be7b
* Wed Feb  7 2018 jslaby@suse.cz
- x86/dumpstack: Avoid uninitlized variable (git-fixes).
- commit 7668118
* Wed Feb  7 2018 tbogendoerfer@suse.de
- net/mlx5e: IPoIB, Use correct timestamp in child receive flow
  (bsc#1075020).
- net/mlx5: Update ptp_clock_event foreach PPS event
  (bsc#1075020).
- IB/ipoib: Fix lockdep issue found on ipoib_ib_dev_heavy_flush
  (bsc#1075020).
- commit 6acdbe8
* Wed Feb  7 2018 tbogendoerfer@suse.de
- net/mlx5e: IPoIB, Modify rdma netdev allocate and free to
  support PKEY (bsc#1075020).
- net/mlx5e: IPoIB, Add PKEY child interface ethtool ops
  (bsc#1075020).
- net/mlx5e: IPoIB, Add PKEY child interface ndos (bsc#1075020).
- net/mlx5e: IPoIB, Add PKEY child interface nic profile
  (bsc#1075020).
- net/mlx5e: IPoIB, Use hash-table to map between QPN to child
  netdev (bsc#1075020).
- net/mlx5e: IPoIB, Support for setting PKEY index to underlay QP
  (bsc#1075020).
- IB/ipoib: Add ability to set PKEY index to lower device driver
  (bsc#1075020).
- IB/ipoib: Grab rtnl lock on heavy flush when calling
  ndo_open/stop (bsc#1075020).
- net/mlx5: Support for attaching multiple underlay QPs to root
  flow table (bsc#1075020).
- net/mlx5e: IPoIB, Move underlay QP init/uninit to separate
  functions (bsc#1075020).
- net/mlx5: PTP code migration to driver core section
  (bsc#1075020).
  Refresh
  patches.drivers/Revert-mlx5-move-affinity-hints-assignments-to-gener.patch.
- net/mlx5: File renaming towards ptp core implementation
  (bsc#1075020).
- commit e473354
* Wed Feb  7 2018 agraf@suse.de
- Move KVM patches to sorted section
  Refresh
  patches.arch/0001-kvm-nVMX-Don-t-allow-L2-to-access-the-hardware-CR8.patch.
- commit 5d643b3
* Wed Feb  7 2018 jthumshirn@suse.de
- s390/zcrypt: externalize AP queue interrupt control
  (FATE#324118, LTC#158322).
- s390/zcrypt: externalize AP config info query (FATE#324118,
  LTC#158322).
- s390/zcrypt: externalize test AP queue (FATE#324118,
  LTC#158322).
- commit 0c2b243
* Tue Feb  6 2018 msuchanek@suse.de
- rfi-flush: Switch to new linear fallback flush (bsc#1068032).
  Refresh patches.arch/powerpc-xmon-Add-RFI-flush-related-fields-to-paca-du.patch.
- commit 0b9f66c
* Tue Feb  6 2018 msuchanek@suse.de
- powerpc/radix: Remove trace_tlbie call from radix__flush_tlb_all
  (bsc#1055117, fate#323286, git-fixes).
- commit e6674e9
* Tue Feb  6 2018 tbogendoerfer@suse.de
- iw_cxgb4: Change error/warn prints to pr_debug (bsc#1079355).
- iser-target: avoid reinitializing rdma contexts for isert
  commands (bsc#1079355).
- iw_cxgb4: Only validate the MSN for successful completions
  (bsc#1079355).
- commit f364c92
* Tue Feb  6 2018 tbogendoerfer@suse.de
- cxgb4: add geneve offload support for T6 (bsc#1074220).
- cxgb4: implement ndo_features_check (bsc#1074220).
- cxgb4: add support for vxlan segmentation offload (bsc#1074220).
- cxgb4: implement udp tunnel callbacks (bsc#1074220).
- cxgb4: add data structures to support vxlan (bsc#1074220).
- IB/qib: Fix comparison error with qperf compare/swap test
  (bsc#1027067 FATE#322649).
- commit a50f30f
* Tue Feb  6 2018 mgorman@suse.de
- cpufreq: intel_pstate: Add Skylake servers support (bnc#1068680
  Update schedutil and intel_pstate to default to load-based
  policy).
- cpufreq: intel_pstate: Replace bxt_funcs with core_funcs
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- commit 5047ebd
* Tue Feb  6 2018 mgorman@suse.de
- Refresh
  patches.suse/mm-numa-do-not-trap-faults-on-shared-data-section-pages.patch.
- commit 8c37e01
* Tue Feb  6 2018 msuchanek@suse.de
- ibmvnic: fix empty firmware version and errors cleanup
  (bsc#1079038).
- commit 0b2f959
* Tue Feb  6 2018 msuchanek@suse.de
- Refresh sorted section.
- Refresh patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- commit f04d16a
* Tue Feb  6 2018 pmladek@suse.com
- printk: Never set console_may_schedule in console_trylock()
  (bnc#744692, bnc#789311, bsc#1078391).
- commit d2af2e6
* Tue Feb  6 2018 pmladek@suse.com
- printk: Hide console waiter logic into helpers (bnc#744692,
  bnc#789311, bsc#1078391).
- commit 9d02b3e
* Tue Feb  6 2018 pmladek@suse.com
- printk: Add console owner and waiter logic to load balance
  console writes (bnc#744692, bnc#789311, bsc#1078391).
- commit 5d9e509
* Tue Feb  6 2018 pmladek@suse.com
- Remove the SUSE-specific print-softlockup fix (bnc#744692, bnc#789311)
  It is going to be replaced by the upstream solution using console waiter
  logic.
- Delete
  patches.suse/printk-Switch-to-the-sync-mode-when-an-emergency-mes.patch.
- Delete patches.suse/printk-default-to-async-printing.patch.
- Delete patches.suse/printk-fix-suspend-hang.patch.
- Delete patches.suse/printk-make-async.patch.
- Delete patches.suse/printk-make-kthread-priority-normal.patch.
- Delete patches.suse/printk-make-synchronous-param-rw.patch.
- Delete patches.suse/printk-make-wakeup-klogd-async-fixup.patch.
- Delete patches.suse/printk-make-wakeup-klogd-async.patch.
- Delete
  patches.suse/printk-xen-Force-printk-sync-mode-when-migrating-Xen.patch.
- commit 3ed9739
* Tue Feb  6 2018 tbogendoerfer@suse.de
- cxgb4: add new T5 and T6 device id's (bsc#1079352).
- scsi: libcxgbi: use GFP_ATOMIC in cxgbi_conn_alloc_pdu()
  (bsc#1079355).
- commit e0eecbf
* Tue Feb  6 2018 msuchanek@suse.de
- powerpc/pseries: Add Initialization of VF Bars (FATE#324970,
  bsc#1078720).
- powerpc/pseries/pci: Associate PEs to VFs in configure SR-IOV
  (FATE#324970, bsc#1078720).
- powerpc/eeh: Add EEH notify resume sysfs (FATE#324970,
  bsc#1078720).
- powerpc/eeh: Add EEH operations to notify resume (FATE#324970,
  bsc#1078720).
- powerpc/pseries: Set eeh_pe of EEH_PE_VF type (FATE#324970,
  bsc#1078720).
- PCI/AER: Add uevents in AER and EEH error/resume (FATE#324970,
  bsc#1078720).
- powerpc/eeh: Update VF config space after EEH (FATE#324970,
  bsc#1078720).
- PCI/IOV: Add pci_vf_drivers_autoprobe() interface (FATE#324970,
  bsc#1078720).
- powerpc/pseries: Add pseries SR-IOV Machine dependent calls
  (FATE#324970, bsc#1078720).
- powerpc/pci: Separate SR-IOV Calls (FATE#324970, bsc#1078720).
- PCI: Remove reset argument from pci_iov_{add,remove}_virtfn()
  (FATE#324970, bsc#1078720).
- commit 57512c6
* Tue Feb  6 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvme-don-t-free-uuid-pointer-before-printing-it.patch.
- Refresh
  patches.drivers/nvme-fabrics-fix-memory-leak-when-parsing-host-ID-op.patch.
- Refresh
  patches.drivers/nvme-fabrics-protect-against-module-unload-during-cr.patch.
- Refresh
  patches.drivers/nvme-fix-comment-typos-in-nvme_create_io_queues.patch.
- Refresh
  patches.drivers/nvme-fix-subsystem-multiple-controllers-support-chec.patch.
- Refresh
  patches.drivers/nvme-host-delete_work-and-reset_work-on-separate-wor.patch.
- Refresh
  patches.drivers/nvme-modify-the-debug-level-for-setting-shutdown-tim.patch.
- Refresh
  patches.drivers/nvme-pci-Fix-queue-double-allocations.patch.
- Refresh
  patches.drivers/nvme-pci-Suspend-queues-after-deleting-them.patch.
- Refresh
  patches.drivers/nvme-pci-allocate-device-queues-storage-space-at-pro.patch.
- Refresh
  patches.drivers/nvme-pci-clean-up-CMB-initialization.patch.
- Refresh
  patches.drivers/nvme-pci-clean-up-SMBSZ-bit-definitions.patch.
- Refresh
  patches.drivers/nvme-pci-don-t-open-code-nvme_reset_ctrl.patch.
- Refresh
  patches.drivers/nvme-pci-fix-NULL-pointer-reference-in-nvme_alloc_ns.patch.
- Refresh
  patches.drivers/nvme-pci-introduce-RECONNECTING-state-to-mark-initia.patch.
- Refresh
  patches.drivers/nvme-pci-remove-an-unnecessary-initialization-in-HMB.patch.
- Refresh patches.drivers/nvme-pci-serialize-pci-resets.patch.
- Refresh
  patches.drivers/nvme-rdma-remove-redundant-boolean-for-inline_data.patch.
- Refresh
  patches.drivers/nvme-take-refcount-on-transport-module.patch.
- Refresh
  patches.drivers/nvme_fcloop-disassocate-local-port-structs.patch.
- Refresh
  patches.drivers/nvme_fcloop-fix-abort-race-condition.patch.
- Refresh
  patches.drivers/nvme_fcloop-refactor-host-target-io-job-access.patch.
- Refresh
  patches.drivers/nvme_fcloop-rework-to-remove-xxx_IN_ISR-feature-flag.patch.
- Refresh
  patches.drivers/nvmet-fix-error-flow-in-nvmet_alloc_ctrl.patch.
- Refresh
  patches.drivers/nvmet-lower-log-level-for-each-queue-creation.patch.
- Refresh
  patches.drivers/nvmet-rdma-lowering-log-level-for-chatty-debug-messa.patch.
- Refresh
  patches.drivers/nvmet-rdma-removed-queue-cleanup-from-module-exit.patch.
- Refresh patches.drivers/nvmet-rearrange-nvmet_ctrl_free.patch.
- Refresh
  patches.drivers/nvmet-release-a-ns-reference-in-nvmet_req_uninit-if-.patch.
- nvme-fc: correct hang in nvme_ns_remove() (bsc#1075811).
- nvme-fc: fix rogue admin cmds stalling teardown (bsc#1075811).
- commit dc349bb
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-pci: introduce RECONNECTING state to mark initializing
  procedure (FATE#323952, FATE#322506).
- nvme-rdma: remove redundant boolean for inline_data
  (FATE#323952, FATE#322506).
- nvme: don't free uuid pointer before printing it (FATE#323952,
  FATE#322506).
- nvme-pci: Suspend queues after deleting them (FATE#323952,
  FATE#322506).
- nvme-pci: Fix queue double allocations (FATE#323952,
  FATE#322506).
- nvme-pci: clean up SMBSZ bit definitions (FATE#323952,
  FATE#322506).
- nvme-pci: clean up CMB initialization (FATE#323952,
  FATE#322506).
- nvmet: release a ns reference in nvmet_req_uninit if needed
  (FATE#323952, FATE#322506).
- nvme-fabrics: fix memory leak when parsing host ID option
  (FATE#323952, FATE#322506).
- nvme: fix comment typos in nvme_create_io_queues (FATE#323952,
  FATE#322506).
- nvme: host delete_work and reset_work on separate workqueues
  (FATE#323952, FATE#322506).
- nvme-pci: allocate device queues storage space at probe
  (FATE#323952, FATE#322506).
- nvme-pci: serialize pci resets (FATE#323952, FATE#322506).
- nvme: fix subsystem multiple controllers support check
  (FATE#323952, FATE#322506).
- nvme: take refcount on transport module (FATE#323952,
  FATE#322506).
- nvme-pci: fix NULL pointer reference in nvme_alloc_ns
  (FATE#323952, FATE#322506).
- nvme: modify the debug level for setting shutdown timeout
  (FATE#323952, FATE#322506).
- nvme-pci: don't open-code nvme_reset_ctrl (FATE#323952,
  FATE#322506).
- nvmet: rearrange nvmet_ctrl_free() (FATE#323952, FATE#322506).
- nvmet: fix error flow in nvmet_alloc_ctrl() (FATE#323952,
  FATE#322506).
- nvme-pci: remove an unnecessary initialization in HMB code
  (FATE#323952, FATE#322506).
- nvme-fabrics: protect against module unload during create_ctrl
  (FATE#323952, FATE#322506).
- nvme_fcloop: refactor host/target io job access (FATE#323952,
  FATE#322506).
- nvme_fcloop: rework to remove xxx_IN_ISR feature flags
  (FATE#323952, FATE#322506).
- nvme_fcloop: disassocate local port structs (FATE#323952,
  FATE#322506).
- nvme_fcloop: fix abort race condition (FATE#323952,
  FATE#322506).
- nvmet: lower log level for each queue creation (FATE#323952,
  FATE#322506).
- nvmet-rdma: lowering log level for chatty debug messages
  (FATE#323952, FATE#322506).
- nvmet-rdma: removed queue cleanup from module exit (FATE#323952,
  FATE#322506).
- commit be5f8ed
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-pci: check segement valid for SGL use (FATE#323952,
  FATE#322506).
- nvme-pci: move use_sgl initialization to nvme_init_iod()
  (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/nvme-pci-take-sglist-coalescing-in-dma_map_sg-into-a.patch.
- commit ccc76c3
* Tue Feb  6 2018 msuchanek@suse.de
- powerpc/pseries: Fix cpu hotplug crash with memoryless nodes
  (FATE#323746, bsc#1079524).
- powerpc/numa: Ensure nodes initialized for hotplug (FATE#323746,
  bsc#1079524).
- powerpc/numa: Use ibm,max-associativity-domains to discover
  possible nodes (FATE#323746, bsc#1079524).
- commit a5a5351
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-fabrics: initialize default host->id in nvmf_host_default()
  (FATE#323952, FATE#322506).
- nvme-fcloop: avoid possible uninitialized variable warning
  (FATE#323952, FATE#322506).
- nvme-rdma: fix concurrent reset and reconnect (FATE#323952,
  FATE#322506).
- nvme: fix sector units when going between formats (FATE#323952,
  FATE#322506).
- nvme: setup streams after initializing namespace head
  (FATE#323952, FATE#322506).
- nvme: check hw sectors before setting chunk sectors
  (FATE#323952, FATE#322506).
- nvme: call blk_integrity_unregister after queue is cleaned up
  (FATE#323952, FATE#322506).
- nvme: set discard_alignment to zero (FATE#323952, FATE#322506).
- nvme-pci: fix NULL pointer dereference in nvme_free_host_mem()
  (FATE#323952, FATE#322506).
- nvme-rdma: fix memory leak during queue allocation (FATE#323952,
  FATE#322506).
- commit 4cd5e8f
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme: Suppress static analyis warning (FATE#323952,
  FATE#322506).
- Refresh
  patches.drivers/nvme-mpath-fix-last-path-removal-during-traffic.patch.
- commit 8ff7b73
* Tue Feb  6 2018 jthumshirn@suse.de
- nvme-rdma: Use mr pool (FATE#323952, FATE#322506).
- nvme-rdma: Check remotely invalidated rkey matches our expected
  rkey (FATE#323952, FATE#322506).
- nvme-rdma: wait for local invalidation before completing a
  request (FATE#323952, FATE#322506).
- nvme-rdma: don't complete requests before a send work request
  has completed (FATE#323952, FATE#322506).
- nvme-rdma: don't suppress send completions (FATE#323952,
  FATE#322506).
- nvme-pci: add quirk for delay before CHK RDY for WDC SN200
  (FATE#323952, FATE#322506).
- nvme: fix spelling mistake: "requeing" -> "requeuing"
  (FATE#323952, FATE#322506).
- nvme-pci: avoid hmb desc array idx out-of-bound when hmmaxd set
  (FATE#323952, FATE#322506).
- nvme-pci: disable APST on Samsung SSD 960 EVO + ASUS PRIME
  B350M-A (FATE#323952, FATE#322506).
- commit 98c37e8
* Tue Feb  6 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
  Re-sort series.conf
- commit ff52d23
* Tue Feb  6 2018 bpoirier@suse.com
- Refresh patch order in sorted section
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- scripts/git_sort/git_sort.py:
- scripts/git_sort/tests/test_git_sort.py:
- commit afdc520
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: Remove immediate feature (bsc#1071995 fate#323487).
  From upstream klp tree, branch for-4.16/remove-immediate.
- commit b4083e7
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: add locking to force and signal functions
  (bsc#1071995 fate#323487).
  Coming from upstream klp tree, branch for-4.16/signal-sysfs-force-v2.
- commit a2bfaf3
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: force transition to finish (bsc#1071995 fate#323487).
  Coming from upstream klp tree, branch for-4.16/signal-sysfs-force-v2.
- commit 15e3f65
* Mon Feb  5 2018 mbenes@suse.cz
- livepatch: send a fake signal to all blocking tasks (bsc#1071995
  fate#323487).
  Fake signal support. Coming from upstream klp tree, branch
  for-4.16/signal-sysfs-force-v2.
- commit c16c12d
* Mon Feb  5 2018 tbogendoerfer@suse.de
- iser-target: Fix possible use-after-free in connection
  establishment error (bsc#1046306 FATE#322942).
- net/mlx5e: Check support before TC swap in ETS init (bsc#1046303
  FATE#322944).
- net/mlx5e: Add error print in ETS init (bsc#1046303
  FATE#322944).
- IB/core: Fix unable to change lifespan entry for hw_counters
  (bsc#1046306 FATE#322942).
- commit 14a58fe
* Mon Feb  5 2018 tbogendoerfer@suse.de
- Re-sorted with series_sort
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- commit 6db6f83
* Mon Feb  5 2018 oneukum@suse.com
- usbip: fix stub_rx: harden CMD_SUBMIT path to handle malicious
  input (bsc#1078672 CVE-2017-16913).
- commit 317c5b6
* Mon Feb  5 2018 oneukum@suse.com
- ahci: Add Intel Cannon Lake PCH-H PCI ID (bsc#1079088
  FATE#321195 FATE#322631).
- commit 1ad2ccd
* Mon Feb  5 2018 bp@suse.de
- x86/cpufeatures: Add Intel feature bits for Speculation Control
  (bsc#1068032 CVE-2017-5754).
- commit f45d5d3
* Mon Feb  5 2018 oneukum@suse.com
- Refresh
  patches.drivers/ibmvnic-Wait-for-device-response-when-changing-MAC.patch.
- Refresh
  patches.drivers/ibmvnic-fix-firmware-version-when-no-firmware-level-.patch.
- Refresh patches.drivers/scsi-cxlflash-Reset-command-ioasc.patch.
- Refresh
  patches.fixes/ipvlan-remove-excessive-packet-scrubbing.patch.
- commit 41ae0d8
* Mon Feb  5 2018 bp@suse.de
- x86/cpufeatures: Add CPUID_7_EDX CPUID leaf (bsc#1068032
  CVE-2017-5754).
- commit 914add9
* Mon Feb  5 2018 bp@suse.de
- x86/bugs: Drop one "mitigation" from dmesg (bsc#1068032
  CVE-2017-5754).
- commit 53d0557
* Mon Feb  5 2018 bp@suse.de
- blacklist.conf:
- commit f67c619
* Mon Feb  5 2018 tbogendoerfer@suse.de
- enic: add wq clean up budget (bsc#1075697).
- commit 245a193
* Mon Feb  5 2018 ghe@suse.com
- ocfs2: try a blocking lock before return AOP_TRUNCATED_PAGE
  (bsc#1073440).
- commit 26c40f8
* Mon Feb  5 2018 neilb@suse.com
- NFS: Add a cond_resched() to nfs_commit_release_pages()
  (bsc#1077779).
- commit 012a157
* Sun Feb  4 2018 neilb@suse.com
- nfsd: auth: Fix gid sorting when rootsquash enabled
  (CVE-2018-1000028, bsc#1078287).
- commit dda492e
* Fri Feb  2 2018 lduncan@suse.com
- rbd: set max_segments to USHRT_MAX (bsc#1078861).
- rbd: reacquire lock should update lock owner client id
  (bsc#1078873).
- netfilter: uapi: correct UNTRACKED conntrack state bit number
  (bsc#1078865).
- scsi: libiscsi: fix shifting of DID_REQUEUE host byte
  (bsc#1078875).
- commit 9a95b4e
* Fri Feb  2 2018 lduncan@suse.com
- ASN.1: fix out-of-bounds read when parsing indefinite length
  item (bsc#1078868).
- ASN.1: check for error from ASN1_OP_END__ACT actions
  (bsc#1078867).
- KEYS: fix NULL pointer dereference during ASN.1 parsing
  (bsc#1078866).
- KEYS: fix out-of-bounds read during ASN.1 parsing (bsc#1078862).
- commit 49124a8
* Fri Feb  2 2018 lduncan@suse.com
- lib/digsig: fix dereference of NULL user_key_payload
  (bsc#1078860).
- commit e74597f
* Fri Feb  2 2018 msuchanek@suse.de
- Update config files.
- commit 9008ce2
* Fri Feb  2 2018 jkosina@suse.cz
- README.BRANCH: make Jeff co-maintainer during my absence
- commit a8ed74e
* Fri Feb  2 2018 bp@suse.de
- x86/retpoline: Remove the esp/rsp thunk (bsc#1068032
  CVE-2017-5754).
- x86/intel_rdt/cqm: Prevent use after free (fate#323965).
- commit e562833
* Fri Feb  2 2018 msuchanek@suse.de
- ibmvnic: fix firmware version when no firmware level has been
  provided by the VIOS server (bsc#1079038).
- commit 3aa382e
* Fri Feb  2 2018 ohering@suse.de
- x86/hyper-v: stop suppressing X86_FEATURE_PCID (bsc#1077499).
- commit d007750
* Thu Feb  1 2018 msuchanek@suse.de
- ibmvnic: Wait for device response when changing MAC
  (bsc#1078681).
- commit 4a4b78c
* Thu Feb  1 2018 msuchanek@suse.de
- blacklist 070e004912fe powerpc/4xx: Fix compile error with 64K pages on 40x, 44x
- commit cafc1fc
* Thu Feb  1 2018 msuchanek@suse.de
- scsi: cxlflash: Reset command ioasc (fate#322239, git-fixes).
- commit 930f93e
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: take slots_lock in kvm_free_pit (bsc#1077761).
- commit 5c47320
* Thu Feb  1 2018 agraf@suse.de
- kvm: vmx: Properly handle machine check during VM-entry
  (bsc#1077761).
- commit 630935e
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: update master clock before computing kvmclock_offset
  (bsc#1077761).
- commit 5546449
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Shadow "high" parts of shadowed 64-bit VMCS fields
  (bsc#1077761).
- commit 9c9cd12
* Thu Feb  1 2018 agraf@suse.de
- Move patches.fixes/kvm-nvmx-fix-nested_vmx_check_msr_bitmap_controls into sorted section
- commit 597672f
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Validate the I/O bitmaps on nested VM-entry
  (bsc#1077761).
- commit ae097f9
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Don't set vmcs12 to "launched" when VMLAUNCH fails
  (bsc#1077761).
- commit fb500c7
* Thu Feb  1 2018 agraf@suse.de
- KVM: use correct accessor function for __kvm_memslots
  (bsc#1077761).
- commit e6f2939
* Thu Feb  1 2018 agraf@suse.de
- KVM: mark memory slots as rcu (bsc#1077761).
- commit a4d1b3d
* Thu Feb  1 2018 agraf@suse.de
- KVM: mark kvm->busses as rcu protected (bsc#1077761).
- commit ba3fd3a
* Thu Feb  1 2018 agraf@suse.de
- KVM: use rcu access function for irq routing (bsc#1077761).
- commit d866df7
* Thu Feb  1 2018 agraf@suse.de
- KVM: mark vcpu->pid pointer as rcu protected (bsc#1077761).
- commit f2e0948
* Thu Feb  1 2018 agraf@suse.de
- KVM: vmx: expose more information for
  KVM_INTERNAL_ERROR_DELIVERY_EV exits (bsc#1077761).
- commit 0622f81
* Thu Feb  1 2018 agraf@suse.de
- kvm: avoid unused variable warning for UP builds (bsc#1077761).
- commit 2e79598
* Thu Feb  1 2018 agraf@suse.de
- x86: kvm: mmu: use ept a/d in vmcs02 iff used in vmcs12
  (bsc#1077761).
- commit b81235c
* Thu Feb  1 2018 agraf@suse.de
- kvm: x86: mmu: allow A/D bits to be disabled in an mmu
  (bsc#1077761).
- commit aa98336
* Thu Feb  1 2018 agraf@suse.de
- x86: kvm: mmu: make spte mmio mask more explicit (bsc#1077761).
- commit 05b622d
* Thu Feb  1 2018 agraf@suse.de
- x86: kvm: mmu: dead code thanks to access tracking
  (bsc#1077761).
- commit 8c29652
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Add capability to report possible virtual
  SMT modes (bsc#1077761).
- commit ff30e98
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Virtualize doorbell facility on POWER9
  (bsc#1077761).
- commit 73e258b
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Allow userspace to set the desired SMT mode
  (bsc#1077761).
- commit ef28960
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Context-switch HFSCR between host and
  guest on POWER9 (bsc#1077761).
- commit f4ba5c4
* Thu Feb  1 2018 agraf@suse.de
- KVM: PPC: Book3S HV: Enable guests to use large decrementer
  mode on POWER9 (bsc#1077761).
- commit 5e26c30
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: remove ignored type attribute (bsc#1077761).
- commit f488813
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Signal SIGBUS when stage2 discovers hwpoison
  memory (bsc#1077761).
- commit 94ecc41
* Thu Feb  1 2018 agraf@suse.de
- arm64/kvm: vgic: use SYS_DESC() (bsc#1077761).
- commit 35d3070
* Thu Feb  1 2018 agraf@suse.de
- arm64/kvm: sysreg: fix typo'd SYS_ICC_IGRPEN*_EL1 (bsc#1077761).
- commit 4396c4d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Log an error if trapping a write-to-read-only
  GICv3 access (bsc#1077761).
- commit f14efa3
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Log an error if trapping a read-from-write-only
  GICv3 access (bsc#1077761).
- commit e878ccd
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Log which GICv3 system registers are
  trapped (bsc#1077761).
- commit c2ec271
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Enable GICv3 common sysreg trapping via command-line
  (bsc#1077761).
- commit 83b2209
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_PMR_EL1 handler (bsc#1077761).
- commit b32111f
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_CTLR_EL1 handler (bsc#1077761).
- commit c6056fb
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_RPR_EL1 handler (bsc#1077761).
- commit 4d8e18a
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_DIR_EL1 handler (bsc#1077761).
- commit dc81a76
* Thu Feb  1 2018 agraf@suse.de
- arm64: Add workaround for Cavium Thunder erratum 30115
  (bsc#1077761).
- Refresh
  patches.drivers/0003-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- Refresh
  patches.drivers/0004-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- commit 672e3a4
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Enable GICv3 Group-0 sysreg trapping via
  command-line (bsc#1077761).
- commit a43257d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Enable trapping of Group-0 system registers
  (bsc#1077761).
- commit 6704cd7
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add misc Group-0 handlers (bsc#1077761).
- commit f366ea5
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_IGNREN0_EL1 handler (bsc#1077761).
- commit 843e1f8
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_BPR0_EL1 handler (bsc#1077761).
- commit 4da31c6
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Enable GICv3 Group-1 sysreg trapping via
  command-line (bsc#1077761).
- commit 11e3aa3
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Enable trapping of Group-1 system registers
  (bsc#1077761).
- commit 98ed82e
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_HPPIR1_EL1 handler (bsc#1077761).
- commit ae8c87c
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_AP1Rn_EL1 handler (bsc#1077761).
- commit 43c6bc4
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_EOIR1_EL1 handler (bsc#1077761).
- commit ceeaa18
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_IAR1_EL1 handler (bsc#1077761).
- commit 12da559
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_IGRPEN1_EL1 handler (bsc#1077761).
- commit e1b4ec3
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add ICV_BPR1_EL1 handler (bsc#1077761).
- commit 559ee43
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: vgic-v3: Add hook to handle guest GICv3 sysreg
  accesses at EL2 (bsc#1077761).
- commit 08361be
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Make kvm_condition_valid32() accessible from EL2
  (bsc#1077761).
- commit accb6b5
* Thu Feb  1 2018 aaptel@suse.com
- CIFS: dump IPC tcon in debug proc file (bsc#1071306).
- commit e844d61
* Thu Feb  1 2018 aaptel@suse.com
- CIFS: use tcon_ipc instead of use_ipc parameter of SMB2_ioctl
  (bsc#1071306).
- commit 31e7d7b
* Thu Feb  1 2018 aaptel@suse.com
- CIFS: make IPC a regular tcon (bsc#1071306).
- commit baba794
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: vgic-v3: Add accessors for the ICH_APxRn_EL2
  registers (bsc#1077761).
- commit e0e50a9
* Thu Feb  1 2018 lhenriques@suse.com
- xfs: reinit btree pointer on attr tree inactivation walk
  (bsc#1078787).
- commit 00accea
* Thu Feb  1 2018 tbogendoerfer@suse.de
- cxgb4: make symbol pedits static (bsc#1064802 bsc#1066129).
- nfp: fix error return code in nfp_pci_probe() (bsc#1055968).
- IB/core: Fix ib_wc structure size to remain in 64 bytes boundary
  (bsc#1046306 FATE#322942).
- net/mlx5: Fix race for multiple RoCE enable (bsc#1046303
  FATE#322944).
- RDMA/cma: Mark end of CMA ID messages (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Add UAR SRQ macros in ABI header file
  (bsc#1046306 FATE#322942).
- iw_cxgb4: make pointer reg_workq static (bsc#1064802
  bsc#1066129).
- net/mlx5e: Fix ETS BW check (bsc#1075360).
- commit 76cecfb
* Thu Feb  1 2018 tbogendoerfer@suse.de
- Re-sorted series and Updated patch-mainline
- Refresh
  patches.drivers/IB-CM-Change-sgid-to-IB-GID-when-handling-CM-request.patch.
- Refresh
  patches.drivers/IB-hfi1-Mask-the-path-bits-with-the-LMC-for-16B-RC-A.patch.
- Refresh
  patches.drivers/IB-hfi1-Use-4096-for-default-active-MTU-in-query_qp.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Add-SRQ-support-for-Broadcom-adapters.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Add-support-for-MRs-with-Huge-pages.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Add-support-for-query-firmware-version.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-Enable-RoCE-on-virtual-functions.patch.
- Refresh
  patches.drivers/RDMA-bnxt_re-expose-detailed-stats-retrieved-from-HW.patch.
- Refresh patches.drivers/bnxt_en-Add-ETH_RESET_AP-support.patch.
- Refresh
  patches.drivers/bnxt_en-Don-t-print-Link-speed-1-no-longer-supported.patch.
- Refresh
  patches.drivers/bnxt_en-Uninitialized-variable-in-bnxt_tc_parse_acti.patch.
- Refresh patches.drivers/bnxt_en-Use-NETIF_F_GRO_HW.patch.
- Refresh patches.drivers/cxgb4-RSS-table-is-4k-for-T6.patch.
- Refresh patches.drivers/cxgb4-collect-HMA-memory-dump.patch.
- Refresh patches.drivers/cxgb4-collect-MC-memory-dump.patch.
- Refresh
  patches.drivers/cxgb4-collect-PCIe-configuration-logs.patch.
- Refresh
  patches.drivers/cxgb4-collect-TX-rate-limit-info-in-UP-CIM-logs.patch.
- Refresh
  patches.drivers/cxgb4-collect-egress-and-ingress-SGE-queue-contexts.patch.
- Refresh
  patches.drivers/cxgb4-collect-on-chip-memory-information.patch.
- Refresh
  patches.drivers/cxgb4-skip-TX-and-RX-payload-regions-in-memory-dumps.patch.
- Refresh
  patches.drivers/ibmvnic-Don-t-handle-RX-interrupts-when-not-up.patch.
- Refresh
  patches.drivers/ibmvnic-Include-header-descriptor-support-for-ARP-pa.patch.
- Refresh
  patches.drivers/ibmvnic-Increase-maximum-number-of-RX-TX-queues.patch.
- Refresh
  patches.drivers/ibmvnic-Rename-IBMVNIC_MAX_TX_QUEUES-to-IBMVNIC_MAX_.patch.
- Refresh
  patches.drivers/lpfc-Adjust-default-value-of-lpfc_nvmet_mrq.patch.
- Refresh
  patches.drivers/lpfc-Beef-up-stat-counters-for-debug.patch.
- Refresh
  patches.drivers/lpfc-Correct-driver-deregistrations-with-host-n.patch.
- Refresh
  patches.drivers/lpfc-Driver-fails-to-detect-direct-attach-stora.patch.
- Refresh
  patches.drivers/lpfc-Expand-WQE-capability-of-every-NVME-hardwa.patch.
- Refresh
  patches.drivers/lpfc-FLOGI-failures-are-reported-when-connected.patch.
- Refresh
  patches.drivers/lpfc-Fix-EOVERFLOW-behavior-for-NVMET-and-defer.patch.
- Refresh patches.drivers/lpfc-Fix-NVME-LS-abort_xri.patch.
- Refresh
  patches.drivers/lpfc-Fix-SCSI-LUN-discovery-when-SCSI-and-NVME-.patch.
- Refresh
  patches.drivers/lpfc-Fix-crash-after-bad-bar-setup-on-driver-at.patch.
- Refresh
  patches.drivers/lpfc-Fix-crash-during-driver-unload-with-runnin.patch.
- Refresh
  patches.drivers/lpfc-Fix-display-for-debugfs-queInfo.patch.
- Refresh
  patches.drivers/lpfc-Fix-driver-handling-of-nvme-resources-duri.patch.
- Refresh
  patches.drivers/lpfc-Fix-infinite-wait-when-driver-unregisters-.patch.
- Refresh
  patches.drivers/lpfc-Fix-issues-connecting-with-nvme-initiator.patch.
- Refresh
  patches.drivers/lpfc-Fix-ndlp-ref-count-for-pt2pt-mode-issue-RS.patch.
- Refresh
  patches.drivers/lpfc-Fix-random-heartbeat-timeouts-during-heavy.patch.
- Refresh patches.drivers/lpfc-Fix-receive-PRLI-handling.patch.
- Refresh
  patches.drivers/lpfc-Handle-XRI_ABORTED_CQE-in-soft-IRQ.patch.
- Refresh
  patches.drivers/lpfc-Increase-SCSI-CQ-and-WQ-sizes.patch.
- Refresh
  patches.drivers/lpfc-Linux-LPFC-driver-does-not-process-all-RSC.patch.
- Refresh
  patches.drivers/lpfc-Raise-maximum-NVME-sg-list-size-for-256-el.patch.
- Refresh
  patches.drivers/lpfc-correct-port-registrations-with-nvme_fc.patch.
- Refresh
  patches.drivers/lpfc-correct-sg_seg_cnt-attribute-min-vs-defaul.patch.
- Refresh
  patches.drivers/lpfc-don-t-dereference-localport-before-it-has-.patch.
- Refresh
  patches.drivers/lpfc-fix-a-couple-of-minor-indentation-issues.patch.
- Refresh patches.drivers/lpfc-small-sg-cnt-cleanup.patch.
- Refresh
  patches.drivers/lpfc-update-driver-version-to-11.4.0.5.patch.
- Refresh
  patches.drivers/lpfc-update-driver-version-to-11.4.0.6.patch.
- Refresh
  patches.drivers/net-Disable-GRO_HW-when-generic-XDP-is-installed-on-.patch.
- Refresh patches.drivers/net-Introduce-NETIF_F_GRO_HW.patch.
- Refresh
  patches.drivers/net-ethtool-add-support-for-reset-of-AP-inside-NIC-i.patch.
- Refresh
  patches.drivers/scsi-libiscsi-allow-sd_shutdown-on-bad-transport.
- Refresh
  patches.drivers/scsi-qla2xxx-Fix-recursion-while-sending-terminate-e.patch.
- commit f6992cb
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Don't assume initialized vgic when setting
  PMU IRQ (bsc#1077761).
- commit e46c7d2
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Disallow userspace control of in-kernel IRQ
  lines (bsc#1077761).
- commit 17a802a
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Check if irq lines to the GIC are already used
  (bsc#1077761).
- commit c6c6bff
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Introduce an allocator for in-kernel irq lines
  (bsc#1077761).
- commit 3904963
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Allow setting the timer IRQ numbers from
  userspace (bsc#1077761).
- commit 46f128d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Move timer IRQ default init to arch_timer.c
  (bsc#1077761).
- commit e809754
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Move irq_is_ppi() to header file (bsc#1077761).
- commit e5a67f0
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm: Handle VCPU device attributes in guest.c
  (bsc#1077761).
- commit 550f6bb
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Allow creating the PMU without the in-kernel GIC
  (bsc#1077761).
- commit ed17f94
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: timer: remove request-less vcpu kick
  (bsc#1077761).
- commit c014526
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: PMU: remove request-less vcpu kick
  (bsc#1077761).
- commit fd61d9a
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: use vcpu requests for irq injection
  (bsc#1077761).
- commit 9f686bf
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: change exit request to sleep request
  (bsc#1077761).
- commit e8990de
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: optimize VCPU RUN (bsc#1077761).
- commit 5d5c02d
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: use vcpu requests for power_off (bsc#1077761).
- commit 3b24c3f
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: replace pause checks with vcpu request checks
  (bsc#1077761).
- commit 1df0a22
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: properly use vcpu requests (bsc#1077761).
- commit c19d6ba
* Thu Feb  1 2018 agraf@suse.de
- KVM: add kvm_request_pending (bsc#1077761).
- commit 7d071ca
* Thu Feb  1 2018 agraf@suse.de
- KVM: improve arch vcpu request defining (bsc#1077761).
- commit fcdd37e
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Use uaccess functions for GICv3 {sc}active
  (bsc#1077761).
- commit a6aa308
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Simplify active_change_prepare and plug race
  (bsc#1077761).
- commit 5f251f5
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Separate guest and uaccess writes to dist
  {sc}active (bsc#1077761).
- commit 06c1e27
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm/arm64: Allow GICv2 to supply a uaccess register
  function (bsc#1077761).
- commit a828f2c
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm64: Restore host physical timer access on hyp_panic()
  (bsc#1077761).
- commit 3c9a486
* Thu Feb  1 2018 agraf@suse.de
- KVM: arm: Restore banked registers and physical timer access
  on hyp_panic() (bsc#1077761).
- commit 81c5b15
* Thu Feb  1 2018 agraf@suse.de
- KVM: LAPIC: Fix lapic timer injection delay (bsc#1077761).
- commit 2887434
* Thu Feb  1 2018 agraf@suse.de
- KVM: lapic: reorganize restart_apic_timer (bsc#1077761).
- commit b3c54e2
* Thu Feb  1 2018 agraf@suse.de
- KVM: lapic: reorganize start_hv_timer (bsc#1077761).
- commit d1ec16e
* Thu Feb  1 2018 agraf@suse.de
- KVM: s390: avoid packed attribute (bsc#1077761).
- Refresh
  patches.drivers/kvm-Inject-machine-check-into-the-nested-guest.patch.
- commit 0fb9b38
* Thu Feb  1 2018 agraf@suse.de
- KVM: S390: add new group for flic (bsc#1077761).
- commit 957f3a8
* Thu Feb  1 2018 agraf@suse.de
- KVM: s390: implement instruction execution protection for
  emulated ifetch (bsc#1077761).
- commit 9f7e596
* Thu Feb  1 2018 agraf@suse.de
- kvm: nVMX: Check memory operand to INVVPID (bsc#1077761).
- commit a142483
* Thu Feb  1 2018 agraf@suse.de
- KVM: explain missing kvm_put_kvm in case of failure
  (bsc#1077761).
- commit f859907
* Thu Feb  1 2018 agraf@suse.de
- KVM: Replaces symbolic permissions with numeric (bsc#1077761).
- commit c981562
* Thu Feb  1 2018 agraf@suse.de
- KVM: nVMX: Don't update vmcs12->xss_exit_bitmap on nested
  VM-exit (bsc#1077761).
- commit 334fe01
* Thu Feb  1 2018 agraf@suse.de
- KVM: x86: avoid large stack allocations in em_fxrstor
  (bsc#1077761).
- commit 2980e35
* Thu Feb  1 2018 agraf@suse.de
- KVM: white space cleanup in nested_vmx_setup_ctls_msrs()
  (bsc#1077761).
- commit 4ba3a7c
* Thu Feb  1 2018 agraf@suse.de
- KVM: Tidy the whitespace in nested_svm_check_permissions()
  (bsc#1077761).
- commit 8351f67
* Thu Feb  1 2018 agraf@suse.de
- s390: rename struct psw_bits members (bsc#1077761).
- commit b1352ea
* Thu Feb  1 2018 agraf@suse.de
- s390: rename psw_bits enums (bsc#1077761).
- commit df2b8ca
* Thu Feb  1 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-pseries-rfi-flush-Call-setup_rfi_flush-after.patch.
  Fix return value
- commit b1d44b2
* Wed Jan 31 2018 jslaby@suse.cz
- ftrace, orc, x86: Handle ftrace dynamically allocated
  trampolines (bnc#1058115).
- objtool: Fix seg fault caused by missing parameter
  (bnc#1058115).
- objtool: Move synced files to their original relative locations
  (bnc#1058115).
- objtool: Fix seg fault with clang-compiled objects
  (bnc#1058115).
- objtool: Move kernel headers/code sync check to a script
  (bnc#1058115).
- tracing: Update stack trace skipping for ORC unwinder
  (bnc#1058115).
- objtool: Fix 64-bit build on 32-bit host (bnc#1058115).
- objtool: Fix Clang enum conversion warning (bnc#1058115).
- objtool: Fix cross-build (bnc#1058115).
- tools/objtool/Makefile: don't assume sync-check.sh is executable
  (bnc#1058115).
- x86/ftrace: Add one more ENDPROC annotation (bnc#1058115).
- x86/ftrace: Fix ORC unwinding from ftrace handlers
  (bnc#1058115).
- x86/stacktrace: Make zombie stack traces reliable (bnc#1058115).
- Refresh
  patches.arch/10-x86-dumpstack-handle-stack-overflow-on-all-stacks.patch.
- Refresh
  patches.arch/11-x86-entry-rename-sysenter_stack-to-cpu_entry_area_entry_stack.patch.
- Refresh
  patches.arch/24-x86-retpoline-ftrace-convert-ftrace-assembler-indirect-jumps.patch.
- Refresh
  patches.suse/0002-x86-stacktrace-make-clear-the-success-paths.patch.
  Update ORC to the upstream status.
- commit 3cd5617
* Wed Jan 31 2018 msuchanek@suse.de
- include/linux/mm.h: fix typo in VM_MPX definition (FATE#322447,
  bsc#1078248).
- commit 981f4b2
* Wed Jan 31 2018 msuchanek@suse.de
- Update config files.
- commit c74eda6
* Wed Jan 31 2018 msuchanek@suse.de
- selftests/powerpc: Add core file test for Protection Key
  register (FATE#322447, bsc#1078248).
- selftests/powerpc: Add ptrace tests for Protection Key register
  (FATE#322447, bsc#1078248).
- selftests/vm: Fix deadlock in protection_keys.c (FATE#322447,
  bsc#1078248).
- selftests/vm: sub-page allocator (FATE#322447, bsc#1078248).
- selftests/vm: testcases must restore pkey-permissions
  (FATE#322447, bsc#1078248).
- selftests/vm: detect write violation on a mapped
  access-denied-key page (FATE#322447, bsc#1078248).
- selftests/vm: associate key on a mapped page and detect write
  violation (FATE#322447, bsc#1078248).
- selftests/vm: associate key on a mapped page and detect access
  violation (FATE#322447, bsc#1078248).
- selftests/vm: fix an assertion in test_pkey_alloc_exhaust()
  (FATE#322447, bsc#1078248).
- selftests/vm: powerpc implementation to check support for pkey
  (FATE#322447, bsc#1078248).
- selftests/vm: clear the bits in shadow reg when a pkey is freed
  (FATE#322447, bsc#1078248).
- selftests/vm: powerpc implementation for generic abstraction
  (FATE#322447, bsc#1078248).
- selftests/vm: generic cleanup (FATE#322447, bsc#1078248).
- selftests/vm: pkey register should match shadow pkey
  (FATE#322447, bsc#1078248).
- selftests/vm: introduce two arch independent abstraction
  (FATE#322447, bsc#1078248).
- selftests/vm: fix alloc_random_pkey() to make it really random
  (FATE#322447, bsc#1078248).
- selftests/vm: clear the bits in shadow reg when a pkey is freed
  (FATE#322447, bsc#1078248).
- selftests/vm: fixed bugs in pkey_disable_clear() (FATE#322447,
  bsc#1078248).
- selftests/vm: fix the wrong assert in pkey_disable_set()
  (FATE#322447, bsc#1078248).
- selftests/vm: generic function to handle shadow key register
  (FATE#322447, bsc#1078248).
- selftests/vm: typecast the pkey register (FATE#322447,
  bsc#1078248).
- selftests/vm: move generic definitions to header file
  (FATE#322447, bsc#1078248).
- selftests/vm: rename all references to pkru to a generic name
  (FATE#322447, bsc#1078248).
- selftests/x86: Move protecton key selftest to arch neutral
  directory (FATE#322447, bsc#1078248).
- x86/pkeys/selftests: Fix protection keys write() warning
  (FATE#322447, bsc#1078248).
- x86/pkeys/selftests: Rename 'si_pkey' to 'siginfo_pkey'
  (FATE#322447, bsc#1078248).
- selftests/x86/protection_keys: Fix syscall NR redefinition
  warnings (FATE#322447, bsc#1078248).
- signal/testing: Don't look for __SI_FAULT in userspace
  (FATE#322447, bsc#1078248).
- Documentation/vm: PowerPC specific updates to memory protection
  keys (FATE#322447, bsc#1078248).
- Documentation/x86: Move protecton key documentation to arch
  neutral directory (FATE#322447, bsc#1078248).
- mm, x86: display pkey in smaps only if arch supports pkeys
  (FATE#322447, bsc#1078248).
- Refresh patches.suse/mm-fix-KSM-data-corruption.patch.
- powerpc: sys_pkey_mprotect() system call (FATE#322447,
  bsc#1078248).
- powerpc: sys_pkey_alloc() and sys_pkey_free() system calls
  (FATE#322447, bsc#1078248).
- powerpc: Enable pkey subsystem (FATE#322447, bsc#1078248).
- powerpc/ptrace: Add memory protection key regset (FATE#322447,
  bsc#1078248).
- powerpc: Deliver SEGV signal on pkey violation (FATE#322447,
  bsc#1078248).
- powerpc: introduce get_mm_addr_key() helper (FATE#322447,
  bsc#1078248).
- powerpc: Handle exceptions caused by pkey violation
  (FATE#322447, bsc#1078248).
- powerpc: implementation for arch_vma_access_permitted()
  (FATE#322447, bsc#1078248).
- powerpc: check key protection for user page access (FATE#322447,
  bsc#1078248).
- powerpc: helper to validate key-access permissions of a pte
  (FATE#322447, bsc#1078248).
- powerpc: Program HPTE key protection bits (FATE#322447,
  bsc#1078248).
- powerpc: map vma key-protection bits to pte key bits
  (FATE#322447, bsc#1078248).
- powerpc: implementation for arch_override_mprotect_pkey()
  (FATE#322447, bsc#1078248).
- powerpc: ability to associate pkey to a vma (FATE#322447,
  bsc#1078248).
- powerpc: introduce execute-only pkey (FATE#322447, bsc#1078248).
- powerpc: store and restore the pkey state across context
  switches (FATE#322447, bsc#1078248).
- powerpc: ability to create execute-disabled pkeys (FATE#322447,
  bsc#1078248).
- powerpc: implementation for arch_set_user_pkey_access()
  (FATE#322447, bsc#1078248).
- powerpc: cleanup AMR, IAMR when a key is allocated or freed
  (FATE#322447, bsc#1078248).
- powerpc: helper functions to initialize AMR, IAMR and UAMOR
  registers (FATE#322447, bsc#1078248).
- powerpc: helper function to read, write AMR, IAMR, UAMOR
  registers (FATE#322447, bsc#1078248).
- powerpc: track allocation status of all pkeys (FATE#322447,
  bsc#1078248).
- powerpc: initial pkey plumbing (FATE#322447, bsc#1078248).
- mm, powerpc, x86: introduce an additional vma bit for powerpc
  pkey (FATE#322447, bsc#1078248).
- mm, powerpc, x86: define VM_PKEY_BITx bits if
  CONFIG_ARCH_HAS_PKEYS is enabled (FATE#322447, bsc#1078248).
- powerpc: capture the PTE format changes in the dump pte report
  (FATE#322447, bsc#1078248).
- powerpc: use helper functions to get and set hash slots
  (FATE#322447, bsc#1078248).
- powerpc: Swizzle around 4K PTE bits to free up bit 5 and bit 6
  (FATE#322447, bsc#1078248).
- powerpc: shifted-by-one hidx value (FATE#322447, bsc#1078248).
- powerpc: Free up four 64K PTE bits in 64K backed HPTE pages
  (FATE#322447, bsc#1078248).
- powerpc: Free up four 64K PTE bits in 4K backed HPTE pages
  (FATE#322447, bsc#1078248).
- powerpc: introduce pte_get_hash_gslot() helper (FATE#322447,
  bsc#1078248).
- powerpc: introduce pte_set_hidx() helper (FATE#322447,
  bsc#1078248).
- powerpc/mm/book3s/64: Add proper pte access check helper
  (FATE#322447, bsc#1078248).
- powerpc/mm: Don't lose "major" fault indication on retry
  (FATE#322447, bsc#1078248).
- powerpc/mm: Set fault flags earlier (FATE#322447, bsc#1078248).
- powerpc/mm: Evaluate user_mode(regs) only once in
  do_page_fault() (FATE#322447, bsc#1078248).
- powerpc/mm: Remove a redundant test in do_page_fault()
  (FATE#322447, bsc#1078248).
- powerpc/mm: Only call store_updates_sp() on stores in
  do_page_fault() (FATE#322447, bsc#1078248).
- powerpc: Fix DABR match on hash based systems (FATE#322447,
  bsc#1078248).
- powerpc/64s: Replace CONFIG_PPC_STD_MMU_64 with
  CONFIG_PPC_BOOK3S_64 (FATE#322447, bsc#1078248).
- powerpc/mm: Update bits used to skip hash_page (FATE#322447,
  bsc#1078248).
- powerpc/mm: Update definitions of DSISR bits (FATE#322447,
  bsc#1078248).
- x86,mpx: make mpx depend on x86-64 to free up VMA flag
  (FATE#322447, bsc#1078248).
- commit 90fbf25
* Wed Jan 31 2018 yousaf.kaukab@suse.com
- arm64: Branch predictor hardening for Cavium ThunderX2
  (bsc#1068032).
- commit c0ea639
* Wed Jan 31 2018 mgorman@suse.de
- Refresh
  patches.fixes/mm-Batch-radix-tree-operations-when-truncating-pages.patch.
- Refresh
  patches.fixes/mm-Factor-out-checks-and-accounting-from-__delete_fr.patch.
- Refresh
  patches.fixes/mm-Factor-out-page-cache-page-freeing-into-a-separat.patch.
- Refresh
  patches.fixes/mm-Move-accounting-updates-before-page_cache_tree_de.patch.
- Refresh
  patches.fixes/mm-Move-clearing-of-page-mapping-to-page_cache_tree_.patch.
- Refresh patches.fixes/mm-Refactor-truncate_complete_page.patch.
- Refresh
  patches.fixes/mm-Speedup-cancel_dirty_page-for-clean-pages.patch.
- Refresh
  patches.suse/sched-Only-immediately-migrate-tasks-due-to-interrupts-if-prev-and-target-CPUs-share-cache.patch.
- Refresh
  patches.suse/sched-wait-fix-add_wait_queue-behavior-change.patch.
- commit c2de752
* Wed Jan 31 2018 jthumshirn@suse.de
- scsi: qla2xxx: Initialize Work element before requesting IRQs
  (bsc#1050313).
- scsi: qla2xxx: Fix uninitialized work element (bsc#1050313).
- commit 20470eb
* Wed Jan 31 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/block-Provide-blk_status_t-decoding-for-path-errors.patch.
- Refresh patches.drivers/dm-mpath-Use-blk_path_error.patch.
- Refresh
  patches.drivers/nvme-Add-more-command-status-translation.patch.
- Refresh
  patches.drivers/nvme-add-tracepoint-for-nvme_complete_rq.patch.
- Refresh
  patches.drivers/nvme-add-tracepoint-for-nvme_setup_cmd.patch.
- Refresh
  patches.drivers/nvme-also-expose-the-namespace-identification-sysfs-.patch.
- Refresh
  patches.drivers/nvme-fix-visibility-of-uuid-ns-attribute.patch.
- Refresh
  patches.drivers/nvme-introduce-a-nvme_ns_ids-structure.patch.
- Refresh
  patches.drivers/nvme-multipath-Consult-blk_status_t-for-failover.patch.
- Refresh patches.drivers/nvme-multipath-Use-blk_path_error.patch.
- Refresh patches.drivers/nvme-track-shared-namespaces.patch.
- Refresh
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
  Re-sort series.conf
- commit 2edda93
* Tue Jan 30 2018 lhenriques@suse.com
- Refresh
  patches.fixes/ceph-drop-negative-child-dentries-before-try-pruning-inode-s-alias.patch.
- commit 66812af
* Tue Jan 30 2018 lhenriques@suse.com
- libceph: don't WARN() if user tries to add invalid key
  (FATE#324714).
- ceph: silence sparse endianness warning in encode_caps_cb
  (FATE#324714).
- ceph: present consistent fsid, regardless of arch endianness
  (FATE#324714).
- ceph: clean up spinlocking and list handling around
  cleanup_cap_releases() (FATE#324714).
- ceph: remove unused and redundant variable dropping
  (FATE#324714).
- ceph: mark expected switch fall-throughs (FATE#324714).
- ceph: -EINVAL on decoding failure in ceph_mdsc_handle_fsmap()
  (FATE#324714).
- ceph: disable cached readdir after dropping positive dentry
  (FATE#324714).
- ceph: fix bool initialization/comparison (FATE#324714).
- ceph: handle 'session get evicted while there are file locks'
  (FATE#324714).
- ceph: optimize flock encoding during reconnect (FATE#324714).
- ceph: make lock_to_ceph_filelock() static (FATE#324714).
- ceph: keep auth cap when inode has flocks or posix locks
  (FATE#324714).
- commit b22d2c0
* Tue Jan 30 2018 lhenriques@suse.com
- ceph: unlock dangling spinlock in try_flush_caps()
  (FATE#324714).
- ceph: fix __choose_mds() for LSSNAP request (FATE#324714).
- ceph: properly queue cap snap for newly created snap realm
  (FATE#324714).
- ceph: avoid panic in create_session_open_msg() if utsname()
  returns NULL (FATE#324714).
- libceph: don't allow bidirectional swap of pg-upmap-items
  (FATE#324714).
- ceph: stop on-going cached readdir if mds revokes FILE_SHARED
  cap (FATE#324714).
- ceph: wait on writeback after writing snapshot data
  (FATE#324714).
- ceph: fix capsnap dirty pages accounting (FATE#324714).
- ceph: ignore wbc->range_{start,end} when write back snapshot
  data (FATE#324714).
- ceph: fix "range cyclic" mode writepages (FATE#324714).
- ceph: cleanup local variables in ceph_writepages_start()
  (FATE#324714).
- ceph: optimize pagevec iterating in ceph_writepages_start()
  (FATE#324714).
- ceph: make writepage_nounlock() invalidate page that beyonds
  EOF (FATE#324714).
- ceph: properly get capsnap's size in get_oldest_context()
  (FATE#324714).
- ceph: remove stale check in ceph_invalidatepage() (FATE#324714).
- ceph: queue cap snap only when snap realm's context changes
  (FATE#324714).
- ceph: handle race between vmtruncate and queuing cap snap
  (FATE#324714).
- ceph: fix message order check in handle_cap_export()
  (FATE#324714).
- ceph: fix NULL pointer dereference in ceph_flush_snaps()
  (FATE#324714).
- ceph: adjust 36 checks for NULL pointers (FATE#324714).
- ceph: delete an unnecessary return statement in
  update_dentry_lease() (FATE#324714).
- ceph: ENOMEM pr_err in __get_or_create_frag() is redundant
  (FATE#324714).
- ceph: check negative offsets in ceph_llseek() (FATE#324714).
- ceph: more accurate statfs (FATE#324714).
- ceph: properly set snap follows for cap reconnect (FATE#324714).
- ceph: don't use CEPH_OSD_FLAG_ORDERSNAP (FATE#324714).
- ceph: include snapc in debug message of write (FATE#324714).
- ceph: make sure flushsnap messages are sent in proper order
  (FATE#324714).
- ceph: fix -EOLDSNAPC handling (FATE#324714).
- ceph: send LSSNAP request to auth mds of directory inode
  (FATE#324714).
- ceph: don't fill readdir cache for LSSNAP reply (FATE#324714).
- ceph: cleanup ceph_readdir_prepopulate() (FATE#324714).
- ceph: new cap message flags indicate if there is pending capsnap
  (FATE#324714).
- ceph: nuke startsync op (FATE#324714).
- ceph: validate correctness of some mount options (FATE#324714).
- ceph: limit osd write size (FATE#324714).
- ceph: limit osd read size to CEPH_MSG_MAX_DATA_LEN
  (FATE#324714).
- ceph: remove unused cap_release_safety mount option
  (FATE#324714).
- commit a10585c
* Tue Jan 30 2018 lhenriques@suse.com
- libceph: make RECOVERY_DELETES feature create a new interval
  (FATE#324714).
- libceph: upmap semantic changes (FATE#324714).
- crush: assume weight_set != null imples weight_set_size > 0
  (FATE#324714).
- libceph: fallback for when there isn't a pool-specific
  choose_arg (FATE#324714).
- libceph: don't call ->reencode_message() more than once per
  message (FATE#324714).
- libceph: make encode_request_*() work with r_mempool requests
  (FATE#324714).
- libceph: potential NULL dereference in ceph_msg_data_create()
  (FATE#324714).
- libceph: don't call encode_request_finish() on MOSDBackoff
  messages (FATE#324714).
- libceph: use alloc_pg_mapping() in __decode_pg_upmap_items()
  (FATE#324714).
- libceph: set -EINVAL in one place in crush_decode()
  (FATE#324714).
- libceph: NULL deref on osdmap_apply_incremental() error path
  (FATE#324714).
- libceph: fix old style declaration warnings (FATE#324714).
- libceph: advertise support for NEW_OSDOP_ENCODING and
  SERVER_LUMINOUS (FATE#324714).
- libceph: osd_state is 32 bits wide in luminous (FATE#324714).
- crush: remove an obsolete comment (FATE#324714).
- crush: crush_init_workspace starts with struct crush_work
  (FATE#324714).
- libceph, crush: per-pool crush_choose_arg_map for
  crush_do_rule() (FATE#324714).
- crush: implement weight and id overrides for straw2
  (FATE#324714).
- libceph: apply_upmap() (FATE#324714).
- libceph: compute actual pgid in ceph_pg_to_up_acting_osds()
  (FATE#324714).
- libceph: pg_upmap[_items] infrastructure (FATE#324714).
- libceph: ceph_decode_skip_* helpers (FATE#324714).
- libceph: kill __{insert,lookup,remove}_pg_mapping()
  (FATE#324714).
- libceph: introduce and switch to decode_pg_mapping()
  (FATE#324714).
- libceph: don't pass pgid by value (FATE#324714).
- libceph: respect RADOS_BACKOFF backoffs (FATE#324714).
- libceph: make DEFINE_RB_* helpers more general (FATE#324714).
- libceph: avoid unnecessary pi lookups in calc_target()
  (FATE#324714).
- libceph: use target pi for calc_target() calculations
  (FATE#324714).
- libceph: always populate t->target_{oid,oloc} in calc_target()
  (FATE#324714).
- libceph: make sure need_resend targets reflect latest map
  (FATE#324714).
- libceph: delete from need_resend_linger before
  check_linger_pool_dne() (FATE#324714).
- libceph: resend on PG splits if OSD has RESEND_ON_SPLIT
  (FATE#324714).
- libceph: drop need_resend from calc_target() (FATE#324714).
- libceph: MOSDOp v8 encoding (actual spgid + full hash)
  (FATE#324714).
- libceph: ceph_connection_operations::reencode_message() method
  (FATE#324714).
- libceph: encode_{pgid,oloc}() helpers (FATE#324714).
- libceph: introduce ceph_spg, ceph_pg_to_primary_shard()
  (FATE#324714).
- libceph: new pi->last_force_request_resend (FATE#324714).
- libceph: foldreq->last_force_resend into ceph_osd_request_target
  (FATE#324714).
- libceph: support SERVER_JEWEL feature bits (FATE#324714).
- libceph: advertise support for OSD_POOLRESEND (FATE#324714).
- libceph: handle non-empty dest in ceph_{oloc,oid}_copy()
  (FATE#324714).
- libceph: new features macros (FATE#324714).
- libceph: remove ceph_sanitize_features() workaround
  (FATE#324714).
- ceph: update ceph_dentry_info::lease_session when necessary
  (FATE#324714).
- ceph: new mount option that specifies fscache uniquifier
  (FATE#324714).
- ceph: avoid accessing freeing inode in ceph_check_delayed_caps()
  (FATE#324714).
- ceph: avoid invalid memory dereference in the middle of umount
  (FATE#324714).
- ceph: getattr before read on ceph.* xattrs (FATE#324714).
- ceph: don't re-send interrupted flock request (FATE#324714).
- ceph: cleanup writepage_nounlock() (FATE#324714).
- ceph: redirty page when writepage_nounlock() skips unwritable
  page (FATE#324714).
- ceph: remove useless page->mapping check in writepage_nounlock()
  (FATE#324714).
- ceph: update the 'approaching max_size' code (FATE#324714).
- ceph: re-request max size after importing caps (FATE#324714).
- ceph: ensure RNG is seeded before using (FATE#324714).
- commit f96ea6d
* Tue Jan 30 2018 mhocko@suse.com
- Documentation/kernel-parameters.txt: Update 'memmap=' boot
  option description (bnc#1077917).
- Update
  patches.suse/0001-x86-KASLR-Parse-all-memmap-boot-option-entries.patch
  (bnc#1071680, bnc#1077917, fate#323473).
- Update
  patches.suse/0002-x86-KASLR-Handle-the-memory-limit-specified-by-the-m.patch
  (bnc#1071680, bnc#1077917, fate#323473).
- commit 139f441
* Tue Jan 30 2018 mkubecek@suse.cz
- RDS: Heap OOB write in rds_message_alloc_sgs() (CVE-2018-5332
  bsc#1075621).
- commit 8848928
* Tue Jan 30 2018 mkubecek@suse.cz
- RDS: null pointer dereference in rds_atomic_free_op
  (CVE-2018-5333 bsc#1075617).
- commit 4d458e8
* Tue Jan 30 2018 mkubecek@suse.cz
- net: Fix double free and memory corruption in get_net_ns_by_id()
  (CVE-2017-15129 bsc#1074839).
- commit 249e5ac
* Tue Jan 30 2018 mkubecek@suse.cz
- net: ipv4: emulate READ_ONCE() on ->hdrincl bit-field in
  raw_sendmsg() (CVE-2017-17712 bsc#1073229).
- net: ipv4: fix for a race condition in raw_sendmsg
  (CVE-2017-17712 bsc#1073229).
- commit 34b8075
* Tue Jan 30 2018 mgorman@suse.de
- sched/fair: Use a recently used CPU as an idle candidate and
  the basis for SIS (bnc#1066110).
- sched/fair: Do not migrate if the prev_cpu is idle
  (bnc#1066110).
- sched/fair: Restructure wake_affine to return a CPU id
  (bnc#1066110).
- sched/fair: Remove unnecessary parameters from wake_affine_idle
  (bnc#1066110).
- sched/fair: Sync task util before slow-path wakeup
  (bnc#1066110).
- commit f574d1e
* Tue Jan 30 2018 mkubecek@suse.cz
- ipvlan: remove excessive packet scrubbing (bsc#1070799).
- commit 0cc2da1
* Tue Jan 30 2018 mkubecek@suse.cz
- tipc: improve link resiliency when rps is activated
  (bsc#1068038).
- commit edad3d6
* Tue Jan 30 2018 mkubecek@suse.cz
- series.conf: refresh
  (ran series_sort.py)
- Refresh
  patches.drivers/nvme-also-expose-the-namespace-identification-sysfs-.patch.
  patches.drivers/nvme-fix-visibility-of-uuid-ns-attribute.patch.
  patches.drivers/nvme-introduce-a-nvme_ns_ids-structure.patch.
  patches.drivers/nvme-track-shared-namespaces.patch.
- Update upstream reference:
  patches.drivers/block-Provide-blk_status_t-decoding-for-path-errors.patch.
  patches.drivers/dm-mpath-Use-blk_path_error.patch.
  patches.drivers/nvme-Add-more-command-status-translation.patch.
  patches.drivers/nvme-add-tracepoint-for-nvme_complete_rq.patch.
  patches.drivers/nvme-add-tracepoint-for-nvme_setup_cmd.patch.
  patches.drivers/nvme-multipath-Consult-blk_status_t-for-failover.patch.
  patches.drivers/nvme-multipath-Use-blk_path_error.patch.
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
- commit 8073960
* Mon Jan 29 2018 jeffm@suse.com
- btrfs: fix btrfs_evict_inode to handle abnormal inodes correctly (bsc#1078019).
- commit 776dc75
* Mon Jan 29 2018 jeffm@suse.com
- Btrfs: fix unexpected return value of bio_readpage_error
  (bsc#1067598).
- commit 30d5aee
* Mon Jan 29 2018 hare@suse.de
- scsi: lpfc: fix a couple of minor indentation issues
  (bsc#1076693,bsc#1076672).
- scsi: lpfc: don't dereference localport before it has been
  null checked (bsc#1076693,bsc#1076672).
- scsi: lpfc: correct sg_seg_cnt attribute min vs default
  (bsc#1076693,bsc#1076672).
- commit 5817551
* Mon Jan 29 2018 hare@suse.de
- scsi: lpfc: update driver version to 11.4.0.6 (bsc#1076693).
- scsi: lpfc: Beef up stat counters for debug (bsc#1076693).
- scsi: lpfc: Fix infinite wait when driver unregisters a remote
  NVME port (bsc#1076693).
- scsi: lpfc: Fix issues connecting with nvme initiator
  (bsc#1076693).
- scsi: lpfc: Fix SCSI LUN discovery when SCSI and NVME enabled
  (bsc#1076693).
- scsi: lpfc: Increase SCSI CQ and WQ sizes (bsc#1076693).
- scsi: lpfc: Fix receive PRLI handling (bsc#1076693).
- scsi: lpfc: Fix -EOVERFLOW behavior for NVMET and defer_rcv
  (bsc#1076693).
- scsi: lpfc: Fix random heartbeat timeouts during heavy IO
  (bsc#1076693).
- commit 89d95b9
* Mon Jan 29 2018 jthumshirn@suse.de
- nvme: add tracepoint for nvme_complete_rq (FATE#323952,
  FATE#322506).
- nvme: add tracepoint for nvme_setup_cmd (FATE#323952,
  FATE#322506).
- commit 870ce83
* Mon Jan 29 2018 hare@suse.de
- Update patch header for ibmvnic patches
- Refresh
  patches.drivers/ibmvnic-Allocate-and-request-vpd-in-init_resources.patch.
- Refresh
  patches.drivers/ibmvnic-Modify-buffer-size-and-number-of-queues-on-f.patch.
- Refresh
  patches.drivers/ibmvnic-Revert-to-previous-mtu-when-unsupported-valu.patch.
- commit ac37059
* Mon Jan 29 2018 hare@suse.de
- scsi: lpfc: update driver version to 11.4.0.5 (bsc#1076693).
- scsi: lpfc: small sg cnt cleanup (bsc#1076693).
- scsi: lpfc: Fix driver handling of nvme resources during unload
  (bsc#1076693).
- scsi: lpfc: Fix crash during driver unload with running nvme
  traffic (bsc#1076693).
- scsi: lpfc: Correct driver deregistrations with host nvme
  transport (bsc#1076693).
- scsi: lpfc: correct port registrations with nvme_fc
  (bsc#1076693).
- scsi: lpfc: Linux LPFC driver does not process all RSCNs
  (bsc#1076693).
- scsi: lpfc: Fix ndlp ref count for pt2pt mode issue RSCN
  (bsc#1076693).
- scsi: lpfc: Adjust default value of lpfc_nvmet_mrq
  (bsc#1076693).
- scsi: lpfc: Fix display for debugfs queInfo (bsc#1076693).
- scsi: lpfc: Driver fails to detect direct attach storage array
  (bsc#1076693).
- scsi: lpfc: Raise maximum NVME sg list size for 256 elements
  (bsc#1076693).
- scsi: lpfc: Fix NVME LS abort_xri (bsc#1076693).
- scsi: lpfc: Fix crash after bad bar setup on driver attachment
  (bsc#1076693).
- scsi: lpfc: Handle XRI_ABORTED_CQE in soft IRQ (bsc#1076693).
- scsi: lpfc: Expand WQE capability of every NVME hardware queue
  (bsc#1076693).
- scsi: lpfc: FLOGI failures are reported when connected to a
  private loop (bsc#1076693).
- commit 1f4d880
* Mon Jan 29 2018 tbogendoerfer@suse.de
- net/mlx5e: Keep updating ethtool statistics when the interface
  is down (bsc#1046303 FATE#322944).
- commit 4075ba4
* Mon Jan 29 2018 msuchanek@suse.de
- KEYS: Fix race between updating and finding a negative key
  (CVE-2017-15951, bsc#1065615, bsc#1071927).
- KEYS: don't let add_key() update an uninstantiated key
  (CVE-2017-15951, bsc#1065615, bsc#1071927).
- commit d6cb5a2
* Mon Jan 29 2018 tbogendoerfer@suse.de
- net/mlx5: Fix memory leak in bad flow of mlx5_alloc_irq_vectors
  (bsc#1046303 FATE#322944).
- commit c5e8efb
* Mon Jan 29 2018 mhocko@suse.com
- mm/mprotect: add a cond_resched() inside change_pmd_range()
  (bnc#1077871).
- commit e2d94df
* Mon Jan 29 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvme-fix-visibility-of-uuid-ns-attribute.patch.
  Fix upstream commit-id.
- commit 4210304
* Mon Jan 29 2018 mkubecek@suse.cz
- blacklist.conf: add 040ee69226f8
- commit bc8f9b1
* Mon Jan 29 2018 mkubecek@suse.cz
- ipv6: ip6_make_skb() needs to clear cork.base.dst (bsc#1076830).
- xfrm: Use __skb_queue_tail in xfrm_trans_queue (bsc#1076830).
- tcp/dccp: fix other lockdep splats accessing ireq_opt
  (bsc#1076830).
- tcp/dccp: fix lockdep splat in inet_csk_route_req()
  (bsc#1076830).
- udp: fix bcast packet reception (bsc#1076830).
- vti: fix NULL dereference in xfrm_input() (bsc#1076830).
- sctp: Fix a big endian bug in sctp_diag_dump() (bsc#1076830).
- commit 08c4a13
* Mon Jan 29 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.drivers/ibmvnic-Allocate-and-request-vpd-in-init_resources.patch.
  patches.drivers/ibmvnic-Modify-buffer-size-and-number-of-queues-on-f.patch.
  patches.drivers/ibmvnic-Revert-to-previous-mtu-when-unsupported-valu.patch.
- commit 3fd778c
* Sun Jan 28 2018 mcgrof@suse.com
- xfs: validate sb_logsunit is a multiple of the fs blocksize (bsc#1077513).
- commit b3bd89b
* Fri Jan 26 2018 yousaf.kaukab@suse.com
- config: arm64: enable ARM64_HW_AFDBM and ARM64_PAN
- commit 45aa9c3
* Fri Jan 26 2018 hare@suse.de
- lpfc: Fix hard lock up NMI in els timeout handling
  (bsc#1076672).
- commit 203b3e9
* Fri Jan 26 2018 hare@suse.de
- lpfc: tie in to new dev_loss_tmo interface in nvme transport
  (bsc#1076672).
- commit ccb6905
* Fri Jan 26 2018 hare@suse.de
- scsi: qla2xxx: Fix recursion while sending terminate exchange
  (bsc#1076093).
- commit e94594b
* Fri Jan 26 2018 tbogendoerfer@suse.de
- qed* - bump drivers to version 8.10.10.55 (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- commit c7852cd
* Thu Jan 25 2018 msuchanek@suse.de
- powerpc: Don't preempt_disable() in show_cpuinfo()
  (bsc#1065729).
- commit 54d3151
* Thu Jan 25 2018 msuchanek@suse.de
- genirq/msi: Fix populating multiple interrupts (bsc#1070194).
- genirq: Track whether the trigger type has been set
  (bsc#1070194).
- genirq: Fix for_each_action_of_desc() macro (bsc#1070194).
- genirq: Make sparse_irq_lock protect what it should protect
  (bsc#1070194).
- powerpc/xmon: Check before calling xive functions (FATE#322438,
  bsc#1065729).
- powerpc/powernv/cpufreq: Fix the frequency read by /proc/cpuinfo
  (bsc#1065729).
- powerpc/jprobes: Disable preemption when triggered through
  ftrace (bsc#1065729).
- KVM: PPC: Book3S HV: Always flush TLB in
  kvmppc_alloc_reset_hpt() (bsc#1061840).
- KVM: PPC: Book3S HV: Fix use after free in case of multiple
  resize requests (bsc#1061840).
- KVM: PPC: Book3S HV: Drop prepare_done from struct
  kvm_resize_hpt (bsc#1061840).
- genirq/msi: Fix populating multiple interrupts (bsc#1070194).
- genirq: Track whether the trigger type has been set
  (bsc#1070194).
- genirq: Fix for_each_action_of_desc() macro (bsc#1070194).
- genirq: Make sparse_irq_lock protect what it should protect
  (bsc#1070194).
- powerpc/xmon: Check before calling xive functions (FATE#322438,
  bsc#1065729).
- powerpc/powernv/cpufreq: Fix the frequency read by /proc/cpuinfo
  (bsc#1065729).
- powerpc/jprobes: Disable preemption when triggered through
  ftrace (bsc#1065729).
- KVM: PPC: Book3S HV: Always flush TLB in
  kvmppc_alloc_reset_hpt() (bsc#1061840).
- KVM: PPC: Book3S HV: Fix use after free in case of multiple
  resize requests (bsc#1061840).
- KVM: PPC: Book3S HV: Drop prepare_done from struct
  kvm_resize_hpt (bsc#1061840).
- commit 265931d
* Thu Jan 25 2018 mcgrof@suse.com
- fs: Avoid invalidation in interrupt context in dio_complete() (bsc#1073407 bsc#1069135).
- Refresh patches.suse/0023-block-switch-bios-to-blk_status_t.patch.
- commit 4cb0a08
* Thu Jan 25 2018 yousaf.kaukab@suse.com
- arm64: Move BP hardening to check_and_switch_context
  (bsc#1068032).
- commit 45ddc1d
* Thu Jan 25 2018 tbogendoerfer@suse.de
- RDMA/bnxt_re: Add SRQ support for Broadcom adapters (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: expose detailed stats retrieved from HW
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Add support for MRs with Huge pages (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add support for query firmware version
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Enable RoCE on virtual functions (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add SRQ support for Broadcom adapters (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: expose detailed stats retrieved from HW
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Add support for MRs with Huge pages (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add support for query firmware version
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Enable RoCE on virtual functions (bsc#1050244
  FATE#322915).
- commit 75e0deb
* Thu Jan 25 2018 tbogendoerfer@suse.de
- be2net: restore properly promisc mode after queues
  reconfiguration (bsc#1050252 FATE#322920).
- net/mlx5e: Fix fixpoint divide exception in
  mlx5e_am_stats_compare (bsc#1071289).
- be2net: restore properly promisc mode after queues
  reconfiguration (bsc#1050252 FATE#322920).
- net/mlx5e: Fix fixpoint divide exception in
  mlx5e_am_stats_compare (bsc#1071289).
- commit 8395ca0
* Thu Jan 25 2018 jslaby@suse.cz
- Documentation: document array_ptr (bsc#1068032 CVE-2017-5753).
- asm/nospec, array_ptr: sanitize speculative array de-references
  (bsc#1068032 CVE-2017-5753).
- x86: implement array_ptr_mask() (bsc#1068032 CVE-2017-5753).
- x86: introduce __uaccess_begin_nospec and ifence (bsc#1068032
  CVE-2017-5753).
- x86, __get_user: use __uaccess_begin_nospec (bsc#1068032
  CVE-2017-5753).
- x86, get_user: use pointer masking to limit speculation
  (bsc#1068032 CVE-2017-5753).
- x86: narrow out of bounds syscalls to sys_read under speculation
  (bsc#1068032 CVE-2017-5753).
- vfs, fdtable: prevent bounds-check bypass via speculative
  execution (bsc#1068032 CVE-2017-5753).
- kvm, x86: update spectre-v1 mitigation (bsc#1068032
  CVE-2017-5753).
- nl80211: sanitize array index in parse_txq_params (bsc#1068032
  CVE-2017-5753).
- KVM: x86: Add memory barrier on vmcs field lookup (bsc#1068032
  CVE-2017-5753).
- Refresh
  patches.arch/23-x86-retpoline-entry-convert-entry-assembler-indirect-jumps.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0003-locking-barriers-introduce-new-observable-speculatio.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0014-fs-prevent-speculative-execution.patch.
  Usee array_ptr on x86. This should put things back to normal.
- commit 469e0d1
* Thu Jan 25 2018 oneukum@suse.com
- PCI: Do not allocate more buses than available in parent
  (FATE#323948).
- Refresh
  patches.drivers/0001-thunderbolt-tb-fix-use-after-free-in-tb_activate_pci.patch.
- commit 4836e10
* Thu Jan 25 2018 tbogendoerfer@suse.de
- Delete
  patches.suse/net-mlx5-Fix-fixpoint-divide-exception-in-mlx5e_am_s.patch.
  replace with upstreamed patch
- commit 4970de8
* Wed Jan 24 2018 msuchanek@suse.de
- powerpc/pseries: rfi-flush: Call setup_rfi_flush() after LPM migration (bsc#1068032).
  Really fix the migration patch
- Delete patches.arch/powerpc-rfi-flush-Make-setup_rfi_flush-not-__init.patch.
- Delete patches.arch/powerpc-rfi-flush-prevent-crash-when-changing-flush-.patch.
- commit 4efb860
* Wed Jan 24 2018 msuchanek@suse.de
- Fix build error in drmem.c (bsc#1077428).
- commit 522031e
* Wed Jan 24 2018 msuchanek@suse.de
- Move fadump patches to powerpc section.
- commit d2c2ae6
* Wed Jan 24 2018 msuchanek@suse.de
- powerpc/pseries: Enable support of ibm,dynamic-memory-v2
  (bsc#1077428).
- powerpc/drmem: Add support for ibm, dynamic-memory-v2 property
  (bsc#1077428).
- powerpc: Move of_drconf_cell struct to asm/drmem.h
  (bsc#1077428).
- powerpc/pseries: Update memory hotplug code to use drmem LMB
  array (bsc#1077428).
- powerpc/numa: Update numa code use walk_drmem_lmbs
  (bsc#1077428).
- powerpc/mm: Separate ibm, dynamic-memory data from DT format
  (bsc#1077428).
- powerpc/numa: Look up associativity array in
  of_drconf_to_nid_single (bsc#1077428).
- powerpc/numa: Look up device node in of_get_usable_memory()
  (bsc#1077428).
- powerpc/numa: Look up device node in of_get_assoc_arrays()
  (bsc#1077428).
- powerpc/pseries: Enable support of ibm,dynamic-memory-v2
  (bsc#1077428).
- powerpc/drmem: Add support for ibm, dynamic-memory-v2 property
  (bsc#1077428).
- powerpc: Move of_drconf_cell struct to asm/drmem.h
  (bsc#1077428).
- powerpc/pseries: Update memory hotplug code to use drmem LMB
  array (bsc#1077428).
- powerpc/numa: Update numa code use walk_drmem_lmbs
  (bsc#1077428).
- powerpc/mm: Separate ibm, dynamic-memory data from DT format
  (bsc#1077428).
- powerpc/numa: Look up associativity array in
  of_drconf_to_nid_single (bsc#1077428).
- powerpc/numa: Look up device node in of_get_usable_memory()
  (bsc#1077428).
- powerpc/numa: Look up device node in of_get_assoc_arrays()
  (bsc#1077428).
- commit 25a4560
* Wed Jan 24 2018 mgorman@suse.de
- mm: numa: do not trap faults on shared data section pages
  (Automatic NUMA Balancing (fate#315482)).
- commit ccce19f
* Wed Jan 24 2018 mcgrof@suse.com
- fs: invalidate page cache after end_io() in dio completion (bsc#1073407 bsc#1069135).
- fs: Fix page cache inconsistency when mixing buffered and AIO DIO (bsc#1073407 bsc#1069135).
- commit fcc82bf
* Tue Jan 23 2018 msuchanek@suse.de
- Refresh
  patches.drivers/ibmvnic-Allocate-and-request-vpd-in-init_resources.patch.
- Refresh
  patches.drivers/ibmvnic-Modify-buffer-size-and-number-of-queues-on-f.patch.
- Refresh
  patches.drivers/ibmvnic-Revert-to-previous-mtu-when-unsupported-valu.patch.
  Add commit hash
- commit 917e6ff
* Tue Jan 23 2018 msuchanek@suse.de
- powerpc/64s: Wire up cpu_show_meltdown() (bsc#1068032).
- commit 066f80a
* Tue Jan 23 2018 oneukum@suse.com
- CDC-ACM: apply quirk for card reader (bsc#1060279).
- commit b9670bb
* Mon Jan 22 2018 bp@suse.de
- x86/mce: Make machine check speculation protected (bsc#1068032
  CVE-2017-5754).
- commit 6961313
* Mon Jan 22 2018 msuchanek@suse.de
- ibmvnic: Allocate and request vpd in init_resources
  (bsc#1076872).
- ibmvnic: Revert to previous mtu when unsupported value requested
  (bsc#1076872).
- ibmvnic: Modify buffer size and number of queues on failover
  (bsc#1076872).
- commit 2ae4beb
* Mon Jan 22 2018 msuchanek@suse.de
- ibmvnic: Fix IPv6 packet descriptors (bsc#1076899).
- ibmvnic: Fix IP offload control buffer (bsc#1076899).
- commit b164618
* Mon Jan 22 2018 msuchanek@suse.de
- Refresh
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
- commit 04a2099
* Mon Jan 22 2018 yousaf.kaukab@suse.com
- arm64: Turn on KPTI only on CPUs that need it (bsc#1076187).
- arm64: kpti: Fix the interaction between ASID switching and
  software PAN (bsc#1068032).
- arm64: SW PAN: Update saved ttbr0 value on enter_lazy_tlb
  (bsc#1068032).
- arm64: SW PAN: Point saved ttbr0 at the zero page when switching
  to init_mm (bsc#1068032).
- arm64: KVM: Fix SMCCC handling of unimplemented SMC/HVC calls
  (bsc#1068032).
- arm64: cputype: Add MIDR values for Cavium ThunderX2 CPUs
  (bsc#1068032).
- arm64: Implement branch predictor hardening for Falkor
  (bsc#1068032).
- arm64: Implement branch predictor hardening for affected
  Cortex-A CPUs (bsc#1068032).
- drivers/firmware: Expose psci_get_version through psci_ops
  structure (bsc#1068032).
- arm64: cputype: Add missing MIDR values for Cortex-A72 and
  Cortex-A75 (bsc#1068032).
- arm64: KVM: Make PSCI_VERSION a fast path (bsc#1068032).
- arm64: KVM: Use per-CPU vector when BP hardening is enabled
  (bsc#1068032).
- arm64: Add skeleton to harden the branch predictor against
  aliasing attacks (bsc#1068032).
- arm64: Move post_ttbr_update_workaround to C code (bsc#1068032).
- arm64: cpufeature: Pass capability structure to ->enable
  callback (bsc#1068032).
- arm64: Take into account ID_AA64PFR0_EL1.CSV3 (bsc#1068032).
- arm64: Kconfig: Reword UNMAP_KERNEL_AT_EL0 kconfig entry
  (bsc#1068032).
- arm64: use RET instruction for exiting the trampoline
  (bsc#1068032).
- arm64: Define cputype macros for Falkor CPU (bsc#1068032).
- arm64: entry.S: convert elX_irq (bsc#1068032).
- arm64: entry.S convert el0_sync (bsc#1068032).
- arm64: entry.S: convert el1_sync (bsc#1068032).
- arm64: entry.S: Remove disable_dbg (bsc#1068032).
- commit ff2c728
* Mon Jan 22 2018 bp@suse.de
- x86: Use __nostackprotect for sme_encrypt_kernel (fate#322123).
- commit 26b52c7
* Mon Jan 22 2018 jthumshirn@suse.de
- scsi: fnic: do not call host reset from command abort
  (bsc#1075700).
- commit d6f2a44
* Mon Jan 22 2018 bp@suse.de
- x86/mm: Rework wbinvd, hlt operation in stop_this_cpu()
  (fate#322123).
- x86/mm: Encrypt the initrd earlier for BSP microcode update
  (fate#322123).
- x86/mm: Prepare sme_encrypt_kernel() for PAGE aligned encryption
  (fate#322123).
- x86/mm: Centralize PMD flags in sme_encrypt_kernel()
  (fate#322123).
- x86/mm: Use a struct to reduce parameters for SME PGD mapping
  (fate#322123).
- x86/mm: Clean up register saving in the __enc_copy() assembly
  code (fate#322123).
- commit 1891f37
* Mon Jan 22 2018 yousaf.kaukab@suse.com
- config: arm64: enable HARDEN_BRANCH_PREDICTOR
- commit 4d0bfd9
* Mon Jan 22 2018 tbogendoerfer@suse.de
- RDMA/mlx5: Fix out-of-bound access while querying AH
  (bsc#1046305 FATE#322943).
- IB/hfi1: Prevent a NULL dereference (bsc#1060463 FATE#323043).
- nfp: use the correct index for link speed table (bsc#1055968).
- net/mlx5e: Don't override netdev features field unless in
  error flow (bsc#1046303 FATE#322944).
- net/mlx5: Fix error handling in load one (bsc#1046303
  FATE#322944).
- net/mlx5: Fix mlx5_get_uars_page to return error code
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix get vector affinity helper function (bsc#1046303
  FATE#322944 bsc#1075185).
- {net,ib}/mlx5: Don't disable local loopback multicast traffic
  when needed (bsc#1046303 FATE#322944).
- commit f819e2e
* Mon Jan 22 2018 msuchanek@suse.de
- rpm/mkspec-dtb: Remove COPYING file (bsc#1076905).
  It conflicts between different versions of dtb package.
- commit 0e5fcf9
* Mon Jan 22 2018 jthumshirn@suse.de
- scsi: core: check for device state in __scsi_remove_target()
  (bsc#1071302).
- scsi: fixup kernel warning during rmmod() (bsc#1071302).
- commit df49e29
* Mon Jan 22 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/block-Provide-blk_status_t-decoding-for-path-errors.patch.
- Refresh patches.drivers/dm-mpath-Use-blk_path_error.patch.
- Refresh
  patches.drivers/nvme-Add-more-command-status-translation.patch.
- Refresh
  patches.drivers/nvme-multipath-Consult-blk_status_t-for-failover.patch.
- Refresh patches.drivers/nvme-multipath-Use-blk_path_error.patch.
- Refresh
  patches.drivers/nvme-pci-take-sglist-coalescing-in-dma_map_sg-into-a.patch.
  Re-sort series.conf
- commit b506849
* Mon Jan 22 2018 bpoirier@suse.com
- Delete
  patches.suse/e1000e-Avoid-receiver-overrun-interrupt-bursts.patch.
  See bsc#1075428 comment 24.
  A workaround is being discussed upstream. Remove this patch for now. I'll
  re-add it once the workaround lands upstream.
- commit 5a22940
* Sun Jan 21 2018 bp@suse.de
- module: Add retpoline tag to VERMAGIC (bsc#1068032
  CVE-2017-5754).
- x86/cpufeature: Move processor tracing out of scattered features
  (bsc#1068032 CVE-2017-5754).
- objtool: Improve error message for bad file argument
  (bsc#1068032 CVE-2017-5754).
- objtool: Fix seg fault with gold linker (bsc#1068032
  CVE-2017-5754).
- x86/retpoline: Add LFENCE to the retpoline/RSB filling RSB
  macros (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Fill RSB on context switch for affected CPUs
  (bsc#1068032 CVE-2017-5754).
- commit ffce37e
* Sat Jan 20 2018 bp@suse.de
- x86/retpoline: Remove compile time warning (bsc#1068032
  CVE-2017-5754).
- Update config files.
- x86/retpoline: Fill return stack buffer on vmexit (bsc#1068032
  CVE-2017-5754).
- x86/retpoline/xen: Convert Xen hypercall indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/hyperv: Convert assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/ftrace: Convert ftrace assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/entry: Convert entry assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/retpoline/crypto: Convert crypto assembler indirect jumps
  (bsc#1068032 CVE-2017-5754).
- x86/spectre: Add boot time option to select Spectre v2
  mitigation (bsc#1068032 CVE-2017-5754).
- x86/retpoline: Add initial retpoline support (bsc#1068032
  CVE-2017-5754).
- objtool: Allow alternatives to be ignored (bsc#1068032
  CVE-2017-5754).
- objtool: Detect jumps to retpoline thunks (bsc#1068032
  CVE-2017-5754).
- x86/alternatives: Fix optimize_nops() checking (bsc#1068032
  CVE-2017-5754).
- sysfs/cpu: Fix typos in vulnerability documentation (bsc#1068032
  CVE-2017-5754).
- x86/cpu: Implement CPU vulnerabilites sysfs functions
  (bsc#1068032 CVE-2017-5754).
- sysfs/cpu: Add vulnerability folder (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Add X86_BUG_SPECTRE_V (bsc#1068032
  CVE-2017-5754).
- x86/Documentation: Add PTI description (bsc#1068032
  CVE-2017-5754).
- x86/pti: Unbreak EFI old_memmap (bsc#1068032 CVE-2017-5754).
- x86/pti: Rename BUG_CPU_INSECURE to BUG_CPU_MELTDOWN
  (bsc#1068032 CVE-2017-5754).
- x86/alternatives: Add missing '\n' at end of ALTERNATIVE inline
  asm (bsc#1068032 CVE-2017-5754).
- x86/mm: Map cpu_entry_area at the same place on 4/5 level
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Set MODULES_END to 0xffffffffff000000 (bsc#1068032
  CVE-2017-5754).
- x86/dumpstack: Print registers for first stack frame
  (bsc#1068032 CVE-2017-5754).
- x86/cpu, x86/pti: Do not enable PTI on AMD processors
  (bsc#1068032 CVE-2017-5754).
- x86/pti: Enable PTI by default (bsc#1068032 CVE-2017-5754).
- x86/ldt: Make LDT pgtable free conditional (bsc#1068032
  CVE-2017-5754).
- x86/mm: Remove preempt_disable/enable() from
  __native_flush_tlb() (bsc#1068032 CVE-2017-5754).
- x86/smpboot: Remove stale TLB flush invocations (bsc#1068032
  CVE-2017-5754).
- commit 1c37e0f
* Sat Jan 20 2018 bp@suse.de
- x86/cpu/AMD: Make LFENCE a serializing instruction (bsc#1068032
  CVE-2017-5753).
- x86/cpu/AMD: Use LFENCE_RDTSC in preference to MFENCE_RDTSC
  (bsc#1068032 CVE-2017-5753).
- Delete
  patches.suse/0001-x86-cpu-AMD-Make-the-LFENCE-instruction-serialized.patch.
- Delete
  patches.suse/0002-x86-cpu-AMD-Remove-now-unused-definition-of-MFENCE_R.patch.
- commit 739d51a
* Fri Jan 19 2018 mkubecek@suse.cz
- ipv6: fix possible mem leaks in ipv6_make_skb() (bsc#1076830).
- sctp: Replace use of sockets_allocated with specified macro
  (bsc#1076830).
- xfrm: Reinject transport-mode packets through tasklet
  (bsc#1076830).
- xfrm: Fix xfrm_input() to verify state is valid when (encap_type
  < 0) (bsc#1076830).
- openvswitch: Fix pop_vlan action for double tagged frames
  (bsc#1076830).
- tcp: fix potential underestimation on rcv_rtt (bsc#1076830).
- netfilter: xt_bpf: add overflow checks (bsc#1076830).
- tcp md5sig: Use skb's saddr when replying to an incoming segment
  (bsc#1076830).
- fou: fix some member types in guehdr (bsc#1076830).
- sctp: make sure stream nums can match optlen in
  sctp_setsockopt_reset_streams (bsc#1076830).
- tcp: use current time in tcp_rcv_space_adjust() (bsc#1076830).
- tcp: use IPCB instead of TCP_SKB_CB in inet_exact_dif_match()
  (bsc#1076830).
- net/packet: fix a race in packet_bind() and packet_notifier()
  (bsc#1076830).
- packet: fix crash in fanout_demux_rollover() (bsc#1076830).
- ipv6: Do not consider linkdown nexthops during multipath
  (bsc#1076830).
- route: also update fnhe_genid when updating a route cache
  (bsc#1076830).
- ipv6: avoid zeroing per cpu data again (bsc#1076830).
- tcp: fix tcp_fastretrans_alert warning (bsc#1076830).
- net: vrf: correct FRA_L3MDEV encode type (bsc#1076830).
- tcp: fix tcp_mtu_probe() vs highest_sack (bsc#1076830).
- xfrm: Fix GSO for IPsec with GRE tunnel (bsc#1076830).
- xfrm: Clear sk_dst_cache when applying per-socket policy
  (bsc#1076830).
- tap: double-free in error path in tap_open() (bsc#1076830).
- packet: avoid panic in packet_getsockopt() (bsc#1076830).
- tcp/dccp: fix ireq->opt races (bsc#1076830).
- netfilter: xt_bpf: Fix XT_BPF_MODE_FD_PINNED mode of
  'xt_bpf_info_v1' (bsc#1076830).
- netfilter: nf_tables: fix update chain error (bsc#1076830).
- netfilter: xt_socket: Restore mark from full sockets only
  (bsc#1076830).
- xfrm: Fix negative device refcount on offload failure
  (bsc#1076830).
- udp: perform source validation for mcast early demux
  (bsc#1076830).
- IPv4: early demux can return an error code (bsc#1076830).
- udpv6: Fix the checksum computation when HW checksum does not
  apply (bsc#1076830).
- sctp: fix an use-after-free issue in sctp_sock_dump
  (bsc#1076830).
- ip_tunnel: fix ip tunnel lookup in collect_md mode
  (bsc#1076830).
- ip_tunnel: fix setting ttl and tos value in collect_md mode
  (bsc#1076830).
- netfilter: ipvs: fix the issue that sctp_conn_schedule drops
  non-INIT packet (bsc#1076830).
- xfrm: Clear RX SKB secpath xfrm_offload (bsc#1076830).
- ip/options: explicitly provide net ns to __ip_options_echo()
  (bsc#1076830).
- net/netfilter/nf_conntrack_core: Fix net_conntrack_lock()
  (bsc#1076830).
- xfrm_user: fix info leak in build_aevent() (bsc#1076830).
- xfrm_user: fix info leak in xfrm_notify_sa() (bsc#1076830).
- netfilter: nf_tables: Fix nft limit burst handling
  (bsc#1076830).
- netfilter: ipt_CLUSTERIP: fix use-after-free of proc entry
  (bsc#1076830).
- esp: Fix error handling on layer 2 xmit (bsc#1076830).
- net/packet: Fix Tx queue selection for AF_PACKET (bsc#1076830).
- netfilter: ebt_nflog: fix unexpected truncated packet
  (bsc#1076830).
- commit a12e319
* Fri Jan 19 2018 msuchanek@suse.de
- powerpc/rfi-flush: prevent crash when changing flush type to
  fallback after system boot (bsc#1068032).
- commit 8b07c66
* Fri Jan 19 2018 mkubecek@suse.cz
- tcp: refresh tcp_mstamp from timers callbacks (bsc#1061739).
- tcp: refresh tp timestamp before tcp_mtu_probe() (bsc#1061739).
- tcp: do tcp_mstamp_refresh before retransmits on TSQ handler
  (bsc#1061739).
- tcp: fix TCP_SYNCNT flakes (bsc#1061739).
- tcp: fix tcp_probe_timer() for TCP_USER_TIMEOUT (bsc#1061739).
- tcp: fix tcp_rearm_rto() (bsc#1061739).
- tcp: switch TCP TS option (RFC 7323) to 1ms clock (bsc#1061739).
- tcp: replace misc tcp_time_stamp to tcp_jiffies32 (bsc#1061739).
- tcp_lp: cache tcp_time_stamp (bsc#1061739).
- tcp_westwood: use tcp_jiffies32 instead of tcp_time_stamp
  (bsc#1061739).
- tcp: use tcp_jiffies32 in __tcp_oow_rate_limited()
  (bsc#1061739).
- tcp: uses jiffies_32 to feed tp->chrono_start (bsc#1061739).
- tcp: use tcp_jiffies32 to feed probe_timestamp (bsc#1061739).
- tcp: use tcp_jiffies32 for rcv_tstamp and lrcvtime
  (bsc#1061739).
- tcp: bic, cubic: use tcp_jiffies32 instead of tcp_time_stamp
  (bsc#1061739).
- tcp_bbr: use tcp_jiffies32 instead of tcp_time_stamp
  (bsc#1061739).
- tcp: use tcp_jiffies32 to feed tp->snd_cwnd_stamp (bsc#1061739).
- tcp: use tcp_jiffies32 to feed tp->lsndtime (bsc#1061739).
- dccp: do not use tcp_time_stamp (bsc#1061739).
- tcp: introduce tcp_jiffies32 (bsc#1061739).
- tcp: use tp->tcp_mstamp in output path (bsc#1061739).
- commit a53ef41
* Fri Jan 19 2018 mkubecek@suse.cz
- Update upstream reference:
  patches.drivers/nvme-pci-take-sglist-coalescing-in-dma_map_sg-into-a.patch.
- commit 5fce852
* Fri Jan 19 2018 jkosina@suse.cz
- s390: add ppa to system call and program check path
  (bsc#1068032).
- commit 0642e4e
* Fri Jan 19 2018 jthumshirn@suse.de
- nvme-pci: take sglist coalescing in dma_map_sg into account
  (FATE#323952, FATE#322506).
- commit d73f2b8
* Fri Jan 19 2018 tiwai@suse.de
- Update config files: refresh arm64, ppc64le and s390x configs
  Some configs got removed from default but only in vanilla:
  CONFIG_TREE_RCU_TRACE and CONFIG_PPC_ICSWX*
- commit b9e21dc
* Thu Jan 18 2018 tiwai@suse.de
- Update config files: fix x86_64/vanilla build breakage
- commit 9c77b4d
* Thu Jan 18 2018 bp@suse.de
- x86/pti: Make unpoison of pgd for trusted boot work for real
  (bsc#1068032 CVE-2017-5754).
- blacklist.conf:
- commit 3bf8f4e
* Thu Jan 18 2018 bp@suse.de
- x86,perf: Disable intel_bts when PTI (bsc#1068032
  CVE-2017-5754).
- Update config files.
- x86/pti: Fix !PCID and sanitize defines (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Remove dead logic in pti_user_pagetable_walk*()
  (bsc#1068032 CVE-2017-5754).
- x86/tboot: Unbreak tboot with PTI enabled (bsc#1068032
  CVE-2017-5754).
- x86/tlb: Drop the _GPL from the cpu_tlbstate export (bsc#1068032
  CVE-2017-5754).
- x86/events/intel/ds: Use the proper cache flush method for
  mapping ds buffers (bsc#1068032 CVE-2017-5754).
- x86/pti: Switch to kernel CR3 at early in entry_SYSCALL_compat()
  (bsc#1068032 CVE-2017-5754).
- x86/pti: Make sure the user/kernel PTEs match (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Plug memory leak in error path (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Make the LDT mapping RO (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Allow dumping current pagetables
  (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Check user space page table for WX pages
  (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Add page table directory to the debugfs
  VFS hierarchy (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Add Kconfig (bsc#1068032 CVE-2017-5754).
- x86/dumpstack: Indicate in Oops whether PTI is configured and
  enabled (bsc#1068032 CVE-2017-5754).
- x86/mm: Clarify the whole ASID/kernel PCID/user PCID naming
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Use INVPCID for __native_flush_tlb_single() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Optimize RESTORE_CR3 (bsc#1068032 CVE-2017-5754).
- x86/mm: Use/Fix PCID to optimize user/kernel switches
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Abstract switching CR3 (bsc#1068032 CVE-2017-5754).
- x86/mm: Allow flushing for future ASID switches (bsc#1068032
  CVE-2017-5754).
- x86/pti: Map the vsyscall page if needed (bsc#1068032
  CVE-2017-5754).
- x86/pti: Put the LDT in its own PGD if PTI is on (bsc#1068032
  CVE-2017-5754).
- x86/mm/64: Make a full PGD-entry size hole in the memory map
  (bsc#1068032 CVE-2017-5754).
- x86/events/intel/ds: Map debug buffers in cpu_entry_area
  (bsc#1068032 CVE-2017-5754).
- x86/cpu_entry_area: Add debugstore entries to cpu_entry_area
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Map ESPFIX into user space (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Share entry text PMD (bsc#1068032 CVE-2017-5754).
- irq: Make the irqentry text section unconditional (bsc#1068032
  CVE-2017-5754).
- x86/entry: Align entry text section to PMD boundary (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Share cpu_entry_area with user space page tables
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Force entry through trampoline when PTI active
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Add functions to clone kernel PMDs (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Populate user PGD (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Allocate a separate user PGD (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Allow NX poison to be set in p4d/pgd (bsc#1068032
  CVE-2017-5754).
- x86/mm/pti: Add mapping helper functions (bsc#1068032
  CVE-2017-5754).
- x86/pti: Add the pti= cmdline option and documentation
  (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Add infrastructure for page table isolation
  (bsc#1068032 CVE-2017-5754).
- drivers/misc/intel/pti: Rename the header file to free up the
  namespace (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Prepare the x86/entry assembly code for entry/exit
  CR3 switching (bsc#1068032 CVE-2017-5754).
- x86/mm/pti: Disable global pages if PAGE_TABLE_ISOLATION=y
  (bsc#1068032 CVE-2017-5754).
- x86/cpufeatures: Add X86_BUG_CPU_INSECURE (bsc#1068032
  CVE-2017-5754).
- commit b8791ed
* Thu Jan 18 2018 msuchanek@suse.de
- powerpc/rfi-flush: Add DEBUG_RFI config option (bsc#1068032).
- commit ff01a26
* Thu Jan 18 2018 jroedel@suse.de
- KVM: Fix stack-out-of-bounds read in write_mmio (CVE-2017-17741
  bsc#1073311).
- commit a0834ee
* Thu Jan 18 2018 jroedel@suse.de
- x86/platform/uv/BAU: Replace hard-coded values with MMR
  definitions (bsc#1076263 #fate#322814).
- x86/platform/UV: Fix UV4A BAU MMRs (bsc#1076263 #fate#322814).
- x86/platform/UV: Fix GAM MMR references in the UV x2apic code
  (bsc#1076263 #fate#322814).
- x86/platform/UV: Fix GAM MMR changes in UV4A (bsc#1076263
  [#]fate#322814).
- x86/platform/UV: Add references to access fixed UV4A HUB MMRs
  (bsc#1076263 #fate#322814).
- x86/platform/UV: Update uv_mmrs.h to prepare for UV4A fixes
  (bsc#1076263 #fate#322814).
- commit fe3d886
* Wed Jan 17 2018 mhocko@suse.com
- x86/boot/KASLR: Prefer mirrored memory regions for the kernel
  physical address (bnc#1071680, fate#323473).
- x86/KASLR: Parse all 'memmap=' boot option entries (bnc#1071680,
  fate#323473).
- x86/boot/KASLR: Wrap e820 entries walking code into new function
  process_e820_entries() (bnc#1071680, fate#323473).
- x86/KASLR: Handle the memory limit specified by the 'memmap='
  and 'mem=' boot options (bnc#1071680, fate#323473).
- x86/boot/KASLR: Switch to pass struct mem_vector to
  process_e820_entry() (bnc#1071680, fate#323473).
- x86/boot/KASLR: Rename process_e820_entry() into
  process_mem_region() (bnc#1071680, fate#323473).
- efi: Introduce efi_early_memdesc_ptr to get pointer to memmap
  descriptor (bnc#1071680, fate#323473).
- Refresh
  patches.suse/0003-x86-KASLR-public-the-function-for-getting-random-lon.patch.
- commit 08d4ed7
* Wed Jan 17 2018 msuchanek@suse.de
- Update supported.conf
  + drivers/rpmsg/rpmsg_core
- commit 3bebef7
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/rfi-flush: Make setup_rfi_flush() not __init
  (bsc#1068032).
- commit 475655a
* Wed Jan 17 2018 tiwai@suse.de
- serial: 8250_pci: Add Amazon PCI serial device ID (bsc#1076416).
- commit a5ea307
* Wed Jan 17 2018 tbogendoerfer@suse.de
- net/mlx5: Fix fixpoint divide exception in
  mlx5e_am_stats_compare (bsc#1071289).
- commit 3a609ef
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/pseries: include linux/types.h in asm/hvcall.h
  (bsc#1068032).
- commit cf01f3a
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/64s: Allow control of RFI flush via debugfs (bsc#1068032).
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
  Also remove the sysfs interface of the same now that there is upstream
  solution.
- commit c30bac4
* Wed Jan 17 2018 rjschwei@suse.com
- kernel-obs-build.spec.in: enable xfs module
  This allows the public cloud team to build images with XFS
  as root filesystem
- commit 95a2d6f
* Wed Jan 17 2018 msuchanek@suse.de
- powerpc/xmon: Add RFI flush related fields to paca dump
  (bsc#1068032).
- commit 87bb47e
* Wed Jan 17 2018 msuchanek@suse.de
- macros.kernel-source: pass -f properly in module subpackage (boo#1076393).
- commit 66bd9b8
* Wed Jan 17 2018 oneukum@suse.com
- iwlwifi: pcie: fix DMA memory mapping / unmapping (FATE#322675).
- commit ce89961
* Wed Jan 17 2018 oneukum@suse.com
- Refresh
  patches.drivers/ibmvnic-Fix-pending-MAC-address-changes.patch.
- commit 4c95b8e
* Wed Jan 17 2018 msuchanek@suse.de
- Refresh patches.drivers/ibmvnic-Fix-pending-MAC-address-changes.patch.
  Add commit hash
- commit b83a6a8
* Wed Jan 17 2018 tiwai@suse.de
- ALSA: pcm: Remove yet superfluous WARN_ON() (bsc#1051510).
- commit 10af5fa
* Wed Jan 17 2018 tiwai@suse.de
- ALSA: hda - Apply the existing quirk to iMac 14,1 (bsc#1051510).
- ALSA: hda - Apply headphone noise quirk for another Dell XPS
  13 variant (bsc#1051510).
- commit 82d50bd
* Wed Jan 17 2018 tiwai@suse.de
- Move the sound patch to sorted section
  Also refreshed the upstreamed patch tags
- commit affe9a9
* Wed Jan 17 2018 bp@suse.de
- s390/mm: use generic mm_hooks (bsc#1068032 CVE-2017-5754).
- commit 565b1ca
* Tue Jan 16 2018 bp@suse.de
- Refresh
  patches.arch/21-x86-cpu_entry_area-move-it-to-a-separate-unit.patch.
- commit b987a74
* Tue Jan 16 2018 bp@suse.de
- x86/kaslr: Fix the vaddr_end mess (bsc#1068032 CVE-2017-5754).
- blacklist.conf:
- init: Invoke init_espfix_bsp() from mm_init() (bsc#1068032
  CVE-2017-5754).
- x86/cpu_entry_area: Move it out of the fixmap (bsc#1068032
  CVE-2017-5754).
- x86/cpu_entry_area: Move it to a separate unit (bsc#1068032
  CVE-2017-5754).
- x86/mm: Create asm/invpcid.h (bsc#1068032 CVE-2017-5754).
- x86/mm: Put MMU to hardware ASID translation in one place
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove hard-coded ASID limit checks (bsc#1068032
  CVE-2017-5754).
- x86/mm: Move the CR3 construction functions to tlbflush.h
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Add comments to clarify which TLB-flush functions are
  supposed to flush what (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove superfluous barriers (bsc#1068032 CVE-2017-5754).
- x86/mm: Use __flush_tlb_one() for kernel memory (bsc#1068032
  CVE-2017-5754).
- x86/microcode: Dont abuse the TLB-flush interface (bsc#1068032
  CVE-2017-5754).
- x86/uv: Use the right TLB-flush API (bsc#1068032 CVE-2017-5754).
- x86/entry: Rename SYSENTER_stack to CPU_ENTRY_AREA_entry_stack
  (bsc#1068032 CVE-2017-5754).
- x86/doc: Remove obvious weirdnesses from the x86 MM layout
  documentation (bsc#1068032 CVE-2017-5754).
- x86/mm/64: Improve the memory map documentation (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Prevent LDT inheritance on exec (bsc#1068032
  CVE-2017-5754).
- x86/ldt: Rework locking (bsc#1068032 CVE-2017-5754).
- x86/ldt/64: Refresh DS and ES when modify_ldt changes an entry
  (bsc#1068032 CVE-2017-5754).
- arch, mm: Allow arch_dup_mmap() to fail (bsc#1068032
  CVE-2017-5754).
- x86/vsyscall/64: Warn and fail vsyscall emulation in NATIVE mode
  (bsc#1068032 CVE-2017-5754).
- x86/vsyscall/64: Explicitly set _PAGE_USER in the pagetable
  hierarchy (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Make the address hints correct and
  readable (bsc#1068032 CVE-2017-5754).
- x86/mm/dump_pagetables: Check PAGE_PRESENT for real (bsc#1068032
  CVE-2017-5754).
- commit 7f3f7c7
* Tue Jan 16 2018 tiwai@suse.de
- ALSA: seq: Make ioctls race-free (CVE-2018-1000004,bsc#1076017).
- commit 971e9f4
* Tue Jan 16 2018 msuchanek@suse.de
- scsi: sr: wait for the medium to become ready (bsc#1048585).
- cdrom: wait for tray to close (bsc#1048585).
- cdrom: factor out common open_for_* code (bsc#1048585).
- delay: add poll_event_interruptible (bsc#1048585).
- commit 4aae228
* Tue Jan 16 2018 lpechacek@suse.com
- x86/intel_rdt: Fix a silent failure when writing zero value
  schemata (fate#324327).
- x86/intel_rdt: Add diagnostics when making directories
  (fate#324327).
- x86/intel_rdt: Add diagnostics when writing the cpus file
  (fate#324327).
- x86/intel_rdt: Add diagnostics when writing the tasks file
  (fate#324327).
- x86/intel_rdt: Add diagnostics when writing the schemata file
  (fate#324327).
- x86/intel_rdt: Add framework for better RDT UI diagnostics
  (fate#324327).
- commit 14b8e33
* Tue Jan 16 2018 jslaby@suse.cz
- x86/cpuid: Replace set/clear_bit32() (fate#324438).
- x86/cpufeatures: Enable new SSE/AVX/AVX512 CPU features
  (fate#324438).
- x86/cpuid: Prevent out of bound access in do_clear_cpu_cap()
  (fate#324438).
- x86/cpuid: Add generic table for CPUID dependencies
  (fate#324438).
- commit 02ab826
* Tue Jan 16 2018 jlee@suse.com
- Update config files.
  Disabled CONFIG_EFI_SECURE_BOOT_LOCK_DOWN. (bsc#1075051)
- commit 29e80d3
* Tue Jan 16 2018 mkubecek@suse.cz
- bpf: fix two missing target_size settings in
  bpf_convert_ctx_access (bsc#1073928).
- commit 7f7bbde
* Tue Jan 16 2018 tiwai@suse.de
- Re-sort previous bcache patches in the sorted section
- commit fb5ff24
* Tue Jan 16 2018 colyli@suse.de
- bcache: check return value of register_shrinker (bsc#1076110).
- bcache: recover data from backing when data is clean
  (bsc#1076110, bsc#1043652).
- bcache: Fix building error on MIPS (bsc#1076110).
- bcache: add a comment in journal bucket reading (bsc#1076110).
- bcache: explicitly destroy mutex while exiting (bsc#1076110).
- bcache: fix wrong cache_misses statistics (bsc#1076110).
- bcache: update bucket_in_use in real time (bsc#1076110).
- bcache: convert cached_dev.count from atomic_t to refcount_t
  (bsc#1076110).
- bcache: only permit to recovery read error when cache device
  is clean (bsc#1076110, bsc#1043652).
- bcache: writeback rate clamping: make 32 bit safe (bsc#1076110).
- bcache: safeguard a dangerous addressing in closure_queue
  (bsc#1076110).
- bcache: rearrange writeback main thread ratelimit (bsc#1076110).
- bcache: writeback rate shouldn't artifically clamp
  (bsc#1076110).
- bcache: smooth writeback rate control (bsc#1076110).
- bcache: implement PI controller for writeback rate
  (bsc#1076110).
- bcache: don't write back data if reading it failed (bsc#1076110,
  bsc#1043652).
- bcache: remove unused parameter (bsc#1076110).
- bcache: update bio->bi_opf bypass/writeback REQ_ flag hints
  (bsc#1076110).
- bcache: Remove redundant set_capacity (bsc#1076110).
- bcache: rewrite multiple partitions support (bsc#1076110,
  bsc#1038085).
- bcache: fix a comments typo in bch_alloc_sectors()
  (bsc#1076110).
- bcache: check ca->alloc_thread initialized before wake up it
  (bsc#1076110).
- bcache: Avoid nested function definition (bsc#1076110).
- bcache: use llist_for_each_entry_safe() in __closure_wake_up()
  (bsc#1076110).
- bcache: initialize dirty stripes in flash_dev_run()
  (bsc#1076110).
- bcache: fix bch_hprint crash and improve output (bsc#1076110).
- bcache: Update continue_at() documentation (bsc#1076110).
- bcache: silence static checker warning (bsc#1076110).
- bcache: fix for gc and write-back race (bsc#1076110).
- bcache: increase the number of open buckets (bsc#1076110).
- bcache: Correct return value for sysfs attach errors
  (bsc#1076110).
- bcache: correct cache_dirty_target in __update_writeback_rate()
  (bsc#1076110).
- bcache: gc does not work when triggering by manual command
  (bsc#1076110, bsc#1038078).
- bcache: Don't reinvent the wheel but use existing llist API
  (bsc#1076110).
- bcache: do not subtract sectors_to_gc for bypassed IO
  (bsc#1076110).
- bcache: fix sequential large write IO bypass (bsc#1076110).
- commit 54ef3ac
* Tue Jan 16 2018 colyli@suse.de
- bcache: Fix leak of bdev reference (bsc#1076110).
- commit fbfa4d4
* Tue Jan 16 2018 mkubecek@suse.cz
- Update
  patches.drivers/bpf-don-t-prune-branches-when-a-scalar-is-replaced-w.patch
  references (add CVE-2017-17855 bsc#1073928).
- Update
  patches.drivers/bpf-fix-incorrect-sign-extension-in-check_alu_op.patch
  references (add CVE-2017-16995 bsc#1073928).
- Update
  patches.drivers/bpf-fix-missing-error-return-in-check_stack_boundary.patch
  references (add CVE-2017-17857 bsc#1073928).
- Update
  patches.drivers/bpf-force-strict-alignment-checks-for-stack-pointers.patch
  references (add CVE-2017-17856 bsc#1073928).
- Update
  patches.drivers/bpf-verifier-fix-bounds-calculation-on-BPF_RSH.patch
  references (add CVE-2017-17853 bsc#1073928).
- commit e19e1fe
* Mon Jan 15 2018 bp@suse.de
- x86/mm, KVM: Fix warning when !CONFIG_PREEMPT_COUNT (bsc#1068032
  CVE-2017-5754).
- KVM: nVMX: fix HOST_CR3/HOST_CR4 cache (bsc#1068032
  CVE-2017-5754).
- Refresh
  patches.arch/19-x86-mm-implement-pcid-based-optimization-try-to-preserve-old-tlb-entries-using-pcid.patch.
- Refresh
  patches.arch/23-x86-mm-factor-out-cr3-building-code.patch.
- commit 237ac1a
* Mon Jan 15 2018 bp@suse.de
- x86/mm/64: Fix reboot interaction with CR4.PCIDE (bsc#1068032
  CVE-2017-5754).
- blacklist.conf:
- x86/mm/64: Initialize CR4.PCIDE early (bsc#1068032
  CVE-2017-5754).
- x86/hibernate/64: Mask off CR3's PCID bits in the saved CR3
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Add the 'nopcid' boot option to turn off PCID
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Enable CR4.PCIDE on supported systems (bsc#1068032
  CVE-2017-5754).
- Revert "x86/mm: Stop calling leave_mm() in idle code"
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove debug/x86/tlb_defer_switch_to_init_mm
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Tidy up "x86/mm: Flush more aggressively in lazy TLB
  mode" (bsc#1068032 CVE-2017-5754).
- x86/mm/64: Remove the last VM_BUG_ON() from the TLB code
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Flush more aggressively in lazy TLB mode (bsc#1068032
  CVE-2017-5754).
- x86/mm: Factor out CR3-building code (bsc#1068032
  CVE-2017-5754).
- x86/mm: Get rid of VM_BUG_ON in switch_tlb_irqs_off()
  (bsc#1068032 CVE-2017-5754).
- x86/mm/64: Fix an incorrect warning with CONFIG_DEBUG_VM=y,
  !PCID (bsc#1068032 CVE-2017-5754).
- x86/mm: Reinitialize TLB state on hotplug and resume
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Implement PCID based optimization: try to preserve
  old TLB entries using PCID (bsc#1068032 CVE-2017-5754).
- x86/mm, KVM: Teach KVM's VMX code that CR3 isn't a constant
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Stop calling leave_mm() in idle code (bsc#1068032
  CVE-2017-5754).
- x86/mm: Rework lazy TLB mode and TLB freshness tracking
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove reset_lazy_tlbstate() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Track the TLB's tlb_gen and update the flushing
  algorithm (bsc#1068032 CVE-2017-5754).
- x86/mm: Give each mm TLB flush generation a unique ID
  (bsc#1068032 CVE-2017-5754).
- x86/ldt: Simplify the LDT switching logic (bsc#1068032
  CVE-2017-5754).
- x86/mm: Be more consistent wrt PAGE_SHIFT vs PAGE_SIZE in tlb
  flush code (bsc#1068032 CVE-2017-5754).
- x86/mm: Don't reenter flush_tlb_func_common() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Rework lazy TLB to track the actual loaded mm
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Remove the UP asm/tlbflush.h code, always use the
  (formerly) SMP code (bsc#1068032 CVE-2017-5754).
- x86/mm: Use new merged flush logic in arch_tlbbatch_flush()
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Refactor flush_tlb_mm_range() to merge local and remote
  cases (bsc#1068032 CVE-2017-5754).
- x86/mm: Change the leave_mm() condition for local TLB flushes
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Pass flush_tlb_info to flush_tlb_others() etc
  (bsc#1068032 CVE-2017-5754).
- mm, x86/mm: Make the batched unmap TLB flush API more generic
  (bsc#1068032 CVE-2017-5754).
- x86/mm: Reduce indentation in flush_tlb_func() (bsc#1068032
  CVE-2017-5754).
- x86/mm: Reimplement flush_tlb_page() using flush_tlb_mm_range()
  (bsc#1068032 CVE-2017-5754).
- commit 10bb3d6
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: simplify narrower ctx access (bsc#1073928).
- commit e69d191
* Mon Jan 15 2018 tbogendoerfer@suse.de
- nfp: always unmask aux interrupts at init (bsc#1055968).
- cxgb4: Fix FW flash errors (bsc#1064802 bsc#1066129).
- net/sched: Fix update of lastuse in act modules implementing
  stats_update (bsc#1056787).
- IB/srpt: Fix ACL lookup during login (bsc#1046306 FATE#322942).
- RDMA/netlink: Fix locking around __ib_get_device_by_index
  (bsc#1046306 FATE#322942).
- IB/ipoib: Fix race condition in neigh creation (bsc#1046307
  FATE#322941).
- IB/mlx4: Fix mlx4_ib_alloc_mr error flow (bsc#1046302
  FATE#322945).
- RDMA/cxgb3: remove redundant first assignement of sqp
  (bsc#1046306 FATE#322942).
- commit 861131d
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix integer overflows (CVE-2017-17854 bsc#1073928).
- commit 30aa5d1
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix 32-bit ALU op verification (CVE-2017-17852
  bsc#1073928).
- commit 9e3ea9b
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix incorrect tracking of register size truncation
  (CVE-2017-16996 bsc#1073928).
- commit fcb9274
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: fix branch pruning logic (CVE-2017-17862 CVE-2017-17864
  bsc#1073928).
- commit 72c5166
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: move global verifier log into verifier environment
  (bsc#1073928).
- Refresh
  patches.drivers/bpf-fix-missing-error-return-in-check_stack_boundary.patch.
- Refresh
  patches.drivers/bpf-verifier-fix-bounds-calculation-on-BPF_RSH.patch.
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
- commit be080dc
* Mon Jan 15 2018 mkubecek@suse.cz
- bpf: encapsulate verifier log state into a structure
  (bsc#1073928).
- bpf/verifier: improve disassembly of BPF_NEG instructions
  (bsc#1073928).
- bpf/verifier: improve disassembly of BPF_END instructions
  (bsc#1073928).
- commit 1108f7e
* Mon Jan 15 2018 mkubecek@suse.cz
- Move Spectre BPF fixes into sorted section
- Refresh patches.drivers/bpf-Introduce-bpf_map-ID.patch.
- Refresh
  patches.drivers/bpf-free-up-BPF_JMP-BPF_CALL-BPF_X-opcode.patch.
- Refresh
  patches.suse/bpf-array-fix-overflow-in-max_entries-and-undefined-.patch.
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
  (Strictly speaking, not exactly a refresh as the resulting expanded tree
  differs but I preferred to order the members of struct bpf_map as they are
  in mainline.)
- commit 7834099
* Sat Jan 13 2018 jkosina@suse.cz
- Update config files: run oldconfig on vanilla (HMM merge fallout)
- commit ffda3e4
* Fri Jan 12 2018 bp@suse.de
- x86/dumpstack: Fix partial register dumps (bsc#1068032
  CVE-2017-5754).
- x86/process: Define cpu_tss_rw in same section as declaration
  (bsc#1068032 CVE-2017-5754).
- x86/xen/64: Fix the reported SS and CS in SYSCALL (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Fix entry_SYSCALL_64_after_hwframe() IRQ tracing
  (bsc#1068032 CVE-2017-5754).
- Refresh
  patches.arch/10-x86-dumpstack-handle-stack-overflow-on-all-stacks.patch.
- Refresh
  patches.arch/22-x86-entry-64-make-cpu_entry_area-tss-read-only.patch.
- commit ea8be21
* Fri Jan 12 2018 bp@suse.de
- x86/cpufeatures: Make CPU bugs sticky (bsc#1068032
  CVE-2017-5754).
- x86/paravirt: Provide a way to check for hypervisors
  (bsc#1068032 CVE-2017-5754).
- x86/virt: Add enum for hypervisors to replace x86_hyper
  (bsc#1068032 CVE-2017-5754).
- x86/virt, x86/platform: Merge 'struct x86_hyper' into 'struct
  x86_platform' and 'struct x86_init' (bsc#1068032 CVE-2017-5754).
- x86/paravirt: Dont patch flush_tlb_single (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Make cpu_entry_area.tss read-only (bsc#1068032
  CVE-2017-5754).
- x86/entry: Clean up the SYSENTER_stack code (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Remove the SYSENTER stack canary (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Move the IST stacks into struct cpu_entry_area
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Create a per-CPU SYSCALL entry trampoline
  (bsc#1068032 CVE-2017-5754).
- x86/xen/64: Rearrange the SYSCALL entries (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Return to userspace from the trampoline stack
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Use a per-CPU trampoline stack for IDT entries
  (bsc#1068032 CVE-2017-5754).
- x86/espfix/64: Stop assuming that pt_regs is on the entry stack
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Separate cpu_current_top_of_stack from TSS.sp0
  (bsc#1068032 CVE-2017-5754).
- x86/entry: Remap the TSS into the CPU entry area (bsc#1068032
  CVE-2017-5754).
- x86/entry: Move SYSENTER_stack to the beginning of struct
  tss_struct (bsc#1068032 CVE-2017-5754).
- x86/dumpstack: Handle stack overflow on all stacks (bsc#1068032
  CVE-2017-5754).
- x86/entry: Fix assumptions that the HW TSS is at the beginning
  of cpu_tss (bsc#1068032 CVE-2017-5754).
- x86/mm/fixmap: Generalize the GDT fixmap mechanism, introduce
  struct cpu_entry_area (bsc#1068032 CVE-2017-5754).
- x86/entry/gdt: Put per-CPU GDT remaps in ascending order
  (bsc#1068032 CVE-2017-5754).
- x86/dumpstack: Add get_stack_info() support for the SYSENTER
  stack (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Allocate and enable the SYSENTER stack
  (bsc#1068032 CVE-2017-5754).
- x86/irq/64: Print the offending IP in the stack overflow warning
  (bsc#1068032 CVE-2017-5754).
- x86/unwinder: Handle stack overflows more gracefully
  (bsc#1068032 CVE-2017-5754).
- x86/unwinder/orc: Dont bail on stack overflow (bsc#1068032
  CVE-2017-5754).
- x86/entry/64/paravirt: Use paravirt-safe macro to access eflags
  (bsc#1068032 CVE-2017-5754).
- commit 4ffe4d7
* Fri Jan 12 2018 msuchanek@suse.de
- Refresh patches.arch/powerpc-rfi-flush-Move-the-logic-to-avoid-a-redo-int.patch.
  Add missing hunk
- commit 77b0afb
* Fri Jan 12 2018 jslaby@suse.cz
- bpf, array: fix overflow in max_entries and undefined behavior
  in index_mask (bsc#1068032 CVE-2017-5753).
- commit e1fc2a6
* Fri Jan 12 2018 jthumshirn@suse.de
- s390/disassembler: correct disassembly lines alignment
  (bnc#1072915, LTC#161577).
- commit 588da4b
* Fri Jan 12 2018 msuchanek@suse.de
- powerpc/pseries/rfi-flush: Call setup_rfi_flush() after LPM
  migration (bsc#1068032).
- powerpc/rfi-flush: Move the logic to avoid a redo into the
  sysfs code (bsc#1068032).
- commit 1eb315e
* Fri Jan 12 2018 jthumshirn@suse.de
- s390/pci: handle insufficient resources during dma tlb flush
  (bnc#1072915, LTC#163393).
- s390/disassembler: increase show_code buffer size (bnc#1072915,
  LTC#161577).
- s390/qeth: fix early exit from error path (bnc#1072915,
  LTC#162173).
- s390: fix transactional execution control register handling
  (bnc#1072915, LTC#162116).
- s390/disassembler: add missing end marker for e7 table
  (bnc#1072915, LTC#162117).
- commit aa6f28e
* Fri Jan 12 2018 jthumshirn@suse.de
- dm mpath: Use blk_path_error (FATE#323952, FATE#322506).
- nvme/multipath: Use blk_path_error (FATE#323952, FATE#322506).
- block: Provide blk_status_t decoding for path errors
  (FATE#323952, FATE#322506).
- nvme/multipath: Consult blk_status_t for failover (FATE#323952,
  FATE#322506).
- nvme: Add more command status translation (FATE#323952,
  FATE#322506).
- commit 0e5402c
* Fri Jan 12 2018 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: add Jens Axboe's for-next branch
- commit 07603e6
* Fri Jan 12 2018 hare@suse.de
- nvme_fc: correct hang in nvme_ns_remove() (bsc#1075811).
- nvme_fc: fix rogue admin cmds stalling teardown (bsc#1075811).
- commit 529f10d
* Fri Jan 12 2018 jslaby@suse.cz
- Refresh
  patches.suse/bpf-prevent-out-of-bounds-speculation.patch.
- Delete
  patches.suse/0004-bpf-prevent-speculative-execution-in-eBPF-interprete.patch.
  Update the upstream status of the former.
  And removed the latter as it has been just replaced by the proper
  upstream solution.
- commit c092517
* Fri Jan 12 2018 jthumshirn@suse.de
- nvme: Fix NULL dereference on reservation request (FATE#323952,
  FATE#322506).
- commit 989d61e
* Fri Jan 12 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvme-mpath-fix-last-path-removal-during-traffic.patch.
- commit b181043
* Fri Jan 12 2018 tbogendoerfer@suse.de
- iw_cxgb4: only clear the ARMED bit if a notification is needed
  (bsc#1074762).
- commit c4e49f6
* Fri Jan 12 2018 tiwai@suse.de
- drm/i915/cfl: Adding more Coffee Lake PCI IDs (FATE#322643
  bsc#1055900).
- x86/gpu: add CFL to early quirks (FATE#322643 bsc#1055900).
- drm/i915: Apply Display WA #1183 on skl, kbl, and cfl
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Map VBT DDC Pin to BSpec DDC Pin (FATE#322643
  bsc#1055900).
- drm/i915: Pass encoder type to cnl_ddi_vswing_sequence()
  explicitly (FATE#322643 bsc#1055900).
- drm/i915/kbl: Change a KBL pci id to GT2 from GT1.5 (FATE#322643
  bsc#1055900).
- drm/i915: rework IS_*_GT* macros (FATE#322643 bsc#1055900).
- drm/i915: mark all device info struct with __initconst
  (FATE#322643 bsc#1055900).
- drm/i915: add GT number to intel_device_info (FATE#322643
  bsc#1055900).
- drm/i915: Unify GT* and GT3 definitions (FATE#322643
  bsc#1055900).
- commit 1aca3f9
* Fri Jan 12 2018 msuchanek@suse.de
- ibmvnic: Don't handle RX interrupts when not up (bsc#1075066).
- powerpc/tm: Flush TM only if CPU has TM feature (bsc#1075746).
- commit 10ca720
* Fri Jan 12 2018 tiwai@suse.de
- Delete buggy i915 WA#1133
  Upstream reverted the commit via 7a8b70535037.
- commit f3d58a2
* Fri Jan 12 2018 tbogendoerfer@suse.de
- enic: Add support for 'ethtool -g/-G' (bsc#1037697).
- enic: reset fetch index (bsc#1037697).
- commit 1de5aa3
* Fri Jan 12 2018 jslaby@suse.cz
- bpf: prevent out-of-bounds speculation (bsc#1068032
  CVE-2017-5753).
- Refresh patches.drivers/bpf-Introduce-bpf_map-ID.patch.
- Refresh
  patches.drivers/bpf-free-up-BPF_JMP-BPF_CALL-BPF_X-opcode.patch.
- commit 5e34282
* Thu Jan 11 2018 tbogendoerfer@suse.de
- bnxt_en: Fix the 'Invalid VF' id check in bnxt_vf_ndo_prep
  routine (bsc#1050242 FATE#32291).
- bnxt_en: Fix population of flow_type in
  bnxt_hwrm_cfa_flow_alloc() (bsc#1050242 FATE#32291).
- commit a5c4842
* Thu Jan 11 2018 msuchanek@suse.de
- powerpc/powernv: Check device-tree for RFI flush settings
  (bsc#1068032).
- powerpc/pseries: Query hypervisor for RFI flush settings
  (bsc#1068032).
- powerpc/64s: Support disabling RFI flush with no_rfi_flush
  and nopti (bsc#1068032).
- powerpc/64s: Add support for RFI flush of L1-D cache
  (bsc#1068032).
- powerpc/64s: Convert slb_miss_common to use RFI_TO_USER/KERNEL
  (bsc#1068032).
- powerpc/64: Convert fast_exception_return to use
  RFI_TO_USER/KERNEL (bsc#1068032).
- powerpc/64: Convert the syscall exit path to use
  RFI_TO_USER/KERNEL (bsc#1068032).
- powerpc/64s: Simple RFI macro conversions (bsc#1068032).
- powerpc/64: Add macros for annotating the destination of
  rfid/hrfid (bsc#1068032).
- powerpc/pseries: Add H_GET_CPU_CHARACTERISTICS flags & wrapper
  (bsc#1068032).
- powerpc/64s: masked_interrupt() returns to kernel so avoid
  restoring r13 (bsc#1068032).
- powerpc/64s: Add EX_SIZE definition for paca exception save
  areas (bsc#1068032).
- commit 4d37f12
* Thu Jan 11 2018 msuchanek@suse.de
- ibmvnic: Fix pending MAC address changes (bsc#1075627).
- commit 6c5f5a0
* Thu Jan 11 2018 msuchanek@suse.de
- powerpc/pseries: Make RAS IRQ explicitly dependent on DLPAR WQ
  (FATE#323745, bsc#1067906).
- commit a40c0d4
* Thu Jan 11 2018 mgorman@suse.de
- Refresh
  patches.suse/cpufreq-intel_pstate-Temporarily-boost-P-state-when-exiting-from-idle.patch.
- commit 0b73b50
* Thu Jan 11 2018 tiwai@suse.de
- Refresh patches.drivers/mfd-Add-support-for-Cherry-Trail-Dollar-Cove-TI-PMIC (bsc#1068546)
  Fix the i2c probe due to missing empty table
- commit d3b0394
* Thu Jan 11 2018 lpechacek@suse.com
- rpm/kernel-binary.spec.in: more specific kGraft Provides: (fate#323682)
  Follow openSUSE packaging practices described at
  https://en.opensuse.org/openSUSE:Package_dependencies#Renaming_a_package.
- commit 050081b
* Thu Jan 11 2018 tiwai@suse.de
- ALSA: pcm: Allow aborting mutex lock at OSS read/write loops
  (bsc#1051510).
- ALSA: pcm: Abort properly at pending signal in OSS read/write
  loops (bsc#1051510).
- ALSA: aloop: Fix racy hw constraints adjustment (bsc#1051510).
- ALSA: aloop: Fix inconsistent format due to incomplete rule
  (bsc#1051510).
- ALSA: aloop: Release cable upon open error path (bsc#1051510).
- ALSA: pcm: Add missing error checks in OSS emulation plugin
  builder (bsc#1051510).
- ALSA: pcm: Remove incorrect snd_BUG_ON() usages (bsc#1051510).
- commit e8d347b
* Wed Jan 10 2018 bp@suse.de
- x86/entry/64: Shorten TEST instructions (bsc#1068032
  CVE-2017-5754).
- x86/traps: Use a new on_thread_stack() helper to clean up an
  assertion (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove thread_struct::sp0 (bsc#1068032
  CVE-2017-5754).
- x86/entry/32: Fix cpu_current_top_of_stack initialization at
  boot (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove all remaining direct thread_struct::sp0
  reads (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Stop initializing TSS.sp0 at boot (bsc#1068032
  CVE-2017-5754).
- x86/xen/64, x86/entry/64: Clean up SP code in
  cpu_initialize_context() (bsc#1068032 CVE-2017-5754).
- x86/entry: Add task_top_of_stack() to find the top of a task's
  stack (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Pass SP0 directly to load_sp0() (bsc#1068032
  CVE-2017-5754).
- x86/entry/32: Pull the MSR_IA32_SYSENTER_CS update code out
  of native_load_sp0() (bsc#1068032 CVE-2017-5754).
- x86/entry/64: De-Xen-ify our NMI code (bsc#1068032
  CVE-2017-5754).
- xen, x86/entry/64: Add xen NMI trap entry (bsc#1068032
  CVE-2017-5754).
- x86/xen: Get rid of paravirt op adjust_exception_frame
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove the RESTORE_..._REGS infrastructure
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Use POP instead of MOV to restore regs on NMI
  return (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Merge the fast and slow SYSRET paths (bsc#1068032
  CVE-2017-5754).
- x86/entry/64: Use pop instead of movq in
  syscall_return_via_sysret (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Shrink paranoid_exit_restore and make labels local
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Simplify reg restore code in the standard IRET
  paths (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Move SWAPGS into the common IRET-to-usermode path
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Split the IRET-to-user and IRET-to-kernel paths
  (bsc#1068032 CVE-2017-5754).
- x86/entry/64: Remove the restore_c_regs_and_iret label
  (bsc#1068032 CVE-2017-5754).
- commit 0f7ab23
* Wed Jan 10 2018 tiwai@suse.de
- ACPI / watchdog: Make acpi_has_watchdog() false after failing
  the device creation (bsc#1073960).
- commit c0345e4
* Wed Jan 10 2018 mgorman@suse.de
- Refresh
  patches.suse/cpufreq-intel_pstate-Temporarily-boost-P-state-when-exiting-from-idle.patch.
- commit 7b370e7
* Wed Jan 10 2018 tiwai@suse.de
- Re-enable CONFIG_KEXEC_VERIFY_SIG=y for x86_64 (bsc#1075051)
  It was turned off due to the breakage of kdump in Leap 42.1, but now
  it's mandatory for kexec in secure boot mode.
- commit bb64d0d
* Wed Jan 10 2018 jthumshirn@suse.de
- nvme-mpath: fix last path removal during traffic (FATE#323952,
  FATE#322506).
- commit d221a0c
* Tue Jan  9 2018 lduncan@suse.com
- scsi: libiscsi: Allow sd_shutdown on bad transport
  (bsc#1075234).
- commit 31d7cc7
* Tue Jan  9 2018 tiwai@suse.de
- Update config files: fix arm64/vanilla config
- commit 33b1664
* Tue Jan  9 2018 tiwai@suse.de
- Move upstreamed input and misc driver patches into sorted section
- commit 5b07263
* Tue Jan  9 2018 tiwai@suse.de
- ASoC: atmel-classd: select correct Kconfig symbol (bsc#1051510).
- ASoC: rockchip: disable clock on error (bsc#1051510).
- ASoC: rsnd: ssiu: clear SSI_MODE for non TDM Extended modes
  (bsc#1051510).
- commit 3cec1bc
* Tue Jan  9 2018 tiwai@suse.de
- drm/i915: Protect DDI port to DPLL map from theoretical race
  (bsc#1051510).
- commit c8c45d6
* Tue Jan  9 2018 tbogendoerfer@suse.de
- Revert "mlx5: move affinity hints assignments to generic code"
  (bsc#1046303 FATE#322944 bsc#1075185).
- commit 9ba5d83
* Tue Jan  9 2018 tiwai@suse.de
- Move Wireless driver patches into the sorted section
  Update patch tags accordingly, too.
  Also, correct the bad backport in
  patches.drivers/0001-iwlwifi-mvm-send-all-non-bufferable-frames-on-the-pr
  Refreshed patches:
  patches.drivers/0123-iwlwifi-mvm-map-cab_queue-to-real-one-earlier.patch
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-assoc-response-fr
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-disassoc-frames
  patches.drivers/iwlwifi-pcie-fix-TVQM-queue-ID-range-check
  patches.drivers/iwlwifi-pcie-fix-command-completion-name-debug
  patches.drivers/0001-iwlwifi-mvm-send-all-non-bufferable-frames-on-the-pr.patch
  patches.drivers/0039-iwlwifi-pcie-don-t-init-a-Tx-queue-with-an-SSN-size-.patch
  patches.drivers/0048-iwlwifi-pcie-support-short-Tx-queues-for-A000-device.patch
  patches.drivers/0144-iwlwifi-mvm-send-delba-upon-rx-ba-session-timeout.patch
  patches.drivers/iwlwifi-mvm-fix-a-NULL-pointer-dereference-of-error-
- commit 7a1ea61
* Tue Jan  9 2018 yousaf.kaukab@suse.com
- config: arm64: enable UNMAP_KERNEL_AT_EL0
- commit 6afa3ca
* Tue Jan  9 2018 tiwai@suse.de
- Move DRM/video patches into the sorted section
  Update patch tags accordingly, too.
  Refreshed patches:
  patches.drivers/drm-i915-Always-use-9-bits-of-the-LPC-bridge-device-
  patches.drivers/drm-i915-Fix-PCH-names-for-KBP-and-CNP
  patches.drivers/drm-i915-cfl-Add-Coffee-Lake-PCI-IDs-for-H-Sku
  patches.drivers/drm-i915-cfl-Add-Coffee-Lake-PCI-IDs-for-S-Skus
  patches.drivers/drm-i915-cfl-Add-Coffee-Lake-PCI-IDs-for-U-Sku
  patches.drivers/drm-i915-cfl-Introduce-Coffee-Lake-workarounds
  patches.drivers/drm-i915-cnl-Add-Cannonlake-PCI-IDs-for-U-skus
  patches.drivers/drm-i915-cnl-Fix-the-CURSOR_COEFF_MASK-used-in-DDI-V
  patches.drivers/drm-i915-gen9-Reintroduce-WaEnableYV12BugFixInHalfSl
- commit 415c89f
* Tue Jan  9 2018 yousaf.kaukab@suse.com
- arm64: kaslr: Put kernel vectors address in separate data page
  (bsc#1068032).
- arm64: mm: Introduce TTBR_ASID_MASK for getting at the ASID
  in the TTBR (bsc#1068032).
- arm64: Kconfig: Add CONFIG_UNMAP_KERNEL_AT_EL0 (bsc#1068032).
- arm64: entry: Add fake CPU feature for unmapping the kernel
  at EL0 (bsc#1068032).
- arm64: tls: Avoid unconditional zeroing of tpidrro_el0 for
  native tasks (bsc#1068032).
- arm64: erratum: Work around Falkor erratum #E1003 in trampoline
  code (bsc#1068032).
- arm64: entry: Hook up entry trampoline to exception vectors
  (bsc#1068032).
- arm64: entry: Explicitly pass exception level to kernel_ventry
  macro (bsc#1068032).
- arm64: entry.S: move SError handling into a C function for
  future expansion (bsc#1068032).
- arm64: Mask all exceptions during kernel_exit (bsc#1068032).
- arm64: Move the async/fiq helpers to explicitly set process
  context flags (bsc#1068032).
- arm64: introduce an order for exceptions (bsc#1068032).
- arm64: explicitly mask all exceptions (bsc#1068032).
- arm64: add VMAP_STACK overflow detection (bsc#1068032).
- arm64: add on_accessible_stack() (bsc#1068032).
- arm64: add basic VMAP_STACK support (bsc#1068032).
- arm64: use an irq stack pointer (bsc#1068032).
- arm64: assembler: allow adr_this_cpu to use the stack pointer
  (bsc#1068032).
- arm64: factor out entry stack manipulation (bsc#1068032).
- efi/arm64: add EFI_KIMG_ALIGN (bsc#1068032).
- arm64: move SEGMENT_ALIGN to <asm/memory.h> (bsc#1068032).
- arm64: clean up irq stack definitions (bsc#1068032).
- arm64: clean up THREAD_* definitions (bsc#1068032).
- arm64: factor out PAGE_* and CONT_* definitions (bsc#1068032).
- arm64: kernel: remove {THREAD,IRQ_STACK}_START_SP (bsc#1068032).
- fork: allow arch-override of VMAP stack alignment (bsc#1068032).
- arm64: remove __die()'s stack dump (bsc#1068032).
- arm64: unwind: remove sp from struct stackframe (bsc#1068032).
- arm64: unwind: reference pt_regs via embedded stack frame
  (bsc#1068032).
- arm64: Add dump_backtrace() in show_regs (bsc#1068032).
- arm64: Call __show_regs directly (bsc#1068032).
- arm64: unwind: disregard frame.sp when validating frame pointer
  (bsc#1068032).
- arm64: unwind: avoid percpu indirection for irq stack
  (bsc#1068032).
- arm64: move non-entry code out of .entry.text (bsc#1068032).
- arm64: consistently use bl for C exception entry (bsc#1068032).
- arm64: Add ASM_BUG() (bsc#1068032).
- arm64: mm: Map entry trampoline into trampoline and kernel
  page tables (bsc#1068032).
- arm64: entry: Add exception trampoline page for exceptions
  from EL0 (bsc#1068032).
- arm64: mm: Invalidate both kernel and user ASIDs when performing
  TLBI (bsc#1068032).
- arm64: mm: Add arm64_kernel_unmapped_at_el0 helper
  (bsc#1068032).
- arm64: mm: Allocate ASIDs in pairs (bsc#1068032).
- arm64: mm: Fix and re-enable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Rename post_ttbr0_update_workaround (bsc#1068032).
- arm64: mm: Remove pre_ttbr0_update_workaround for Falkor
  erratum #E1003 (bsc#1068032).
- arm64: context: Fix comments and remove pointless smp_wmb()
  (bsc#1068032).
- arm64: mm: Move ASID from TTBR0 to TTBR1 (bsc#1068032).
- arm64: mm: Temporarily disable ARM64_SW_TTBR0_PAN (bsc#1068032).
- arm64: mm: Use non-global mappings for kernel space
  (bsc#1068032).
- arm64: Move PTE_RDONLY bit handling out of set_pte_at()
  (bsc#1068032).
- arm64: Convert pte handling from inline asm to using (cmp)xchg
  (bsc#1068032).
- arm64: Fix potential race with hardware DBM in
  ptep_set_access_flags() (bsc#1068032).
- commit 0b6ce86
* Tue Jan  9 2018 tbogendoerfer@suse.de
- net/mlx5: Fix misspelling in the error message and comment
  (bsc#1046303 FATE#322944).
- net/mlx4_core: Fix wrong calculation of free counters
  (bsc#1046300 FATE#322946).
- net/mlx4_en: Fix selftest for small MTUs (bsc#1046299
  FATE#322947 Mellanox).
- i40e: fix the calculation of VFs mac addresses (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: only redistribute MSI-X vectors when needed (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- net/mlx4_core: Fix cast warning in fw.c (bsc#1046300
  FATE#322946).
- net/mlx4: Fix endianness issue in qp context params (bsc#1046300
  FATE#322946).
- commit 15cabbf
* Tue Jan  9 2018 jslaby@suse.cz
- userns: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- udf: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- net: mpls: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- fs: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- ipv6: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- ipv4: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- Thermal/int340x: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- cw1200: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- qla2xxx: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- p54: prevent speculative execution (bsc#1068032 CVE-2017-5753).
- carl9170: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- uvcvideo: prevent speculative execution (bsc#1068032
  CVE-2017-5753).
- x86, bpf, jit: prevent speculative execution when JIT is enabled
  (bsc#1068032 CVE-2017-5753).
- bpf: prevent speculative execution in eBPF interpreter
  (bsc#1068032 CVE-2017-5753).
- locking/barriers: introduce new observable speculation barrier
  (bsc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Remove now unused definition of MFENCE_RDTSC
  feature (bsc#1068032 CVE-2017-5753).
- x86/cpu/AMD: Make the LFENCE instruction serialized (bsc#1068032
  CVE-2017-5753).
- commit ee60c7e
* Mon Jan  8 2018 tiwai@suse.de
- x86/mm: Unbreak modules that use the DMA API (bsc#1075052).
- commit 0f06940
* Mon Jan  8 2018 jack@suse.cz
- ext4: Fix ENOSPC handling in DAX page fault handler
  (bsc#1067281).
- dax: Pass detailed error code from dax_iomap_fault()
  (bsc#1067281).
- commit a1646e6
* Mon Jan  8 2018 jthumshirn@suse.de
- bsg-lib: fix use-after-free under memory-pressure (bsc#1074140).
- commit 67cee42
* Mon Jan  8 2018 tbogendoerfer@suse.de
- RDMA/vmw_pvrdma: Avoid use after free due to QP/CQ/SRQ destroy
  (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Use refcount_dec_and_test to avoid warning
  (bsc#1046306 FATE#322942).
- s390/qeth: fix error handling in checksum cmd callback
  (bsc#1061024 FATE#323301).
- s390/qeth: update takeover IPs after configuration change
  (bsc#1061024 FATE#323301).
- s390/qeth: lock IP table while applying takeover changes
  (bsc#1061024 FATE#323301).
- s390/qeth: don't apply takeover changes to RXIP (bsc#1061024
  FATE#323301).
- s390/qeth: apply takeover changes when mode is toggled
  (bsc#1061024 FATE#323301).
- RDMA/vmw_pvrdma: Add shared receive queue support (bsc#1046306
  FATE#322942).
- IB/mlx4: Increase maximal message size under UD QP (bsc#1046302
  FATE#322945).
- IB/mlx5: Assign send CQ and recv CQ of UMR QP (bsc#1046305
  FATE#322943).
- commit 573bb09
* Mon Jan  8 2018 jthumshirn@suse.de
- bsg-lib: fix kernel panic resulting from missing allocation
  of reply-buffer (bsc#1074140).
- commit 707b96d
* Mon Jan  8 2018 jthumshirn@suse.de
- Refresh
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch.
- Delete patches.drivers/nvmet_fc-correct-broken-add_port.patch.
- commit 38a8d6d
* Mon Jan  8 2018 tbogendoerfer@suse.de
- blacklist.conf: mark cd36c3a21a40 as duplicate of 33ba43ed0afc
- commit 08645b1
* Mon Jan  8 2018 tbogendoerfer@suse.de
- bpf: fix incorrect sign extension in check_alu_op()
  (bsc1056787).
- commit 977b7b1
* Mon Jan  8 2018 msuchanek@suse.de
- KVM: PPC: Book3S: fix XIVE migration of pending interrupts
  (bsc#1061840).
- KVM: PPC: Book3S HV: Fix pending_pri value in
  kvmppc_xive_get_icp() (bsc#1061840).
- commit d8d002b
* Mon Jan  8 2018 msuchanek@suse.de
- powerpc/perf/imc: Fix nest-imc cpuhotplug callback failure
  (bsc#1054914).
- powerpc/perf: Fix kfree memory allocated for nest pmus
  (bsc#1054914).
- cxl: Check if vphb exists before iterating over AFU devices
  (bsc#1055014).
- commit 61c1d48
* Mon Jan  8 2018 msuchanek@suse.de
- powerpc/perf: Dereference BHRB entries safely (bsc#1065729).
- commit 57f8b50
* Mon Jan  8 2018 tbogendoerfer@suse.de
- net/mlx5: Stay in polling mode when command EQ destroy fails
  (bsc#1046303 FATE#322944).
- net/mlx5: Cleanup IRQs in case of unload failure (bsc#1046303
  FATE#322944).
- net/mlx5e: Prevent possible races in VXLAN control flow
  (bsc#1046303 FATE#322944).
- net/mlx5e: Add refcount to VXLAN structure (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix possible deadlock of VXLAN lock (bsc#1046303
  FATE#322944).
- socket, bpf: fix possible use after free (bsc1056787).
- commit e08b924
* Mon Jan  8 2018 tbogendoerfer@suse.de
- net_sched: fix a compile warning in act_ife (bsc1056787).
- commit bd78fe1
* Mon Jan  8 2018 tbogendoerfer@suse.de
- crypto: chelsio - select CRYPTO_GF128MUL (bsc#1046548).
- net: sched: fix static key imbalance in case of
  ingress/clsact_init error (bsc1056787).
- net_sched: red: Avoid illegal values (bsc1056787).
- net: sched: cbq: create block for q->link.block (bsc1056787).
- net: sched: fix crash when deleting secondary chains
  (bsc1056787).
- net sched actions: fix module auto-loading (bsc1056787).
- net sched actions: change IFE modules alias names (bsc1056787).
- net_sched: gen_estimator: fix scaling error in bytes/packets
  samples (bsc1056787).
- net sched actions: Use proper root attribute table for actions
  (bsc1056787).
- commit 2bbf18d
* Mon Jan  8 2018 ohering@suse.de
- scsi: storvsc: Fix scsi_cmd error assignments in
  storvsc_handle_error (fate#323887).
- vmbus: unregister device_obj->channels_kset (fate#323887).
- hv: kvp: Avoid reading past allocated blocks from KVP file
  (fate#323887).
- Drivers: hv: vmbus: Fix a rescind issue (fate#323887).
- commit 12ffd27
* Mon Jan  8 2018 msuchanek@suse.de
- kernel-obs-build.spec.in: add --no-hostonly-cmdline to dracut invocation (boo#1062303).
  call dracut with --no-hostonly-cmdline to avoid the random rootfs UUID
  being added into the initrd's /etc/cmdline.d/95root-dev.conf
- commit da5186f
* Mon Jan  8 2018 mgorman@suse.de
- cpufreq: intel_pstate: Temporarily boost P-state when exiting
  from idle (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- commit 3b0b990
* Mon Jan  8 2018 mgorman@suse.de
- Refresh
  patches.suse/mm-page_alloc.c-avoid-excessive-IRQ-disabled-times-in-free_unref_page_list.patch.
- commit fcb0706
* Sun Jan  7 2018 lduncan@suse.com
- X.509: fix buffer overflow detection in sprint_oid()
  (bsc#1074877).
- 509: fix printing uninitialized stack memory when OID is empty
  (bsc#1074879).
- KEYS: add missing permission check for request_key() destination
  (bsc#1074878).
- KEYS: trusted: fix writing past end of buffer in trusted_read()
  (bsc#1074880).
- KEYS: encrypted: fix dereference of NULL user_key_payload
  (bsc#1074876).
- commit 3160a2d
* Sat Jan  6 2018 jslaby@suse.cz
- rpm/constraints.in: lower kernel-syzkaller's mem requirements
  OBS now reports that it needs only around 2G, so lower the limit to
  8G, so that more compliant workers can be used.
- commit a73399a
* Sat Jan  6 2018 jbohac@suse.cz
- Remove patches.arch/x86_64-hpet-64bit-timer.patch.
  This is an ancient patch we should have never included in the first place. It
  adds a command-line  parameter "hpet64" which works around a hardware "bug" that
  is only visible if applications mmap HPET.
  The bug makes the HPET main counter wrap at the 32 bit boundary when Timer 0 is
  used in 32 bit mode.
  Thomas Gleixner refused the patch upstream, he claims this does not work on
  some HPETs: https://patchwork.kernel.org/patch/10103049/
  If someone insists on accessing the hardware directly, they should deal with
  hardware oddities.
- commit 20efbd0
* Fri Jan  5 2018 lhenriques@suse.com
- regulator: da9063: Return an error code on probe failure
  (bsc#1074847).
- commit ca048fa
* Fri Jan  5 2018 tbogendoerfer@suse.de
- IB/mlx5: Serialize access to the VMA list (bsc#1046305
  FATE#322943).
- RDMA/vmw_pvrdma: Call ib_umem_release on destroy QP path
  (bsc#1046306 FATE#322942).
- iw_cxgb4: when flushing, complete all wrs in a chain
  (bsc#1046543 FATE#322927).
- bpf: force strict alignment checks for stack pointers
  (bsc#1056787).
- net/mlx5: Fix error flow in CREATE_QP command (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix defaulting RX ring size when not needed
  (bsc#1046303 FATE#322944).
- bpf, ppc64: do not reload skb pointers in non-skb context
  (bsc#1056787).
- bpf, s390x: do not reload skb pointers in non-skb context
  (bsc#1056787).
- net/mlx5e: Add support for ethtool msglvl support (bsc#1046303
  FATE#322944).
- commit d4fe50f
* Fri Jan  5 2018 tbogendoerfer@suse.de
- cxgb4: collect TX rate limit info in UP CIM logs (bsc#1073513).
- cxgb4: RSS table is 4k for T6 (bsc#1073513).
- cxgb4: collect PCIe configuration logs (bsc#1073513).
- cxgb4: collect egress and ingress SGE queue contexts
  (bsc#1073513).
- cxgb4: skip TX and RX payload regions in memory dumps
  (bsc#1073513).
- cxgb4: collect HMA memory dump (bsc#1073513).
- cxgb4: collect MC memory dump (bsc#1073513).
- cxgb4: collect on-chip memory information (bsc#1073513).
- commit 5208a72
* Fri Jan  5 2018 mgorman@suse.de
- cpufreq, intel_pstate: Update setpoint for unspecified ACPI
  profile (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- commit 61ed90d
* Fri Jan  5 2018 ghe@suse.com
- dlm: recheck kthread_should_stop() before schedule()
  (bsc#1071422).
- commit ecebdc2
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix NULL pointer dereference in send_to_sock()
  (bsc#1074590).
- commit 33ddb10
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix to reschedule rwork (bsc#1074590).
- commit e8637ae
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix to use sk_callback_lock correctly (bsc#1074590).
- commit 710c4fa
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix overflow dlm_cb_seq (bsc#1074590).
- commit 09372fc
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix memory leak in tcp_accept_from_sock() (bsc#1074590).
- commit 5aedf91
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix conversion deadlock when DLM_LKF_NODLCKWT flag is set
  (bsc#1074590).
- commit 69894be
* Fri Jan  5 2018 ghe@suse.com
- DLM: use CF_CLOSE flag to stop dlm_send correctly (bsc#1074590).
- commit e8a6712
* Fri Jan  5 2018 ghe@suse.com
- DLM: Reanimate CF_WRITE_PENDING flag (bsc#1074590).
- commit a4de653
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix race condition between dlm_recoverd_stop and
  dlm_recoverd (bsc#1074590).
- commit 819a622
* Fri Jan  5 2018 ghe@suse.com
- DLM: close othercon at send/receive error (bsc#1074590).
- commit 0937fb9
* Fri Jan  5 2018 ghe@suse.com
- DLM: retry rcom when dlm_wait_function is timed out
  (bsc#1074590).
- commit c842f52
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix to use sock_mutex correctly in xxx_accept_from_sock
  (bsc#1074590).
- commit 78dd4c6
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix race condition between dlm_send and dlm_recv
  (bsc#1074590).
- commit 11bc1dd
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix double list_del() (bsc#1074590).
- commit a0f2a2c
* Fri Jan  5 2018 ghe@suse.com
- DLM: fix remove save_cb argument from add_sock() (bsc#1074590).
- commit 4b9a8d1
* Fri Jan  5 2018 ghe@suse.com
- DLM: Fix saving of NULL callbacks (bsc#1074590).
- commit 59e7b7b
* Fri Jan  5 2018 ghe@suse.com
- DLM: Eliminate CF_WRITE_PENDING flag (bsc#1074590).
- commit 28eba49
* Fri Jan  5 2018 ghe@suse.com
- DLM: Eliminate CF_CONNECT_PENDING flag (bsc#1074590).
- commit 367693f
* Fri Jan  5 2018 ghe@suse.com
- dlm: remove this patch temporarily
  since I plan to back-port valuable patches of DLM dlm-4.15 to SLE15
  kernel source, but this patch will impact more older patches to
  apply SLE15 kernel. So, I will remove this patch temporarily,
  then get this patch back after this back-port is done.
- commit 70cb39a
* Fri Jan  5 2018 lduncan@suse.com
- scsi: libcxgbi: simplify task->hdr allocation for mgmt cmds
  (bsc#1073515).
- scsi: cxgb4i: fix Tx skb leak (bsc#1073515).
- commit c19f0ba
* Fri Jan  5 2018 lduncan@suse.com
- Fixed incorrect commit for nvmet-fc patch.
  The commits seems to be incorrect for
  patches.drivers/nvmet-fc-cleanup-nvmet-add_port-remove_port.patch,
  perhaps because of upstream merging? Set it to the
  correct commit.
- commit 3e2aa51
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Avoid invalid lockdep class warning (bsc#1051510).
- commit 1d6dc29
* Thu Jan  4 2018 ghe@suse.com
- dlm: use sock_create_lite inside tcp_accept_from_sock
  (bsc#1069364).
- commit 8b8e456
* Thu Jan  4 2018 neilb@suse.com
- sunrpc: use supplimental groups in auth hash (bsc#1012917).
- commit 9a10aa8
* Thu Jan  4 2018 neilb@suse.com
- kernel: make groups_sort calling a responsibility group_info
  allocators (bsc#1070623).
- commit de0ae1a
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda: Drop useless WARN_ON() (bsc#1051510).
- commit f2fb93c
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: twl4030: fix child-node lookup (bsc#1051510).
- commit 69b6ece
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: tlv320aic31xx: Fix GPIO1 register definition
  (bsc#1051510).
- commit 11c73a1
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: codecs: msm8916-wcd: Fix supported formats (bsc#1051510).
- commit 374ba25
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: fsl_ssi: AC'97 ops need regmap, clock and cleaning up
  on failure (bsc#1051510).
- commit dcacf0c
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: da7218: fix fix child-node lookup (bsc#1051510).
- commit e945eac
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: wm_adsp: Fix validation of firmware and coeff lengths
  (bsc#1051510).
- commit 51a0c9c
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Fix the missing ctl name suffix at parsing SU
  (bsc#1051510).
- commit 563b896
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: rawmidi: Avoid racy info ioctl via ctl device
  (bsc#1051510).
- commit 9c189e8
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - Add vendor id for Cannonlake HDMI codec
  (bsc#1051510).
- commit e971433
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Add native DSD support for Esoteric D-05X
  (bsc#1051510).
- commit 4d85d23
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: pcm: prevent UAF in snd_pcm_info (bsc#1051510).
- commit 25f7384
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Add check return value for usb_string()
  (bsc#1051510).
- commit 3171828
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Fix out-of-bound error (bsc#1051510).
- commit 6578e73
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Remove spurious WARN_ON() at timer check
  (bsc#1051510).
- commit fc7e398
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - fix headset mic problem for Dell machines with
  alc274 (bsc#1051510).
- commit d23de14
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Fix OSS sysex delivery in OSS emulation
  (bsc#1051510).
- commit 510ff99
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: timer: Limit max instances per timer (bsc#1051510).
- commit 103491e
* Thu Jan  4 2018 tiwai@suse.de
- ASoC: adau17x1: Workaround for noise bug in ADC (bsc#1051510).
- commit 85fa8c4
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Fix nested rwsem annotation for lockdep splat
  (bsc#1051510).
- commit fa3fd1f
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Enable 'use' locking in all configurations
  (bsc#1051510).
- commit 655ae8d
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usb-audio: Add native DSD support for Pro-Ject Pre Box
  S2 Digital (bsc#1051510).
- commit 6cd87cf
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: caiaq: Fix stray URB at probe error path (bsc#1051510).
- commit 43475d3
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: seq: Fix copy_from_user() call inside lock (bsc#1051510).
- commit 2297056
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: usx2y: Suppress kernel warning at page allocation failures
  (bsc#1051510).
- commit 13eccc1
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - Add MIC_NO_PRESENCE fixup for 2 HP machines
  (bsc#1051510).
- commit 81dfa71
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - Fix missing COEF init for ALC225/295/299
  (bsc#1051510).
- commit a3ae07c
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - change the location for one mic on a Lenovo machine
  (bsc#1051510).
- commit 53462d1
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda - fix headset mic detection issue on a Dell machine
  (bsc#1051510).
- commit ec4781a
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda/realtek - Fix Dell AIO LineOut issue (bsc#1051510).
- commit 4de0a3d
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda/realtek - New codec support for ALC257 (bsc#1051510).
- commit c025c50
* Thu Jan  4 2018 tiwai@suse.de
- ALSA: hda/realtek - Add support for ALC1220 (bsc#1051510).
- commit cd79b10
* Thu Jan  4 2018 tiwai@suse.de
- Move upstreamed sound patches into sorted section
- commit 2f5f898
* Wed Jan  3 2018 mgorman@suse.de
- rcu: Remove debugfs tracing (bnc#1073315 remove defunct
  debugfs tracing).
- commit 761bb8f
* Wed Jan  3 2018 mbenes@suse.cz
- livepatch: Mark the kernel unsupported when disabling a live
  patch (fate#323487).
- commit 38cb6c2
* Wed Jan  3 2018 ghe@suse.com
- dlm: Make dismatch error message more clear (bsc#1074440).
- commit 47fea46
* Wed Jan  3 2018 mgalbraith@suse.de
- sched/rt: Do not pull from current CPU if only one CPU to pull
  (bnc#1022476).
- sched/rt: Simplify the IPI based RT balancing logic
  (bnc#1022476).
- commit 2c0bd50
* Tue Jan  2 2018 tbogendoerfer@suse.de
- IB/mlx5: Fix mlx5_ib_alloc_mr error flow (bsc#1046303
  FATE#322944).
- IB/core: Verify that QP is security enabled in create and
  destroy (bsc#1046306 FATE#322942).
- IB/uverbs: Fix command checking as part of
  ib_uverbs_ex_modify_qp() (bsc#1046306 FATE#322942).
- IB/hfi: Only read capability registers if the capability exists
  (bsc#1060463 FATE#323043).
- IB/mlx5: Fix congestion counters in LAG mode (bsc#1046303
  FATE#322944).
- iw_cxgb4: reflect the original WR opcode in drain cqes
  (bsc#1064802 bsc#1066129).
- bpf: don't prune branches when a scalar is replaced with a
  pointer (bsc#1056787).
- bpf: fix missing error return in check_stack_boundary()
  (bsc#1056787).
- bpf/verifier: fix bounds calculation on BPF_RSH (bsc#1056787).
- net/mlx5e: Fix features check of IPv6 traffic (bsc#1046305
  FATE#322943).
- net/mlx5: Fix rate limit packet pacing naming and struct
  (bsc#1046305 FATE#322943).
- net/mlx5: FPGA, return -EINVAL if size is zero (bsc#1046303
  FATE#322944).
- net/mlx4_en: Fill all counters under one call of stats lock
  (bsc#1046299 FATE#322947).
- commit 9946ea4
* Tue Jan  2 2018 ghe@suse.com
- ocfs2: fix a static checker warning (bsc#1074282).
- commit 691c72c
* Mon Jan  1 2018 bpoirier@suse.com
- git-sort tests wip
- commit fac0c20
* Thu Dec 28 2017 acho@suse.com
- Bluetooth: Prevent stack info leak from the EFS element
  (bsc#1070535 CVE-2017-1000410).
- commit 0214ec3
* Wed Dec 27 2017 bpoirier@suse.com
- git_sort: Use pygit2 to read git config.
  Fixes an error when operating on a repository with no configured remotes.
- commit f28d0a2
* Tue Dec 26 2017 bpoirier@suse.com
- scripts/git_sort/README.md: Add information about quilt package.
- commit 41d89b6
* Tue Dec 26 2017 bpoirier@suse.com
- scripts/git-pre-commit: Specify paths to check to git diff.
  Also, specifically check for changes between the index and HEAD (--cached).
- commit 2450ed3
* Tue Dec 26 2017 dbueso@suse.de
- Delete patches.fixes/0001-autofs-fix-AT_NO_AUTOMOUNT-not-being-honored.patch.
  Per upstream commit:
    5d38f049cee (autofs: revert "autofs: fix AT_NO_AUTOMOUNT not being honored")
- commit ed5935d
* Tue Dec 26 2017 dbueso@suse.de
- blacklist.conf: we don't build null_blk module
- commit bb0a8a8
* Tue Dec 26 2017 dbueso@suse.de
- block: unalign call_single_data in struct request (bsc#1050549).
- commit 5e7d58d
* Tue Dec 26 2017 bpoirier@suse.com
- git_sort: Support configurable cache path.
  Also, create the cache directory if it does not exist.
- commit db0e54d
* Mon Dec 25 2017 bpoirier@suse.com
- series_sort: Catch pygit2 import failure.
  Provide some instructions about how to install the module in the README.
  Note that this only catches the exception from series_sort.py. There are
  other executable python scripts which import pygit2 and those will still
  raise an ImportError if the pygit2 module is not available. However,
  series_sort.py is the most common entry point for new users.
- commit 3c7e689
* Fri Dec 22 2017 jthumshirn@suse.de
- nvmet_fc: correct broken add_port (bsc#1072553).
- commit cc3e8db
* Fri Dec 22 2017 bpoirier@suse.com
- e1000e: Fix e1000_check_for_copper_link_ich8lan return value
  (bsc#1073809).
- e1000e: Avoid receiver overrun interrupt bursts (bsc#1073809).
- e1000e: Separate signaling for link check/link up (bsc#1073809).
- e1000e: Fix return value test (bsc#1073809).
- e1000e: Fix wrong comment related to link detection
  (bsc#1073809).
- e1000e: Fix error path in link detection (bsc#1073809).
- commit 6843b8f
* Fri Dec 22 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 45e9108
* Fri Dec 22 2017 msuchanek@suse.de
- ibmvnic: Include header descriptor support for ARP packets
  (bsc#1073912).
- ibmvnic: Increase maximum number of RX/TX queues (bsc#1073912).
- ibmvnic: Rename IBMVNIC_MAX_TX_QUEUES to IBMVNIC_MAX_QUEUES
  (bsc#1073912).
- commit e6d9f08
* Fri Dec 22 2017 msuchanek@suse.de
- Refresh sorted section.
- commit 08f400d
* Thu Dec 21 2017 mbenes@suse.cz
- Delete
  patches.suse/0002-module-move-add_taint_module-to-a-header-file.patch.
  kGraft-specific patch not needed with upstream livepatch. We have
  add_taint_module() call in kernel/module.c (upstream commit 2992ef29ae01
  ("livepatch/module: make TAINT_LIVEPATCH module-specific")).
- commit cfddc2c
* Thu Dec 21 2017 tbogendoerfer@suse.de
- bnxt_en: Uninitialized variable in bnxt_tc_parse_actions()
  (bsc#1050242 FATE#322914).
- bnxt_en: Add ETH_RESET_AP support (bsc#1050242 FATE#322914).
- commit a2af10c
* Thu Dec 21 2017 tbogendoerfer@suse.de
- drivers: net: bnxt: use setup_timer() helper (bsc#1050242
  FATE#322914).
- Refresh
  patches.drivers/bnxt_en-Reorganize-the-coalescing-parameters.patch.
- commit a924173
* Thu Dec 21 2017 tiwai@suse.de
- crypto: hmac - require that the underlying hash algorithm is
  unkeyed (CVE-2017-17806,bsc#1073874).
- commit ab2ecae
* Thu Dec 21 2017 tiwai@suse.de
- crypto: salsa20 - fix blkcipher_walk API usage
  (CVE-2017-17805,bsc#1073792).
- commit 81ba0ab
* Thu Dec 21 2017 tbogendoerfer@suse.de
- bnxt_en: Use NETIF_F_GRO_HW (bsc#1050242 FATE#322914).
- net: Disable GRO_HW when generic XDP is installed on a device
  (bsc#1050242 FATE#322914).
- net: Introduce NETIF_F_GRO_HW (bsc#1050242 FATE#322914).
- net: ethtool: add support for reset of AP inside NIC interface
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix sources of spurious netpoll warnings (bsc#1050242
  FATE#322914).
- bnxt_en: fix dst/src fid for vxlan encap/decap actions
  (bsc#1050242 FATE#322914).
- bnxt_en: wildcard smac while creating tunnel decap filter
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix an error handling path in
  'bnxt_get_module_eeprom()' (bsc#1050242 FATE#322914).
- bnxt_re: Make room for mapping beyond 32 entries (bsc#1050242
  FATE#322914).
- bnxt: fix bnxt_hwrm_fw_set_time for y2038 (bsc#1050242
  FATE#322914).
- bnxt_en: Fix IRQ coalescing regression (bsc#1050242
  FATE#322914).
- bnxt_en: fix typo in bnxt_set_coalesce (bsc#1050242
  FATE#322914).
- bnxt_en: Fix randconfig build errors (bsc#1050242 FATE#322914).
- bnxt_en: alloc tc_info{} struct only when tc flower is enabled
  (bsc#1050242 FATE#322914).
- bnxt_en: query cfa flow stats periodically to compute 'lastused'
  attribute (bsc#1050242 FATE#322914).
- bnxt_en: add hwrm FW cmds for cfa_encap_record and decap_filter
  (bsc#1050242 FATE#322914).
- bnxt_en: add support for Flower based vxlan encap/decap offload
  (bsc#1050242 FATE#322914).
- bnxt_en: Refactor and simplify coalescing code (bsc#1050242
  FATE#322914).
- bnxt_en: Reorganize the coalescing parameters (bsc#1050242
  FATE#322914).
- bnxt_en: Add ethtool reset method (bsc#1050242 FATE#322914).
- bnxt_en: Check maximum supported MTU from firmware (bsc#1050242
  FATE#322914).
- bnxt_en: Optimize .ndo_set_mac_address() for VFs (bsc#1050242
  FATE#322914).
- bnxt_en: Get firmware package version one time (bsc#1050242
  FATE#322914).
- bnxt_en: Check for zero length value in bnxt_get_nvram_item()
  (bsc#1050242 FATE#322914).
- bnxt_en: adding PCI ID for SMARTNIC VF support (bsc#1050242
  FATE#322914).
- bnxt_en: Add PCIe device ID for bcm58804 (bsc#1050242
  FATE#322914).
- bnxt_en: Update firmware interface to 1.8.3.1 (bsc#1050242
  FATE#322914).
- bnxt: Move generic devlink code to new file (bsc#1050242
  FATE#322914).
- bnxt_en: don't consider building bnxt_tc.o if option not enabled
  (bsc#1050242 FATE#322914).
- bnxt_en: Remove redundant unlikely() (bsc#1050242 FATE#322914).
- net: add new netdevice feature for offload of RX port for UDP
  tunnels (bsc#1056787).
- commit 8a8e435
* Thu Dec 21 2017 msuchanek@suse.de
- kernel-obs-build: use pae and lpae kernels where available
  (bsc#1073579).
- commit 1ac1946
* Thu Dec 21 2017 tiwai@suse.de
- Disable CONFIG_SPI_INTEL_SPI_PLATFORM for BIOS breakge on Lenovo laptops
  (bsc#1073836)
- commit 47130d8
* Wed Dec 20 2017 dbueso@suse.de
- epoll: remove ep_call_nested() from ep_eventpoll_poll()
  (bsc#1056427).
- epoll: avoid calling ep_call_nested() from ep_poll_safewake()
  (bsc#1056427).
- locking/qrwlock: Prevent slowpath writers getting held up by
  fastpath (bsc#1050549).
- locking/qrwlock: Use atomic_cond_read_acquire() when spinning
  in qrwlock (bsc#1050549).
- locking/qrwlock: Use 'struct qrwlock' instead of 'struct
  __qrwlock' (bsc#1050549).
- locking/atomic: Add atomic_cond_read_acquire() (bsc#1050549).
- commit f353922
* Wed Dec 20 2017 msuchanek@suse.de
- Refresh patches.arch/powerpc-64s-Implement-system-reset-idle-wakeup-reason.patch.
- commit 2e65242
* Wed Dec 20 2017 msuchanek@suse.de
- powerpc/64s: Fix Power9 DD2.1 logic in DT CPU features
  (bsc#1055121).
- powerpc/64s: Fix Power9 DD2.0 workarounds by adding DD2.1
  feature (bsc#1055121).
- powerpc/64s/idle: avoid POWER9 DD1 and DD2.0 PMU workaround
  on DD2.1 (bsc#1055121).
- powerpc/powernv: Save/Restore additional SPRs for stop4 cpuidle
  (bsc#1055121).
- powerpc/64s/idle: avoid POWER9 DD1 and DD2.0 ERAT workaround
  on DD2.1 (bsc#1055121).
- powerpc/64s: idle POWER9 can execute stop in virtual mode
  (bsc#1055121).
- powerpc/64s: Drop no longer used IDLE_STATE_ENTER_SEQ
  (bsc#1055121).
- powerpc/64s: POWER9 can execute stop without a sync sequence
  (bsc#1055121).
- powerpc/64s: Move IDLE_STATE_ENTER_SEQ[_NORET] into
  idle_book3s.S (bsc#1055121).
- powerpc/powernv/idle: Clear r12 on wakeup from stop lite
  (bsc#1055121).
- powerpc/64s/idle: Avoid SRR usage in idle sleep/wake paths
  (bsc#1055121).
- powerpc: add POWER9_DD20 feature (bsc#1055121).
- powerpc/64: Free up CPU_FTR_ICSWX (bsc#1055121).
- commit 9dfdd40
* Wed Dec 20 2017 tiwai@suse.de
- Update config files: Fix ppc64le vanilla config
- commit 410ed34
* Wed Dec 20 2017 msuchanek@suse.de
- powerpc: conditionally compile platform-specific serial drivers
  (bsc#1065729).
- tpm: ibmvtpm: simplify crq initialization and document crq
  format (bsc#1065729).
- commit d8d888e
* Wed Dec 20 2017 msuchanek@suse.de
- supported.conf: add missing modules.
  Changed:
  crypto/aes_generic -> crypto/aes_ti
  drivers/scsi/ibmvscsi/ibmvstgt -> drivers/scsi/ibmvscsi_tgt/ibmvscsis
  New modules:
  arch/powerpc/crypto/crc32c-vpmsum
  drivers/tty/serial/8250/8250_of
  - drivers/char/powernv-op-panel
  Add core/lib:
  drivers/char/tpm/tpm_tis_core
  drivers/pci/hotplug/pnv-php
  lib/parman
- commit d4b29da
* Wed Dec 20 2017 msuchanek@suse.de
- supported.conf: remove garbage.
- commit 1ce25e4
* Wed Dec 20 2017 sparschauer@suse.de
- scsi_scan: Exit loop if TUR to LUN0 fails with 0x05/0x25 (bsc#1063043).
  This is specific to FUJITSU ETERNUS_DX* targets. They can return
  "Illegal Request - Logical unit not supported" and processing should
  leave the timeout loop in this case.
- commit c16da9f
* Wed Dec 20 2017 jkosina@suse.cz
- README.BRANCH: Add Takashi as a temporary co-maintainer. Thanks Takashi!
- commit 076bb17
* Wed Dec 20 2017 neilb@suse.com
- NFS: Fix uninitialized rpc_wait_queue (git-fixes).
- xprtrdma: Throw away reply when version is unrecognized
  (git-fixes).
- svcrdma: Preserve CB send buffer across retransmits (git-fixes).
- commit 3eac6c0
* Tue Dec 19 2017 neilb@suse.com
- blacklist.conf: mark 11e3e8d6d927 not-applicable
- commit 250f889
* Tue Dec 19 2017 neilb@suse.com
- autofs: fix careless error in recent commit (bnc#1012382
  bsc#1065180).
- NFS: revalidate "." etc correctly on "open" (git-fixes).
- commit 4c82a6d
* Tue Dec 19 2017 msuchanek@suse.de
- powerpc/64s: Fix hypercall entry clobbering r12 input
  (bsc#1055117).
- powerpc/64s: Optimize hypercall/syscall entry (bsc#1055117).
- commit 0ca40fc
* Tue Dec 19 2017 jkosina@suse.cz
- README.BRANCH: add Takashi as comaintainer
- commit d7552c3
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix migration and HPT resizing of HPT
  guests on radix hosts (bsc#1061840).
- KVM: PPC: Book3S HV: Add infrastructure for running HPT guests
  on radix host (bsc#1061840).
- KVM: PPC: Book3S HV: Unify dirty page map between HPT and radix
  (bsc#1061840).
- commit 51c7c60
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Rename hpte_setup_done to mmu_ready (bsc#1061840).
- Refresh patches.arch/KVM-PPC-Book3S-HV-Fix-exclusion-between-HPT-resizing.patch.
- commit 052b912
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Tie KVM_CAP_PPC_HTM to the user-visible TM feature (bsc#1061840).
- Refresh patches.arch/KVM-PPC-Fix-oops-when-checking-KVM_CAP_PPC_HTM.patch.
- commit 9c0b1aa
* Tue Dec 19 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't rely on host's page size information
  (bsc#1061840).
- KVM: PPC: Book3S HV: Explicitly disable HPT operations on
  radix guests (bsc#1061840).
- KVM: PPC: Book3S HV: Fix memory leak in kvm_vm_ioctl_get_htab_fd
  (bsc#1061840).
- KVM: PPC: Book3S HV: Report storage key support to userspace
  (bsc#1061840).
- commit 1a88a98
* Tue Dec 19 2017 bp@suse.de
- x86/ACPI/cstate: Allow ACPI C1 FFH MWAIT use on AMD systems
  (bsc#1069881).
- commit 8e6ab6a
* Tue Dec 19 2017 lhenriques@suse.com
- ceph: drop negative child dentries before try pruning inode's
  alias (bsc#1073525).
- commit aeb9e15
* Mon Dec 18 2017 jlee@suse.com
- Update config files.
  Enabling hibernation verification.
- commit 490e23f
* Mon Dec 18 2017 jack@suse.cz
- fanotify: fix fsnotify_prepare_user_wait() failure
  (bsc#1052766).
- commit 080b493
* Mon Dec 18 2017 jack@suse.cz
- mm/frame_vector.c: release a semaphore in 'get_vaddr_frames()'
  (bsc#1052766).
- commit e8d4b10
* Mon Dec 18 2017 jlee@suse.com
- PM / hibernate: require hibernate snapshot image to be validly
  signed when kernel is locked down (fate#316350).
- PM / hibernate: a option to request that snapshot image must
  be validly signed (fate#316350).
- PM / hibernate: prevent EFI secret key to be regenerated
  (fate#316350).
- PM / hibernate: Generate and verify signature for snapshot image
  (fate#316350).
- PM / hibernate: encrypt hidden area (fate#316350).
- efi: allow user to regenerate secret key (fate#316350).
- efi: generate secret key in EFI boot environment (fate#316350).
- x86/KASLR: public the function for getting random long number
  (fate#316350).
- hibernate: avoid the data in hidden area to be snapshotted
  (fate#316350).
- security: create hidden area to keep sensitive data
  (fate#316350).
- commit 8c35bf3
* Mon Dec 18 2017 mhocko@suse.com
- userfaultfd: hugetlbfs: remove superfluous page unlock in
  VM_SHARED case (bnc#1073113, CVE-2017-15127).
- commit 0332d2e
* Mon Dec 18 2017 mhocko@suse.com
- userfaultfd: hugetlbfs: prevent UFFDIO_COPY to fill beyond
  the end of i_size (bnc#1073112, CVE-2017-15128).
- commit 31f7526
* Mon Dec 18 2017 mhocko@suse.com
- mm, oom_reaper: gather each vma to prevent leaking TLB entry
  (bnc#1073258).
- commit b55bb20
* Mon Dec 18 2017 tbogendoerfer@suse.de
- IB/ipoib: Restore MM behavior in case of tx_ring allocation
  failure (bsc#1046307 FATE#322941).
- iw_cxgb4: only insert drain cqes if wq is flushed (bsc#1046543
  FATE#32292).
- RDMA/netlink: Fix general protection fault (bsc#1046306
  FATE#322942).
- IB/mlx4: Fix RSS hash fields restrictions (bsc#1046302
  FATE#322945).
- IB/core: Don't enforce PKey security on SMI MADs (bsc#1046306
  FATE#322942).
- IB/core: Bound check alternate path port number (bsc#1046306
  FATE#322942).
- sfc: pass valid pointers from efx_enqueue_unwind (bsc#1058169
  FATE#322922).
- commit 6688227
* Mon Dec 18 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit 108f419
* Mon Dec 18 2017 jlee@suse.com
- Delete
  patches.suse/0001-PM-hibernate-Fix-2G-size-issue-of-snapshot-image-ver.patch.
- Delete
  patches.suse/0001-PM-hibernate-Fix-warning-about-non-void-function-not.patch.
- Delete
  patches.suse/0001-PM-hibernate-Force-verify-hibernation-signature-in-s.patch.
- Delete
  patches.suse/0001-PM-hibernate-define-HMAC-algorithm-and-digest-size-o.patch.
- Delete
  patches.suse/0001-x86-Removed-the-free-memblock-of-hibernat-keys-to-av.patch.
- Delete
  patches.suse/0001-x86-efi-Fix-invalid-parameter-error-when-getting-hib.patch.
- Delete
  patches.suse/0002-x86-efi-Add-get-and-set-variable-to-EFI-services-poi.patch.
- Delete
  patches.suse/0003-x86-boot-Public-getting-random-boot-function.patch.
- Delete
  patches.suse/0004-x86-efi-Generating-random-number-in-EFI-stub.patch.
- Delete
  patches.suse/0005-x86-efi-Get-entropy-through-EFI-random-number-genera.patch.
- Delete
  patches.suse/0006-x86-efi-Generating-random-HMAC-key-for-siging-hibern.patch.
- Delete
  patches.suse/0007-efi-Make-efi_status_to_err-public.patch.
- Delete
  patches.suse/0008-x86-efi-Carrying-hibernation-key-by-setup-data.patch.
- Delete
  patches.suse/0009-PM-hibernate-Reserve-hibernation-key-and-erase-footp.patch.
- Delete
  patches.suse/0010-PM-hibernate-Generate-and-verify-signature-of-hibern.patch.
- Delete
  patches.suse/0011-PM-hibernate-Avoid-including-hibernation-key-to-hibe.patch.
- Delete
  patches.suse/0012-PM-hibernate-Forward-signature-verifying-result-and-.patch.
- Delete
  patches.suse/0013-PM-hibernate-Add-configuration-to-enforce-signature-.patch.
- Delete
  patches.suse/0014-PM-hibernate-Allow-user-trigger-hibernation-key-re-g.patch.
- Delete
  patches.suse/0015-PM-hibernate-Bypass-verification-logic-on-legacy-BIO.patch.
- Delete
  patches.suse/0016-PM-hibernate-Document-signature-verification-of-hibe.patch.
  The hibernation verification will be refactored against v4.12.
  Removed old version.
- commit 80cd2cb
* Mon Dec 18 2017 jlee@suse.com
- Delete
  patches.suse/0049-uswsusp-Disable-when-the-kernel-is-locked-down.patch.
  Because the code is duplicate with
  0048-hibernate-Disable-when-the-kernel-is-locked-down.patch
- commit 713a68b
* Fri Dec 15 2017 msuchanek@suse.de
- Refresh patches.drivers/nvme-fc-remove-double-put-reference-if-admin-connect.patch.
  Fix commit hash.
- commit 61669a7
* Fri Dec 15 2017 msuchanek@suse.de
- Refresh sorted section.
- commit 8c10740
* Fri Dec 15 2017 msuchanek@suse.de
- git_sort.py: add rdma/rdma remote.
- commit ec2ea23
* Fri Dec 15 2017 mgorman@suse.de
- sched: Only immediately migrate tasks due to interrupts if prev
  and target CPUs share cache (bnc#1066110 Scheduler utilisation
  tracking).
- commit 8747826
* Fri Dec 15 2017 mgorman@suse.de
- mm/page_alloc.c: avoid excessive IRQ disabled times in
  free_unref_page_list() (bnc#971975 VM -- git fixes).
- commit e2361a2
* Fri Dec 15 2017 msuchanek@suse.de
- genwqe: Take R/W permissions into account when dealing with
  memory pages (bsc#1073090).
- commit 0f3a06a
* Fri Dec 15 2017 mhocko@suse.com
- mm, oom_reaper: fix memory corruption (bnc#1073039).
- commit c664e6e
* Fri Dec 15 2017 jslaby@suse.cz
- x86/stacktrace: make clear the success paths (bnc#1058115).
- Refresh
  patches.suse/0003-x86-stacktrace-remove-STACKTRACE_DUMP_ONCE-from-__sa.patch.
- Refresh
  patches.suse/0004-x86-stacktrace-do-not-fail-for-ORC-with-regs-on-stac.patch.
- Delete
  patches.suse/0002-x86-stacktrace-remove-unwind_state-error.patch.
  Fix livepatch to succeed also for kthreads and idle tasks.
- commit 228dd50
* Fri Dec 15 2017 tiwai@suse.de
- APEI / ERST: Fix missing error handling in erst_reader()
  (bsc#1072556).
- commit 1d69ef4
* Fri Dec 15 2017 tonyj@suse.de
- perf/x86/intel/uncore: Fix memory leaks on allocation failures
  (git-fixes).
- blacklist.conf:  Update perf git-fixes
- commit 25d3ce5
* Thu Dec 14 2017 oneukum@suse.com
- media: dvb-usb-v2: lmedm04: Improve logic checking of warm start
  (bsc#1066569 CVE-2017-16538).
- commit 4f7cbf8
* Thu Dec 14 2017 tiwai@suse.de
- Enable build of CX2072X codec for Intel Atom SST (bsc#1068546)
- commit dde0783
* Thu Dec 14 2017 tiwai@suse.de
- Enable Intel CHTDC-TI powerbutton driver (bsc#1068546)
- commit 5a6685e
* Thu Dec 14 2017 tiwai@suse.de
- platform/x86: Add support for Dollar Cove TI power button
  (bsc#1068546).
- commit e0bff99
* Thu Dec 14 2017 jthumshirn@suse.de
- nvmet-fc: cleanup nvmet add_port/remove_port (bsc#1072553).
- nvme-fc: remove double put reference if admin connect fails
  (bsc#1072553).
- nvme-fc: don't use bit masks for set/test_bit() numbers
  (bsc#1072553).
- nvmet-fc: correct ref counting error when deferred rcv used
  (bsc#1072553).
- nvme-loop: check if queue is ready in queue_rq (bsc#1072553).
- nvme-fc: check if queue is ready in queue_rq (bsc#1072553).
- nvme-fabrics: introduce init command check for a queue that
  is not alive (bsc#1072553).
- commit c9fa2b2
* Thu Dec 14 2017 tbogendoerfer@suse.de
- IB/hfi1: Use 4096 for default active MTU in query_qp
  (bsc#1070622).
- IB/CM: Change sgid to IB GID when handling CM request
  (bsc#1070622).
- IB/hfi1: Mask the path bits with the LMC for 16B RC Acks
  (bsc#1070622).
- bnxt_en: Don't print "Link speed -1 no longer supported"
  messages (bsc#1070116).
- commit 48fe400
* Thu Dec 14 2017 jthumshirn@suse.de
- lpfc: remove use of FC-specific error codes (bsc#1072553).
- nvme-fc: remove use of FC-specific error codes (bsc#1072553).
- nvme.h: remove FC transport-specific error values (bsc#1072553).
- nvmet-fc: remove use of FC-specific error codes (bsc#1072553).
- qla2xxx: remove use of FC-specific error codes (bsc#1072553).
- Refresh
  patches.drivers/nvme-fc-correct-io-termination-handling.patch.
- commit c63aa5a
* Thu Dec 14 2017 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: Add nvme-4.16 to indexed heads
- commit f08f096
* Thu Dec 14 2017 fdmanana@suse.com
- Btrfs: fix reported number of inode blocks after buffered
  append writes (bsc#1061589).
- Btrfs: move definition of the function
  btrfs_find_new_delalloc_bytes (bsc#1061589).
- commit 3954048
* Thu Dec 14 2017 oneukum@suse.com
- USB: core: prevent malicious bNumInterfaces overflow
  (bsc#1072561 CVE-2017-17558).
- commit cdc5902
* Thu Dec 14 2017 jthumshirn@suse.de
- block: fix a crash caused by wrong API (bsc#1072355).
- commit 6bffd0a
* Thu Dec 14 2017 yousaf.kaukab@suse.com
- config: arm64: enable rk3399 missing drivers
- commit 611930b
* Thu Dec 14 2017 tiwai@suse.de
- qxl: alloc & use shadow for dumb buffers (bsc#1072190).
- drm/qxl: replace QXL_INFO with DRM_DEBUG_DRIVER (bsc#1072190).
- commit 6fed647
* Wed Dec 13 2017 jeffm@suse.com
- Btrfs: change how we iterate bios in endio (bsc#1071219).
- commit 248d2a7
* Wed Dec 13 2017 jeffm@suse.com
- housekeeping: update btrfs patch tags
- commit 5824e3f
* Wed Dec 13 2017 fdmanana@suse.com
- Refresh
  patches.suse/btrfs-add-support-for-fallocate-s-zero-range-operati.patch.
- commit c5e275b
* Wed Dec 13 2017 msuchanek@suse.de
- powerpc/powernv/npu: Move tlb flush before launching ATSD
  (bsc#1055120).
- commit 2674fa8
* Wed Dec 13 2017 mgorman@suse.de
- sched/fair: Update and fix the runnable propagation rule
  (bnc#1066110 Scheduler utilisation tracking).
- commit 426857f
* Wed Dec 13 2017 neilb@suse.com
- NFSv4: always set NFS_LOCK_LOST when a lock is lost
  (bsc#1068951).
- commit 8816f29
* Tue Dec 12 2017 bp@suse.de
- x86/microcode/AMD: Add support for fam17h microcode loading
  (bsc#1068032).
- commit 13cc8c9
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: validate commands against the device type
  (FATE#324505).
- commit 606c2ff
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi: always include uuid.h (FATE#324505).
- commit 6bbdd80
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: xt_osf: Add missing permission checks (CVE-2017-17450
  bsc#1071695).
- commit 3196363
* Tue Dec 12 2017 mkubecek@suse.cz
- netlink: Add netns check on taps (CVE-2017-17449 bsc#1071694).
- commit e92da0c
* Tue Dec 12 2017 mkubecek@suse.cz
- netfilter: nfnetlink_cthelper: Add missing permission checks
  (CVE-2017-17448 bsc#1071693).
- commit b16758e
* Tue Dec 12 2017 jthumshirn@suse.de
- scsi: bfa: fix type conversion warning (bsc#1065101).
- scsi: bfa: fix access to bfad_im_port_s (bsc#1065101).
- commit f3a3c83
* Tue Dec 12 2017 jthumshirn@suse.de
- git_sort.py: Add Martin Petersen's 4.15/scsi-fixes branch
- commit 20244cd
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: add 'Enable Latch System Shutdown Status' command
  support (FATE#324505).
- acpi, nfit: add support for NVDIMM_FAMILY_INTEL v1.6 DSMs
  (FATE#324505).
- commit 00a6cf4
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: add support for the _LSI, _LSR, and _LSW label
  methods (FATE#324505).
- Refresh
  patches.drivers/acpi-nfit-hide-unknown-commands-from-nmemX-commands.patch.
- commit 33bc52f
* Tue Dec 12 2017 mkubecek@suse.cz
- sctp: do not peel off an assoc from one netns to another one
  (CVE-2017-15115 bsc#1068671).
- commit 500f976
* Tue Dec 12 2017 tbogendoerfer@suse.de
- net_sched: red: Avoid devision by zero (bsc#1056787).
- i40iw: Notify user of established connection after QP in RTS
  (bsc#1058659 FATE#322535).
- i40iw: Move MPA request event for loopback after connect
  (bsc#1058659 FATE#322535).
- i40iw: Correct ARP index mask (bsc#1058659 FATE#322535).
- i40iw: Do not free sqbuf when event is I40IW_TIMER_TYPE_CLOSE
  (bsc#1058659 FATE#322535).
- i40iw: Allocate a sdbuf per CQP WQE (bsc#1058659 FATE#322535).
- s390/qeth: build max size GSO skbs on L2 devices (bsc#1061024
  FATE#323301).
- s390/qeth: fix GSO throughput regression (bsc#1061024
  FATE#323301).
- s390/qeth: fix thinko in IPv4 multicast address tracking
  (bsc#1061024 FATE#323301).
- IB/mlx5: Fix RoCE Address Path fields (bsc#1046305 FATE#322943).
- IB/srpt: Do not accept invalid initiator port names (bsc#1046306
  FATE#322942).
- commit 647cda2
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi, nfit: hide unknown commands from nmemX/commands
  (FATE#324505).
- commit 26aa55c
* Tue Dec 12 2017 jthumshirn@suse.de
- acpi nfit: nfit_test supports translate SPA (FATE#324505).
- acpi nfit: Enable to show what feature is supported via
  ND_CMD_CALL for nfit_test (FATE#324505).
- acpi, nfit: Show bus_dsm_mask in sysfs (FATE#324505).
- libnvdimm, acpi, nfit: Add bus level dsm mask for pass thru
  (FATE#324505).
- acpi, nfit: Enable DSM pass thru for root functions
  (FATE#324505).
- commit 09b07e6
* Tue Dec 12 2017 mkubecek@suse.cz
- dccp: CVE-2017-8824: use-after-free in DCCP code (CVE-2017-8824
  bsc#1070771).
- commit ed1dc5d
* Tue Dec 12 2017 jthumshirn@suse.de
- thermal: int340x_thermal: fix compile after the UUID API switch
  (FATE#324505).
- thermal: int340x_thermal: Switch to use new generic UUID API
  (FATE#324505).
- commit 0f58456
* Tue Dec 12 2017 mkubecek@suse.cz
- Update
  patches.kernel.org/4.12.11-023-xfrm-policy-check-policy-direction-value.patch
  references (add CVE-2017-11600 bsc#1050231).
- commit c24a6f8
* Tue Dec 12 2017 jthumshirn@suse.de
- ACPI: Switch to use generic guid_t in acpi_evaluate_dsm()
  (FATE#324505).
- Refresh
  patches.drivers/0017-usb-typec-ucsi-Add-ACPI-driver.patch.
- Refresh
  patches.drivers/net-hns-add-acpi-function-of-xge-led-control.patch
- commit b154a19
* Mon Dec 11 2017 mbrugger@suse.com
- drm: hibmc: Initialize the hibmc_bo_driver.io_mem_pfn
  (bnc#1067977).
- drm: hibmc: Use set_busid function from drm core (bsc#1067977).
- vgaarb: Factor out EFI and fallback default device selection
  (bsc#1067977).
- vgaarb: Select a default VGA device even if there's no legacy
  VGA (bsc#1067977).
- commit 56166ea
* Mon Dec 11 2017 jthumshirn@suse.de
- ACPI / bus: Switch to use new generic UUID API (FATE#324505).
- commit eeb5838
* Mon Dec 11 2017 tiwai@suse.de
- blacklist.conf: Add drm inapplicable commits (bsc#1051510)
- commit ba5ee60
* Mon Dec 11 2017 tiwai@suse.de
- drm/i915/cnl: Mask previous DDI - PLL mapping (bsc#1051510).
- commit e06d654
* Mon Dec 11 2017 jthumshirn@suse.de
- ACPI / extlog: Switch to use new generic UUID API (FATE#324505).
- commit 9e27ec4
* Mon Dec 11 2017 msuchanek@suse.de
- powerpc: Force reload for recheckpoint during tm {fp, vec,
  vsx} unavailable exception (bsc#1065729).
- powerpc: Don't enable FP/Altivec if not checkpointed
  (bsc#1065729).
- powerpc: Fix missing newline before { (bsc#1065729).
- cxl: Rename register PSL9_FIR2 to PSL9_FIR_MASK (bsc#1055014).
- cxl: Enable global TLBIs for cxl contexts (bsc#1055014).
- powerpc/mm: Export flush_all_mm() (bsc#1055014).
- powerpc/mm: Make switch_mm_irqs_off() out of line (bsc#1055014).
- powerpc: Remove old unused icswx based coprocessor support
  (bsc#1055014).
- powerpc/mm: Optimize detection of thread local mm's
  (bsc#1055014).
- powerpc/mm: Move pgdir setting into a helper (bsc#1055014).
- commit 5bc2261
* Mon Dec 11 2017 msuchanek@suse.de
- Reorder powerpc patches.
- commit ddca890
* Mon Dec 11 2017 tbogendoerfer@suse.de
- Refresh
  patches.drivers/cxgb4-add-tc-flower-support-for-ETH-DMAC-rewrite.patch.
- commit 449190e
* Mon Dec 11 2017 mgorman@suse.de
- locking/x86: Use LOCK ADD for smp_mb() instead of MFENCE
  (bnc#1072172 x86 performance -- barriers).
- commit a4b5e51
* Mon Dec 11 2017 tiwai@suse.de
- supported.conf: Add missing supported modules (bsc#1072163)
- commit fb1f805
* Mon Dec 11 2017 jthumshirn@suse.de
- acpi, nfit: Switch to use new generic UUID API (FATE#324505).
- commit a3ed858
* Mon Dec 11 2017 tbogendoerfer@suse.de
- net: thunderx: Fix TCP/UDP checksum offload for IPv4 pkts
  (bsc#1069583).
- nfp: fix port stats for mac representors (bsc#1055968).
- IB/core: Only enforce security for InfiniBand (bsc#1070482).
- IB: INFINIBAND should depend on HAS_DMA (bsc#1046306
  FATE#322942).
- IB/hfi1: Initialize bth1 in 16B rc ack builder (bsc#1060463
  FATE#323043).
- bnxt_en: Fix a variable scoping in bnxt_hwrm_do_send_msg()
  (bsc#1050242 FATE#322914).
- bnxt_en: Need to unconditionally shut down RoCE in bnxt_shutdown
  (bsc#1050242 FATE#322914).
- IB/core: Avoid unnecessary return value check (bsc#1070482).
- commit 232528a
* Mon Dec 11 2017 jthumshirn@suse.de
- scsi: lpfc: Fix a precedence bug in lpfc_nvme_io_cmd_wqe_cmpl()
  (bsc#1050239,FATE#322918).
- commit 2fe735c
* Mon Dec 11 2017 jthumshirn@suse.de
- scsi: qla2xxx: Suppress a kernel complaint in
  qla_init_base_qpair() (FATE#322910).
- commit 9d4fd8e
* Mon Dec 11 2017 jgross@suse.com
- xen: fix hvm guest with kaslr enabled (bnc#1071891).
- xen: split up xen_hvm_init_shared_info() (bnc#1071891).
- x86: provide an init_mem_mapping hypervisor hook (bnc#1071891).
- commit 2820573
* Mon Dec 11 2017 mbenes@suse.cz
- livepatch: __klp_disable_patch() should never be called for
  disabled patches (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: Correctly call klp_post_unpatch_callback() in error
  paths (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: add transition notices (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: move transition "complete" notice into
  klp_complete_transition() (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- livepatch: add (un)patch callbacks (bsc#1071995 fate#323487).
  Callbacks support. Coming from upstream klp tree, branch
  for-4.15/callbacks.
- commit bfcc8d1
* Mon Dec 11 2017 tiwai@suse.de
- Remove buggy IPMI patch (bsc#1071877)
  The broken fix was identified and removed/blacklisted now.
  Also re-enable the rest IPMI fixes that have been disabled.
- commit 0128c61
* Mon Dec 11 2017 mgorman@suse.de
- Update patches.suse/cpufreq-intel_pstate-use-setpoint-of-10-on-servers.patch
  (bnc#945201,bnc#1064414).
- commit f696fcb
* Mon Dec 11 2017 mbenes@suse.cz
- livepatch: Small shadow variable documentation fixes
  (bsc#1071995 fate#323487).
  Shadow variables support. Coming from upstream klp tree, branch
  for-4.15/shadow-variables.
- livepatch: __klp_shadow_get_or_alloc() is local to shadow.c
  (bsc#1071995 fate#323487).
  Shadow variables support. Coming from upstream klp tree, branch
  for-4.15/shadow-variables.
- livepatch: introduce shadow variable API (bsc#1071995
  fate#323487).
  Shadow variables support. Coming from upstream klp tree, branch
  for-4.15/shadow-variables.
- commit 576f832
* Mon Dec 11 2017 mbenes@suse.cz
- livepatch: unpatch all klp_objects if klp_module_coming fails
  (bsc#1071995 fate#323487).
  Fix coming from upstream klp tree, branch for-4.14/upstream-fixes
- commit 198dbfe
* Sat Dec  9 2017 tiwai@suse.de
- Disable IPMI fix patches due to regression (bsc#1071877)
- commit 8d8a8ff
* Fri Dec  8 2017 mkubecek@suse.cz
- net: openvswitch: datapath: fix data type in queue_gso_packets
  (bsc#1066757).
- net: accept UFO datagrams from tuntap and packet (bsc#1066757).
- net: Remove unused skb_shared_info member (bsc#1066757).
- commit 6e1c320
* Fri Dec  8 2017 mkubecek@suse.cz
- netfilter: ebtables: fix race condition in
  frame_filter_net_init() (bsc#1071929).
- commit 615d8a0
* Fri Dec  8 2017 mkubecek@suse.cz
- series.conf: refresh
  (just ran series_sort.py)
- commit 50b424d
* Fri Dec  8 2017 msuchanek@suse.de
- supported.conf add crypto_simd (bsc#1071991).
- commit 94d5bb1
* Fri Dec  8 2017 mcgrof@suse.com
- xfs: extend unsupported annotations: reflink or reverse mapping btree (FATE#324503).
- commit 53eb059
* Fri Dec  8 2017 vbabka@suse.cz
- hmm: heterogeneous memory management documentation (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/device-public-memory: device memory cache coherent with CPU
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/device-public-memory: fix edge case in _vm_normal_page()
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/hmm: add new helper to hotplug CDM memory region (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm: avoid bloating arch that do not make use of HMM (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm/devmem: device memory hotplug using ZONE_DEVICE (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm/devmem: dummy HMM device for ZONE_DEVICE memory (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm: fix build when HMM is disabled (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/hmm: heterogeneous memory management (HMM for short)
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/hmm/mirror: device page fault handler (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/hmm/mirror: helper to snapshot CPU page table (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/hmm/mirror: mirror process address space on device with
  HMM helpers (VM Functionality, FATE#323338, bsc#1047814).
- mm/memcontrol: allow to uncharge page without using page->lru
  field (VM Functionality, FATE#323338, bsc#1047814).
- mm/memcontrol: support MEMORY_DEVICE_PRIVATE (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/memory_hotplug: introduce add_pages (VM Functionality,
  FATE#323338, bsc#1047814).
- mm/migrate: allow migrate_vma() to alloc new page on empty entry
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: fix indexing bug (off by one) and avoid out of
  bound access (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: migrate_vma() unmap page from vma while collecting
  pages (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: new memory migration helper for use with device
  memory (VM Functionality, FATE#323338, bsc#1047814).
- mm/migrate: new migrate mode MIGRATE_SYNC_NO_COPY (VM
  Functionality, FATE#323338, bsc#1047814).
- mm/migrate: support un-addressable ZONE_DEVICE page in migration
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/ZONE_DEVICE: new type of ZONE_DEVICE for unaddressable memory
  (VM Functionality, FATE#323338, bsc#1047814).
- mm/ZONE_DEVICE: special case put_page() for device private pages
  (VM Functionality, FATE#323338, bsc#1047814).
- Update config files.
- commit 5579b56
* Fri Dec  8 2017 mwilck@suse.com
- Fix git-repo: header in scsi_devinfo patches
- Refresh
  patches.fixes/scsi-scsi_devinfo-cleanly-zero-pad-devinfo-strings.patch.
- Refresh
  patches.fixes/scsi-scsi_devinfo-handle-non-terminated-strings.patch.
- commit 53814b0
* Fri Dec  8 2017 tiwai@suse.de
- iwlwifi: mvm: mark MIC stripped MPDUs (bsc#1071648).
- iwlwifi: mvm: enable RX offloading with TKIP and WEP
  (bsc#1071648).
- iwlwifi: mvm: flush queue before deleting ROC (bsc#1071648).
- iwlwifi: add new cards for 9260 and 22000 series (bsc#1071648).
- iwlwifi: mvm: fix packet injection (bsc#1071648).
- iwlwifi: mvm: don't use transmit queue hang detection when it
  is not possible (bsc#1071648).
- iwlwifi: fix firmware names for 9000 and A000 series hw
  (bsc#1071648).
- iwlwifi: mvm: use IWL_HCMD_NOCOPY for MCAST_FILTER_CMD
  (bsc#1071648).
- iwlwifi: fix PCI IDs and configuration mapping for 9000 series
  (bsc#1071648).
- iwlwifi: add new cards for a000 series (bsc#1071648).
- iwlwifi: add new cards for 8265 series (bsc#1071648).
- iwlwifi: add new cards for 8260 series (bsc#1071648).
- iwlwifi: pcie: sort IDs for the 9000 series for easier
  comparisons (bsc#1071648).
- commit d40b4c9
* Fri Dec  8 2017 msuchanek@suse.de
- Add undefine _unique_build_ids (bsc#964063)
- commit 47e91a1
* Fri Dec  8 2017 yousaf.kaukab@suse.com
- scsi: libsas: align sata_device's rps_resp on a cacheline
  (bsc#1071401).
- scsi: hisi_sas: add v3 hw port AXI error handling (bsc#1071401).
- scsi: hisi_sas: add v3 hw support for AXI fatal error
  (bsc#1071401).
- scsi: hisi_sas: complete all tasklets prior to host reset
  (bsc#1071401).
- scsi: hisi_sas: fix a bug when free device for v3 hw
  (bsc#1071401).
- scsi: hisi_sas: add hisi_hba.rst_work init for v3 hw
  (bsc#1071401).
- scsi: hisi_sas: add v3 hw DFX feature (bsc#1071401).
- scsi: hisi_sas: init connect cfg register for v3 hw
  (bsc#1071401).
- scsi: hisi_sas: check PHY state in get_wideport_bitmap_v3_hw()
  (bsc#1071401).
- scsi: hisi_sas: use array for v2 hw AXI errors (bsc#1071401).
- scsi: hisi_sas: fix the risk of freeing slot twice
  (bsc#1071401).
- scsi: hisi_sas: fix NULL check in SMP abort task path
  (bsc#1071401).
- scsi: hisi_sas: us start_phy in PHY_FUNC_LINK_RESET
  (bsc#1071401).
- scsi: hisi_sas: fix SATA breakpoint memory size (bsc#1071401).
- scsi: hisi_sas: grab hisi_hba.lock when processing slots
  (bsc#1071401).
- scsi: hisi_sas: use spin_lock_irqsave() for hisi_hba.lock
  (bsc#1071401).
- scsi: hisi_sas: delete get_ncq_tag_v3_hw() (bsc#1071401).
- scsi: libsas: remove unused variable sas_ha (bsc#1071401).
- scsi: libsas: add event to defer list tail instead of head
  when draining (bsc#1071401).
- scsi: libsas: rename notify_port_event() for consistency
  (bsc#1071401).
- scsi: libsas: remove unused port_gone_completion and
  DISCE_PORT_GONE (bsc#1071401).
- scsi: libsas: remove the numbering for each event enum
  (bsc#1071401).
- scsi: libsas: kill useless ha_event and do some cleanup
  (bsc#1071401).
- scsi: libsas: Annotate fall-through in a switch statement
  (bsc#1071401).
- scsi: libsas: Remove a set-but-not-used variable (bsc#1071401).
- scsi: hisi_sas: replace kfree with scsi_host_put (bsc#1071401).
- scsi: hisi_sas: remove phy_down_v3_hw() res variable
  (bsc#1071401).
- scsi: hisi_sas: add phy_set_linkrate_v3_hw() (bsc#1071401).
- scsi: hisi_sas: update some v3 register init settings
  (bsc#1071401).
- scsi: hisi_sas: add reset handler for v3 hw (bsc#1071401).
- scsi: hisi_sas: kill tasklet when destroying irq in v3 hw
  (bsc#1071401).
- scsi: hisi_sas: fix v3 hw channel interrupt processing
  (bsc#1071401).
- scsi: hisi_sas: Modify v3 hw STP_LINK_TIMER setting
  (bsc#1071401).
- commit 9c6ddbc
* Fri Dec  8 2017 mgorman@suse.de
- cpufreq, intel_pstate: Ramp up frequency faster when utilisation
  reaches setpoint (bnc#1068680 Update schedutil and intel_pstate
  to default to load-based policy).
- cpufreq: intel_pstate: Improve IO performance with per-core
  P-states (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- cpufreq: intel_pstate: Use load-based policy by default
  but allow PID to be used (bnc#1068680 Update schedutil and
  intel_pstate to default to load-based policy).
- sched/fair: Update calc_group_*() comments (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Calculate runnable_weight slightly differently
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Implement more accurate async detach (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Align PELT windows between cfs_rq and its se
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Implement synchonous PELT detach on load-balance
  migrate (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Propagate an effective runnable_load_avg
  (bnc#1066110 Scheduler utilisation tracking).
- sched/pelt: Fix false running accounting (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Rewrite PELT migration propagation (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Rewrite cfs_rq->removed_*avg (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Use reweight_entity() for set_user_nice()
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: More accurate reweight_entity() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Introduce {en,de}queue_load_avg() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Rename {en,de}queue_entity_load_avg() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Move enqueue migrate handling (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Change update_load_avg() arguments (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Remove se->load.weight from se->avg.load_sum
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Cure calc_cfs_shares() vs. reweight_entity()
  (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Add comment to calc_cfs_shares() (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Clean up calc_cfs_shares() (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Drop always true parameter of
  update_cfs_rq_load_avg() (bnc#1066110 Scheduler utilisation
  tracking).
- sched/fair: Avoid checking cfs_rq->nr_running twice (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Pass 'rq' to weighted_cpuload() (bnc#1066110
  Scheduler utilisation tracking).
- sched/core: Reuse put_prev_task() (bnc#1066110 Scheduler
  utilisation tracking).
- sched/fair: Use task_groups instead of leaf_cfs_rq_list to
  walk all cfs_rqs (bnc#1066110 Scheduler utilisation tracking).
- sched/fair: Fix O(nr_cgroups) in load balance path (bnc#1066110
  Scheduler utilisation tracking).
- sched/fair: Call cpufreq update util handlers less frequently
  on UP (bnc#1066110 Scheduler utilisation tracking).
- commit 9ea022c
* Thu Dec  7 2017 dbueso@suse.de
- fs/proc: Report eip/esp in /prod/PID/stat for coredumping
  (bsc#1050549).
- locking/x86: Use LOCK ADD for smp_mb() instead of MFENCE
  (bsc#1050549).
- commit 1941e2e
* Wed Dec  6 2017 tiwai@suse.de
- iwlwifi: mvm: support version 7 of the SCAN_REQ_UMAC FW command
  (bsc#1068838,bsc#1071652).
- commit d602917
* Wed Dec  6 2017 oneukum@suse.com
- USB: uas: fix bug in handling of alternate settings
  (bsc#1071074).
- commit e1e1aea
* Wed Dec  6 2017 tbogendoerfer@suse.de
- IB/mlx4: Add contig support for control objects (bsc#1071218).
- IB/mlx4: Use optimal numbers of MTT entries (bsc#1071218).
- IB/mlx4: Add report for RSS capabilities by vendor channel
  (bsc#1071218).
- commit 8514de9
* Wed Dec  6 2017 yousaf.kaukab@suse.com
- regulator: fan53555: fix I2C device ids (bsc#1071296).
- Update config files.
- supported.conf:
- regulator: fan53555: Use of_device_get_match_data() to simplify
  probe (bsc#1071296).
- commit aab6c79
* Wed Dec  6 2017 oneukum@suse.com
- blacklist.conf: usbtest is not compiled
  document that patch for security issue is not needed
- commit 33a85d1
* Wed Dec  6 2017 oneukum@suse.com
- blacklist.conf: the driver is not compiled. Ignore fixes.
- commit eab7a74
* Wed Dec  6 2017 mgorman@suse.de
- sched/wait: fix add_wait_queue() behavior change (bnc#971975
  VM performance -- page waitqueue).
- commit b67e247
* Wed Dec  6 2017 mwilck@suse.com
- scsi: scsi_devinfo: cleanly zero-pad devinfo strings
  (bsc#1062941, bsc#1037404, bsc#1012523, bsc#1038299).
- scsi: scsi_devinfo: handle non-terminated strings (bsc#1062941,
  bsc#1037404, bsc#1012523, bsc#1038299).
- commit fcb27f8
* Wed Dec  6 2017 tiwai@suse.de
- isa: Prevent NULL dereference in isa_bus driver callbacks
  (bsc#1051510).
- commit 32eeca3
* Wed Dec  6 2017 gqjiang@suse.com
- md: always set THREAD_WAKEUP and wake up wqueue if thread
  existed (bsc#1071403).
- dlm: recheck kthread_should_stop() before schedule()
  (bsc#1071422).
- commit a2cb166
* Wed Dec  6 2017 mwilck@suse.com
- scsi_devinfo fixes from 4.15 (bsc#1062941, bsc#1037404)
- scsi: scsi_devinfo: Add 'AIX VDASD' to blacklist (bsc#1012523
  bsc#1037404 bsc#1038299 bsc#1062941).
- scsi: scsi_devinfo: Add TRY_VPD_PAGES to HITACHI OPEN-V
  blacklist entry (bsc#1012523 bsc#1037404 bsc#1038299
  bsc#1062941).
- scsi: scsi_devinfo: fixup string compare (bsc#1012523
  bsc#1037404 bsc#1038299 bsc#1062941).
- scsi: scsi_devinfo: Whitespace fixes (bsc#1012523 bsc#1037404
  bsc#1038299 bsc#1062941).
- commit 0b796f6
* Wed Dec  6 2017 mwilck@suse.com
- Move iTCO_wdt patch to sorted section
- commit c15439f
* Tue Dec  5 2017 jeffm@suse.com
- btrfs: fix NULL pointer dereference from free_reloc_roots()
  (bsc#1071099).
- commit f5d556f
* Tue Dec  5 2017 jack@suse.cz
- dax: fix general protection fault in dax_alloc_inode
  (bsc#1052766).
- commit cc66850
* Tue Dec  5 2017 jack@suse.cz
- f2fs: fix to show ino management cache size correctly
  (bsc#1052766).
- commit 3007e0f
* Tue Dec  5 2017 jack@suse.cz
- Revert "f2fs: handle dirty segments inside refresh_sit_entry"
  (bsc#1052766).
- commit dcc8098
* Tue Dec  5 2017 jack@suse.cz
- f2fs: fix to clear FI_NO_PREALLOC (bsc#1052766).
- commit 8a0aa54
* Tue Dec  5 2017 jack@suse.cz
- ocfs2: ip_alloc_sem should be taken in ocfs2_get_block()
  (bsc#1052766).
- commit 8d3384d
* Tue Dec  5 2017 jack@suse.cz
- dnotify: Handle errors from fsnotify_add_mark_locked() in
  fcntl_dirnotify() (bsc#1052766).
- commit 16097ad
* Tue Dec  5 2017 jack@suse.cz
- fsnotify: pin both inode and vfsmount mark (bsc#1052766).
- commit 1702fdd
* Tue Dec  5 2017 jack@suse.cz
- fsnotify: clean up fsnotify_prepare/finish_user_wait()
  (bsc#1052766).
- commit cb63dd7
* Tue Dec  5 2017 mbrugger@suse.com
- supported.conf: update arm64 relevant drivers
- commit 4d1cbfb
* Tue Dec  5 2017 tbogendoerfer@suse.de
- IB/rdmavt: Don't wait for resources in QP reset (bsc#1070622).
- IB/hfi1: Allow meta version 4 for platform configuration
  (bsc#1070622).
- IB/hfi1: Add parsing for platform configuration format version 4
  (bsc#1070622).
- commit 63d7eea
* Tue Dec  5 2017 jack@suse.cz
- mm/memory.c: mark create_huge_pmd() inline to prevent build
  failure (fate#323590).
- commit 8e193c8
* Tue Dec  5 2017 oneukum@suse.com
- crypto: cavium - clean up clang warning on unread variable
  offset (FATE#323051).
- commit f445359
* Tue Dec  5 2017 mbrugger@suse.com
- scsi: hisi_sas: fix internal abort slot timeout bug
  (bsc#1068693).
- commit 645ee34
* Tue Dec  5 2017 jslaby@suse.cz
- x86/stacktrace: do now unwind after user regs (bnc#1058115).
- x86/stacktrace: remove unwind_state->error (bnc#1058115).
- x86/stacktrace: remove STACKTRACE_DUMP_ONCE from
  __save_stack_trace_reliable (bnc#1058115).
- x86/stacktrace: do not fail for ORC with regs on stack
  (bnc#1058115).
  More make-ORC-reliable patches.
- commit 91578f6
* Mon Dec  4 2017 bp@suse.de
- perf/x86/intel/bts: Fix exclusive event reference leak
  (git-fixes d2878d642a4ed).
- commit 798cbcd
* Mon Dec  4 2017 tiwai@suse.de
- blacklist.conf: Add inapplicable / non-issues commits for WiFi and DRM
- commit 999cd73
* Mon Dec  4 2017 tiwai@suse.de
- mmc: core: prepend 0x to OCR entry in sysfs (bsc#1051510).
- mmc: core: prepend 0x to pre_eol_info entry in sysfs
  (bsc#1051510).
- mac80211_hwsim: Fix memory leak in hwsim_new_radio_nl()
  (bsc#1051510).
- rtlwifi: rtl8821ae: Fix connection lost problem (bsc#1051510).
- brcmfmac: fix double free upon register_netdevice() failure
  (bsc#1051510).
- ath10k: fix reported HT MCS rates with NSS > 1 (bsc#1051510).
- drm/i915: Prevent zero length "index" write (bsc#1051510).
- drm/i915: Don't try indexed reads to alternate slave addresses
  (bsc#1051510).
- commit 4923254
* Mon Dec  4 2017 oneukum@suse.com
- thunderbolt: tb: fix use after free in tb_activate_pcie_devices
  (FATE#323948).
- commit d3f0bb9
* Mon Dec  4 2017 tiwai@suse.de
- Refresh
  patches.drivers/drm-i915-Suppress-switch_mm-emission-between-the-sam.
  Add the cherry-picked upstream commit id, too
- commit f2ecc61
* Mon Dec  4 2017 tiwai@suse.de
- blacklist.conf: Add inapplicable DRM and IIO commits (bsc#1051510)
- commit b18d7d1
* Mon Dec  4 2017 tiwai@suse.de
- ipmi_ssif: unlock on allocation failure (bsc#1051510).
- iio: trigger: stm32-timer: fix a corner case to write preset
  (bsc#1051510).
- iio: inkern: fix a static checker error (bsc#1051510).
- mfd: omap-usb-tll: Fix register offsets (bsc#1051510).
- drm/omap: displays: panel-dpi: add backlight dependency
  (bsc#1051510).
- drm/omap: Fix error handling path in 'omap_dmm_probe()'
  (bsc#1051510).
- drm/i915: fix intel_backlight_device_register declaration
  (bsc#1051510).
- commit d3a4e07
* Mon Dec  4 2017 rgoldwyn@suse.com
- apparmor: fix off-by-one comparison on MAXMAPPED_SIG
  (bsc#1071070).
- apparmor: fix locking when creating a new complain profile
  (bsc#1071061).
- apparmor: fix leak of null profile name if profile allocation
  fails (bsc#1071057).
- apparmor: fix profile attachment for special unconfined profiles
  (bsc#1071035).
- commit 196f7ba
* Mon Dec  4 2017 jack@suse.cz
- mm: always enable thp for dax mappings (fate#323590).
  Refresh patches.fixes/dax-use-common-4k-zero-page-for-dax-mmap-reads.patch
- commit a9ff0a7
* Mon Dec  4 2017 oneukum@suse.com
- iwlwifi: mvm: support version 7 of the SCAN_REQ_UMAC FW command (FATE#322675).
- commit be16b41
* Mon Dec  4 2017 jack@suse.cz
- mm: improve readability of transparent_hugepage_enabled()
  (fate#323590).
- commit 52d3d3e
* Mon Dec  4 2017 msuchanek@suse.de
- blacklist 65c5ec11c25e powerpc/boot: Fix 64-bit boot wrapper build with
  non-biarch compiler
  - correct backlisted commit id
- commit 2fd25e6
* Mon Dec  4 2017 oneukum@suse.com
- iwlwifi: fix wrong struct for a000 device (FATE#322675).
- commit 6762404
* Mon Dec  4 2017 jack@suse.cz
- IB/core: disable memory registration of filesystem-dax vmas
  (bsc#1070967).
- commit 68da5e4
* Mon Dec  4 2017 jack@suse.cz
- v4l2: disable filesystem-dax mapping support (bsc#1070967).
- commit add8a46
* Mon Dec  4 2017 jack@suse.cz
- mm: fail get_vaddr_frames() for filesystem-dax mappings
  (bsc#1070967).
- commit 9705a09
* Mon Dec  4 2017 jack@suse.cz
- mm: introduce get_user_pages_longterm (bsc#1070967).
- commit 3240a1e
* Mon Dec  4 2017 jack@suse.cz
- ecryptfs: fix dereference of NULL user_key_payload
  (bsc#1052766).
- commit b2e39ae
* Mon Dec  4 2017 jack@suse.cz
- dax: fix PMD faults on zero-length files (bsc#1052766).
- commit 640b01c
* Mon Dec  4 2017 jack@suse.cz
- quota: Check for register_shrinker() failure (bsc#1052766).
- commit 7ea927a
* Mon Dec  4 2017 jack@suse.cz
- xfs: evict all inodes involved with log redo item (bsc#1052766).
- commit 1e78f32
* Mon Dec  4 2017 jack@suse.cz
- xfs: clear MS_ACTIVE after finishing log recovery (bsc#1052766).
- commit cd4c172
* Mon Dec  4 2017 jack@suse.cz
- mm, hugetlbfs: introduce ->split() to vm_operations_struct
  (bsc#1070968).
- commit b96e8a1
* Mon Dec  4 2017 jack@suse.cz
- device-dax: implement ->split() to catch invalid munmap attempts
  (bsc#1070968).
- commit 542be39
* Mon Dec  4 2017 jack@suse.cz
- 9p: set page uptodate when required in write_end()
  (bsc#1052766).
- commit de002ea
* Mon Dec  4 2017 tbogendoerfer@suse.de
- net: thunderx: Fix TCP/UDP checksum offload for IPv6 pkts
  (bsc#1069583).
- bpf: fix lockdep splat (bsc#1056787).
- net/mlx5e: Add rollback on add VLAN failure (bsc#1046303
  FATE#322944).
- rtnetlink: bring NETDEV_CHANGEMTU event process back in
  rtnetlink_event (bsc#1056787).
- net: sched: fix use-after-free in tcf_action_destroy and
  tcf_del_walker (bsc#1056787).
- commit 7674fd9
* Mon Dec  4 2017 tbogendoerfer@suse.de
- Re-sorted series.conf
- commit da1763f
* Mon Dec  4 2017 mhocko@suse.com
- mm/hugetlb: fix NULL-pointer dereference on 5-level paging
  machine (bnc#1070965).
- commit 008deb0
* Mon Dec  4 2017 mhocko@suse.com
- mm/madvise.c: fix madvise() infinite loop under special
  circumstances (bnc#1070964).
- commit 6645258
* Mon Dec  4 2017 mhocko@suse.com
- mm/cma: fix alloc_contig_range ret code/potential leak
  (bnc#1070962).
- commit 0363569
* Mon Dec  4 2017 mhocko@suse.com
- blacklist.conf: blacklist 3f3295709edea6268ff1609855f498035286af73 as a
  minor optimization
- commit 689fb18
* Fri Dec  1 2017 mcgrof@suse.com
- xfs: Properly retry failed inode items in case of error during buffer writeback (bsc#1070682).
- xfs: Add infrastructure needed for error propagation during buffer IO failure (bsc#1070682).
- commit b6a619b
* Fri Dec  1 2017 jthumshirn@suse.de
- dm, dax: Make sure dm_dax_flush() is called if device supports
  it (FATE#323717).
- Refresh
  patches.drivers/dax-remove-the-pmem_dax_ops-flush-abstraction.patch.
- commit 5a023df
* Fri Dec  1 2017 hare@suse.de
- Btrfs: work around maybe-uninitialized warning (FATE#323952,
  FATE#322506).
- commit c56eb06
* Fri Dec  1 2017 rgoldwyn@suse.com
- apparmor: fix oops in audit_signal_cb hook (bsc#1070227).
- commit da7b6ca
* Fri Dec  1 2017 jthumshirn@suse.de
- dax: convert to bitmask for flags (FATE#323717).
- dax, pmem: introduce an optional 'flush' dax_operation
  (FATE#323717).
- dax: remove the pmem_dax_ops->flush abstraction (FATE#323717).
- dm: add ->copy_from_iter() dax operation support (FATE#323717).
- dm: add ->flush() dax operation support (FATE#323717).
- filesystem-dax: convert to dax_copy_from_iter() (FATE#323717).
- filesystem-dax: convert to dax_flush() (FATE#323717).
- libnvdimm, nd_blk: remove mmio_flush_range() (FATE#323717).
- libnvdimm, pmem, dax: export a cache control attribute
  (FATE#323717).
- libnvdimm, pmem: disable dax flushing when pmem is fronting
  a volatile region (FATE#323717).
- x86, dax, libnvdimm: remove wb_cache_pmem() indirection
  (FATE#323717).
- x86, dax: replace clear_pmem() with open coded memset +
  dax_ops->flush (FATE#323717).
- x86, libnvdimm, pmem: move arch_invalidate_pmem() to libnvdimm
  (FATE#323717).
- Refresh
  patches.fixes/dax-explain-how-read-2-write-2-addresses-are-validat.patch.
- commit 2bc41df
* Fri Dec  1 2017 ohering@suse.de
- hv_netvsc: preserve hw_features on mtu/channels/ringparam
  changes (fate#323887).
- hv_netvsc: hide warnings about uninitialized/missing rndis
  device (fate#323887).
- hv_netvsc: netvsc_teardown_gpadl() split (fate#323887).
- scsi: storvsc: Avoid excessive host scan on controller change
  (fate#323887).
- hyper-v: trace channel events (fate#323887).
- hyper-v: trace vmbus_send_tl_connect_request() (fate#323887).
- hyper-v: trace vmbus_release_relid() (fate#323887).
- hyper-v: trace vmbus_negotiate_version() (fate#323887).
- hyper-v: trace vmbus_teardown_gpadl() (fate#323887).
- hyper-v: trace vmbus_establish_gpadl() (fate#323887).
- hyper-v: trace vmbus_close_internal() (fate#323887).
- hyper-v: trace vmbus_open() (fate#323887).
- hyper-v: trace vmbus_request_offers() (fate#323887).
- hyper-v: trace vmbus_onversion_response() (fate#323887).
- hyper-v: trace vmbus_ongpadl_torndown() (fate#323887).
- hyper-v: trace vmbus_ongpadl_created() (fate#323887).
- hyper-v: trace vmbus_onopen_result() (fate#323887).
- hyper-v: trace vmbus_onoffer_rescind() (fate#323887).
- hyper-v: trace vmbus_onoffer() (fate#323887).
- hyper-v: trace vmbus_on_message() (fate#323887).
- hyper-v: trace vmbus_on_msg_dpc() (fate#323887).
- scsi: storvsc: Allow only one remove lun work item to be issued
  per lun (fate#323887).
- Drivers: hv: vmbus: Make panic reporting to be more useful
  (fate#323887).
- Drivers: hv: vmbus: Expose per-channel interrupts and events
  counters (fate#323887).
- hv_netvsc: Set tx_table to equal weight after subchannels open
  (fate#323887).
- vmbus: initialize reserved fields in messages (fate#323887).
- hv_netvsc: Add initialization of tx_table in netvsc_device_add()
  (fate#323887).
- hv_netvsc: Rename tx_send_table to tx_table (fate#323887).
- hv_netvsc: Rename ind_table to rx_table (fate#323887).
- hv_netvsc: Add ethtool handler to set and get TCP hash levels
  (fate#323887).
- hv_netvsc: Change the hash level variable to bit flags
  (fate#323887).
- HID: hyperv: pr_err() strings should end with newlines
  (fate#323887).
- vmbus: add per-channel sysfs info (fate#323887).
- hv_netvsc: report stop_queue and wake_queue (fate#323887).
- hv_netvsc: Fix the real number of queues of non-vRSS cases
  (fate#323887).
- hv_netvsc: make const array ver_list static, reduces object
  code size (fate#323887).
- commit 76f63c8
* Fri Dec  1 2017 hare@suse.de
- scsi: mpt3sas: remove a stray KERN_INFO (bsc#1067965).
- scsi: mpt3sas: cleanup _scsih_pcie_enumeration_event()
  (bsc#1067965).
- scsi: mpt3sas: fix dma_addr_t casts (bsc#1067965).
- scsi: mpt3sas: Update mpt3sas driver version (bsc#1067965).
- scsi: mpt3sas: Fix sparse warnings (bsc#1067965).
- scsi: mpt3sas: Fix nvme drives checking for tlr (bsc#1067965).
- scsi: mpt3sas: NVMe drive support for BTDHMAPPING ioctl command
  and log info (bsc#1067965).
- scsi: mpt3sas: Add-Task-management-debug-info-for-NVMe-drives
  (bsc#1067965).
- scsi: mpt3sas: scan and add nvme device after controller reset
  (bsc#1067965).
- scsi: mpt3sas: Set NVMe device queue depth as 128 (bsc#1067965).
- scsi: mpt3sas: Handle NVMe PCIe device related events generated
  from firmware (bsc#1067965).
- scsi: mpt3sas: API's to remove nvme drive from sml
  (bsc#1067965).
- scsi: mpt3sas: API 's to support NVMe drive addition to SML
  (bsc#1067965).
- scsi: mpt3sas: Added support for nvme encapsulated request
  message (bsc#1067965).
- scsi: mpt3sas: SGL to PRP Translation for I/Os to NVMe devices
  (bsc#1067965).
- scsi: mpt3sas: Add nvme device support in slave alloc, target
  alloc and probe (bsc#1067965).
- commit 5d6012f
* Fri Dec  1 2017 hare@suse.de
- Rediff patches after sorting series.conf
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- Refresh patches.drivers/s390-cpu-alternatives.patch.
- commit 92c2ed1
* Fri Dec  1 2017 ohering@suse.de
- rename a bunch hyperv patches to reflect new upstream ordering
- commit ab8bb68
* Fri Dec  1 2017 hare@suse.de
- patches.arch/s390-sles15-00-10-03-kernel-sthyi-add-s390_sthyi-system-call.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- patches.arch/s390-sles15-00-10-02-kernel-sthyi-add-cache-to-store-hypervisor-info.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- patches.arch/s390-sles15-00-10-01-kernel-sthyi-reorganize-sthyi-implementation.patch:
  (FATE#324258, LTC#160415, bsc#1068273).
- commit bbfb48f
* Fri Dec  1 2017 hare@suse.de
- KVM: s390: Support Configuration z/Architecture Mode
  (FATE#324111, LTC#158961,bsc#1066434).
- commit 39c4947
* Fri Dec  1 2017 tbogendoerfer@suse.de
- iw_cxgb4: atomically flush the qp (bsc#1064802 bsc#1066129).
- iw_cxgb4: only call the cq comp_handler when the cq is armed
  (bsc#1064802 bsc#1066129).
- iw_cxgb4: Fix possible circular dependency locking warning
  (bsc#1064802 bsc#1066129).
- iw_cxgb4: remove BUG_ON() usage (bsc#1064802 bsc#1066129).
- RDMA/cxgb4: Protect from possible dereference (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Annotate r2 and stag as __be32 (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Declare stag as __be32 (bsc#1064802 bsc#1066129).
- RDMA/cxgb4: Remove a set-but-not-used variable (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Suppress gcc 7 fall-through complaints (bsc#1064802
  bsc#1066129).
- RDMA/cxgb4: Remove the obsolete kernel module option
  'c4iw_debug' (bsc#1064802 bsc#1066129).
- RDMA/cxgb4: Fix indentation (bsc#1064802 bsc#1066129).
- iw_cxgb4: add referencing to wait objects (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each ep object (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each qp object (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each cq object (bsc#1064802
  bsc#1066129).
- iw_cxgb4: allocate wait object for each memory object
  (bsc#1064802 bsc#1066129).
- iw_cxgb4: change pr_debug to appropriate log level (bsc#1064802
  bsc#1066129).
- iw_cxgb4: Remove __func__ parameter from pr_debug() (bsc#1064802
  bsc#1066129).
- IB/{cxgb3,cxgb4}: Remove unneeded config dependencies
  (bsc#1064802 bsc#1066129).
- cxgb4: collect SGE queue context dump (bsc#1064802 bsc#1066129).
- cxgb4: collect LE-TCAM dump (bsc#1064802 bsc#1066129).
- cxgb4: collect vpd info directly from hardware (bsc#1064802
  bsc#1066129).
- cxgb4vf: define get_fecparam ethtool callback (bsc#1064802
  bsc#1066129).
- cxgb4: fix error return code in cxgb4_set_hash_filter()
  (bsc#1064802 bsc#1066129).
- cxgb4: add support to create hash-filters via tc-flower offload
  (bsc#1064802 bsc#1066129).
- cxgb4: add support to retrieve stats for hash filters
  (bsc#1064802 bsc#1066129).
- cxgb4: add support to delete hash filter (bsc#1064802
  bsc#1066129).
- cxgb4: add support to create hash filters (bsc#1064802
  bsc#1066129).
- cxgb4: initialize hash-filter configuration (bsc#1064802
  bsc#1066129).
- cxgb4: save additional filter tuple field shifts in tp_params
  (bsc#1064802 bsc#1066129).
- cxgb3: Check and handle the dma mapping errors (bsc#1064802
  bsc#1066129).
- cxgb4: collect hardware misc dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect hardware scheduler dumps (bsc#1064802
  bsc#1066129).
- cxgb4: collect PBT tables dump (bsc#1064802 bsc#1066129).
- cxgb4: collect MPS-TCAM dump (bsc#1064802 bsc#1066129).
- cxgb4: collect TID info dump (bsc#1064802 bsc#1066129).
- cxgb4: collect RSS dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect CIM queue configuration dump (bsc#1064802
  bsc#1066129).
- cxgb4: collect hardware LA dumps (bsc#1064802 bsc#1066129).
- cxgb4: fix overflow in collecting IBQ and OBQ dump (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower support for L3/L4 rewrite (bsc#1064802
  bsc#1066129).
- cxgb4: introduce fw_filter2_wr to prepare for L3/L4 rewrite
  support (bsc#1064802 bsc#1066129).
- cxgb4: add tc flower support for ETH-SMAC rewrite (bsc#1064802
  bsc#1066129).
- cxgb4: introduce SMT ops to prepare for SMAC rewrite support
  (bsc#1064802 bsc#1066129).
- cxgb4: add tc flower support for ETH-DMAC rewrite (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower support for action PASS (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower match support for vlan (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower match support for TOS (bsc#1064802
  bsc#1066129).
- cxgb4: fix missing break in switch and indent return statements
  (bsc#1064802 bsc#1066129).
- cxgb4: collect IBQ and OBQ dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect hardware module dumps (bsc#1064802 bsc#1066129).
- cxgb4: collect TP dump (bsc#1064802 bsc#1066129).
- cxgb4: update API for TP indirect register access (bsc#1064802
  bsc#1066129).
- cxgb4: collect firmware mbox and device log dump (bsc#1064802
  bsc#1066129).
- cxgb4: collect on-chip memory dump (bsc#1064802 bsc#1066129).
- cxgb4: collect register dump (bsc#1064802 bsc#1066129).
- cxgb4: implement ethtool dump data operations (bsc#1064802
  bsc#1066129).
- cxgb4: Add support for new flash parts (bsc#1064802
  bsc#1066129).
- cxgb4vf: make a couple of functions static (bsc#1064802
  bsc#1066129).
- cxgb4: Update comment for min_mtu (bsc#1064802 bsc#1066129).
- cxgb4: make function ch_flower_stats_cb, fixes warning
  (bsc#1064802 bsc#1066129).
- net: sched: introduce helper to identify gact pass action
  (bsc#1064802 bsc#1066129).
- cxgb4: do DCB state reset in couple of places (bsc#1064802
  bsc#1066129).
- cxgb4: fetch stats for offloaded tc flower flows (bsc#1064802
  bsc#1066129).
- cxgb4: add support to offload action vlan (bsc#1064802
  bsc#1066129).
- cxgb4: add basic tc flower offload support (bsc#1064802
  bsc#1066129).
- cxgb4: add tc flower offload skeleton (bsc#1064802 bsc#1066129).
- cxgb4: avoid stall while shutting down the adapter (bsc#1064802
  bsc#1066129).
- net: sched: add couple of goto_chain helpers (bsc#1064802
  bsc#1066129).
- net: sched: introduce helper to identify gact trap action
  (bsc#1064802 bsc#1066129).
- commit 20cef46
* Fri Dec  1 2017 tbogendoerfer@suse.de
- Re-sorted series.conf
- commit 7b3ce49
* Fri Dec  1 2017 ghe@suse.com
- ocfs2: fstrim: Fix start offset of first cluster group during
  fstrim (bsc#1063586).
- commit 0ab4132
* Fri Dec  1 2017 lduncan@suse.com
- target: Move a declaration of a global variable into a header
  file (bsc#1070678).
- commit 4efa2af
* Wed Nov 29 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: fix incorrectly moved comment
  While moving # END COMMON DEPS moved following comment with it.
- commit 858b7e7
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: checking the blacklisted hash before loading a kernel
  module (fate#316531, bnc#854875).
- Delete
  patches.suse/0001-MODSIGN-Print-appropriate-status-message-when-access.patch.
- Delete
  patches.suse/MODSIGN-loading-keys-from-db-when-SecureBoot-disabled.patch.
- commit edc0be3
* Wed Nov 29 2017 jack@suse.cz
- eCryptfs: use after free in ecryptfs_release_messaging()
  (bsc#1052766).
- commit f859ac2
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: load blacklist from MOKx (fate#316531, bnc#854875).
- Delete
  patches.suse/0001-MODSIGN-check-hash-of-PKCS-7-signed-kernel-module-in.patch.
- commit 803e6b3
* Wed Nov 29 2017 jack@suse.cz
- xfs: skip bmbt block ino validation during owner change
  (bsc#1052766).
- commit 6bfd0e1
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: print appropriate status message when getting UEFI
  certificates list (fate#316531, bnc#854875).
- Delete
  patches.suse/0002-MODSIGN-load-hash-blacklist-of-modules-from-MOKx.patch.
- commit 7bcb5b3
* Wed Nov 29 2017 jack@suse.cz
- fs/9p: Compare qid.path in v9fs_test_inode (bsc#1052766).
- commit dbfff87
* Wed Nov 29 2017 jack@suse.cz
- mm/page-writeback.c: remove unused parameter from
  balance_dirty_pages() (bsc#1052766).
- blacklist.conf: Blacklist 0fafdc9f888b
- commit 1229ece
* Wed Nov 29 2017 jlee@suse.com
- MODSIGN: do not load mok when secure boot disabled (fate#316531,
  bnc#854875).
- Delete
  patches.suse/0001-MODSIGN-check-hash-of-kernel-module-in-blacklist.patch.
- commit 8579580
* Wed Nov 29 2017 lhenriques@suse.com
- blaclist.conf: ignore a non-critical clk compile-testing fix
- commit e7dbc17
* Wed Nov 29 2017 msuchanek@suse.de
- powerpc/signal: Properly handle return value from
  uprobe_deny_signal() (bsc#1066223, bsc#1065729).
- powerpc/powernv: Make opal_event_shutdown() callable from IRQ
  context (bsc#1066223, bsc#1065729).
- powerpc/opal: Fix EBUSY bug in acquiring tokens (bsc#1066223,
  bsc#1065729).
- commit 8e87d41
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Add MODULE_FIRMWARE statements (bsc#1060463 FATE#323043
  bsc#1036800).
- commit 4895106
* Wed Nov 29 2017 mkubecek@suse.cz
- ipsec: Fix aborted xfrm policy dump crash (CVE-2017-16939
  bsc#1069702).
- commit 1423016
* Wed Nov 29 2017 mkubecek@suse.cz
- series.conf: refresh
  (just ran scripts/series_sort.py)
- commit ae21bc7
* Wed Nov 29 2017 tbogendoerfer@suse.de
- RDMA/core: avoid uninitialized variable warning in create_udata
  (bsc#1046306 FATE#322942).
- commit f931b31
* Wed Nov 29 2017 msuchanek@suse.de
- powerpc/perf: Fix core-imc hotplug callback failure during
  imc initialization (FATE#322448, bsc#1054914).
- commit 38573c2
* Wed Nov 29 2017 tbogendoerfer@suse.de
- blacklist.conf: mark duplicate commit
- commit e6f182d
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Allow MgmtAllowed on B2B setups (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix incorrect available receive user context count
  (bsc#1060463 FATE#323043).
- commit 040fd09
* Wed Nov 29 2017 jthumshirn@suse.de
- Delete
  patches.fixes/nvme-check-for-disk-before-submitting-cmd.patch.
  Not needed anymore and in fact causing regressions (bsc#1070098).
- commit 1c081cf
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Extend input hdr tracing for packet type (bsc#1060463
  FATE#323043).
- Refresh
  patches.drivers/IB-hfi1-Fix-output-trace-issues-from-16B-change.patch.
- commit 5d3e02e
* Wed Nov 29 2017 tbogendoerfer@suse.de
- IB/cm: Fix memory corruption in handling CM request (bsc#1046306
  FATE#322942).
- i40iw: Move cqp_cmd_head init to CQP initialization (bsc#1058659
  FATE#322535).
- i40iw: Remove UDA QP from QoS list if creation fails
  (bsc#1058659 FATE#322535).
- i40iw: Clear CQP Head/Tail during initialization (bsc#1058659
  FATE#322535).
- i40iw: Account for IPv6 header when setting MSS (bsc#1058659
  FATE#322535).
- i40iw: Move exception_lan_queue to VSI structure (bsc#1058659
  FATE#322535).
- i40iw: Ignore AE source field in AEQE for some AEs (bsc#1058659
  FATE#322535).
- i40iw: Cleanup AE processing (bsc#1058659 FATE#322535).
- IB/srp: Avoid that a cable pull can trigger a kernel crash
  (bsc#1046306 FATE#322942).
- i40iw: Do not allow posting WR after QP is flushed (bsc#1058659
  FATE#322535).
- i40iw: Do not generate CQE for RTR on QP flush (bsc#1058659
  FATE#322535).
- i40iw: Do not retransmit MPA request after it is ACKed
  (bsc#1058659 FATE#322535).
- IB/uverbs: clean up INIT_UDATA_BUF_OR_NULL usage (bsc#1046306
  FATE#322942).
- IB/core: Fix calculation of maximum RoCE MTU (bsc#1046306
  FATE#322942).
- net/smc: dev_put for netdev after usage of ib_query_gid()
  (bsc#1046306 FATE#322942).
- net/mlx4_en: Use __force to fix a sparse warning in TX datapath
  (bsc#1046299 FATE#322947).
- net/mlx5: Avoid NULL pointer dereference on steering cleanup
  (bsc#1046303 FATE#322944).
- commit edced08
* Wed Nov 29 2017 mhocko@suse.com
- Update
  patches.kernel.org/4.12.10-050-fork-fix-incorrect-fput-of-exe_file-causing-u.patch
  (bnc#1060662, bnc#1070266, CVE-2017-17052).
- commit e963703
* Wed Nov 29 2017 msuchanek@suse.de
- ibmvnic: fix dma_mapping_error call (bsc#1069942).
  - refresh sorted section
- ibmvnic: Feature implementation of Vital Product Data (VPD)
  for the ibmvnic driver (bsc#1069942).
- commit 4421afe
* Wed Nov 29 2017 msuchanek@suse.de
- ibmvnic: Add vnic client data to login buffer (bsc#1069942).
- commit d008cdc
* Wed Nov 29 2017 tiwai@suse.de
- blacklist.conf: Add an inapplicable DRM blacklist commit
- commit ac5e9b7
* Wed Nov 29 2017 tiwai@suse.de
- video: udlfb: Fix read EDID timeout (bsc#1051510).
- drm/vc4: Account for interrupts in flight (bsc#1051510).
- drm/kirin: Checking for IS_ERR() instead of NULL (bsc#1051510).
- drm/i915: Clear breadcrumb node when cancelling signaling
  (bsc#1051510).
- drm/edid: Don't send non-zero YQ in AVI infoframe for HDMI
  1.x sinks (bsc#1051510).
- drm: handle HDMI 2.0 VICs in AVI info-frames (bsc#1051510).
- drm/tegra: Set MODULE_FIRMWARE for the VIC (bsc#1051510).
- drm/fsl-dcu: avoid disabling pixel clock twice on suspend
  (bsc#1051510).
- drm/atomic-helper: Realign function parameters (bsc#1051510).
- drm/amdgpu: Throttle visible VRAM moves separately
  (bsc#1051510).
- commit a1d9e66
* Wed Nov 29 2017 tiwai@suse.de
- ipmi_si: fix memory leak on new_smi (bsc#1070006).
- ipmi: Prefer ACPI system interfaces over SMBIOS ones
  (bsc#1070006).
- drm/i915: Fix init_clock_gating for resume (bsc#1051510).
- commit e55a660
* Wed Nov 29 2017 lduncan@suse.com
- KEYS: return full count in keyring_read() if buffer is too small
  (bsc#1066478).
- commit db9dfe7
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/mm/radix: Fix crashes on Power9 DD1 with radix MMU and
  STRICT_RWX (bsc#1055186, fate#323286, git-fixes 7614ff3272a1).
- commit a720d8d
* Tue Nov 28 2017 msuchanek@suse.de
- blacklist: fc2a5a6161a2 powerpc/64s: ppc_save_regs is now needed for
  all 64s builds
- commit 23ca0a5
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/64s/slice: Use addr limit when computing slice mask
  (bsc#1070169).
- powerpc/64s: mm_context.addr_limit is only used on hash
  (bsc#1070169).
- powerpc/64s/hash: Allow MAP_FIXED allocations to cross 128TB
  boundary (bsc#1070169).
- powerpc/64s/hash: Fix 128TB-512TB virtual address boundary
  case allocation (bsc#1070169).
- powerpc/64s/hash: Fix fork() with 512TB process address space
  (bsc#1070169).
- powerpc/64s/radix: Fix 128TB-512TB virtual address boundary
  case allocation (bsc#1070169).
- powerpc/64s/hash: Fix 512T hint detection to use >= 128T
  (bsc#1070169).
- commit 9e4b8a7
* Tue Nov 28 2017 tbogendoerfer@suse.de
- RDMA/bnxt_re: synchronize poll_cq and req_notify_cq verbs
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Flush CQ notification Work Queue before destroying
  QP (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Set QP state in case of response completion errors
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Add memory barriers when processing CQ/EQ entries
  (bsc#1050244 FATE#322915).
- bnxt_re: changing the ip address shouldn't affect new
  connections (bsc#1050244 FATE#322915).
- bnxt_re: fix a crash in qp error event processing (bsc#1050244
  FATE#322915).
- bnxt_re: Implement the shutdown hook of the L2-RoCE driver
  interface (bsc#1050244 FATE#322915).
- bnxt_re: Fix incorrect usage of test_bit() (bsc#1050244
  FATE#322915).
- cxgb4: add new T6 pci device id's (bsc#1062057).
- cxgb4: add new T5 pci device id's (bsc#1062057).
- cxgb4: add new T6 pci device id's (bsc#1062057).
- cxgb4: add new T5 pci device id's (bsc#1062057).
- commit c0d6d87
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/kexec: Fix kexec/kdump in P9 guest kernels
  (bsc#1070053).
- powerpc/powernv: Fix kexec crashes caused by tlbie tracing
  (bsc#1055117, fate#323286, git-fixes 0428491cba92).
- commit 1619f34
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/perf/imc: Use cpu_to_node() not
  topology_physical_package_id() (FATE#322448, bsc#1054914).
- powerpc/perf: Fix IMC_MAX_PMU macro (FATE#322448, bsc#1054914).
- commit aff096d
* Tue Nov 28 2017 msuchanek@suse.de
- powerpc/book3s: EXPORT_SYMBOL_GPL machine_check_print_event_info
  (bsc#1061840).
- commit bf1a2aa
* Tue Nov 28 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't call real-mode XICS hypercall
  handlers if not enabled (bsc#1061840).
- KVM: PPC: Book3S HV: Fix exclusion between HPT resizing and
  other HPT updates (bsc#1061840).
- KVM: PPC: Book3S HV: Add more barriers in XIVE load/unload code
  (bsc#1061840).
- KVM: PPC: Book3S HV: Close race with testing for signals on
  guest entry (bsc#1061840).
- KVM: PPC: Book3S HV: Simplify dynamic micro-threading code
  (bsc#1061840).
- KVM: PPC: Book3S HV: Exit guest upon MCE when FWNMI capability
  is enabled (bsc#1061840).
- KVM: PPC: Book3S HV: Add new capability to control MCE behaviour
  (bsc#1061840).
  Refresh patches.drivers/KVM-s390-02-CMMA-tracking-ESSA-emulation-migration-mode.patch.
- commit 1cc7495
* Tue Nov 28 2017 msuchanek@suse.de
- Reorder KVM patches.
- commit 78a9369
* Tue Nov 28 2017 ddiss@suse.de
- target: fix ALUA state file path truncation (bsc#1064606).
- target: fix PR state file path truncation (bsc#1064606).
  Also update patches.drivers/0058-fs-fix-kernel_write-prototype context.
- rbd: set discard_alignment to zero (bsc#1064320).
- commit 684d96b
* Tue Nov 28 2017 mhocko@suse.com
- mm/pagewalk.c: report holes in hugetlb ranges (bnc#1069996,
  CVE-2017-16994).
- commit 346de02
* Mon Nov 27 2017 msuchanek@suse.de
- Do not enforce patch directories yet.
- commit f0d8a60
* Mon Nov 27 2017 dbueso@suse.de
- lib/int_sqrt: adjust comments (bsc#1069436).
- lib/int_sqrt: optimize initial value compute (bsc#1069436).
- lib/int_sqrt: optimize small argument (bsc#1069436).
- kernel/kcmp.c: drop branch leftover typo (bsc#1052639).
- autofs: fix AT_NO_AUTOMOUNT not being honored (bsc#1069987).
- commit 8651b98
* Mon Nov 27 2017 tbogendoerfer@suse.de
- supported.conf: added liquidio, liquidio_vf and opa_vnic
- commit 6dd2c4f
* Mon Nov 27 2017 tbogendoerfer@suse.de
- Update config files.
- commit d61614e
* Mon Nov 27 2017 tbogendoerfer@suse.de
- liquidio: fix timespec64_to_ns typo (bsc#1067126).
- liquidio: fix crash in presence of zeroed-out base address regs
  (bsc#1067126).
- liquidio: show NIC's U-Boot version in a dev_info() message
  (bsc#1067126).
- liquidio: change manner of detecting whether or not NIC firmware
  is loaded (bsc#1067126).
- liquidio: make VF driver notify NIC firmware of MTU change
  (bsc#1067126).
- liquidio: move macro definition to a proper place (bsc#1067126).
- liquidio: fix use of pf in pass-through mode in a virtual
  machine (bsc#1067126).
- liquidio: remove support for deprecated f/w cmd
  OCTNET_CMD_RESET_PF (bsc#1067126).
- liquidio: fix Smatch error (bsc#1067126).
- liquidio: with embedded f/w, issue droq credits before
  enablement (bsc#1067126).
- liquidio: with embedded f/w, don't reload f/w, issue pf flr
  at exit (bsc#1067126).
- liquidio: fix spelling mistake: "interuupt" -> "interrupt"
  (bsc#1067126).
- liquidio: update VF's netdev->max_mtu if there's a change in
  PF's MTU (bsc#1067126).
- liquidio: added support for ethtool --set-channels feature
  (bsc#1067126).
- liquidio: moved octeon_setup_interrupt to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_legacy_intr_handler to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_msix_intr_handler to lio_core.c
  (bsc#1067126).
- liquidio: fix issues with fw_type module parameter
  (bsc#1067126).
- liquidio: added support for ethtool --set-ring feature
  (bsc#1067126).
- liquidio: moved liquidio_setup_io_queues to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_napi_poll to lio_core.c (bsc#1067126).
- liquidio: moved liquidio_napi_drv_callback to lio_core.c
  (bsc#1067126).
- liquidio: moved liquidio_push_packet to lio_core.c
  (bsc#1067126).
- liquidio: moved octeon_setup_droq to lio_core.c (bsc#1067126).
- liquidio: moved update_txq_status to lio_core.c (bsc#1067126).
- liquidio: moved wait_for_pending_requests to octeon_network.h
  (bsc#1067126).
- liquidio: fix duplicated code for different branches
  (bsc#1067126).
- liquidio: update debug console logging mechanism (bsc#1067126).
- liquidio: moved ptp_enable to octeon_device structure
  (bsc#1067126).
- liquidio: removed check for queue size alignment (bsc#1067126).
- liquidio: rx/tx queue cleanup (bsc#1067126).
- liquidio: napi cleanup (bsc#1067126).
- liquidio: fix misspelled firmware image filenames (bsc#1067126).
- liquidio: fix wrong info about vf rx/tx ring parameters reported
  to ethtool (bsc#1067126).
- liquidio: moved console_bitmask module param to lio_main.c
  (bsc#1067126).
- liquidio: add missing strings in oct_dev_state_str array
  (bsc#1067126).
- liquidio: set sriov_totalvfs correctly (bsc#1067126).
- liquidio: bump up driver version to match newer NIC firmware
  (bsc#1067126).
- liquidio: cleanup: removed cryptic and misleading macro
  (bsc#1067126).
- liquidio: standardization: use min_t instead of custom macro
  (bsc#1067126).
- liquidio: fix implicit irq include causing build failures
  (bsc#1067126).
- liquidio: lio_main: remove unnecessary static in
  setup_io_queues() (bsc#1067126).
- liquidio: lio_vf_main: remove unnecessary static in
  setup_io_queues() (bsc#1067126).
- liquidio: lowmem: init allocated memory to 0 (bsc#1067126).
- liquidio: lowmem: do not dereference null ptr (bsc#1067126).
- liquidio: lowmem: init allocated memory to 0 (bsc#1067126).
- liquidio: support new firmware statistic fw_err_pki
  (bsc#1067126).
- liquidio: fix possible eeprom format string overflow
  (bsc#1067126).
- liquidio: stop using huge static buffer, save 4096k in .data
  (bsc#1067126).
- liquidio: replace info-pointer mode with buffer-pointer-only
  mode (bsc#1067126).
- liquidio: implement vlan filter enable and disable
  (bsc#1067126).
- liquidio: fix VF driver off-by-one bug when setting ethtool
  - C ethX rx-frames (bsc#1067126).
- liquidio: disallow enabling firmware debug from a VF
  (bsc#1067126).
- liquidio: Fix checkpatch errors with references crossing single
  line (bsc#1067126).
- liquidio: VF interrupt initialization cleanup (bsc#1067126).
- liquidio: fix inaccurate count of napi-processed rx packets
  reported to Octeon (bsc#1067126).
- liquidio: fix rare pci_driver.probe failure of VF driver
  (bsc#1067126).
- liquidio: make the spinlock octeon_devices_lock static
  (bsc#1067126).
- liquidio: fix PF falsely indicating success at setting MAC
  address of a nonexistent VF (bsc#1067126).
- liquidio: fix insmod failure when multiple NICs are plugged in
  (bsc#1067126).
- liquidio: use pcie_flr instead of duplicating it (bsc#1067126).
- commit 4fe19f6
* Mon Nov 27 2017 tbogendoerfer@suse.de
- IB/rxe: put the pool on allocation failure (bsc#1050662
  FATE#323951).
- commit 927c30e
* Mon Nov 27 2017 pmladek@suse.com
- printk: Make sure to wake up printk kthread from irq work for
  pending output (bnc#744692, bnc#789311).
- Refresh patches.suse/printk-make-synchronous-param-rw.patch.
- commit 2e337de
* Mon Nov 27 2017 tbogendoerfer@suse.de
- IB/rxe: don't crash, if allocation of crc algorithm failed
  (bsc#1051635).
- IB/rxe: check for allocation failure on elem (bsc#1050662
  FATE#323951).
- i40e: Avoid some useless variables and initializers in NVM
  functions (bsc#1056658 FATE#322188).
- i40e: Add programming descriptors to cleaned_count (bsc#1056658
  FATE#322188).
- i40e: Fix incorrect use of tx_itr_setting when checking for
  Rx ITR setup (bsc#1056658 FATE#322188).
- ixgbe: Fix Tx map failure path (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- igb: Fix TX map failure path (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- e1000: avoid null pointer dereference on invalid stat type
  (bsc#1056665 FATE#322184).
- e1000: fix race condition between e1000_down() and
  e1000_watchdog (bsc#1056665 FATE#322184).
- i40e: Fix memory leak related filter programming status
  (bsc#1056658 FATE#322188).
- i40e: Fix comment about locking for __i40e_read_nvm_word()
  (bsc#1056658 FATE#322188).
- ixgbe: incorrect XDP ring accounting in ethtool tx_frame param
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: fix masking of bits read from IXGBE_VXLANCTRL register
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Return error when getting PHY address if PHY access is
  not supported (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- commit 71a839f
* Mon Nov 27 2017 pmladek@suse.com
- Port async printk for SLE15 (bsc#744692, bsc#789311, bsc#995541, bsc#1034995, bsc#1043347)
- Refresh
  patches.suse/printk-Switch-to-the-sync-mode-when-an-emergency-mes.patch.
- Refresh patches.suse/printk-fix-suspend-hang.patch.
- Refresh patches.suse/printk-make-async.patch.
- Refresh
  patches.suse/printk-xen-Force-printk-sync-mode-when-migrating-Xen.patch.
- commit b97b16d
* Mon Nov 27 2017 jthumshirn@suse.de
- Update config files, activate NVMe multipathing on the default kernel.
- commit 02da60f
* Mon Nov 27 2017 jthumshirn@suse.de
- nvmet_fc: fix better length checking (FATE#323952, FATE#322506).
- nvme: expose subsys attribute to sysfs (FATE#323952,
  FATE#322506).
- nvme: create 'slaves' and 'holders' entries for hidden
  controllers (FATE#323952, FATE#322506).
- block: create 'slaves' and 'holders' entries for hidden gendisks
  (FATE#323952, FATE#322506).
- nvme: also expose the namespace identification sysfs files
  for mpath nodes (FATE#323952, FATE#322506).
- nvme: implement multipath access to nvme subsystems
  (FATE#323952, FATE#322506).
- nvme: track shared namespaces (FATE#323952, FATE#322506).
- nvme: introduce a nvme_ns_ids structure (FATE#323952,
  FATE#322506).
- nvme: track subsystems (FATE#323952, FATE#322506).
- commit 6e1681a
* Mon Nov 27 2017 tbogendoerfer@suse.de
- Update config files.
- commit 81510df
* Mon Nov 27 2017 vbabka@suse.cz
- x86/mm: fix use-after-free of vma during userfaultfd fault
  (Git-fixes, bsc#1069916).
- x86/mm: Fix fault error path using unsafe vma pointer
  (Git-fixes, bsc#1069916).
- commit 26d860b
* Mon Nov 27 2017 jthumshirn@suse.de
- nvmet: kill nvmet_inline_bio_init (FATE#323952, FATE#322506).
- nvmet: better data length validation (FATE#323952, FATE#322506).
- nvme-pci: avoid dereference of symbol from unloaded module
  (FATE#323952, FATE#322506).
- nvme: send uevent for some asynchronous events (FATE#323952,
  FATE#322506).
- nvme: unexport starting async event work (FATE#323952,
  FATE#322506).
- nvme: remove handling of multiple AEN requests (FATE#323952,
  FATE#322506).
- nvme-fc: remove unused "queue_size" field (FATE#323952,
  FATE#322506).
- nvme: centralize AEN defines (FATE#323952, FATE#322506).
- nvmet: remove redundant local variable (FATE#323952,
  FATE#322506).
- nvmet: remove redundant memset if failed to get_smart_log failed
  (FATE#323952, FATE#322506).
- blk-mq: Avoid that request queue removal can trigger list
  corruption (FATE#323952, FATE#322506).
- commit de963be
* Mon Nov 27 2017 tbogendoerfer@suse.de
- qed: Fix iWARP out of order flow (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- Refresh
  patches.drivers/IB-Move-PCI-dependency-from-root-KConfig-to-HW-s-KCo.patch.
- commit 8815545
* Mon Nov 27 2017 jthumshirn@suse.de
- nvme: fix eui_show() print format (FATE#323952, FATE#322506).
- nvme: compare NQN string with right size (FATE#323952,
  FATE#322506).
- nvmet: fix comment typos in admin-cmd.c (FATE#323952,
  FATE#322506).
- nvme-rdma: fix nvme_rdma_create_queue_ib error flow
  (FATE#323952, FATE#322506).
- nvmet-rdma: update queue list during ib_device removal
  (FATE#323952, FATE#322506).
- nvme-fc: decouple ns references from lldd references
  (FATE#323952, FATE#322506).
- nvme-fc: fix localport resume using stale values (FATE#323952,
  FATE#322506).
- nvme: check admin passthru command effects (FATE#323952,
  FATE#322506).
- nvme: factor get log into a helper (FATE#323952, FATE#322506).
- nvme: fix and clarify the check for missing metadata
  (FATE#323952, FATE#322506).
- nvme: split __nvme_revalidate_disk (FATE#323952, FATE#322506).
- nvme: set the chunk size before freezing the queue (FATE#323952,
  FATE#322506).
- nvme: don't pass struct nvme_ns to nvme_config_discard
  (FATE#323952, FATE#322506).
- nvme: don't pass struct nvme_ns to nvme_init_integrity
  (FATE#323952, FATE#322506).
- nvme: always unregister the integrity profile in
  __nvme_revalidate_disk (FATE#323952, FATE#322506).
- nvme: move the dying queue check from cancel to completion
  (FATE#323952, FATE#322506).
- commit de01ab6
* Mon Nov 27 2017 jthumshirn@suse.de
- Re-sort series.conf
- commit 3402cbf
* Mon Nov 27 2017 tbogendoerfer@suse.de
- nfp: inherit the max_mtu from the PF netdev (bsc#1055968).
- nfp: fix vlan receive MAC statistics typo (bsc#1055968).
- nfp: fix flower offload metadata flag usage (bsc#1055968).
- IB/core: Only maintain real QPs in the security lists
  (bsc#1046306 FATE#322942).
- IB/hfi1: Mask upper 16Bits of Extended LID prior to rvt_cq_entry
  (bsc#1046306 FATE#322942).
- IB/core: Convert OPA AH to IB for Extended LIDs only
  (bsc#1046306 FATE#322942).
- IB/core: Avoid crash on pkey enforcement failed in received MADs
  (bsc#1046306 FATE#322942).
- IB/mlx4: Fix RSS's QPC attributes assignments (bsc#1046302
  FATE#322945).
- IB/hfi1: Set hdr_type when tx req is allocated (bsc#1060463
  FATE#323043).
- IB/hfi1: Eliminate allocation while atomic (bsc#1060463
  FATE#323043).
- IB/hfi1: Mask out A bit from psn trace (bsc#1060463
  FATE#323043).
- IB/core: Fix endianness annotation in rdma_is_multicast_addr()
  (bsc#1046306 FATE#322942).
- infiniband: add MMU dependency for user_mem (bsc#1046306
  FATE#322942).
- IB/hfi1: Do not warn on lid conversions for OPA (bsc#1046306
  FATE#322942).
- IB/core: Do not warn on lid conversions for OPA (bsc#1046306
  FATE#322942).
- IB/core: Use __be32 for LIDs in opa_is_extended_lid (bsc#1046306
  FATE#322942).
- IB/hfi1: Prevent LNI out of sync by resetting host interface
  version (bsc#1060463 FATE#323043).
- IB/hfi1: Fix output trace issues from 16B change (bsc#1060463
  FATE#323043).
- IB/core: Fix use workqueue without WQ_MEM_RECLAIM (bsc#1046306
  FATE#322942).
- qed: Add iWARP support for fpdu spanned over more than two
  tcp packets (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add support for MPA header being split over two tcp packets
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add support for freeing two ll2 buffers for corner cases
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add unaligned and packed packet processing (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add mpa buffer descriptors for storing and processing
  mpa fpdus (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 connection for processing unaligned MPA packets
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add LL2 slowpath handling (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: Add the source of a packet sent on an iWARP ll2 connection
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Fix initialization of ll2 offload feature (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 option for dropping a tx packet (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 ability of opening a secondary queue (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add ll2 option to limit the number of bds per packet
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Delete redundant check on dcb_app priority (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: iWARP - Add check for errors on a SYN packet (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Fix maximum number of CQs for iWARP (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Add iWARP out of order support (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: Add iWARP enablement support (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- commit f5625a0
* Mon Nov 27 2017 tbogendoerfer@suse.de
- Re-sorted patches
- commit b5ad2da
* Mon Nov 27 2017 tiwai@suse.de
- Revert a broken USB-audio patch (bsc#1051510)
  Delete
  patches.drivers/ALSA-usb-audio-Fix-potential-zero-division-at-parsin.
  Also blacklist it.
- commit 6ef0b1b
* Mon Nov 27 2017 hare@suse.de
- block: avoid null pointer dereference on null disk (FATE#323952,
  FATE#322506).
- commit 81a37d2
* Mon Nov 27 2017 hare@suse.de
- bio: ensure __bio_clone_fast copies bi_partno (FATE#323952,
  FATE#322506).
- fs: guard_bio_eod() needs to consider partitions (FATE#323952,
  FATE#322506).
- block: add a poll_fn callback to struct request_queue
  (FATE#323952, FATE#322506).
- block: introduce GENHD_FL_HIDDEN (FATE#323952, FATE#322506).
- block: don't look at the struct device dev_t in disk_devt
  (FATE#323952, FATE#322506).
- block: add a blk_steal_bios helper (FATE#323952, FATE#322506).
- block: provide a direct_make_request helper (FATE#323952,
  FATE#322506).
- block: add REQ_DRV bit (FATE#323952, FATE#322506).
- block: move REQ_NOWAIT (FATE#323952, FATE#322506).
- btrfs: Fix bug for misused dev_t when lookup in dev state hash
  table (FATE#323952, FATE#322506).
- block: tolerate tracing of NULL bio (FATE#323952, FATE#322506).
- commit ad4c58e
* Mon Nov 27 2017 hare@suse.de
- block: replace bi_bdev with a gendisk pointer and partitions
  index (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/0004-md-Runtime-support-for-multiple-ppls.patch.
- Refresh
  patches.drivers/nvme-factor-metadata-handling-out-of-__nvme_submit_u.patch.
- Refresh
  patches.fixes/nvme-check-for-disk-before-submitting-cmd.patch.
- commit 2c78f3d
* Fri Nov 24 2017 lhenriques@suse.com
- iommu/vt-d: Don't register bus-notifier under dmar_global_lock
  (bsc#1069793).
- commit 0f58c9b
* Fri Nov 24 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Correct supplements for recent SLE products (bsc#1067494)
- commit 8f05b9f
* Fri Nov 24 2017 yousaf.kaukab@suse.com
- hwmon: (xgene) Fix up error handling path mixup in
  'xgene_hwmon_probe()' (bsc#1069757).
- mmc: dw_mmc: Fix the DTO timeout calculation (bsc#1069721).
- mmc: core: add driver strength selection when selecting hs400es
  (bsc#1069721).
- commit 75c3fc9
* Fri Nov 24 2017 jkosina@suse.cz
- HID: elo: clear BTN_LEFT mapping (bsc#1065866).
- commit 9f9219a
* Fri Nov 24 2017 mbrugger@suse.com
- net: hns: set correct return value (bsc#1068693).
- scsi: libsas: move bus_reset_handler() to target_reset_handler()
  (bsc#1068693).
- scsi: hisi_sas: remove driver versioning (bsc#1068693).
- scsi: hisi_sas: add status and command buffer for internal abort
  (bsc#1068693).
- scsi: hisi_sas: support zone management commands (bsc#1068693).
- scsi: hisi_sas: service interrupt ITCT_CLR interrupt in v2 hw
  (bsc#1068693).
- scsi: hisi_sas: add irq and tasklet cleanup in v2 hw
  (bsc#1068693).
- scsi: hisi_sas: remove repeated device config in v2 hw
  (bsc#1068693).
- scsi: hisi_sas: use array for v2 hw ECC errors (bsc#1068693).
- scsi: hisi_sas: add v2 hw DFX feature (bsc#1068693).
- scsi: hisi_sas: fix v2 hw underflow residual value
  (bsc#1068693).
- scsi: hisi_sas: avoid potential v2 hw interrupt issue
  (bsc#1068693).
- scsi: hisi_sas: fix reset and port ID refresh issues
  (bsc#1068693).
- net: hns: Fix for __udivdi3 compiler error (bsc#1068693).
- net: hns: Add self-adaptive interrupt coalesce support in hns
  driver (bsc#1068693).
- hns: remove useless void cast (bsc#1068693).
- clocksource/drivers/arm_arch_timer: Avoid infinite recursion
  when ftrace is enabled (bsc#1068693).
- net: hns: add acpi function of xge led control (bsc#1068693).
- scsi: hisi_sas: make several const arrays static (bsc#1068693).
- net: hns: Bugfix for Tx timeout handling in hns driver
  (bsc#1068693).
- net: hns: Fix a skb used after free bug (bsc#1068693).
- net: hns: Fix a wrong op phy C45 code (bsc#1068693).
- scsi: hisi_sas: optimise DMA slot memory (bsc#1068693).
- scsi: hisi_sas: redefine hisi_sas_phy.phy_type as u32
  (bsc#1068693).
- scsi: hisi_sas: modify internal abort dev flow for v3 hw
  (bsc#1068693).
- scsi: hisi_sas: add v3 code to fill some more hw function
  pointers (bsc#1068693).
- scsi: hisi_sas: add get_wideport_bitmap_v3_hw() (bsc#1068693).
- scsi: hisi_sas: add v3 code to send internal abort command
  (bsc#1068693).
- scsi: hisi_sas: add v3 code for itct setup and free
  (bsc#1068693).
- scsi: hisi_sas: add v3 code to send ATA frame (bsc#1068693).
- scsi: hisi_sas: add v3 code to send SMP frame (bsc#1068693).
- scsi: hisi_sas: add v3 code to send SSP frame (bsc#1068693).
- scsi: hisi_sas: add v3 cq interrupt handler (bsc#1068693).
- scsi: hisi_sas: add phy up/down/bcast and channel ISR
  (bsc#1068693).
- scsi: hisi_sas: add v3 hw PHY init (bsc#1068693).
- scsi: hisi_sas: add v3 hw init (bsc#1068693).
- scsi: hisi_sas: add initialisation for v3 pci-based controller
  (bsc#1068693).
- scsi: hisi_sas: add skeleton v3 hw driver (bsc#1068693).
- scsi: hisi_sas: create hisi_sas_get_fw_info() (bsc#1068693).
- scsi: hisi_sas: add pci_dev in hisi_hba struct (bsc#1068693).
- scsi: hisi_sas: relocate get_ncq_tag_v2_hw() (bsc#1068693).
- scsi: hisi_sas: relocate sata_done_v2_hw() (bsc#1068693).
- scsi: hisi_sas: relocate get_ata_protocol() (bsc#1068693).
- scsi: hisi_sas: optimise the usage of hisi_hba.lock
  (bsc#1068693).
- scsi: hisi_sas: define hisi_sas_device.device_id as int
  (bsc#1068693).
- scsi: hisi_sas: fix timeout check in
  hisi_sas_internal_task_abort() (bsc#1068693).
- scsi: hisi_sas: add null check before indirect pointer
  dereference (bsc#1068693).
- net: hns: Use phy_driver to setup Phy loopback (bsc#1068693).
- net: phy: Add phy loopback support in net phy framework
  (bsc#1068693).
- commit b48234d
* Fri Nov 24 2017 vbabka@suse.cz
- mm, page_alloc: fix potential false positive in
  __zone_watermark_ok (Git-fixes, bsc#1068978).
- commit 79749ae
* Fri Nov 24 2017 tiwai@suse.de
- ALSA: timer: Remove kernel warning at compat ioctl error paths
  (bsc#1051510).
- ALSA: pcm: update tstamp only if audio_tstamp changed
  (bsc#1051510).
- ALSA: usb-audio: Add sanity checks in v2 clock parsers
  (bsc#1051510).
- ALSA: usb-audio: Fix potential zero-division at parsing FU
  (bsc#1051510).
- ALSA: usb-audio: Fix potential out-of-bound access at parsing SU
  (bsc#1051510).
- ALSA: usb-audio: Add sanity checks to FE parser (bsc#1051510).
- ALSA: usb-audio: uac1: Invalidate ctl on interrupt
  (bsc#1051510).
- ALSA: hda: Add Raven PCI ID (bsc#1051510).
- ALSA: hda/realtek - Fix ALC700 family no sound issue
  (bsc#1051510).
- ALSA: hda/realtek: Add headset mic support for Intel NUC Skull
  Canyon (bsc#1051510).
- ALSA: hda: Fix too short HDMI/DP chmap reporting (bsc#1051510).
- ALSA: hda/realtek - Fix ALC275 no sound issue (bsc#1051510).
- commit 2816ae2
* Fri Nov 24 2017 jack@suse.cz
- ext4: fix null pointer dereference on sbi (fate#322879).
- commit f2b1207
* Fri Nov 24 2017 jack@suse.cz
- dax: fix FS_DAX=n BLOCK=y compilation (fate#322879).
- commit e1180b5
* Thu Nov 23 2017 yousaf.kaukab@suse.com
- i2c: xlp9xx: Handle I2C_M_RECV_LEN in msg->flags (bsc#1067225).
- i2c: xlp9xx: Get clock frequency with clk API (bsc#1067225).
- i2c: xlp9xx: Enable HWMON class probing for xlp9xx (bsc#1067225).
- PCI: Mark Cavium CN8xxx to avoid bus reset (bsc#1069250).
- PCI: Apply Cavium ThunderX ACS quirk to more Root Ports (bsc#1069250).
- PCI: Set Cavium ACS capability quirk flags to assert RR/CR/SV/UF (bsc#1069250).
- ACPI / APD: Add clock frequency for ThunderX2 I2C controller (bsc#1067225).
- commit de9db6c
* Thu Nov 23 2017 tiwai@suse.de
- blacklist.conf: Add an iwlwifi blacklist commit
- commit c177979
* Thu Nov 23 2017 tiwai@suse.de
- iwlwifi: fix multi queue notification for a000 devices
  (bsc#1051510).
- iwlwifi: mvm: reset seq num after restart (bsc#1051510).
- iwlwifi: mvm: add missing lq_color (bsc#1051510).
- mac80211: validate user rate mask before configuring driver
  (bsc#1051510).
- iwlwifi: mvm: fix reorder buffer for 9000 devices (bsc#1051510).
- nl80211: fix null-ptr dereference on invalid mesh configuration
  (bsc#1051510).
- nl80211: look for HT/VHT capabilities in beacon's tail
  (bsc#1051510).
- mac80211: agg-tx: call drv_wake_tx_queue in proper context
  (bsc#1051510).
- mwifiex: replace netif_carrier_on/off by
  netif_device_attach/dettach (bsc#1051510).
- commit f574816
* Thu Nov 23 2017 tiwai@suse.de
- blacklist.conf: Blacklist an already-applied drm commit
- commit 3376c3c
* Thu Nov 23 2017 tiwai@suse.de
- drm/sun4i: tcon: Unconditionally reset the TCON (bsc#1051510).
- drm/sun4i: backend: Offset layer buffer address by DRAM starting
  address (bsc#1051510).
- drm/radeon: disable hard reset in hibernate for APUs
  (bsc#1051510).
- drm/nouveau/kms/nv50: perform null check on msto[i] rathern
  than msto (bsc#1051510).
- drm/i915/perf: fix perf enable/disable ioctls with 32bits
  userspace (bsc#1051510).
- drm/i915: Use crtc_state_is_legacy_gamma in intel_color_check
  (bsc#1051510).
- drm/bridge/sii8620: Fix memory corruption (bsc#1051510).
- commit ff1cf1f
* Thu Nov 23 2017 jthumshirn@suse.de
- Refresh
  patches.drivers/block-Fix-a-race-between-blk_cleanup_queue-and-timeo.patch.
- Refresh
  patches.drivers/block-introduce-blk_mq_tagset_iter.patch.
- Refresh patches.drivers/block-remove-blk_mq_reinit_tagset.patch.
- Refresh patches.drivers/nvme-Remove-unused-headers.patch.
- Refresh patches.drivers/nvme-add-duplicate_connect-option.patch.
- Refresh
  patches.drivers/nvme-add-helper-to-compare-options-to-controller.patch.
- Refresh
  patches.drivers/nvme-allow-controller-RESETTING-to-RECONNECTING-tran.patch.
- Refresh
  patches.drivers/nvme-check-for-a-live-controller-in-nvme_dev_open.patch.
- Refresh
  patches.drivers/nvme-comment-typo-fixed-in-clearing-AER.patch.
- Refresh
  patches.drivers/nvme-consolidate-common-code-from-reset_work.patch.
- Refresh
  patches.drivers/nvme-fc-add-a-dev_loss_tmo-field-to-the-remoteport.patch.
- Refresh
  patches.drivers/nvme-fc-add-dev_loss_tmo-timeout-and-remoteport-resu.patch.
- Refresh
  patches.drivers/nvme-fc-add-support-for-duplicate_connect-option.patch.
- Refresh
  patches.drivers/nvme-fc-add-uevent-for-auto-connect.patch.
- Refresh
  patches.drivers/nvme-fc-avoid-workqueue-flush-stalls.patch.
- Refresh
  patches.drivers/nvme-fc-change-ctlr-state-assignments-during-reset-r.patch.
- Refresh
  patches.drivers/nvme-fc-check-connectivity-before-initiating-reconne.patch.
- Refresh
  patches.drivers/nvme-fc-merge-__nvme_fc_schedule_delete_work-into-__.patch.
- Refresh
  patches.drivers/nvme-fc-remove-NVME_FC_MAX_SEGMENTS.patch.
- Refresh
  patches.drivers/nvme-flush-reset_work-before-safely-continuing-with-.patch.
- Refresh patches.drivers/nvme-get-rid-of-nvme_ctrl_list.patch.
- Refresh patches.drivers/nvme-introduce-nvme_reinit_tagset.patch.
- Refresh
  patches.drivers/nvme-move-controller-deletion-to-common-code.patch.
- Refresh
  patches.drivers/nvme-rdma-Add-debug-message-when-reaches-timeout.patch.
- Refresh
  patches.drivers/nvme-rdma-add-support-for-duplicate_connect-option.patch.
- Refresh
  patches.drivers/nvme-rdma-align-nvme_rdma_device-structure.patch.
- Refresh
  patches.drivers/nvme-rdma-remove-nvme_rdma_remove_ctrl.patch.
- Refresh
  patches.drivers/nvme-rdma-reuse-nvme_delete_ctrl-when-reconnect-atte.patch.
- Refresh patches.drivers/nvme-simplify-nvme_open.patch.
- Refresh
  patches.drivers/nvme-switch-controller-refcounting-to-use-struct-dev.patch.
- Refresh
  patches.drivers/nvme-use-kref_get_unless_zero-in-nvme_find_get_ns.patch.
- Refresh patches.drivers/nvmet-fix-fatal_err_work-deadlock.patch.
  Update Patch-mainline tag.
- commit b021439
* Thu Nov 23 2017 hare@suse.de
- block: cache the partition index in struct block_device
  (FATE#323952, FATE#322506).
- block: add a __disk_get_part helper (FATE#323952, FATE#322506).
- block: reject attempts to allocate more than DISK_MAX_PARTS
  partitions (FATE#323952, FATE#322506).
- raid5: remove a call to get_start_sect (FATE#323952,
  FATE#322506).
- btrfs: index check-integrity state hash by a dev_t (FATE#323952,
  FATE#322506).
- commit f184e50
* Thu Nov 23 2017 tiwai@suse.de
- blacklist.conf: Add an amdgpu blacklist commit (bsc#1051510)
- commit 08272a2
* Thu Nov 23 2017 tiwai@suse.de
- drm/amd/powerplay: initialize a variable before using it
  (bsc#1051510).
- commit c3e3026
* Thu Nov 23 2017 tiwai@suse.de
- Refresh patches.fixes/drm-amdgpu-revert-update-tile-table-for-oland-hainan.patch
  Add the upstream commit information.
- commit 24df947
* Thu Nov 23 2017 tiwai@suse.de
- mmc: sdhci-pci: remove outdated declaration (bsc#1051510).
- mmc: sdhci-pci: Fix default d3_retune for Intel host controllers
  (bsc#1051510).
- staging: rtl8723bs: avoid null pointer dereference on pmlmepriv
  (bsc#1051510).
- rtlwifi: rtl8821ae: Fix HW_VAR_NAV_UPPER operation
  (bsc#1051510).
- PM / devfreq: Fix memory leak when fail to register device
  (bsc#1051510).
- commit 6bc162b
* Thu Nov 23 2017 tiwai@suse.de
- mfd: intel_soc_pmic: Export separate mfd-cell configs for BYT
  and CHT (bsc#1051510).
- Refresh
  patches.drivers/mfd-intel_soc_pmic-Differentiate-between-Bay-and-Che.
- commit 07bf2c4
* Thu Nov 23 2017 tiwai@suse.de
- ASoC: sun8i-codec: Fix left and right channels inversion
  (bsc#1051510).
- ASoC: cs42l56: Fix reset GPIO name in example DT binding
  (bsc#1051510).
- ALSA: usb-audio: support new Amanero Combo384 firmware version
  (bsc#1051510).
- ALSA: timer: Add missing mutex lock for compat ioctls
  (bsc#1051510).
- ALSA: compress: Remove unused variable (bsc#1051510).
- commit 42e54fa
* Thu Nov 23 2017 hare@suse.de
- Move MD RAID patches to ordered section
- Refresh
  patches.drivers/0001-raid5-ppl-check-recovery_offset-when-performing-ppl-.patch.
- Refresh
  patches.drivers/0002-raid5-ppl-don-t-resync-after-rebuild.patch.
- commit eb74fe0
* Thu Nov 23 2017 hare@suse.de
- blk-mq: enable checking two part inflight counts at the same
  time (FATE#323952, FATE#322506).
- blk-mq: provide internal in-flight variant (FATE#323952,
  FATE#322506).
- block: make part_in_flight() take an array of two ints
  (FATE#323952, FATE#322506).
- block: pass in queue to inflight accounting (FATE#323952,
  FATE#322506).
- blk-mq-tag: check for NULL rq when iterating tags (FATE#323952,
  FATE#322506).
- commit 1b31ec9
* Thu Nov 23 2017 jthumshirn@suse.de
- nvme: comment typo fixed in clearing AER (FATE#323952,
  FATE#322506).
- nvme: Remove unused headers (FATE#323952, FATE#322506).
- nvmet: fix fatal_err_work deadlock (FATE#323952, FATE#322506).
- nvme-fc: add dev_loss_tmo timeout and remoteport resume support
  (FATE#323952, FATE#322506).
- nvme: allow controller RESETTING to RECONNECTING transition
  (FATE#323952, FATE#322506).
- nvme-fc: check connectivity before initiating reconnects
  (FATE#323952, FATE#322506).
- nvme-fc: add a dev_loss_tmo field to the remoteport
  (FATE#323952, FATE#322506).
- nvme-fc: change ctlr state assignments during reset/reconnect
  (FATE#323952, FATE#322506).
- nvme: flush reset_work before safely continuing with delete
  operation (FATE#323952, FATE#322506).
- nvme-rdma: reuse nvme_delete_ctrl when reconnect attempts expire
  (FATE#323952, FATE#322506).
- nvme: consolidate common code from ->reset_work (FATE#323952,
  FATE#322506).
- nvme-rdma: remove nvme_rdma_remove_ctrl (FATE#323952,
  FATE#322506).
- nvme: move controller deletion to common code (FATE#323952,
  FATE#322506).
- nvme-fc: merge __nvme_fc_schedule_delete_work into
  __nvme_fc_del_ctrl (FATE#323952, FATE#322506).
- nvme-fc: avoid workqueue flush stalls (FATE#323952,
  FATE#322506).
- nvme-fc: remove NVME_FC_MAX_SEGMENTS (FATE#323952, FATE#322506).
- nvme-fc: add support for duplicate_connect option (FATE#323952,
  FATE#322506).
- nvme-rdma: add support for duplicate_connect option
  (FATE#323952, FATE#322506).
- nvme: add helper to compare options to controller (FATE#323952,
  FATE#322506).
- nvme: add duplicate_connect option (FATE#323952, FATE#322506).
- commit 9578246
* Thu Nov 23 2017 hare@suse.de
- Btrfs: use bio_clone_bioset_partial to simplify DIO submit
  (FATE#323952, FATE#322506).
- Btrfs: new helper btrfs_bio_clone_partial (FATE#323952,
  FATE#322506).
- Btrfs: use bio_clone_fast to clone our bio (FATE#323952,
  FATE#322506).
- commit aef50da
* Thu Nov 23 2017 jthumshirn@suse.de
- nvme: check for a live controller in nvme_dev_open (FATE#323952,
  FATE#322506).
- nvme: get rid of nvme_ctrl_list (FATE#323952, FATE#322506).
- nvme: switch controller refcounting to use struct device
  (FATE#323952, FATE#322506).
- nvme: simplify nvme_open (FATE#323952, FATE#322506).
- nvme: use kref_get_unless_zero in nvme_find_get_ns (FATE#323952,
  FATE#322506).
- nvme-rdma: Add debug message when reaches timeout (FATE#323952,
  FATE#322506).
- nvme-rdma: align nvme_rdma_device structure (FATE#323952,
  FATE#322506).
- commit 8f38e6b
* Thu Nov 23 2017 jthumshirn@suse.de
- block: Fix a race between blk_cleanup_queue() and timeout
  handling (FATE#323952, FATE#322506).
- block: introduce blk_mq_tagset_iter (FATE#323952, FATE#322506).
- block: remove blk_mq_reinit_tagset (FATE#323952, FATE#322506).
- nvme-fc: add uevent for auto-connect (FATE#323952, FATE#322506).
- nvme: introduce nvme_reinit_tagset (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/nvme-fc-move-remote-port-get-put-free-location.patch.
- Refresh patches.suse/blk-timeout-no-round.
- commit 990148a
* Thu Nov 23 2017 jthumshirn@suse.de
- nvme: Fix setting logical block format when revalidating
  (FATE#323952, FATE#322506).
- nvme-fc: fix iowait hang (FATE#323952, FATE#322506).
- nvme-fc: retry initial controller connections 3 times
  (FATE#323952, FATE#322506).
- nvme-pci: Use PCI bus address for data/queues in CMB
  (FATE#323952, FATE#322506).
- nvme-rdma: Fix error status return in tagset allocation failure
  (FATE#323952, FATE#322506).
- nvme-rdma: Fix possible double free in reconnect flow
  (FATE#323952, FATE#322506).
- nvme-rdma: fix possible hang when issuing commands during ctrl
  removal (FATE#323952, FATE#322506).
- nvmet: synchronize sqhd update (FATE#323952, FATE#322506).
- Refresh
  patches.drivers/nvme-rdma-change-queue-flag-semantics-DELETING-ALLOC.patch.
- commit 4b99674
* Thu Nov 23 2017 mgorman@suse.de
- Update
  patches.suse/cpufreq-intel_pstate-use-setpoint-of-40-on-servers.patch
  (bnc#945201,bnc#1064414).
  Update
  patches.suse/cpufreq-ondemand-set-default-up_threshold-to-40-on-multi-core-systems.patch
  (bnc#945201,bnc#1064414).
- commit 4ef8315
* Wed Nov 22 2017 jack@suse.cz
- fs, dax: unify IOMAP_F_DIRTY read vs write handling policy in
  the dax core (fate#322879).
- xfs: support for synchronous DAX faults (fate#322879).
- xfs: Implement xfs_filemap_pfn_mkwrite() using
  __xfs_filemap_fault() (fate#322879).
- ext4: Support for synchronous DAX faults (fate#322879).
- ext4: Simplify error handling in ext4_dax_huge_fault()
  (fate#322879).
- dax: Implement dax_finish_sync_fault() (fate#322879).
- dax, iomap: Add support for synchronous faults (fate#322879).
- mm: Define MAP_SYNC and VM_SYNC flags (fate#322879).
- dax: Allow tuning whether dax_insert_mapping_entry() dirties
  entry (fate#322879).
- dax: Allow dax_iomap_fault() to return pfn (fate#322879).
- dax: Fix comment describing dax_iomap_fault() (fate#322879).
- dax: Inline dax_pmd_insert_mapping() into the callsite
  (fate#322879).
- dax: Inline dax_insert_mapping() into the callsite
  (fate#322879).
- dax: Create local variable for vmf->flags & FAULT_FLAG_WRITE
  test (fate#322879).
- dax: Create local variable for VMA in dax_iomap_pte_fault()
  (fate#322879).
- dax: Factor out getting of pfn out of iomap (fate#322879).
- dax: Simplify arguments of dax_insert_mapping() (fate#322879).
- mm: Remove VM_FAULT_HWPOISON_LARGE_MASK (fate#322879).
- mm: introduce MAP_SHARED_VALIDATE, a mechanism to safely define
  new mmap flags (fate#322879).
- mm: Handle 0 flags in _calc_vm_trans() macro (fate#322879).
- ext4: perform dax_device lookup at mount (fate#322879).
- ext2: perform dax_device lookup at mount (fate#322879).
- xfs: perform dax_device lookup at mount (fate#322879).
- dax: introduce a fs_dax_get_by_bdev() helper (fate#322879).
- ext4: fix fault handling when mounted with -o dax,ro
  (fate#322879).
- xfs: consolidate the various page fault handlers (fate#322879).
- iomap: return VM_FAULT_* codes from iomap_page_mkwrite
  (fate#322879).
- commit 4b7d25c
* Wed Nov 22 2017 jkosina@suse.cz
- Update config files: enable KASLR for x86_64 (FATE#323473)
- commit a75287b
* Wed Nov 22 2017 hare@suse.de
- scsi: megaraid_sas: driver version upgrade
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Add support for 64bit consistent DMA
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Do not limit queue_depth to 1k in non-RDPQ
  mode (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Retry with reduced queue depth when alloc
  fails for higher QD (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Incorrect processing of IOCTL frames for
  SMP/STP commands (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Resize MFA frame used for IOC INIT to 4k
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Update current host time to FW during IOC
  Init (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Move controller memory allocations
  and DMA mask settings from probe to megasas_init_fw
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Move initialization of instance parameters
  inside newly created function megasas_init_ctrl_params
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: remove instance->ctrl_info
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Pre-allocate frequently used DMA buffers
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Create separate functions for allocating
  and freeing controller DMA buffers (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Create separate functions to allocate ctrl
  memory (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: reduce size of fusion_context and use
  kmalloc for allocation (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: replace is_ventura with adapter_type checks
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Remove redundant checks for ctrl_context
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: replace instance->ctrl_context checks with
  instance->adapter_type (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: Add support for Crusader controllers
  (bsc#1066909,FATE#322937).
- scsi: megaraid_sas: use adapter_type for all gen controllers
  (bsc#1066909,FATE#322937).
- commit 2b04e3e
* Wed Nov 22 2017 tbogendoerfer@suse.de
- net/mlx5e: Increase Striding RQ minimum size limit to 4
  multi-packet WQEs (bsc#1046303 FATE#322944).
- net/mlx5e: Set page to null in case dma mapping fails
  (bsc#1046303 FATE#322944).
- net/mlx5e: Fix napi poll with zero budget (bsc#1046305
  FATE#322943).
- net/mlx5: Cancel health poll before sending panic teardown
  command (bsc#1046303 FATE#322944).
- net/mlx5: Loop over temp list to release delay events
  (bsc#1046303 FATE#322944).
- net/mlx5e/core/en_fs: fix pointer dereference after free in
  mlx5e_execute_l2_action (bsc#1046305 FATE#322943).
- commit 919ca4c
* Wed Nov 22 2017 hare@suse.de
- s390x/default: Enable CONFIG_TUNE_Z13 (bsc#1067886)
  Update s390x config files.
- commit e68d618
* Wed Nov 22 2017 hare@suse.de
- Fixup s390x zfcpdump build failure (bsc#1066354)
  Refresh patches.drivers/s390-cpu-alternatives.patch.
- commit 2b990ee
* Wed Nov 22 2017 oneukum@suse.com
- net: cdc_ether: fix divide by 0 on bad descriptors (bsc#1067085
  CVE-2017-16649).
- commit 73a409e
* Wed Nov 22 2017 jkosina@suse.cz
- Update config files: INTEL_SOC_PMIC=n for arm/vanilla
- commit c812597
* Wed Nov 22 2017 tiwai@suse.de
- Enable ACP, SI, CIK and USERPTR for amdgpu (bsc#1069343)
- commit 37a7bbc
* Tue Nov 21 2017 jslaby@suse.cz
- objtool: Print top level commands on incorrect usage
  (bnc#1058115).
- x86/unwind: Disable KASAN checking in the ORC unwinder
  (bnc#1058115).
- x86/module: Detect and skip invalid relocations (bnc#1058115).
- objtool: Prevent GCC from merging annotate_unreachable(),
  take 2 (bnc#1058115).
- commit 24f3048
* Tue Nov 21 2017 tiwai@suse.de
- drm/i915/skl+: unify cpp value in WM calculation (FATE#322643
  bsc#1055900).
- drm/i915/skl+: WM calculation don't require height (FATE#322643
  bsc#1055900).
- drm/i915/skl+: Scaling not supported in IF-ID Interlace mode
  (FATE#322643 bsc#1055900).
- drm/i915/skl+: Check for supported plane configuration in
  Interlace mode (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable wrpll computation for CNL (FATE#322643
  bsc#1055900).
- commit 10cf16b
* Tue Nov 21 2017 tiwai@suse.de
- platform/x86: sony-laptop: Fix error handling in
  sony_nc_setup_rfkill() (bsc#1051510).
- platform/x86: hp-wmi: Fix tablet mode detection for convertibles
  (bsc#1051510).
- platform/x86: fujitsu-laptop: Fix radio LED detection
  (bsc#1051510).
- serial: 8250_fintek: Fix rs485 disablement on invalid ioctl()
  (bsc#1051510).
- mfd: rn5t618: Unregister restart handler on remove
  (bsc#1051510).
- mfd: lpc_ich: Do not touch SPI-NOR write protection bit on
  Haswell/Broadwell (bsc#1051510).
- mfd: intel_soc_pmic: Differentiate between Bay and Cherry
  Trail CRC variants (bsc#1051510).
- mfd: intel_soc_pmic: Select designware i2c-bus driver
  (bsc#1051510).
- media: usbtv: fix brightness and contrast controls
  (bsc#1051510).
- media: omap_vout: Fix a possible null pointer dereference in
  omap_vout_open() (bsc#1051510).
- commit 25e6140
* Tue Nov 21 2017 tiwai@suse.de
- Update blacklist and no-fix tags
  Refreshed:
  patches.drivers/drm-i915-Always-wake-the-device-to-flush-the-GTT
  patches.drivers/drm-i915-bxt-set-min-brightness-from-VBT
- commit e7acd40
* Tue Nov 21 2017 tiwai@suse.de
- drm/tilcdc: Precalculate total frametime in
  tilcdc_crtc_set_mode() (bsc#1051510).
- drm/panel: simple: Fix width and height for Olimex
  LCD-OLinuXino-4.3TS (bsc#1051510).
- drm/panel: simple: Add missing panel_simple_unprepare() calls
  (bsc#1051510).
- drm/i915: Prune the reservation shared fence array
  (bsc#1051510).
- drm/i915: Move init_clock_gating() back to where it was
  (bsc#1051510).
- drm: gma500: fix logic error (bsc#1051510).
- drm: Drop drm_get_link_status_name() (bsc#1051510).
- commit f67acae
* Tue Nov 21 2017 jslaby@suse.cz
- x86/unwind: Make CONFIG_UNWINDER_ORC=y the default in kconfig
  for 64-bit (bnc#1058115).
- Update config files.
- x86/unwind: Rename unwinder config options to
  'CONFIG_UNWINDER_*' (bnc#1058115).
- Refresh patches.suse/0001-orc-mark-it-as-reliable.patch.
- Update config files.
- x86/unwinder: Make CONFIG_UNWINDER_ORC=y the default in the
  64-bit defconfig (bnc#1058115).
- commit b87f785
* Tue Nov 21 2017 jslaby@suse.cz
- x86/stacktrace: Avoid recording save_stack_trace() wrappers
  (bnc#1058115).
- commit d5fd971
* Tue Nov 21 2017 tiwai@suse.de
- ASoC: topology: Fix a potential memory leak in
  'soc_tplg_dapm_widget_denum_create()' (bsc#1051510).
- ASoC: topology: Fix a potential NULL pointer dereference in
  'soc_tplg_dapm_widget_denum_create()' (bsc#1051510).
- ASoC: sun8i-codec: Set the BCLK divider (bsc#1051510).
- ASoC: sun8i-codec: Invert Master / Slave condition
  (bsc#1051510).
- ASoC: samsung: Fix possible double iounmap on s3c24xx driver
  probe failure (bsc#1051510).
- ASoC: samsung: Fix invalid argument when devm_gpiod_get is
  called (bsc#1051510).
- ASoC: rt5665: fix gcc-7 warning (bsc#1051510).
- ASoC: rt5665: Fix uninitialized warning in
  rt5665_i2s_pin_event() (bsc#1051510).
- ASoC: rt5514: fix gcc-7 warning (bsc#1051510).
- ASoC: rsnd: avoid duplicate free_irq() (bsc#1051510).
- ASoC: rockchip: Correct 'dmic-delay' property name
  (bsc#1051510).
- ASoC: mediatek: Fix an error checking code (bsc#1051510).
- ASoC: intel: include linux/module.h as needed (bsc#1051510).
- ASoC: davinci-mcasp: Fix an error handling path in
  'davinci_mcasp_probe()' (bsc#1051510).
- ASoC: codecs: msm8916: fix invalid cast to bool type
  (bsc#1051510).
- commit 4a79751
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
  Update upstream status.
- commit e207155
* Tue Nov 21 2017 bp@suse.de
- blacklist.conf: no need for 9275b933d409
- commit 18d829a
* Tue Nov 21 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-futex-futex_wake_op-do-not-fail-on-invalid-op.patch.
  Update upstream status
- commit 915f469
* Tue Nov 21 2017 jslaby@suse.cz
- crypto: x86/chacha20 - satisfy stack validation 2.0
  (bnc#1058115).
- commit e52c6fc
* Tue Nov 21 2017 bp@suse.de
- X86/KVM: Clear encryption attribute when SEV is active
  (bsc#1063068).
- X86/KVM: Decrypt shared per-cpu variables when SEV is active
  (bsc#1063068).
- percpu: Introduce DEFINE_PER_CPU_DECRYPTED (bsc#1063068).
- x86: Add support for changing memory encryption attribute in
  early boot (bsc#1063068).
- x86/io: Unroll string I/O when SEV is active (bsc#1063068).
- x86/boot: Add early boot support when running with SEV active
  (bsc#1063068).
- x86/mm: Add DMA support for SEV memory encryption (bsc#1063068).
- x86/mm, resource: Use PAGE_KERNEL protection for ioremap of
  memory pages (bsc#1063068).
- resource: Provide resource struct in resource walk callback
  (bsc#1063068).
- resource: Consolidate resource walking code (bsc#1063068).
- x86/efi: Access EFI data as encrypted when SEV is active
  (bsc#1063068).
- x86/mm: Include SEV for encryption memory attribute changes
  (bsc#1063068).
- x86/mm: Use encrypted access of boot related data with SEV
  (bsc#1063068).
- x86/realmode: Don't decrypt trampoline area under SEV
  (bsc#1063068).
- x86/mm: Don't attempt to encrypt initrd under SEV (bsc#1063068).
- x86/mm: Add Secure Encrypted Virtualization (SEV) support
  (bsc#1063068).
- Documentation/x86: Add AMD Secure Encrypted Virtualization
  (SEV) description (bsc#1063068).
- commit 4c52764
* Tue Nov 21 2017 jthumshirn@suse.de
- nvme: check for disk before submitting cmd (bsc#1067848).
- commit 3af97e1
* Mon Nov 20 2017 mgorman@suse.de
- cpufreq: intel_pstate: Drop ->get from intel_pstate structure
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- commit d7b80bc
* Mon Nov 20 2017 mgorman@suse.de
- cpufreq: intel_pstate: report correct CPU frequencies during
  trace (bnc#1068680 Update schedutil and intel_pstate to default
  to load-based policy).
- cpufreq: schedutil: Fix sugov_start() versus
  sugov_update_shared() race (bnc#1068680 Update schedutil and
  intel_pstate to default to load-based policy).
- cpuidle: menu: allow state 0 to be disabled (bnc#1068680 Update
  schedutil and intel_pstate to default to load-based policy).
- cpufreq: intel_pstate: Fix ratio setting for min_perf_pct
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- cpufreq: intel_pstate: constify attribute_group structures
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- cpufreq: intel_pstate: Clean up after performance governor
  changes (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- intel_pstate: skip scheduler hook when in "performance" mode
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- intel_pstate: delete scheduler hook in HWP mode (bnc#1068680
  Update schedutil and intel_pstate to default to load-based
  policy).
- cpufreq: intel_pstate: Remove max/min fractions to limit
  performance (bnc#1068680 Update schedutil and intel_pstate to
  default to load-based policy).
- intel_pstate: use updated msr-index.h HWP.EPP values
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- commit 5cdc1ae
* Mon Nov 20 2017 mhocko@suse.com
- mm/page_ext.c: check if page_ext is not prepared (bnc#1068982).
- commit ee8873e
* Mon Nov 20 2017 mgorman@suse.de
- x86: msr-index.h: fix shifts to ULL results in HWP macros
  (bnc#1068680 Update schedutil and intel_pstate to default to
  load-based policy).
- x86: msr-index.h: define HWP.EPP values (bnc#1068680 Update
  schedutil and intel_pstate to default to load-based policy).
- x86: msr-index.h: define EPB mid-points (bnc#1068680 Update
  schedutil and intel_pstate to default to load-based policy).
- commit d4d2ce6
* Mon Nov 20 2017 jeffm@suse.com
- ext4: in ext4_seek_{hole,data}, return -ENXIO for negative
  offsets (bsc#1068897).
- commit b65087c
* Mon Nov 20 2017 mhocko@suse.com
- mm/page_alloc.c: broken deferred calculation (bnc#1068980).
- commit eef6b44
* Mon Nov 20 2017 jthumshirn@suse.de
- PCI: vmd: Free up IRQs on suspend path (bsc#1067483).
- commit 8be6133
* Mon Nov 20 2017 hare@suse.de
- KVM: s390: Fix KVM_S390_GET_CMMA_BITS ioctl definition
  (LTC#160419,bsc#1066194).
- commit a777801
* Mon Nov 20 2017 hare@suse.de
- Update s390x config files.
- commit ba626f1
* Mon Nov 20 2017 mhocko@suse.com
- mm, sparse: do not swamp log with huge vmemmap allocation
  failures (bnc#1040797).
- commit d6d0c93
* Mon Nov 20 2017 mhocko@suse.com
- mm, memory_hotplug: remove timeout from __offline_memory
  (bnc#1051406).
- mm, memory_hotplug: do not fail offlining too early
  (bnc#1051406).
- mm, page_alloc: fail has_unmovable_pages when seeing reserved
  pages (bnc#1051406).
- mm: distinguish CMA and MOVABLE isolation in
  has_unmovable_pages() (bnc#1051406).
- commit e2cd981
* Mon Nov 20 2017 yousaf.kaukab@suse.com
- drm: bridge: synopsys/dw-hdmi: Provide default configuration
  function for HDMI 2.0 PHY (fate#323912).
- commit 97f9ebc
* Mon Nov 20 2017 bp@suse.de
- x86/MCE/AMD: Always give panic severity for UC errors in kernel
  context (git-fixes bf80bbd7dcf5).
- commit af09f69
* Mon Nov 20 2017 bp@suse.de
- x86/intel_rdt: Initialize bitmask of shareable resource if CDP enabled (git-fixes 0dd2d7494cd8).
- blacklist.conf: 3916a4135c696fa226a1abe6d6a0ff7f5edd9a7c and
  ac5292e9a294618cecb31109d1ba265e3d027ba2
- commit 7d8d364
* Mon Nov 20 2017 hare@suse.de
- s390/noexec: execute kexec datamover without DAT (bnc#1066799, LTC#161403).
- commit 7dec3bf
* Mon Nov 20 2017 hare@suse.de
- scsi: zfcp: fix erp_action use-before-initialize in REC action
  trace (bnc#1066983, LTC#160081).
- s390/cputime: fix guest/irq/softirq times after CPU hotplug
  (bnc#1066983, LTC#161328).
- commit f168a73
* Mon Nov 20 2017 hare@suse.de
- s390/topology: enable / disable topology dynamically
  (bnc#1066983, LTC#159177).
- s390/topology: alternative topology for topology-less machines
  (bnc#1066983, LTC#159177).
- s390/mm: fix write access check in gup_huge_pmd() (bnc#1066983,
  LTC#160551).
- scsi: zfcp: trace high part of "new" 64 bit SCSI LUN
  (bnc#1066983, LTC#158495).
- scsi: zfcp: trace HBA FSF response by default on dismiss or
  timedout late response (bnc#1066983, LTC#158494).
- scsi: zfcp: fix payload with full FCP_RSP IU in SCSI trace
  records (bnc#1066983, LTC#158494).
- scsi: zfcp: fix missing trace records for early returns in
  TMF eh handlers (bnc#1066983, LTC#158494).
- scsi: zfcp: fix passing fsf_req to SCSI trace on TMF to
  correlate with HBA (bnc#1066983, LTC#158494).
- scsi: zfcp: fix capping of unsuccessful GPN_FT SAN response
  trace records (bnc#1066983, LTC#158494).
- scsi: zfcp: fix queuecommand for scsi_eh commands when DIX
  enabled (bnc#1066983, LTC#158493).
- s390/vmcp: make use of contiguous memory allocator (bnc#1066983,
  LTC#159171).
- s390/cpcmd,vmcp: avoid GFP_DMA allocations (bnc#1066983,
  LTC#159112).
- s390/mm: prevent memory offline for memory blocks with cma areas
  (bnc#1066983, LTC#159171).
- s390/mm: add missing virt_to_pfn() etc. helper functions
  (bnc#1066983, LTC#159171).
- s390/pci: recognize name clashes with uids (bnc#1066983,
  LTC#157731).
- s390/pci: provide more debug information (bnc#1066983,
  LTC#157731).
- s390/pci: fix handling of PEC 306 (bnc#1066983, LTC#157731).
- s390/pci: improve pci hotplug (bnc#1066983, LTC#157731).
- s390/pci: introduce clp_get_state (bnc#1066983, LTC#157731).
- s390/pci: improve error handling during fmb (de)registration
  (bnc#1066983, LTC#157731).
- s390/pci: improve unreg_ioat error handling (bnc#1066983,
  LTC#157731).
- s390/pci: improve error handling during interrupt deregistration
  (bnc#1066983, LTC#157731).
- s390/pci: don't cleanup in arch_setup_msi_irqs (bnc#1066983,
  LTC#157731).
- commit 187b6e4
* Mon Nov 20 2017 hare@suse.de
- s390/spinlock: use cpu alternatives to enable niai instruction
  (FATE#322614,LTC#160173,bsc#1066354).
- commit 2099d05
* Mon Nov 20 2017 hare@suse.de
- s390: introduce CPU alternatives
  (FATE#322614,LTC#160173,bsc#1066354).
- commit c544efd
* Mon Nov 20 2017 hare@suse.de
- s390/spinlock: add niai spinlock hints
  (FATE#322614,LTC#160173,bsc#1066354).
- commit 670388a
* Mon Nov 20 2017 hare@suse.de
- Refresh patch header to reflect mainline status
- Refresh
  patches.drivers/0001-scsi-be2iscsi-fix-boot-flags-in-sysfs.
- Refresh
  patches.drivers/0002-scsi-be2iscsi-fix-return-value-in-mgmt_open_connection.
- Refresh
  patches.drivers/0003-scsi-be2iscsi-free-msi_name-and-disable-hw-intr.
- Refresh
  patches.drivers/0004-scsi-be2iscsi-fix-modify_eq_delay-buffer-overflow.
- Refresh
  patches.drivers/0005-scsi-be2iscsi-fix-get_initname-buffer-overflow.
- Refresh
  patches.drivers/0006-scsi-be2iscsi-modify-ioctl-to-fetch-user-configured-iqn.
- Refresh
  patches.drivers/0007-scsi-be2iscsi-add-cmd-to-set-host-data.
- Refresh
  patches.drivers/0008-scsi-be2iscsi-fix-misc-static-analysis-errors.
- Refresh
  patches.drivers/0009-scsi-be2iscsi-remove-a-circumflex-character-in-copyright-marking.
- Refresh
  patches.drivers/0010-scsi-be2iscsi-update-driver-version.
- Refresh
  patches.drivers/IB-Move-PCI-dependency-from-root-KConfig-to-HW-s-KCo.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-iWARP-connection-management-functions.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-iWARP-connection-management-qp-related.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-iWARP-support-in-existing-verbs.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-support-for-iWARP-in-user-space.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-support-for-read-with-invalidate-suppo.patch.
- Refresh
  patches.drivers/RDMA-qedr-Add-support-for-registering-an-iWARP-devic.patch.
- Refresh
  patches.drivers/RDMA-qedr-Fix-rdma_type-initialization.patch.
- Refresh
  patches.drivers/RDMA-qedr-Missing-error-code-in-qedr_init_user_queue.patch.
- Refresh
  patches.drivers/RDMA-qedr-Rename-the-qedr_cm-file-as-a-preparation-f.patch.
- Refresh
  patches.drivers/RDMA-qedr-fix-build-error-without-ipv6.patch.
- Refresh
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- Refresh patches.drivers/ibmvnic-113-Set-state-UP.patch.
- Refresh
  patches.drivers/ibmvnic-115-Enable-scatter-gather-support.patch.
- Refresh patches.drivers/ibmvnic-116-Enable-TSO-support.patch.
- Refresh
  patches.drivers/ibmvnic-117-Let-users-change-net-device-features.patch.
- Refresh
  patches.drivers/ibmvnic-118-Update-reset-infrastructure-to-support-tunab.patch.
- Refresh
  patches.drivers/ibmvnic-119-Fix-failover-error-path-for-non-fatal-resets.patch.
- Refresh
  patches.drivers/nvme-fabrics-request-transport-module.patch.
- Refresh
  patches.drivers/nvme-fc-Add-BLK_MQ_F_NO_SCHED-flag-to-admin-tag-set.patch.
- Refresh
  patches.drivers/nvme-fc-correct-io-termination-handling.patch.
- Refresh
  patches.drivers/nvme-fc-correct-io-timeout-behavior.patch.
- Refresh
  patches.drivers/nvme-fc-create-fc-class-and-transport-device.patch.
- Refresh
  patches.drivers/nvme-fc-move-remote-port-get-put-free-location.patch.
- Refresh
  patches.drivers/nvme-loop-Add-BLK_MQ_F_NO_SCHED-flag-to-admin-tag-se.patch.
- Refresh patches.drivers/nvme-pci-add-SGL-support.patch.
- Refresh patches.drivers/nvme-pci-fix-typos-in-comments.patch.
- Refresh
  patches.drivers/nvme-rdma-Add-BLK_MQ_F_NO_SCHED-flag-to-admin-tag-se.patch.
- Refresh
  patches.drivers/nvme-rdma-Check-that-reinit_request-got-a-proper-mr.patch.
- Refresh
  patches.drivers/nvme-rdma-Don-t-local-invalidate-if-the-queue-is-not.patch.
- Refresh
  patches.drivers/nvme-rdma-change-queue-flag-semantics-DELETING-ALLOC.patch.
- Refresh
  patches.drivers/nvme-rdma-fix-wrong-logging-message.patch.
- Refresh
  patches.drivers/nvme-rdma-move-assignment-to-declaration.patch.
- Refresh
  patches.drivers/nvme-rdma-pass-tagset-to-directly-nvme_rdma_free_tag.patch.
- Refresh
  patches.drivers/nvme-rdma-stop-controller-reset-if-the-controller-is.patch.
- Refresh
  patches.drivers/nvme-rdma-teardown-admin-io-queues-once-on-error-rec.patch.
- Refresh
  patches.drivers/nvme-simplify-compat_ioctl-handling.patch.
- Refresh
  patches.drivers/nvme-update-timeout-module-parameter-type.patch.
- Refresh
  patches.drivers/nvme-use-ida_simple_-get-remove-for-the-controller-i.patch.
- Refresh patches.drivers/nvme-use-menu-Kconfig-interface.patch.
- Refresh
  patches.drivers/nvmet-Change-max_nsid-in-subsystem-due-to-ns_disable.patch.
- Refresh patches.drivers/nvmet-bump-NVMET_NR_QUEUES-to-128.patch.
- Refresh
  patches.drivers/s390-qeth-add-VNICC-enable-disable-support.patch.
- Refresh
  patches.drivers/s390-qeth-add-VNICC-get-set-timeout-support.patch.
- Refresh patches.drivers/s390-qeth-add-basic-VNICC-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Cocci-spatch-pool_zalloc-simple.patch.
- Refresh
  patches.drivers/scsi-lpfc-Disable-NPIV-support-if-NVME-is-enabled.patch.
- Refresh
  patches.drivers/scsi-lpfc-Ensure-io-aborts-interlocked-with-the-targ.patch.
- Refresh patches.drivers/scsi-lpfc-Extend-RDP-support.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-FCP-hba_wqidx-assignment.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-in-lpfc_nvme_fcp_io_submit-durin.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-receiving-ELS-while-detaching-dr.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-lpfc-nvme-host-rejecting-IO-with-Not-R.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-oops-if-nvmet_fc_register_targetport-f.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-oops-of-nvme-host-during-driver-unload.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-secure-firmware-updates.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-warning-messages-when-NVME_TARGET_FC-n.patch.
- Refresh
  patches.drivers/scsi-lpfc-Make-ktime-sampling-more-accurate.patch.
- Refresh
  patches.drivers/scsi-lpfc-Move-CQ-processing-to-a-soft-IRQ.patch.
- Refresh
  patches.drivers/scsi-lpfc-PLOGI-failures-during-NPIV-testing.patch.
- Refresh
  patches.drivers/scsi-lpfc-Reduce-log-spew-on-controller-reconnects.patch.
- Refresh
  patches.drivers/scsi-lpfc-Revise-NVME-module-parameter-descriptions-.patch.
- Refresh
  patches.drivers/scsi-lpfc-Set-missing-abort-context.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-version-to-11.4.0.4.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-nvme-sg-segment-count-check.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-list_add-call.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-timer-management.patch.
- Refresh
  patches.drivers/scsi-lpfc-remove-redundant-null-check-on-eqe.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Adding-support-for-SAS3616-HBA-device.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Bump-mpt3sas-driver-version-to-v16.100..patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Display-chassis-slot-information-of-the.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fix-IO-error-occurs-on-pulling-out-a-dr.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fix-possibility-of-using-invalid-Enclos.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fix-removal-and-addition-of-vSES-device.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Fixed-memory-leaks-in-driver.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Processing-of-Cable-Exception-events.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Reduce-memory-footprint-in-kdump-kernel.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-Updated-MPI-headers-to-v2.00.48.patch.
- Refresh
  patches.drivers/scsi-mpt3sas-remove-redundant-copy_from_user-in-_ctl.patch.
- Refresh
  patches.drivers/scsi-pm80xx-Different-SAS-addresses-for-phys.patch.
- Refresh
  patches.drivers/scsi-pm80xx-ILA-and-inactive-firmware-version-throug.patch.
- Refresh
  patches.drivers/scsi-pm80xx-cleanup-in-pm8001_abort_task-function.patch.
- Refresh
  patches.drivers/scsi-pm80xx-corrected-SATA-abort-handling-sequence.patch.
- Refresh
  patches.drivers/scsi-pm80xx-corrected-linkrate-value.patch.
- Refresh
  patches.drivers/scsi-pm80xx-modified-port-reset-timer-value-for-PM80.patch.
- Refresh
  patches.drivers/scsi-pm80xx-panic-on-ncq-error-cleaning-up-the-read-.patch.
- Refresh
  patches.drivers/scsi-pm80xx-redefine-sas_identify_frame-structure.patch.
- Refresh
  patches.drivers/scsi-pm80xx-tag-allocation-for-phy-control-request.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ATIO-Q-processing-for-INTx-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-MBC_GET_PORT_DATABASE-to-query-an.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Changes-to-support-N2N-logins.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Cocci-spatch-pool_zalloc-simple.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Query-FC4-type-during-RSCN-processing.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reinstate-module-parameter-ql2xenablems.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.02-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-ql2xnvmeenable-to-enable-Q-Pair-for.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-don-t-break-the-bsg-lib-abstractions.patch.
- Refresh
  patches.drivers/scsi-smartpqi-cleanup-raid-map-warning-message.patch.
- Refresh
  patches.drivers/scsi-smartpqi-update-controller-ids.patch.
- Refresh
  patches.drivers/scsi-smartpqi-update-driver-version-to-1.1.2-126.patch.
- commit f976d20
* Mon Nov 20 2017 neilb@suse.com
- autofs: don't fail mount for transient error (bsc#1065180).
- commit f023e91
* Fri Nov 17 2017 tiwai@suse.de
- ASoC: intel: Add headset jack support to cht-cx2072x
  (bsc#1068546).
- ASoC: Intel: add support for CX2072x machine driver
  (bsc#1068546).
- ASoC: Intel: Add machine driver for Cherrytrail-CX2072X
  (bsc#1068546).
- ASoC: add support for Conexant CX2072X CODEC (bsc#1068546).
- ASoC: cx2072x: Add DT bingings documentation for CX2072X CODEC
  (bsc#1068546).
- commit e2196fe
* Fri Nov 17 2017 tiwai@suse.de
- supported.conf: Updated for missing entries (bsc#1066369)
  Also mark old x86-platform ones unsupported
- commit 2e66eed
* Fri Nov 17 2017 tiwai@suse.de
- supported.conf: List up CHT DC TI PMIC and INT0002 VGPIO (bsc#1068546)
- commit 5f4a9b1
* Fri Nov 17 2017 tiwai@suse.de
- blacklist.conf: Add BT commits to be ignored (bsc#1068546)
- commit 2b7fddf
* Fri Nov 17 2017 tiwai@suse.de
- Update config files: Enable Cherrytrail kconfigs (bsc#1068546)
- commit 470e1f9
* Fri Nov 17 2017 tiwai@suse.de
- platform/x86: Add driver for ACPI INT0002 Virtual GPIO device
  (bsc#1068546).
- ASoC: rt5645: Add jack detection workaround for GPD Win
  (bsc#1068546).
- ASoC: rt5645: add inv_jd1_1 flag (bsc#1068546).
- ASoC: rt5645: rename jd_invert flag in platform data
  (bsc#1068546).
- ASoC: rt5645: read jd1_1 status for jd detection (bsc#1068546).
- ACPI / PMIC: Add opregion driver for Intel Dollar Cove TI PMIC
  (bsc#1068546).
- mfd: Add support for Cherry Trail Dollar Cove TI PMIC
  (bsc#1068546).
- brcmfmac: Use separate firmware for revision 0 of the brcm43430
  chip (bsc#1068546).
- Bluetooth: hci_bcm: Add support for BCM2E7E (bsc#1068546).
- mmc: sdhci-acpi: Workaround conflict with PCI wifi on GPD Win
  handheld (bsc#1068546).
- video/console: Update BIOS dates list for GPD win console
  rotation DMI quirk (bsc#1068546).
- video/console: Add new BIOS date for GPD pocket to dmi quirk
  table (bsc#1068546).
- video/console: Add dmi quirk table for x86 systems which need
  fbcon rotation (bsc#1068546).
- ACPI / x86: Extend KIOX000A quirk to cover all affected BIOS
  versions (bsc#1068546).
- ACPI / x86: Add KIOX000A accelerometer on GPD win to
  always_present_ids array (bsc#1068546).
- ACPI / x86: Allow matching always_present_id array entries by
  DMI (bsc#1068546).
- commit 20e1325
* Fri Nov 17 2017 mbrugger@suse.com
- arm64: Update config files and support.conf
  Compile SCSI_HISI_SAS_PCI as a module.
  Mark the driver as not supported.
- commit f6b8981
* Fri Nov 17 2017 mgorman@suse.de
- pcc-cpufreq: Re-introduce deadband effect to reduce number of
  frequency changes (bsc#981838).
- commit 7533cac
* Thu Nov 16 2017 mgorman@suse.de
- Refresh
  patches.suse/mm-only-drain-per-cpu-pagevecs-once-per-pagevec-usage.patch.
- Refresh
  patches.suse/mm-page_alloc-enable-disable-IRQs-once-when-freeing-a-list-of-pages.patch.
- Refresh
  patches.suse/mm-page_alloc-simplify-list-handling-in-rmqueue_bulk.patch.
- Refresh
  patches.suse/mm-pagevec-remove-cold-parameter-for-pagevecs.patch.
- Refresh
  patches.suse/mm-pagevec-rename-pagevec-drained-field.patch.
- Refresh patches.suse/mm-remove-__GFP_COLD.patch.
- Refresh
  patches.suse/mm-remove-cold-parameter-for-release_pages.patch.
- Refresh
  patches.suse/mm-remove-cold-parameter-from-free_hot_cold_page.patch.
- Refresh
  patches.suse/mm-truncate-do-not-check-mapping-for-every-page-being-truncated.patch.
- Refresh
  patches.suse/mm-truncate-remove-all-exceptional-entries-from-pagevec-under-one-lock.patch.
- Delete
  patches.suse/mm-truncate-remove-all-exceptional-entries-from-pagevec-under-one-lock-fix.patch.
- commit b425423
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- PCI: rockchip: Add per-lane PHY support (fate#323912).
- PCI: rockchip: Factor out rockchip_pcie_get_phys()
  (fate#323912).
- commit 42c5487
* Wed Nov 15 2017 mgorman@suse.de
- rcu: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- netpoll: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- timers/posix-cpu-timers: Use lockdep to assert IRQs are
  disabled/enabled (bnc#1068202 Avoid irqs_disabled debugging
  checks in fast paths).
- sched/clock, sched/cputime: Use lockdep to assert IRQs are
  disabled/enabled (bnc#1068202 Avoid irqs_disabled debugging
  checks in fast paths).
- irq_work: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- perf/core: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- x86: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- smp/core: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- timers/hrtimer: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- timers/nohz: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- workqueue: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- irq/softirqs: Use lockdep to assert IRQs are disabled/enabled
  (bnc#1068202 Avoid irqs_disabled debugging checks in fast
  paths).
- locking/lockdep: Add IRQs disabled/enabled assertion APIs:
  lockdep_assert_irqs_enabled()/disabled() (bnc#1068202 Avoid
  irqs_disabled debugging checks in fast paths).
- sched/idle: Micro-optimize the idle loop (bnc#978907 Scheduler
  performance -- idle).
- commit dc86215
* Wed Nov 15 2017 jkosina@suse.cz
- s390x: Update config files.
- commit fcf3905
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- Update config files.
- supported.conf:
  Enable Rockchip rk3399 drivers
  supported.conf checker reported following missing modules:
  drivers/phy/allwinner/phy-sun4i-usb.ko
  drivers/phy/allwinner/phy-sun9i-usb.ko
  drivers/phy/amlogic/phy-meson8b-usb2.ko
  drivers/phy/broadcom/phy-bcm-ns-usb2.ko
  drivers/phy/broadcom/phy-bcm-ns-usb3.ko
  drivers/phy/broadcom/phy-bcm-ns2-pcie.ko
  drivers/phy/broadcom/phy-brcm-sata.ko
  drivers/phy/hisilicon/phy-hi6220-usb.ko
  drivers/phy/qualcomm/phy-qcom-qmp.ko
  drivers/phy/qualcomm/phy-qcom-qusb2.ko
  drivers/phy/qualcomm/phy-qcom-usb-hs.ko
  drivers/phy/qualcomm/phy-qcom-usb-hsic.ko
  Since this patch has not enabled any of them, adding all of them in
  supported.conf with '-' as they were never marked as supported.
- commit 3664826
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- lib/mpi: call cond_resched() from mpi_powm() loop (bsc#1066688).
- commit 35d6a4a
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- iommu/rockchip: ignore isp mmu reset operation (fate#323912).
- commit 59a5545
* Wed Nov 15 2017 yousaf.kaukab@suse.com
- iommu/rockchip: add multi irqs support (fate#323912).
- iommu/rockchip: Enable Rockchip IOMMU on ARM64 (fate#323912).
- drm/rockchip: add CONFIG_OF dependency for lvds (fate#323912).
- drm/rockchip: add PINCTRL dependency for LVDS (fate#323912).
- drm/rockchip: Rely on the default best_encoder() behavior
  (fate#323912).
- drm/rockchip: Cocci spatch "vma_pages" (fate#323912).
- drm/rockchip: Fix uninitialized use of ret (fate#323912).
- drm/rockchip: Replace dev_* with DRM_DEV_* (fate#323912).
- drm/rockchip: Add support for Rockchip Soc LVDS (fate#323912).
- drm/rockchip: switch to drm_*_get(), drm_*_put() helpers
  (fate#323912).
- drm/rockchip: Fix suspend crash when drm is not bound
  (fate#323912).
- drm/rockchip: make drm_connector_funcs structures const
  (fate#323912).
- drm/rockchip: fix race with kms hotplug and fbdev (fate#323912).
- drm/rockchip: vop: no need wait vblank on crtc enable
  (fate#323912).
- drm/rockchip: vop: report error when check resource error
  (fate#323912).
- drm/rockchip: vop: round_up pitches to word align (fate#323912).
- drm/rockchip: vop: fix NV12 video display error (fate#323912).
- drm/rockchip: vop: fix iommu page fault when resume
  (fate#323912).
- drm/rockchip: vop: rk3328: fix overlay abnormal (fate#323912).
- drm/rockchip: vop: add a series of vop support (fate#323912).
- drm/rockchip: vop: group vop registers (fate#323912).
- drm/rockchip: vop: move line_flag_num to interrupt registers
  (fate#323912).
- drm/rockchip: vop: move write_relaxed flags to vop register
  (fate#323912).
- drm/rockchip: vop: initialize registers directly (fate#323912).
- drm/rockchip: Use .dumb_map_offset and .dumb_destroy defaults
  (fate#323912).
- drm/rockchip: Use for_each_oldnew_plane_in_state in
  vop_crtc_atomic_flush (fate#323912).
- drm/rockchip: fix NULL check on devm_kzalloc() return value
  (fate#323912).
- drm/rockchip: Drop drm_vblank_cleanup (fate#323912).
- drm/rockchip: dw_hdmi: introduce the pclk for grf (fate#323912).
- drm/rockchip: dw_hdmi: introduce the VPLL clock setting
  (fate#323912).
- drm/rockchip: dw_hdmi: add RK3399 HDMI support (fate#323912).
- drm/rockchip: Remove unnecessary NULL check (fate#323912).
- drm/rockchip: gem: add the lacks lock and trivial changes
  (fate#323912).
- drm/rockchip: use drm_for_each_connector_iter() (fate#323912).
- drm/rockchip: analogix_dp: Remove unused check and variables
  (fate#323912).
- drm/rockchip: Set line flag config register in vop_crtc_enable
  (fate#323912).
- mfd: rk808: Fix up the chip id get failed (fate#323912).
- pwm: rockchip: Use same PWM ops for each IP (fate#323912).
- pwm: rockchip: Move the configuration of polarity (fate#323912).
- pwm: rockchip: Use pwm_apply() instead of pwm_enable()
  (fate#323912).
- pwm: rockchip: Remove the judge from return value of
  pwm_config() (fate#323912).
- pwm: rockchip: Add APB and function both clocks support
  (fate#323912).
- phy: rockchip-typec: Do the calibration more correctly
  (fate#323912).
- phy: rockchip-typec: Avoid magic numbers + add delays in aux
  calib (fate#323912).
- phy: rockchip-typec: Check for errors from tcphy_phy_init()
  (fate#323912).
- phy: rockchip-typec: Don't set the aux voltage swing to 400 mV
  (fate#323912).
- phy: rockchip-typec: Set the AUX channel flip state earlier
  (fate#323912).
- phy: rockchip-pcie: Reconstruct driver to support per-lane PHYs
  (fate#323912).
- phy: rockchip-typec: remove unused dfp variable (fate#323912).
- phy: rockchip-inno-usb2: add support of usb2-phy for rv1108 SoCs
  (fate#323912).
- phy: rockchip-inno-usb2: add support for otg-mux interrupt
  (fate#323912).
- phy: rockchip-inno-usb2: add support for rockchip,usbgrf
  property (fate#323912).
- phy: rockchip-inno-usb2: Replace the extcon API (fate#323912).
- phy: rockchip-inno-usb2: add support of usb2-phy for rk3228 SoCs
  (fate#323912).
- phy: rockchip-inno-usb2: add one phy comprises with two
  host-ports support (fate#323912).
- phy: rockchip-inno-usb2: increase otg sm work first schedule
  time (fate#323912).
- phy: rockchip-inno-usb2: add a delay after phy resume
  (fate#323912).
- phy: Group vendor specific phy drivers (fate#323912).
- phy: Move ULPI phy header out of drivers to include path
  (fate#323912).
- phy: qcom-usb: Remove unused ulpi phy header (fate#323912).
- clk: rockchip: Remove superfluous error message in
  rockchip_clk_register_cpuclk() (fate#323912).
- clk: rockchip: Mark rockchip_fractional_approximation static
  (fate#323912).
- clk: rockchip: add special approximation to fix up fractional
  clk's jitter (fate#323912).
- clk: fractional-divider: allow overriding of approximation
  (fate#323912).
- clk: rockchip: add ids for rk3399 testclks used for camera
  handling (fate#323912).
- clk: rockchip: add dt-binding header for rk3128 (fate#323912).
- clk: rockchip: add ids for camera on rk3399 (fate#323912).
- spi: rockchip: configure CTRLR1 according to size and data frame
  (fate#323912).
- spi: rockchip: Fix clock handling in suspend/resume
  (fate#323912).
- spi: rockchip: Fix clock handling in remove (fate#323912).
- spi: rockchip: Slightly rework return value handling
  (fate#323912).
- spi: rockchip: Disable Runtime PM when chip select is asserted
  (fate#323912).
- spi: rockchip: Set GPIO_SS flag to enable Slave Select with
  GPIO CS (fate#323912).
- spi: rockchip: fix error handling when probe (fate#323912).
- pinctrl: rockchip: Fix the rk3399 gpio0 and gpio1 banks'
  drv_offset at pmu grf (fate#323912).
- pinctrl: rockchip: Use common interface for recalced iomux
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support for rk3399
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support for rk3328
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support for rk3228
  (fate#323912).
- pinctrl: rockchip: Add iomux-route switching support
  (fate#323912).
- pinctrl: rockchip: remove unneeded (void *) casts in
  of_match_table (fate#323912).
- clocksource/drivers/rockchip: pr_err() strings should end with
  newlines (fate#323912).
- iio: adc: rockchip_saradc: explicitly request exclusive reset
  control (fate#323912).
- iio: adc: rockchip_saradc: add NULL check on of_match_device()
  return value (fate#323912).
- PM / devfreq: rk3399_dmc: fix error return code in
  rk3399_dmcfreq_probe() (fate#323912).
- commit e27a9b1
* Tue Nov 14 2017 tiwai@suse.de
- drm/i915/glk: Add cold boot sequence for GLK DSI (bsc#1067957).
- drm/i915/glk: Split GLK DSI device ready functionality
  (bsc#1067957).
- drm/i915/huc: Update GLK HuC version (bsc#1067957).
- drm/i915/gen9: Reintroduce WaEnableYV12BugFixInHalfSliceChicken7
  (bsc#1067957).
- drm/i915/glk: Calculate high/low switch count for GLK
  (bsc#1067957).
- drm/i915/glk: Don't allow 12 bpc when htotal is too big
  (bsc#1067957).
- drm/i915/GLK/HuC: Load HuC on GLK (bsc#1067957).
- drm/i915/GuC/GLK: Load GuC on GLK (bsc#1067957).
- drm/i915/glk: limit pixel clock to 99%% of cdclk workaround
  (bsc#1067957).
- commit f5509cc
* Tue Nov 14 2017 tiwai@suse.de
- drm/i915/glk: Remove the alpha_support flag (bsc#1067957).
- commit 4bae915
* Tue Nov 14 2017 lpechacek@suse.com
- btrfs: use GFP_KERNEL in mount and remount (bsc#1062897).
- commit e1d90be
* Tue Nov 14 2017 jkosina@suse.cz
- Refresh patches.fixes/ext4-add-ext4_should_use_dax.patch: update upstream
  commit reference SHA
- commit f3bb07f
* Tue Nov 14 2017 jkosina@suse.cz
- Refresh
  patches.fixes/ext4-add-sanity-check-for-encryption-DAX.patch: update
  upstream commit reference SHA
- commit db0eb3c
* Tue Nov 14 2017 jkosina@suse.cz
- Refresh
  patches.fixes/ext4-prevent-data-corruption-with-journaling-DAX.patch: update
  upstream commit SHA
- commit 73f86f5
* Tue Nov 14 2017 tiwai@suse.de
- Correct to the updated upstream fix patch (CVE-2017-16647, bsc#1067102)
  Refreshed
  patches.drivers/net-usb-asix-fill-null-ptr-deref-in-asix_suspend.patch
- commit decd96f
* Tue Nov 14 2017 msuchanek@suse.de
- powerpc/pseries/vio: Dispose of virq mapping on vdevice
  unregister (bsc#1067888).
- commit 927b61a
* Mon Nov 13 2017 msuchanek@suse.de
- powerpc/vphn: Fix numa update end-loop bug (FATE#323745,
  bsc#1067906).
- powerpc/hotplug: Improve responsiveness of hotplug change
  (FATE#323745, bsc#1067906).
- powerpc/vphn: Improve recognition of PRRN/VPHN (FATE#323745,
  bsc#1067906).
- powerpc/vphn: Update CPU topology when VPHN enabled
  (FATE#323745, bsc#1067906).
- commit 2e4ca0c
* Mon Nov 13 2017 tiwai@suse.de
- media: rainshadow-cec: avoid -Wmaybe-uninitialized warning again
  (bsc#1051510).
- commit a30769c
* Mon Nov 13 2017 tiwai@suse.de
- blacklist.conf: add media and other commits (bsc#1051510)
- commit e57653b
* Mon Nov 13 2017 tiwai@suse.de
- serial: pch_uart: Make port type explicit (bsc#1051510).
- Refresh
  patches.drivers/serial-fix-port-type-numbering-for-ti-da8xx.
- commit 71e99cb
* Mon Nov 13 2017 tiwai@suse.de
- iio: dummy: events: Add missing break (bsc#1051510).
- Input: ucb1400_ts - fix suspend and resume handling
  (bsc#1051510).
- Input: ti_am335x_tsc - fix incorrect step config for 5 wire
  touchscreen (bsc#1051510).
- i2c: cadance: fix ctrl/addr reg write order (bsc#1051510).
- rtc: sa1100: fix unbalanced
  clk_prepare_enable/clk_disable_unprepare (bsc#1051510).
- cfg80211: honor NL80211_RRF_NO_HT40{MINUS,PLUS} (bsc#1051510).
- serial: 8250_uniphier: fix serial port index in private data
  (bsc#1051510).
- Revert "net: bcmgenet: Remove init parameter from
  bcmgenet_mii_config" (bsc#1051510).
- rtc: rtc-nuc900: fix loop timeout test (bsc#1051510).
- libertas: Fix lbs_prb_rsp_limit_set() (bsc#1051510).
- mmc: mediatek: Fixed size in dma_free_coherent (bsc#1051510).
- Fix serial console on SNI RM400 machines (bsc#1051510).
- media: v4l2-compat-ioctl32: Fix timespec conversion
  (bsc#1051510).
- [media] rainshadow-cec: use strlcat instead of strncat
  (bsc#1051510).
- [media] rainshadow-cec: avoid -Wmaybe-uninitialized warning
  (bsc#1051510).
- [media] mceusb: fix memory leaks in error path (bsc#1051510).
- media: em28xx: calculate left volume level correctly
  (bsc#1051510).
- media: devnode: Rename mdev argument as devnode (bsc#1051510).
- media: au0828: fix RC_CORE dependency (bsc#1051510).
- media: Revert "[media] et8ek8: Export OF device ID as module
  aliases" (bsc#1051510).
- gpu: ipu-v3: add DRM dependency (bsc#1051510).
- gpu: host1x: Free the IOMMU domain when there is no device to
  attach (bsc#1051510).
- gpu: host1x: Don't fail on NULL bo physical address
  (bsc#1051510).
- drm: rcar-du: Use the VBK interrupt for vblank events
  (bsc#1051510).
- commit 26cdc26
* Mon Nov 13 2017 tiwai@suse.de
- Refresh patch-mainline tag:
  patches.drivers/net-usb-asix-fill-null-ptr-deref-in-asix_suspend.patch.
- commit c4c86fe
* Mon Nov 13 2017 tiwai@suse.de
- ALSA: line6: Fix missing initialization before error path
  (bsc#1052235).
- ALSA: line6: Fix leftover URB at error-path during probe
  (bsc#1052235).
- ALSA: line6: Fix NULL dereference at podhd_disconnect()
  (bsc#1052235).
- commit b480beb
* Mon Nov 13 2017 tiwai@suse.de
- Fix the logic error in mgag200 patch (bsc#1066589)
  Refreshed
  patches.drivers/drm-mgag200-Add-mode-validation-debugging-code.patch.
- commit 507c2b5
* Mon Nov 13 2017 mhocko@suse.com
- blacklist.conf: blacklist a872eb2131e9 (bnc#1066602)
- commit c02d5e2
* Mon Nov 13 2017 oneukum@suse.com
- net: qmi_wwan: fix divide by 0 on bad descriptors (bsc#1067086
  CVE-2017-16650).
- commit 2135e29
* Mon Nov 13 2017 bp@suse.de
- x86/smpboot: Make optimization of delay calibration work
  correctly (git-fixes).
- commit cb9a8c3
* Fri Nov 10 2017 dbueso@suse.de
- locking/pvqspinlock: Implement hybrid PV queued/unfair locks
  (bsc#1050549).
- futex: Fix more put_pi_state() vs. exit_pi_state_list() races
  (bsc#1067665).
- futex: Fix pi_state->owner serialization (bsc#1067665).
- commit df2923d
* Thu Nov  9 2017 tiwai@suse.de
- blacklist.conf: Add drm/vgmem blacklist patch (bsc#1051510)
- commit a526463
* Thu Nov  9 2017 tiwai@suse.de
- drm/crc: Only open CRC on atomic drivers when the CRTC is active
  (bsc#1051510).
- drm/vc4: Don't disable DSI clocks on component unload
  (bsc#1051510).
- drm/vc4: Fix leak of HDMI EDID (bsc#1051510).
- drm/i915: Hold rcu_read_lock when iterating over the radixtree
  (objects) (bsc#1051510).
- commit 34fddd9
* Thu Nov  9 2017 bpoirier@suse.com
- Update some Git-repo tags according to most recent upstream status.
- Refresh
  patches.arch/KVM-PPC-Book3S-0005-Fix-server-always-zero-from-kvmppc_xi.patch.
- Refresh patches.arch/cxl-Fix-memory-page-not-handled.patch.
- Refresh
  patches.arch/perf-pmu-events-support-additional-power8-pvr-in-mapfile.patch.
- Refresh
  patches.arch/perf-vendor-events-add-power9-pmu-events.patch.
- Refresh
  patches.arch/perf-vendor-events-add-power9-pvrs-to-mapfile.patch.
- Refresh
  patches.arch/perf-vendor-events-powerpc-remove-suffix-in-mapfile.patch.
- Refresh
  patches.arch/perf-vendor-events-powerpc-update-power9-events.patch.
- Refresh
  patches.arch/powerpc-Fix-action-argument-for-cpufeatures-based-TLB-flush.patch.
- Refresh
  patches.arch/powerpc-Fix-workaround-for-spurious-MCE-on-POWER9.patch.
- Refresh
  patches.arch/powerpc-Handle-MCE-on-POWER9-with-only-DSISR-bit-30-set.patch.
- Refresh
  patches.arch/powerpc-mm-radix-Avoid-flushing-the-PWC-on-every-flush_tlb_range.patch.
- Refresh
  patches.arch/powerpc-mm-radix-Improve-TLB-PWC-flushes.patch.
- Refresh
  patches.arch/powerpc-mm-radix-Improve-_tlbiel_pid-to-be-usable-for-PWC-flushes.patch.
- Refresh
  patches.arch/powerpc-perf-Cleanup-of-PM_BR_CMPL-vs.-PM_BRU_CMPL-in-Power9-event-list.patch.
- Refresh
  patches.arch/powerpc-perf-Update-default-sdar_mode-value-for-power9.patch.
- Refresh
  patches.arch/powerpc-perf-add-core-imc-pmu-support.patch.
- Refresh
  patches.arch/powerpc-perf-add-nest-imc-pmu-support.patch.
- Refresh
  patches.arch/powerpc-perf-add-thread-imc-pmu-support.patch.
- Refresh
  patches.arch/powerpc-perf-fix-double-unlock-in-imc_common_cpuhp_mem_free.patch.
- Refresh
  patches.arch/powerpc-perf-fix-usage-of-nest_imc_refc.patch.
- Refresh
  patches.arch/powerpc-perf-imc-fix-nest-events-on-muti-socket-system.patch.
- Refresh
  patches.arch/powerpc-xive-04-Ensure-active-irqd-when-setting-affinit.patch.
- Refresh
  patches.arch/powerpc-xive-05-Fix-section-mismatch-warnings.patch.
- Refresh
  patches.arch/powerpc-xive-06-Fix-the-size-of-the-cpumask-used-in-xive_find_target_in_mask.patch.
- Refresh
  patches.arch/powerpc-xive-07-powerpc-xmon-Exclude-all-of-xmon-from-ftrace.patch.
- Refresh
  patches.arch/powerpc-xive-08-introduce-a-common-routine-xive_queue_p.patch.
- Refresh
  patches.arch/powerpc-xive-09-guest-exploitation-of-the-XIVE-interrup.patch.
- Refresh
  patches.arch/powerpc-xive-10-rename-xive_poke_esb-in-xive_esb_read.patch.
- Refresh
  patches.arch/powerpc-xive-11-introduce-xive_esb_write.patch.
- Refresh
  patches.arch/powerpc-xive-12-add-the-HW-IRQ-number-under-xive_irq_da.patch.
- Refresh
  patches.arch/powerpc-xive-13-introduce-H_INT_ESB-hcall.patch.
- Refresh
  patches.arch/powerpc-xive-14-add-XIVE-Exploitation-Mode-to-CAS.patch.
- Refresh
  patches.arch/powerpc-xive-15-improve-debugging-macros.patch.
- Refresh
  patches.arch/powerpc-xive-16-Fix-section-__init-warning.patch.
- Refresh patches.arch/powerpc-xive-18-Fix-IPI-reset.patch.
- Refresh
  patches.arch/powerpc-xive-19-Clear-XIVE-internal-structures-when-a-C.patch.
- Refresh
  patches.drivers/0001-acpica-iort-Update-SMMU-models-for-IORT-rev.-C.patch.
- Refresh
  patches.drivers/0001-ata-ceva-Move-sata-port-phy-oob-settings-to-device-t.patch.
- Refresh
  patches.drivers/0002-ata-ceva-Add-gen-3-mode-support-in-driver.patch.
- Refresh
  patches.drivers/0002-tty-xilinx_uartps-move-to-arch_initcall-for-earlier-.patch.
- Refresh
  patches.drivers/0003-ata-ceva-Disable-Device-Sleep-capability.patch.
- Refresh
  patches.drivers/0004-ata-ceva-Make-RxWaterMark-value-as-module-parameter.patch.
- Refresh
  patches.drivers/0005-ata-ceva-Add-CCI-support-for-SATA-if-CCI-is-enabled.patch.
- Refresh
  patches.drivers/0006-ata-ceva-Correct-the-AXI-bus-configuration-for-SATA-.patch.
- Refresh
  patches.drivers/0007-ata-ceva-Correct-the-suspend-and-resume-logic-for-SA.patch.
- Refresh
  patches.drivers/0008-ata-ceva-Add-SMMU-support-for-SATA-IP.patch.
- Refresh
  patches.drivers/0031-ACPI-APEI-Enable-APEI-multiple-GHES-source-to-share-.patch.
- Refresh
  patches.drivers/05-edac-pnd2-build-in-a-minimal-sideband-driver-for-apollo-lake.patch.
- Refresh
  patches.drivers/06-edac-pnd2-mask-off-the-lower-four-bits-of-a-bar.patch.
- Refresh
  patches.drivers/07-edac-pnd2-conditionally-unhide-hide-the-p2sb-pci-device-to-read-bar.patch.
- Refresh
  patches.drivers/08-edac-pnd2-properly-toggle-hidden-state-for-p2sb-pci-device.patch.
- Refresh
  patches.drivers/ALSA-hda-Abort-capability-probe-at-invalid-register-.
- Refresh
  patches.drivers/ALSA-hda-Implement-mic-mute-LED-mode-enum.
- Refresh
  patches.drivers/ALSA-ice1712-Add-support-for-STAudio-ADCIII.
- Refresh
  patches.drivers/drm-i915-Align-vswing-sequences-with-old-ddi-buffer-.
- Refresh
  patches.drivers/drm-i915-Display-WA-1133-WaFbcSkipSegments-cnl-glk.
- Refresh
  patches.drivers/drm-i915-Enable-voltage-swing-before-enabling-DDI_BU.
- Refresh patches.drivers/drm-i915-Introduce-intel_ddi_dp_level.
- Refresh patches.drivers/drm-i915-Shrink-cnl_ddi_buf_trans.
- Refresh
  patches.drivers/drm-i915-Stop-using-long-platform-names-on-clock-gat.
- Refresh
  patches.drivers/drm-i915-avoid-division-by-zero-on-cnl_calc_wrpll_li.
- Refresh
  patches.drivers/drm-i915-avoid-potential-uninitialized-variable-use.
- Refresh
  patches.drivers/drm-i915-cfl-Coffee-Lake-works-on-Kaby-Lake-PCH.
- Refresh
  patches.drivers/drm-i915-cfl-Remove-alpha-support-protection.
- Refresh patches.drivers/drm-i915-cnl-Add-Gen10-LRC-size.
- Refresh
  patches.drivers/drm-i915-cnl-Add-WaDisableReplayBufferBankArbitratio.
- Refresh
  patches.drivers/drm-i915-cnl-Add-support-slice-subslice-eu-configs.
- Refresh
  patches.drivers/drm-i915-cnl-Allow-the-reg_read-ioctl-to-read-the-RC.
- Refresh
  patches.drivers/drm-i915-cnl-Apply-large-line-width-optimization.
- Refresh
  patches.drivers/drm-i915-cnl-Avoid-ioremap_wc-on-Cannonlake-as-well.
- Refresh
  patches.drivers/drm-i915-cnl-Change-the-macro-name-to-DPLL_CFGCR0_DC.
- Refresh
  patches.drivers/drm-i915-cnl-Do-not-add-an-extra-page-for-precaution.
- Refresh
  patches.drivers/drm-i915-cnl-Extend-WM-workaround-with-IPC-for-CNL.
- Refresh
  patches.drivers/drm-i915-cnl-Fix-DDI-hdmi-level-selection.
- Refresh patches.drivers/drm-i915-cnl-Fix-DP-max-voltage.
- Refresh
  patches.drivers/drm-i915-cnl-Introduce-initial-Cannonlake-Workaround.
- Refresh
  patches.drivers/drm-i915-cnl-Move-ddi-buf-trans-related-functions-up.
- Refresh
  patches.drivers/drm-i915-cnl-Move-voltage-check-into-ddi-buf-trans-f.
- Refresh
  patches.drivers/drm-i915-cnl-Reprogram-DMC-firmware-after-S3-S4-resu.
- Refresh
  patches.drivers/drm-i915-cnl-WA-FtrEnableFastAnisoL1BankingFix.
- Refresh
  patches.drivers/drm-i915-cnl-WaDisableEnhancedSBEVertexCaching.
- Refresh patches.drivers/drm-i915-cnl-WaDisableI2mCycleOnWRPort.
- Refresh
  patches.drivers/drm-i915-cnl-WaForceContextSaveRestoreNonCoherent.patch.
- Refresh
  patches.drivers/drm-i915-cnl-WaPushConstantDereferenceHoldDisable.
- Refresh
  patches.drivers/drm-i915-cnl-WaThrottleEUPerfToAvoidTDBackPressure-c.
- Refresh
  patches.drivers/drm-i915-cnl-don-t-hardcode-DPCLKA_CFGCR0_DDI_CLK_SE.
- Refresh
  patches.drivers/drm-i915-cnl-extract-cnl_set_procmon_ref_values.
- Refresh
  patches.drivers/drm-i915-cnl-simplify-cnl_procmon_values-handling.
- Refresh
  patches.drivers/drm-i915-cnp-Display-Wa-1179-WaHardHangonHotPlug.
- Refresh
  patches.drivers/drm-i915-cnp-Don-t-touch-other-PCH-clock-gating-bits.
- Refresh
  patches.drivers/drm-i915-cnp-Wa-1181-Fix-Backlight-issue.
- Refresh
  patches.drivers/drm-i915-decouple-gen9-and-gen10-dp-signal-levels.
- Refresh
  patches.drivers/drm-i915-glk-cnl-Implement-WaDisableScalarClockGatin.
- Refresh
  patches.drivers/media-cx231xx-cards-fix-NULL-deref-on-missing-associ.
- Refresh
  patches.drivers/media-dib0700-fix-invalid-dvb_detach-argument.
- Refresh
  patches.drivers/media-imon-Fix-null-ptr-deref-in-imon_probe.
- Refresh patches.drivers/powerpc-powernv-Add-IMC-OPAL-APIs.patch.
- Refresh
  patches.drivers/powerpc-powernv-Add-support-for-powercap-framework.patch.
- Refresh
  patches.drivers/powerpc-powernv-Add-support-to-clear-sensor-groups-data.patch.
- Refresh
  patches.drivers/powerpc-powernv-Add-support-to-set-power-shifting-ratio.patch.
- Refresh
  patches.drivers/powerpc-powernv-Detect-and-create-IMC-device.patch.
- Refresh
  patches.drivers/powerpc-powernv-Enable-PCI-peer-to-peer.patch.
- Refresh
  patches.fixes/ALSA-seq-Fix-use-after-free-at-creating-a-port.
- Refresh patches.fixes/loop-Remove-unused-bdev-argument.patch.
- Refresh patches.fixes/loop-fix-error-handling.patch.
- Refresh patches.fixes/loop-support-4k-blocksize.patch.
- Refresh
  patches.fixes/mac80211-accept-key-reinstall-without-changing-anyth.patch.
- Refresh
  patches.fixes/nl80211-check-for-the-required-netlink-attributes-pr.patch.
- Refresh
  patches.fixes/powerpc-mm-book3s64-Make-KERN_IO_START-a-variable.patch.
- Refresh
  patches.fixes/powerpc-mm-hash64-Make-vmalloc-56T-on-hash.patch.
- Refresh
  patches.fixes/powerpc-mm-slb-Move-comment-next-to-the-code-it-s-referring-to.patch.
- Refresh
  patches.fixes/sched-core-Address-more-wake_affine-regressions.patch.
- Refresh
  patches.fixes/sched-core-Fix-wake_affine-performance-regression.patch.
- Refresh
  patches.suse/0001-locking-osq_lock-Fix-osq_lock-queue-corruption.patch.
- Refresh
  patches.suse/0001-objtool-Don-t-report-end-of-section-error-after-an-e.patch.
- Refresh
  patches.suse/0001-sched-wait-Remove-the-lockless-swait_active-check-in.patch.
- Refresh
  patches.suse/0002-x86-head-Remove-confusing-comment.patch.
- Refresh
  patches.suse/0003-x86-head-Remove-unused-bad_address-code.patch.
- Refresh
  patches.suse/0004-x86-head-Fix-head-ELF-function-annotations.patch.
- Refresh
  patches.suse/0005-x86-boot-Annotate-verify_cpu-as-a-callable-function.patch.
- Refresh
  patches.suse/0006-x86-xen-Fix-xen-head-ELF-annotations.patch.
- Refresh
  patches.suse/0007-x86-xen-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-head-Add-unwind-hint-annotations.patch.
- commit b965d15
* Thu Nov  9 2017 tiwai@suse.de
- Revert "ALSA: echoaudio: purge contradictions between dimension
  matrix members and total number of members" (bsc#1051510).
- commit 46377e9
* Thu Nov  9 2017 tiwai@suse.de
- blacklist.conf: Add i915 blacklist (bsc#1051510)
- commit a51cd00
* Thu Nov  9 2017 tiwai@suse.de
- drm/i915: Use bdw_ddi_translations_fdi for Broadwell
  (bsc#1051510).
- drm/i915: Report -EFAULT before pwrite fast path into shmemfs
  (bsc#1051510).
- drm/i915: Order two completing nop_submit_request (bsc#1051510).
- drm/i915: Read timings from the correct transcoder in
  intel_crtc_mode_get() (bsc#1051510).
- drm/i915: remove redundant variable hw_check (bsc#1051510).
- drm/i915: Fix DDI PHY init if it was already on (bsc#1051510).
- drm/i915/glk: Fix DMC/DC state idleness calculation
  (bsc#1051510).
- drm/i915: Re-enable GTT following a device reset (bsc#1051510).
- drm/i915: Clear lost context-switch interrupts across reset
  (bsc#1051510).
- drm/i915: Avoid the gpu reset vs. modeset deadlock
  (bsc#1051510).
- commit c463053
* Thu Nov  9 2017 lpechacek@suse.com
- rpm/kernel-binary.spec.in: rename kGraft to KLP (fate#323682)
- commit 0ed191d
* Thu Nov  9 2017 msuchanek@suse.de
- Support paes_s390 and pkey modules (bsc#1066939)
- commit 5932b2c
* Thu Nov  9 2017 msuchanek@suse.de
- s390/crypto: fix aes/paes Kconfig dependeny (bsc#1066939).
- Update config files.
- commit 85fd2af
* Thu Nov  9 2017 jkosina@suse.cz
- x86/mm: Unbreak modules that rely on external PAGE_KERNEL
  availability (FATE#322123).
- commit 2ce8e65
* Wed Nov  8 2017 jack@suse.cz
- mm, truncate: remove all exceptional entries from pagevec
  under one lock -fix (bsc#1065138).
- commit e824298
* Wed Nov  8 2017 pmladek@suse.com
- lib/ratelimit.c: use deferred printk() version (bsc#979928).
- commit 2c73591
* Wed Nov  8 2017 oneukum@suse.com
- Input: gtco - fix potential out-of-bound access (bsc#1067085
  CVE-2017-16649).
- commit 60895ec
* Wed Nov  8 2017 tiwai@suse.de
- media: dib0700: fix invalid dvb_detach argument (CVE-2017-16646
  bsc#1067105).
- commit 66fca6a
* Wed Nov  8 2017 tiwai@suse.de
- net: usb: asix: fill null-ptr-deref in asix_suspend
  (CVE-2017-16647 bsc#1067102).
- commit f86cac1
* Wed Nov  8 2017 tiwai@suse.de
- Input: ims-psu - check if CDC union descriptor is sane
  (CVE-2017-16645 bsc#1067132).
- commit fba5e7b
* Wed Nov  8 2017 oneukum@suse.com
- USB: core: harden cdc_parse_cdc_header (bsc#1066693
  CVE-2017-16534).
- commit a719332
* Wed Nov  8 2017 gqjiang@suse.com
- Refresh
  patches.drivers/0003-md-cluster-Suspend-writes-in-RAID10-if-within-range.patch.
- Delete
  patches.drivers/0002-md-raid10-add-honouring-of-suspend_-lo-hi.patch.
- commit 6922f7b
* Tue Nov  7 2017 oneukum@suse.com
- USB: core: fix out-of-bounds access bug in
  usb_get_bos_descriptor() (bsc#1066700 CVE-2017-16535).
- commit c7ecdbf
* Tue Nov  7 2017 rgoldwyn@suse.com
- apparmor: Revert network mediation to old patches.
  References: bsc#1065536
  Backport of upstream patch 651e28c5537a ("apparmor: add base
  infastructure for socket mediation") allowed us delete old apparmor
  networking patches which we have been carrying for quite some time.
  However, through 80c094a47dd4 ("Revert "apparmor: add base
  infastructure for socket mediation""), this patch was reverted.
  In order to support our networking infrastructure for apparmor,
  we have to retain our old patches.
- apparmor: update apparmor-basic-networking-rules for 4.11-rc1
  (FATE#300516).
- AppArmor: basic networking rules (FATE#300516).
- apparmor: Fix quieting of audit messages for network mediation
  (FATE#300516).
- Delete
  patches.apparmor/0011-apparmor-add-base-infastructure-for-socket-mediation.patch.
- commit 68ae091
* Tue Nov  7 2017 oneukum@suse.com
- USB: fix out-of-bounds in usb_set_configuration (bsc#1066671
  CVE-2017-16531).
- commit 503cdcb
* Tue Nov  7 2017 nborisov@suse.com
- btrfs: change how we decide to commit transactions during
  flushing (bsc#1060197).
  Also enable Liu Bo's patch now that the maths behind transaction commit is
  fixed.
- commit 090a8a5
* Mon Nov  6 2017 yousaf.kaukab@suse.com
- arm64: Ensure the instruction emulation is ready for userspace
  (bsc#1066688).
- commit d42b0c9
* Mon Nov  6 2017 tiwai@suse.de
- assoc_array: Fix a buggy node-splitting case (CVE-2017-12193
  bsc#1066192).
- commit 2a60539
* Mon Nov  6 2017 tbogendoerfer@suse.de
- net: ethtool: remove error check for legacy setting transceiver
  type (bsc#1056787).
- commit 7d9e6b5
* Mon Nov  6 2017 agraf@suse.de
- Update config files to enable spidev on arm64. (bsc#1066696)
- supported.conf: Support spidev (bsc#1066696)
- commit 181d4fc
* Mon Nov  6 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 8c0cbfa
* Mon Nov  6 2017 tbogendoerfer@suse.de
- net_sched: avoid matching qdisc with zero handle (bsc#1056787).
- soreuseport: fix initialization race (bsc#1056787).
- netlink: fix netlink_ack() extack race (bsc#1056787).
- net: enable interface alias removal via rtnl (bsc#1056787).
- gso: fix payload length when gso_size is zero (bsc#1056787).
- net: rtnetlink: fix info leak in RTM_GETSTATS call
  (bsc#1056787).
- inet: fix improper empty comparison (bsc#1056787).
- net: ethtool: Add back transceiver type (bsc#1056787).
- net_sched: always reset qdisc backlog in qdisc_reset()
  (bsc#1056787).
- net: change skb->mac_header when Generic XDP calls adjust_head
  (bsc#1056787).
- net/sched: cls_matchall: fix crash when used with classful qdisc
  (bsc#1056787).
- net/sock: allow the user to set negative peek offset
  (bsc#1056787).
- sch_tbf: fix two null pointer dereferences on init failure
  (bsc#1056787).
- sch_netem: avoid null pointer deref on init failure
  (bsc#1056787).
- sch_fq_codel: avoid double free on init failure (bsc#1056787).
- sch_cbq: fix null pointer dereferences on init failure
  (bsc#1056787).
- sch_hhf: fix null pointer dereference on init failure
  (bsc#1056787).
- sch_htb: fix crash on init failure (bsc#1056787).
- gue: fix remcsum when GRO on and CHECKSUM_PARTIAL boundary is
  outer UDP (bsc#1056787).
- vxlan: fix remcsum when GRO on and CHECKSUM_PARTIAL boundary
  is outer UDP (bsc#1056787).
- net: bridge: fix dest lookup when vlan proto doesn't match
  (bsc#1056787).
- commit 112af25
* Mon Nov  6 2017 oneukum@suse.com
- USB: serial: console: fix use-after-free on disconnect
  (bsc#1066618 CVE-2017-16525).
- USB: serial: console: fix use-after-free after failed setup
  (bsc#1066618 CVE-2017-16525).
- commit f99e4d9
* Mon Nov  6 2017 tiwai@suse.de
- ALSA: usb-audio: Check out-of-bounds access by corrupted buffer
  descriptor (CVE-2017-16529 bsc#1066650).
- commit d27bf12
* Mon Nov  6 2017 hare@suse.de
- s390/kvm: fix detection of guest machine checks
  (FATE#324256,LTC#160417,bsc#1066327).
- KVM: s390: Inject machine check into the nested guest
  (FATE#324256,LTC#160417,bsc#1066327).
- KVM: s390: Inject machine check into the guest
  (FATE#324256,LTC#160417,bsc#1066327).
- KVM: s390: Backup the guest's machine check info
  (FATE#324256,LTC#160417,bsc#1066327).
- s390/nmi: s390: New low level handling for machine check
  happening in guest (FATE#324256,LTC#160417,bsc#1066327).
- commit 03cf0ff
* Mon Nov  6 2017 hare@suse.de
- KVM: s390: expose no-DAT to guest and migration support
  (LTC#160419,bsc#1066194).
- KVM: s390: ioctls to get and set guest storage attributes
  (LTC#160419,bsc#1066194).
- KVM: s390: CMMA tracking, ESSA emulation, migration mode
  (LTC#160419,bsc#1066194).
- commit c96fac7
* Mon Nov  6 2017 hare@suse.de
- KVM: make pid available for uevents without debugfs
  (FATE#323770,bsc#1061982).
- KVM: trigger uevents when creating or destroying a VM
  (FATE#323770,bsc#1061982).
- commit 4b7e072
* Mon Nov  6 2017 tiwai@suse.de
- media: imon: Fix null-ptr-deref in imon_probe (CVE-2017-16537
  bsc#1066573).
- [media] cx231xx-cards: fix NULL-deref on missing association
  descriptor (CVE-2017-16536 bsc#1066606).
- commit b162a90
* Mon Nov  6 2017 tbogendoerfer@suse.de
- RDMA/nldev: Enforce device index check for port callback
  (bsc#1046306 FATE#322942).
- net/mlx5e: DCBNL, Implement tc with ets type and zero bandwidth
  (bsc#1046303 FATE#322944).
- net/mlx5e: Properly deal with encap flows add/del under neigh
  update (bsc#1046303 FATE#322944).
- net/mlx5: Delay events till mlx5 interface's add complete for
  pci resume (bsc#1046303 FATE#322944).
- net/mlx5: Fix health work queue spin lock to IRQ safe
  (bsc#1046303 FATE#322944).
- nfp: refuse offloading filters that redirects to upper devices
  (bsc#1055968).
- RDMA/netlink: OOPs in rdma_nl_rcv_msg() from misinterpreted flag
  (bsc#1046306 FATE#322942).
- commit c03a7d9
* Mon Nov  6 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit b3742e5
* Mon Nov  6 2017 msuchanek@suse.de
- powerpc/64s/radix: Fix preempt imbalance in TLB flush
  (bsc#1055186).
- commit 4c97add
* Mon Nov  6 2017 vbabka@suse.cz
- Update
  patches.fixes/mm-memcontrol-fix-null-pointer-crash-in-test_clear_page_writeback.patch
  (VM Functionality, bsc#1061849, bsc#1065971). Fix bsc#1065971 by editing the
  patch in-place.
- commit 44552ab
* Mon Nov  6 2017 tiwai@suse.de
- Set CONFIG_MQ_IOSCHED_DEADLINE=y on config/arm64/default (bsc#1066369)
- commit 9841c29
* Mon Nov  6 2017 tiwai@suse.de
- ALSA: usb-audio: Kill stray URB at exiting (CVE-2017-16527
  bsc#1066625).
- ALSA: seq: Cancel pending autoload work at unbinding device
  (CVE-2017-16528 bsc#1066629).
- commit e9dde55
* Mon Nov  6 2017 jkosina@suse.cz
- rpm/kernel-binary.spec.in: add explicit dependency of kernel-*-devel on
  libelf-devel. Otherwise warning that got turned into error by e683952999
  ("objtool: Upgrade libelf-devel warning to error...") would trigger and
  cause any packages being built against kernel-*-devel (such as KMPs,
  crash) not to have the libelf dependency included, and fail to build.
- commit cad1ef9
* Mon Nov  6 2017 bp@suse.de
- x86/alternatives: Fix alt_max_short macro to really be a max()
  (git-fixes).
- commit 440e729
* Mon Nov  6 2017 jkosina@suse.cz
- Revert "scripts/git-pre-commit: Check the content of the series.conf sorted section."
  This reverts commit 869e9a97f5038eb456502f1b0ee7cd06f3b8e5c3; we have to first
  announce this globally with a fixed transition date and give committers time
  to readjust their infrastructure (namely have pygit2 put in place properly).
- commit 28dd483
* Mon Nov  6 2017 mkubecek@suse.cz
- supported.conf: mark vsockmon as supported (bsc#1066369)
  This module creates a device receiving copies of vsock traffic so that it
  packets can be monitored e.g. by tcpdump/wireshark (the same way nlmon
  works for netlink). (vsock is a framework for specific guest-host
  communication channels, used by VMware, virtio and recently also Hyper-V)
- commit 683ca74
* Mon Nov  6 2017 gqjiang@suse.com
- md-cluster/raid10: set "do_balance = 0" if area is resyncing
  (fate#323171).
- md/raid10: add honouring of suspend_{lo,hi} (fate#323171).
- md-cluster: Suspend writes in RAID10 if within range
  (fate#323171).
- md-cluster: Use a small window for raid10 resync (fate#323171).
- md-cluster: update document for raid10 (fate#323171).
- Delete
  patches.suse/0036-md-cluster-remove-EXPERIMENTAL-info.patch.
- commit 0803ffd
* Fri Nov  3 2017 mcgrof@suse.com
- mac80211: don't compare TKIP TX MIC key in reinstall prevention
  (bsc#1066472).
- commit 3545ef0
* Fri Nov  3 2017 mcgrof@suse.com
- mac80211: use constant time comparison with keys (bsc#1066471).
- commit 0ae0929
* Fri Nov  3 2017 mcgrof@suse.com
- kernel/sysctl.c: remove duplicate UINT_MAX check on do_proc_douintvec_conv() (bsc#1066470).
- commit b275255
* Fri Nov  3 2017 tiwai@suse.de
- Update no-fix patch tags for recent i915 patches
  This removes the false-positive checks by git-fixes.
- commit 9fccb15
* Fri Nov  3 2017 tiwai@suse.de
- ALSA: hda - fix headset mic problem for Dell machines with
  alc236 (bsc#1052235).
- ALSA: hda/realtek - Add support for ALC236/ALC3204
  (bsc#1052235).
- ALSA: hda: Remove superfluous '-' added by printk conversion
  (bsc#1052235).
- ALSA: hda - program ICT bits to support HBR audio (bsc#1052235).
- ALSA: hda: Fix forget to free resource in error handling code
  path in hda_codec_driver_probe (bsc#1052235).
- ALSA: hda/realtek - Fix pincfg for Dell XPS 13 9370
  (bsc#1052235).
- ALSA: hda: Add Cannonlake PCI ID (bsc#1052235).
- ALSA: hda - Add hdmi id for a Geminilake variant (bsc#1052235).
- ALSA: hda - Add AZX_DRIVER_SKL for simplification (bsc#1052235).
- commit f2aaa75
* Fri Nov  3 2017 mfleming@suse.de
- sched/fair: Enable SIS_AVG_CPU by default (bsc#1061593).
- commit fc3055c
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Fix failover error path for non-fatal resets
  (bsc#1066382).
- commit 786fbe8
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Update reset infrastructure to support tunable
  parameters (bsc#1066382).
- commit 4058b41
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Let users change net device features (bsc#1066382).
- commit c706428
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Enable TSO support (bsc#1066382).
- commit 251d320
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Enable scatter-gather support (bsc#1066382).
- commit 36f16a2
* Fri Nov  3 2017 msuchanek@suse.de
- ibmvnic: Fix calculation of number of TX header descriptors
  (bsc#1066382).
- commit 5ec05af
* Fri Nov  3 2017 bp@suse.de
- x86/fpu: Don't let userspace set bogus xcomp_bv (bsc#1063984,
  CVE-2017-15537).
- commit 17bafc1
* Fri Nov  3 2017 yousaf.kaukab@suse.com
- ata: ceva: Add SMMU support for SATA IP (bsc#1066345).
- ata: ceva: Correct the suspend and resume logic for SATA
  (bsc#1066345).
- ata: ceva: Correct the AXI bus configuration for SATA ports
  (bsc#1066345).
- ata: ceva: Add CCI support for SATA if CCI is enabled
  (bsc#1066345).
- ata: ceva: Make RxWaterMark value as module parameter
  (bsc#1066345).
- ata: ceva: Disable Device Sleep capability (bsc#1066345).
- ata: ceva: Add gen 3 mode support in driver (bsc#1066345).
- ata: ceva: Move sata port phy oob settings to device-tree
  (bsc#1066345).
- commit 4b09db7
* Fri Nov  3 2017 tiwai@suse.de
- supported.conf: Add wdat_wdt as supported (bsc#1066296)
- commit 45de744
* Fri Nov  3 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 071abc3
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/xmon: Fix display of SPRs (bsc#1065729).
- commit e8eae4d
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/powernv: Increase memory block size to 1GB on radix
  (bsc#1065729).
- commit c2f4068
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/pseries: Don't attempt to acquire drc during memory
  hot add for assigned lmbs (FATE#322022, bsc#1065729).
- powerpc/pseries: Check memory device state before
  onlining/offlining (FATE#322022, bsc#1065729).
- commit 7e9a794
* Thu Nov  2 2017 msuchanek@suse.de
- scsi: ipr: Set no_report_opcodes for RAID arrays (bsc#1066213).
- commit 620e3a3
* Thu Nov  2 2017 msuchanek@suse.de
- scsi: ipr: Fix scsi-mq lockdep issue (bsc#1066213).
- commit a69de39
* Thu Nov  2 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit 96020ad
* Thu Nov  2 2017 hare@suse.de
- dax: initialize variable pfn before using it (FATE#323721).
- dax: use PG_PMD_COLOUR instead of open coding (FATE#323721).
- dax: explain how read(2)/write(2) addresses are validated
  (FATE#323721).
- dax: remove DAX code from page_cache_tree_insert()
  (FATE#323721).
- dax: use common 4k zero page for dax mmap reads (FATE#323721).
- dax: relocate some dax functions (FATE#323721).
- mm: add vm_insert_mixed_mkwrite() (FATE#323721).
- commit ade91b6
* Thu Nov  2 2017 msuchanek@suse.de
- powerpc/sysrq: Fix oops whem ppmu is not registered
  (bsc#1065729).
- commit f08eb15
* Thu Nov  2 2017 tiwai@suse.de
- drm/i915: avoid division by zero on cnl_calc_wrpll_link
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Do not add an extra page for precaution in the
  Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915: avoid potential uninitialized variable use
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Reprogram DMC firmware after S3/S4 resume
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Gen10 LRC size (FATE#322643 bsc#1055900).
- drm/i915/cnl: Extend WM workaround with IPC for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Change the macro name to
  DPLL_CFGCR0_DCO_FRACTION_SHIFT (FATE#322643 bsc#1055900).
- drm/i915: Shrink cnl_ddi_buf_trans (FATE#322643 bsc#1055900).
- drm/i915/glk, cnl: Implement WaDisableScalarClockGating
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add support slice/subslice/eu configs (FATE#322643
  bsc#1055900).
- drm/i915/cnl:
  WaThrottleEUPerfToAvoidTDBackPressure:cnl(pre-prod) (FATE#322643
  bsc#1055900).
- drm/i915: Display WA #1133 WaFbcSkipSegments:cnl, glk
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Display Wa #1179: WaHardHangonHotPlug (FATE#322643
  bsc#1055900).
- drm/i915/cnp: set min brightness from VBT (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Don't touch other PCH clock gating bits
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Wa 1181: Fix Backlight issue (FATE#322643
  bsc#1055900).
- drm/i915: Stop using long platform names on clock gating
  functions (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow the reg_read ioctl to read the RCS TIMESTAMP
  register (FATE#322643 bsc#1055900).
- drm/i915/cnl: Avoid ioremap_wc on Cannonlake as well
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DP max voltage (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix DDI hdmi level selection (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Move ddi buf trans related functions up
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Move voltage check into ddi buf trans functions
  (FATE#322643 bsc#1055900).
- drm/i915: Enable voltage swing before enabling DDI_BUF_CTL
  (FATE#322643 bsc#1055900).
- drm/i915: Align vswing sequences with old ddi buffer registers
  (FATE#322643 bsc#1055900).
- drm/i915: decouple gen9 and gen10 dp signal levels (FATE#322643
  bsc#1055900).
- drm/i915: Introduce intel_ddi_dp_level (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaDisableI2mCycleOnWRPort (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WA FtrEnableFastAnisoL1BankingFix (FATE#322643
  bsc#1055900).
- drm/i915/cnl: don't hardcode DPCLKA_CFGCR0_DDI_CLK_SEL_SHIFT
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: WaForceContextSaveRestoreNonCoherent (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaPushConstantDereferenceHoldDisable (FATE#322643
  bsc#1055900).
- drm/i915/cnl: extract cnl_set_procmon_ref_values (FATE#322643
  bsc#1055900).
- drm/i915/cnl: simplify cnl_procmon_values handling (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Apply large line width optimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: WaDisableEnhancedSBEVertexCaching (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add
  WaDisableReplayBufferBankArbitrationOptimization (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Introduce initial Cannonlake Workarounds
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Remove alpha support protection (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Coffee Lake works on Kaby Lake PCH (FATE#322643
  bsc#1055900).
- commit 2e11a0a
* Thu Nov  2 2017 tiwai@suse.de
- drm/i915/cnl: Fix PLL initialization for HDMI (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix PLL mapping (FATE#322643 bsc#1055900).
- drm/i915: Fix the missing PPAT cache attributes on CNL
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix LSPCON support (FATE#322643 bsc#1055900).
- drm/i915/cnl: Reuse skl_wm_get_hw_state on Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/gen10: implement gen 10 watermarks calculations
  (FATE#322643 bsc#1055900).
- drm/i915: Addition wrapper for fixed16.16 operation (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Setup PAT Index (FATE#322643 bsc#1055900).
- drm/i915/gen10: fix WM latency printing (FATE#322643
  bsc#1055900).
- drm/i915/gen10: fix the gen 10 SAGV block time (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Enable SAGV for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/gen10+: use the SKL code for reading WM latencies
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Dump the right pll registers when dumping pipe
  config (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add allowed DP rates for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add max allowed Cannonlake DC (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add slice and subslice information to debugfs
  (FATE#322643 bsc#1055900).
- drm/i915: Return correct EDP voltage swing table for 0.85V
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Removing missing DDI_E bits from CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix loadgen select programming on ddi vswing
  sequence (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add missing type case (FATE#322643 bsc#1055900).
- drm/i915/cnl: Don't trust VBT's alternate pin for port D for
  now (FATE#322643 bsc#1055900).
- drm/i915/cnl: Get DDI clock based on PLLs (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Inherit RPS stuff from previous platforms
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake color init (FATE#322643 bsc#1055900).
- x86/gpu: CNL uses the same GMS values as SKL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add force wake for gen10+ (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix the CURSOR_COEFF_MASK used in DDI Vswing
  Programming (FATE#322643 bsc#1055900).
- drm/i915/cnl: Fix RMW on ddi vswing sequence (FATE#322643
  bsc#1055900).
- drm/i915/cnl: LSPCON support is gen9+ (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable fifo underrun for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Fix Cannonlake scaler mode programing (FATE#322643
  bsc#1055900).
- drm/i915: Use HAS_CSR instead of gen number on DMC load
  (FATE#322643 bsc#1055900).
- drm/i915/DMC/CNL: Load DMC on CNL (FATE#322643 bsc#1055900).
- drm/i915/cnl: Enable loadgen_select bit for vswing sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement voltage swing sequence (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add DDI Buffer translation tables for Cannonlake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add registers related to voltage swing sequences
  (FATE#322643 bsc#1055900).
- drm/i915: Add MMIO helper for 6 ports with different offsets
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Initialize PLLs (FATE#322643 bsc#1055900).
- drm/i915: Configure DPLL's for Cannonlake (FATE#322643
  bsc#1055900).
- drm/i915/cnl: DDI - PLL mapping (FATE#322643 bsc#1055900).
- drm/i915/cnl: Allow dynamic cdclk changes on CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement CNL display init/unit sequence
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Implement .set_cdclk() for CNL (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Implement .get_display_clock_speed() for CNL
  (FATE#322643 bsc#1055900).
- drm/i915: Remove unnecessary PORT3 definition (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Also need power well sanitize (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add power wells for CNL (FATE#322643 bsc#1055900).
- drm/i915/gen10: Set value of Indirect Context Offset for gen10
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake has same MOCS table than Skylake
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Configure EU slice power gating (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Cannonlake has 4 planes (3 sprites) per pipe
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: add IS_CNL_REVID macro (FATE#322643 bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for Y-skus (FATE#322643
  bsc#1055900).
- drm/i915/cnl: Add Cannonlake PCI IDs for U-skus (FATE#322643
  bsc#1055900).
- drm/i915: Always use 9 bits of the LPC bridge device ID for
  PCH detection (FATE#322643 bsc#1055900).
- drm/i915: Fix PCH names for KBP and CNP (FATE#322643
  bsc#1055900).
- commit 99ef3b0
* Thu Nov  2 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add ext4 git repository
- commit 7d0f4fb
* Thu Nov  2 2017 hare@suse.de
- Update s390x config files (FATE#323442)
- commit 139ffd3
* Thu Nov  2 2017 hare@suse.de
- s390/dasd: Add discard support for FBA devices (FATE#322263,
  bsc#1061020).
- commit fcd8c50
* Thu Nov  2 2017 hare@suse.de
- s390/mm,kvm: use nodat PGSTE tag to optimize TLB flushing
  (FATE#321512, bsc#1061009).
- s390/mm: add guest ASCE TLB flush optimization (FATE#321512,
  bsc#1061009).
- s390/mm: add no-dat TLB flush optimization (FATE#321512,
  bsc#1061009).
- s390/mm: tag normal pages vs pages used in page tables
  (FATE#321512, bsc#1061009).
- s390/sclp: single increment assignment control (FATE#323299,
  bsc#1061050).
- scsi: Do not retry invalid function error (bnc#809122).
- Delete
  patches.suse/scsi-do-not-retry-invalid-function-error.patch.
- commit cbe6ec6
* Wed Nov  1 2017 lduncan@suse.com
- KEYS: prevent KEYCTL_READ on negative key (bsc#1066043).
- KEYS: fix writing past end of user-supplied buffer in
  keyring_read() (bsc#1066046).
- serial: Fix port type numbering for TI DA8xx (bsc#1066048).
- serial: Remove unused port type (bsc#1066045).
- commit e8b8788
* Wed Nov  1 2017 msuchanek@suse.de
- Delete patches.rpmify/firmware-path
  Firmware path is irrelevant since the firmware is not used anyway
  (bsc#1054239).
- commit 6a4e78f
* Wed Nov  1 2017 bp@suse.de
- iommu/amd: Do not disable SWIOTLB if SME is active
  (fate#322123).
- commit bf4176e
* Wed Nov  1 2017 jack@suse.cz
- ext4: add ext4_should_use_dax() (bsc#1064591).
- commit a01f212
* Wed Nov  1 2017 jack@suse.cz
- ext4: add sanity check for encryption + DAX (bsc#1064591).
- commit 19ca8bf
* Wed Nov  1 2017 jack@suse.cz
- ext4: prevent data corruption with journaling + DAX
  (bsc#1064591).
- commit 0aec3e0
* Wed Nov  1 2017 jack@suse.cz
- ext4: prevent data corruption with inline data + DAX
  (bsc#1064591).
- commit 7dfd254
* Wed Nov  1 2017 vbabka@suse.cz
- mm,compaction: serialize waitqueue_active() checks (for real)
  (Git-fixes, VM Performance).
- commit 483dd23
* Wed Nov  1 2017 jgross@suse.com
- Kbuild: use -fshort-wchar globally (bnc#1065600).
- commit 3a70c58
* Wed Nov  1 2017 jgross@suse.com
- xen: x86: mark xen_find_pt_base as __init (bnc#1065600).
- commit 1037440
* Wed Nov  1 2017 jgross@suse.com
- xen/events: events_fifo: Don't use {get,put}_cpu() in
  xen_evtchn_fifo_init() (bnc#1065600).
- commit 61488f9
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S: Protect kvmppc_gpa_to_ua() with SRCU
  (bsc#1061840).
- commit ad12195
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: POWER9 more doorbell fixes (bsc#1061840).
- commit db3a4d5
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Fix oops when checking KVM_CAP_PPC_HTM (bsc#1061840).
- commit 7d9f250
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Use msgsync with hypervisor doorbells on
  POWER9 (bsc#1061840).
- commit 7e124d4
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Hold kvm->lock around call to
  kvmppc_update_lpcr (bsc#1061840).
- commit e13b8b9
* Tue Oct 31 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix case where HDEC is treated as 32-bit
  on POWER9 (bsc#1061840).
- commit 9b7c48e
* Tue Oct 31 2017 bpoirier@suse.com
- Refresh
  patches.drivers/0008-Revert-commit-1a8b6d76dc5b-net-add-one-common-config.patch.
- Refresh
  patches.drivers/0009-ixgbe-Use-new-PCI_DEV_FLAGS_NO_RELAXED_ORDERING-flag.patch.
- Refresh
  patches.drivers/0047-scsi-qla2xxx-Cleanup-FC-NVMe-code.patch.
- Refresh
  patches.drivers/0048-scsi-qla2xxx-Move-function-prototype-to-correct-head.patch.
- Refresh
  patches.drivers/0049-scsi-qla2xxx-Added-change-to-enable-ZIO-for-FC-NVMe-.patch.
- Refresh
  patches.drivers/0050-scsi-qla2xxx-Simpify-unregistration-of-FC-NVMe-local.patch.
- Refresh
  patches.drivers/0051-scsi-qla2xxx-Fix-remoteport-disconnect-for-FC-NVMe.patch.
- Refresh
  patches.drivers/0052-scsi-qla2xxx-use-dma_mapping_error-to-check-map-erro.patch.
- Refresh
  patches.drivers/0053-scsi-qla2xxx-fix-spelling-mistake-of-variable-sfp_ad.patch.
- Refresh
  patches.drivers/0054-scsi-qla2xxx-Correction-to-vha-vref_count-timeout.patch.
- Refresh
  patches.drivers/0055-scsi-qla2xxx-Fix-target-multiqueue-configuration.patch.
- Refresh
  patches.drivers/0056-scsi-qla2xxx-Update-fw_started-flags-at-qpair-creati.patch.
- Refresh
  patches.drivers/0057-scsi-qla2xxx-Add-command-completion-for-error-path.patch.
- Refresh
  patches.drivers/0058-scsi-qla2xxx-Fix-WWPN-WWNN-in-debug-message.patch.
- Refresh
  patches.drivers/0059-scsi-qla2xxx-Fix-system-panic-due-to-pointer-access-.patch.
- Refresh
  patches.drivers/0060-scsi-qla2xxx-Use-BIT_6-to-acquire-FAWWPN-from-switch.patch.
- Refresh
  patches.drivers/0061-scsi-qla2xxx-Fix-NPIV-host-enable-after-chip-reset.patch.
- Refresh
  patches.drivers/0062-scsi-qla2xxx-Remove-extra-register-read.patch.
- Refresh
  patches.drivers/0063-scsi-qla2xxx-Change-ha-wq-max_active-value-to-defaul.patch.
- Refresh
  patches.drivers/0064-scsi-qla2xxx-Use-fabric-name-for-Get-Port-Speed-comm.patch.
- Refresh
  patches.drivers/0065-scsi-qla2xxx-Add-ability-to-autodetect-SFP-type.patch.
- Refresh
  patches.drivers/0066-scsi-qla2xxx-Prevent-sp-free-null-uninitialized-poin.patch.
- Refresh
  patches.drivers/0067-scsi-qla2xxx-Use-sp-free-instead-of-hard-coded-call.patch.
- Refresh
  patches.drivers/0068-scsi-qla2xxx-Move-logging-default-mask-to-execute-on.patch.
- Refresh
  patches.drivers/0069-scsi-qla2xxx-Add-timeout-ability-to-wait_for_sess_de.patch.
- Refresh
  patches.drivers/0070-scsi-qla2xxx-Allow-SNS-fabric-login-to-be-retried.patch.
- Refresh
  patches.drivers/0071-scsi-qla2xxx-Fix-task-mgmt-handling-for-NPIV.patch.
- Refresh
  patches.drivers/0072-scsi-qla2xxx-Print-correct-mailbox-registers-in-fail.patch.
- Refresh
  patches.drivers/0073-scsi-qla2xxx-Remove-potential-macro-parameter-side-e.patch.
- Refresh
  patches.drivers/0074-scsi-qla2xxx-Add-support-for-minimum-link-speed.patch.
- Refresh
  patches.drivers/0075-scsi-qla2xxx-Add-LR-distance-support-from-nvram-bit.patch.
- Refresh
  patches.drivers/0076-scsi-qla2xxx-Cleanup-NPIV-host-in-target-mode-during.patch.
- Refresh
  patches.drivers/0077-scsi-qla2xxx-Enable-Async-TMF-processing.patch.
- Refresh
  patches.drivers/0078-scsi-qla2xxx-Increase-ql2xmaxqdepth-to-64.patch.
- Refresh
  patches.drivers/0079-scsi-qla2xxx-Recheck-session-state-after-RSCN.patch.
- Refresh
  patches.drivers/0080-scsi-qla2xxx-Skip-zero-queue-count-entry-during-FW-d.patch.
- Refresh
  patches.drivers/0081-scsi-qla2xxx-Ability-to-process-multiple-SGEs-in-Com.patch.
- Refresh
  patches.drivers/0082-scsi-qla2xxx-Do-not-call-abort-handler-function-duri.patch.
- Refresh
  patches.drivers/0083-scsi-qla2xxx-Update-driver-version-to-10.00.00.01-k.patch.
- Refresh
  patches.drivers/0084-scsi-qla2xxx-Fix-an-integer-overflow-in-sysfs-code.patch.
- Refresh
  patches.drivers/IB-rxe-Another-fix-for-broken-receive-queue-draining.patch.
- Refresh
  patches.drivers/IB-rxe-Move-refcounting-earlier-in-rxe_send.patch.
- Refresh
  patches.drivers/e1000e-Don-t-return-uninitialized-stats.patch.
- Refresh
  patches.drivers/ibmvnic-103-Initialize-SCRQ-s-during-login-renegotiation.patch.
- Refresh
  patches.drivers/ibmvnic-104-Check-for-transport-event-on-driver-resume.patch.
- Refresh
  patches.drivers/ibmvnic-105-Report-rx-buffer-return-codes-as-netdev_dbg.patch.
- Refresh
  patches.drivers/ibmvnic-106-Implement-per-queue-statistics-reporting.patch.
- Refresh
  patches.drivers/ibmvnic-107-Convert-vnic-server-reported-statistics-to-cpu-endian.patch.
- Refresh
  patches.drivers/ibmvnic-108-Implement-.get_ringparam.patch.
- Refresh
  patches.drivers/ibmvnic-109-Implement-.get_channels.patch.
- Refresh
  patches.drivers/ibmvnic-110-Clean-up-resources-on-probe-failure.patch.
- Refresh
  patches.drivers/ibmvnic-111-Add-netdev_dbg-output-for-debugging.patch.
- Refresh
  patches.drivers/ibmvnic-112-constify-vio_device_id.patch.
- Refresh
  patches.drivers/net-check-type-when-freeing-metadata-dst.patch.
- Refresh
  patches.drivers/net-mlx5e-IPoIB-Fix-driver-name-retrieved-by-ethtool.patch.
- Refresh
  patches.drivers/net-sched-fix-memleak-for-chain-zero.patch.
- Refresh
  patches.drivers/scsi-cxlflash-22-Fix-an-error-handling-path-in-cxlflash.patch.
- Refresh
  patches.drivers/scsi-cxlflash-23-Remove-unnecessary-existence-check.patch.
- Refresh
  patches.drivers/scsi-cxlflash-24-Avoid-double-mutex-unlock.patch.
- Refresh
  patches.drivers/scsi-cxlflash-25-Fix-vlun-resize-failure-in-the-shrink-.patch.
- Refresh
  patches.drivers/scsi-libfc-fix-a-deadlock-in-fc_rport_work.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Add-ATIO-Q-processing-for-INTx-mode.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-MBC_GET_PORT_DATABASE-to-query-an.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Changes-to-support-N2N-logins.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Query-FC4-type-during-RSCN-processing.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Reinstate-module-parameter-ql2xenablems.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Update-driver-version-to-10.00.00.02-k.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Use-ql2xnvmeenable-to-enable-Q-Pair-for.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-don-t-break-the-bsg-lib-abstractions.patch.
- Refresh
  patches.drivers/scsi-scsi_transport_iscsi-fix-the-issue-that.patch.
- Refresh
  patches.drivers/scsi_transport_fc-return-EBUSY-for-deleted-vport.patch.
- Refresh
  patches.fixes/0001-loop-Add-PF_LESS_THROTTLE-to-block-loop-device-threa.patch.
- Refresh
  patches.fixes/0001-md-raid5-fix-a-race-condition-in-stripe-batch.patch.
  Update Git-repo tags according to current content in each repository.
- commit e2d8d15
* Mon Oct 30 2017 msuchanek@suse.de
- cxl: Fix driver use count (bsc#1055014).
- commit 004458e
* Mon Oct 30 2017 msuchanek@suse.de
- powerpc/tm: Fix illegal TM state in signal handler
  (bsc#1065729).
- powerpc/pseries: Fix parent_dn reference leak in add_dt_node()
  (bsc#1065729).
- powerpc/mm/hash: Free the subpage_prot_table correctly
  (bsc#1065729).
- powerpc/mm: Fix check of multiple 16G pages from device tree
  (bsc#1065729).
- powerpc: Correct instruction code for xxlor instruction
  (bsc#1065729).
- commit 701cd66
* Mon Oct 30 2017 ddiss@suse.de
- SMB3: Validate negotiate request must always be signed
  (bsc#1064597).
- SMB: fix validate negotiate info uninitialised memory use
  (bsc#1064597).
- SMB: fix leak of validate negotiate info response buffer
  (bsc#1064597).
- commit f686414
* Mon Oct 30 2017 yousaf.kaukab@suse.com
- cavium: cn99xx: enable out of tree ahci errata
  Refresh
  patches.drivers/0001-PCI-Vulcan-AHCI-PCI-bar-fix-for-Broadcom-Vulcan-earl.patch.
- commit 5b59192
* Mon Oct 30 2017 vbabka@suse.cz
- drivers: dma-mapping: Do not leave an invalid area->pages
  pointer in dma_common_contiguous_remap() (Git-fixes,
  bsc#1065692).
- commit 0f78052
* Mon Oct 30 2017 jgross@suse.com
- xen: fix booting ballooned down hvm guest (bnc#1065600).
- commit 177d959
* Mon Oct 30 2017 jslaby@suse.cz
- objtool: Fix memory leak in decode_instructions() (bnc#1058115).
- x86/unwind: Disable unwinder warnings on 32-bit (bnc#1058115).
- x86/unwind: Align stack pointer in unwinder dump (bnc#1058115).
- x86/unwind: Use MSB for frame pointer encoding on 32-bit
  (bnc#1058115).
- x86/unwind: Fix dereference of untrusted pointer (bnc#1058115).
- x86/kvm: Move kvm_fastop_exception to .fixup section
  (bnc#1058115).
- objtool: Upgrade libelf-devel warning to error for
  CONFIG_ORC_UNWINDER (bnc#1058115).
- kprobes/x86: Set up frame pointer in kprobe trampoline
  (bnc#1058115).
- objtool: Support unoptimized frame pointer setup (bnc#1058115).
- objtool: Skip unreachable warnings for GCC 4.4 and older
  (bnc#1058115).
- commit 0942514
* Mon Oct 30 2017 yousaf.kaukab@suse.com
- tty: xilinx_uartps: move to arch_initcall for earlier console
  (fate#323912).
- serial: xuartps: Remove __init marking from early write
  (fate#323912).
- commit bb8f007
* Sun Oct 29 2017 jslaby@suse.cz
- x86/unwind: Show function name+offset in ORC error messages
  (bnc#1058115).
- x86/entry: Fix idtentry unwind hint (bnc#1058115).
  x86/entry: Fix idtentry unwind hint (bnc#1058115).
- commit a59af47
* Fri Oct 27 2017 fdmanana@suse.com
- Btrfs: add support for fallocate's zero range operation
  (fate#323233).
- commit 5c14b28
* Fri Oct 27 2017 yousaf.kaukab@suse.com
- random: do not ignore early device randomness (bsc#1064475).
- commit 272473f
* Fri Oct 27 2017 msuchanek@suse.de
- powerpc/perf: Fix for core/nest imc call trace on cpuhotplug
  (FATE#322448, bsc#1054914).
- commit c0cc9d1
* Fri Oct 27 2017 msuchanek@suse.de
- powerpc/perf: Fix IMC initialization crash (FATE#322448,
  bsc#1054914).
- powerpc/perf: Add ___GFP_NOWARN flag to alloc_pages_node()
  (FATE#322448, bsc#1054914).
- commit 64c2f61
* Fri Oct 27 2017 jslaby@suse.cz
- futex: futex_wake_op, fix sign_extend32 sign bits (bnc#1064590).
- futex: futex_wake_op, do not fail on invalid op (bnc#1064590).
- commit dff8df7
* Thu Oct 26 2017 neilb@suse.com
- VFS: expedite unmount (bsc#1024412).
- commit 7f33b23
* Wed Oct 25 2017 tbogendoerfer@suse.de
- blacklist.conf: patched file is not backported
- commit 7103104
* Wed Oct 25 2017 tbogendoerfer@suse.de
- bpf: fix byte order test in test_verifier (bsc#1056787).
- commit 0318ced
* Wed Oct 25 2017 tbogendoerfer@suse.de
- nfp: handle page allocation failures (bsc#1055968).
- nfp: fix ethtool stats gather retry (bsc#1055968).
- nfp: wait for the NSP resource to appear on boot (bsc#1055968).
- nfp: wait for board state before talking to the NSP
  (bsc#1055968).
- nfp: flower: restore RTNL locking around representor updates
  (bsc#1055968).
- nfp: build the flower offload by default (bsc#1055968).
- nfp: be drop monitor friendly (bsc#1055968).
- nfp: move the start/stop app callbacks back (bsc#1055968).
- nfp: flower: base lifetime of representors on existence of
  lower vNIC (bsc#1055968).
- nfp: separate app vNIC init/clean from alloc/free (bsc#1055968).
- nfp: add basic SR-IOV ndo functions to representors
  (bsc#1055968).
- nfp: add basic SR-IOV ndo functions (bsc#1055968).
- nfp: don't reuse pointers in ring dumping (bsc#1055968).
- nfp: fix copy paste in names and messages regarding vNICs
  (bsc#1055968).
- nfp: add ethtool statistics for representors (bsc#1055968).
- nfp: add pointer to vNIC config memory to nfp_port structure
  (bsc#1055968).
- nfp: report MAC statistics in ethtool (bsc#1055968).
- nfp: store pointer to MAC statistics in nfp_port (bsc#1055968).
- nfp: split software and hardware vNIC statistics (bsc#1055968).
- nfp: add helper for printing ethtool strings (bsc#1055968).
- nfp: don't report standard netdev statistics in ethtool
  (bsc#1055968).
- nfp: allow retreiving management FW logs on representors
  (bsc#1055968).
- nfp: provide ethtool_drvinfo on representors (bsc#1055968).
- nfp: link basic ethtool ops to representors (bsc#1055968).
- nfp: process MTU updates from firmware flower app (bsc#1055968).
- nfp: process control messages in workqueue in flower app
  (bsc#1055968).
- nfp: send control message when MAC representors are created
  (bsc#1055968).
- bpf, nfp: implement jiting of BPF_J{LT,LE} (bsc#1055968).
- nfp: TX time stamp packets before HW doorbell is rung
  (bsc#1055968).
- commit 773d1a0
* Wed Oct 25 2017 tbogendoerfer@suse.de
- bpf: fix pattern matches for direct packet access (bsc#1056787).
- bpf: fix off by one for range markings with L{T, E} patterns
  (bsc#1056787).
- bpf: do not test for PCPU_MIN_UNIT_SIZE before percpu
  allocations (bsc#1056787).
- bpf: disallow arithmetic operations on context pointer
  (bsc#1056787).
- bpf: fix liveness marking (bsc#1056787).
- bpf: fix bpf_tail_call() x64 JIT (bsc#1056787).
- bpf: do not disable/enable BH in bpf_map_free_id()
  (bsc#1056787).
- bpf/verifier: reject BPF_ALU64|BPF_END (bsc#1056787).
- bpf: Only set node->ref = 1 if it has not been set
  (bsc#1056787).
- bpf: Inline LRU map lookup (bsc#1056787).
- bpf/verifier: document liveness analysis (bsc#1056787).
- bpf/verifier: remove varlen_map_value_access flag (bsc#1056787).
- bpf/verifier: when pruning a branch, ignore its write marks
  (bsc#1056787).
- bpf: inline map in map lookup functions for array and htab
  (bsc#1056787).
- bpf: make htab inlining more robust wrt assumptions
  (bsc#1056787).
- bpf: fix liveness propagation to parent in spilled stack slots
  (bsc#1056787).
- bpf: export bpf_prog_inc_not_zero (bsc#1056787).
- bpf/verifier: track liveness for pruning (bsc#1056787).
- bpf: enable BPF_J{LT, LE, SLT, SLE} opcodes in verifier
  (bsc#1056787).
- bpf: add BPF_J{LT,LE,SLT,SLE} instructions (bsc#1056787).
- bpf: Extend check_uarg_tail_zero() checks (bsc#1056787).
- bpf: Move check_uarg_tail_zero() upward (bsc#1056787).
- bpf/verifier: increase complexity limit to 128k (bsc#1056787).
- bpf/verifier: more concise register state logs for constant
  var_off (bsc#1056787).
- bpf/verifier: track signed and unsigned min/max values
  (bsc#1056787).
- bpf/verifier: rework value tracking (bsc#1056787).
- bpf: fix bpf_prog_get_info_by_fd to dump correct xlated_prog_len
  (bsc#1056787).
- bpf: don't indicate success when copy_from_user fails
  (bsc#1056787).
- selftests/bpf: subtraction bounds test (bsc#1056787).
- bpf: more tests for mixed signed and unsigned bounds checks
  (bsc#1056787).
- bpf: add test for mixed signed and unsigned bounds checks
  (bsc#1056787).
- bpf: fix up test cases with mixed signed/unsigned bounds
  (bsc#1056787).
- bpf: Implement show_options (bsc#1056787).
- bpf: don't open-code memdup_user() (bsc#1056787).
- bpf: export whether tail call has jited owner (bsc#1056787).
- bpf: Fix out-of-bound access on interpreters (bsc#1056787).
- bpf: Add syscall lookup support for fd array and htab
  (bsc#1056787).
- bpf: possibly avoid extra masking for narrower load in verifier
  (bsc#1056787).
- selftests/bpf: Add test cases to test narrower ctx field loads
  (bsc#1056787).
- bpf: reset id on spilled regs in clear_all_pkt_pointers
  (bsc#1056787).
- bpf: reset id on CONST_IMM transition (bsc#1056787).
- bpf: don't check spilled reg state for non-STACK_SPILLed type
  slots (bsc#1056787).
- bpf: cgroup skb progs cannot access ld_abs/ind (bsc#1056787).
- bpf: Add BPF_OBJ_GET_INFO_BY_FD (bsc#1056787).
- bpf: Add jited_len to struct bpf_prog (bsc#1056787).
- bpf: Add BPF_MAP_GET_FD_BY_ID (bsc#1056787).
- bpf: Add BPF_PROG_GET_FD_BY_ID (bsc#1056787).
- bpf: Add BPF_(PROG|MAP)_GET_NEXT_ID command (bsc#1056787).
- bpf: Introduce bpf_map ID (bsc#1056787).
- bpf: Remove the capability check for cgroup skb eBPF program
  (bsc#1056787).
- bpf: Allow CGROUP_SKB eBPF program to access sk_buff
  (bsc#1056787).
- bpf: use different interpreter depending on required stack size
  (bsc#1056787).
- bpf: reconcile bpf_tail_call and stack_depth (bsc#1056787).
- bpf: split bpf core interpreter (bsc#1056787).
- bpf: free up BPF_JMP | BPF_CALL | BPF_X opcode (bsc#1056787).
- commit afa6680
* Wed Oct 25 2017 jthumshirn@suse.de
- Update config files, add CONFIG_BLK_MQ_RDMA=y.
- commit 596d823
* Wed Oct 25 2017 jthumshirn@suse.de
- nvme-fc: correct io timeout behavior (FATE#323952, FATE#322506).
- nvme-fc: correct io termination handling (FATE#323952,
  FATE#322506).
- nvme-pci: add SGL support (FATE#323952, FATE#322506).
- nvme: use ida_simple_{get,remove} for the controller instance
  (FATE#323952, FATE#322506).
- nvmet: Change max_nsid in subsystem due to ns_disable if needed
  (FATE#323952, FATE#322506).
- nvme-loop: Add BLK_MQ_F_NO_SCHED flag to admin tag set
  (FATE#323952, FATE#322506).
- nvme-fc: Add BLK_MQ_F_NO_SCHED flag to admin tag set
  (FATE#323952, FATE#322506).
- nvme-rdma: Add BLK_MQ_F_NO_SCHED flag to admin tag set
  (FATE#323952, FATE#322506).
- nvme-pci: fix typos in comments (FATE#323952, FATE#322506).
- nvme-rdma: stop controller reset if the controller is deleting
  (FATE#323952, FATE#322506).
- nvme-rdma: change queue flag semantics DELETING -> ALLOCATED
  (FATE#323952, FATE#322506).
- nvme-rdma: Don't local invalidate if the queue is not live
  (FATE#323952, FATE#322506).
- nvme-rdma: teardown admin/io queues once on error recovery
  (FATE#323952, FATE#322506).
- nvme-rdma: Check that reinit_request got a proper mr
  (FATE#323952, FATE#322506).
- nvme-rdma: move assignment to declaration (FATE#323952,
  FATE#322506).
- nvme-rdma: fix wrong logging message (FATE#323952, FATE#322506).
- nvme-rdma: pass tagset to directly nvme_rdma_free_tagset
  (FATE#323952, FATE#322506).
- nvme: simplify compat_ioctl handling (FATE#323952, FATE#322506).
- nvme-fc: move remote port get/put/free location (FATE#323952,
  FATE#322506).
- nvme-fc: create fc class and transport device (FATE#323952,
  FATE#322506).
- nvme-fabrics: request transport module (FATE#323952,
  FATE#322506).
- nvmet: bump NVMET_NR_QUEUES to 128 (FATE#323952, FATE#322506).
- nvme: use menu Kconfig interface (FATE#323952, FATE#322506).
- nvme: update timeout module parameter type (FATE#323952,
  FATE#322506).
- nvme-fcloop: fix port deletes and callbacks (FATE#323952,
  FATE#322506).
- nvmet-fc: sync header templates with comments (FATE#323952,
  FATE#322506).
- nvmet-fc: ensure target queue id within range (FATE#323952,
  FATE#322506).
- nvmet-fc: on port remove call put outside lock (FATE#323952,
  FATE#322506).
- nvme-rdma: don't fully stop the controller in error recovery
  (FATE#323952, FATE#322506).
- nvme-rdma: give up reconnect if state change fails (FATE#323952,
  FATE#322506).
- nvme-core: Use nvme_wq to queue async events and fw activation
  (FATE#323952, FATE#322506).
- nvme: fix sqhd reference when admin queue connect fails
  (FATE#323952, FATE#322506).
- nvmet: implement valid sqhd values in completions (FATE#323952,
  FATE#322506).
- nvme-fabrics: Allow 0 as KATO value (FATE#323952, FATE#322506).
- nvme: allow timed-out ios to retry (FATE#323952, FATE#322506).
- nvme: stop aer posting if controller state not live
  (FATE#323952, FATE#322506).
- nvme-pci: Print invalid SGL only once (FATE#323952,
  FATE#322506).
- nvme-pci: initialize queue memory before interrupts
  (FATE#323952, FATE#322506).
- nvmet-fc: fix failing max io queue connections (FATE#323952,
  FATE#322506).
- nvme-fc: use transport-specific sgl format (FATE#323952,
  FATE#322506).
- nvme: add transport SGL definitions (FATE#323952, FATE#322506).
- commit 2ece78f
* Wed Oct 25 2017 jthumshirn@suse.de
- nvmet-fcloop: remove use of FC-specific error codes
  (FATE#323952, FATE#322506).
- nvme-pci: implement the HMB entry number and size limitations
  (FATE#323952, FATE#322506).
- nvme-pci: propagate (some) errors from host memory buffer setup
  (FATE#323952, FATE#322506).
- nvme-pci: use appropriate initial chunk size for HMB allocation
  (FATE#323952, FATE#322506).
- nvme-pci: fix host memory buffer allocation fallback
  (FATE#323952, FATE#322506).
- nvme: fix lightnvm check (FATE#323952, FATE#322506).
- nvmet: add support for reporting the host identifier
  (FATE#323952, FATE#322506).
- nvme: Use metadata for passthrough commands (FATE#323952,
  FATE#322506).
- nvme: Make nvme user functions static (FATE#323952,
  FATE#322506).
- nvme/pci: Use req_op to determine DIF remapping (FATE#323952,
  FATE#322506).
- nvme: factor metadata handling out of __nvme_submit_user_cmd
  (FATE#323952, FATE#322506).
- nvme-fabrics: Convert nvmf_transports_mutex to an rwsem
  (FATE#323952, FATE#322506).
- nvme: don't blindly overwrite identifiers on disk revalidate
  (FATE#323952, FATE#322506).
- nvme: remove nvme_revalidate_ns (FATE#323952, FATE#322506).
- nvme: remove unused struct nvme_ns fields (FATE#323952,
  FATE#322506).
- nvme: allow calling nvme_change_ctrl_state from irq context
  (FATE#323952, FATE#322506).
- nvme: report more detailed status codes to the block layer
  (FATE#323952, FATE#322506).
- nvme: honor RTD3 Entry Latency for shutdowns (FATE#323952,
  FATE#322506).
- nvme: fix uninitialized prp2 value on small transfers
  (FATE#323952, FATE#322506).
- nvme-rdma: Use unlikely macro in the fast path (FATE#323952,
  FATE#322506).
- nvmet-fc: simplify sg list handling (FATE#323952, FATE#322506).
- nvme-fc: Reattach to localports on re-registration (FATE#323952,
  FATE#322506).
- nvme: rename AMS symbolic constants to fit specification
  (FATE#323952, FATE#322506).
- nvme: add symbolic constants for CC identifiers (FATE#323952,
  FATE#322506).
- nvme: fix identify namespace logging (FATE#323952, FATE#322506).
- nvme-fabrics: log a warning if hostid is invalid (FATE#323952,
  FATE#322506).
- nvme-rdma: call ops->reg_read64 instead of nvmf_reg_read64
  (FATE#323952, FATE#322506).
- nvme-rdma: cleanup error path in controller reset (FATE#323952,
  FATE#322506).
- nvme-rdma: introduce nvme_rdma_start_queue (FATE#323952,
  FATE#322506).
- nvme-rdma: rename nvme_rdma_init_queue to nvme_rdma_alloc_queue
  (FATE#323952, FATE#322506).
- nvme-rdma: stop queues instead of simply flipping their state
  (FATE#323952, FATE#322506).
- nvme-rdma: introduce configure/destroy io queues (FATE#323952,
  FATE#322506).
- nvme-rdma: reuse configure/destroy_admin_queue (FATE#323952,
  FATE#322506).
- nvme-rdma: don't free tagset on resets (FATE#323952,
  FATE#322506).
- nvme-rdma: disable the controller on resets (FATE#323952,
  FATE#322506).
- nvme-rdma: move tagset allocation to a dedicated routine
  (FATE#323952, FATE#322506).
- nvme: Add admin_tagset pointer to nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme-rdma: move nvme_rdma_configure_admin_queue code location
  (FATE#323952, FATE#322506).
- nvme-rdma: remove NVME_RDMA_MAX_SEGMENT_SIZE (FATE#323952,
  FATE#322506).
- nvmet-fcloop: remove ALL_OPTS define (FATE#323952, FATE#322506).
- nvmet: fix the return error code of target if host is not
  allowed (FATE#323952, FATE#322506).
- nvmet: use NVME_NSID_ALL (FATE#323952, FATE#322506).
- nvme: add support for NVMe 1.3 Timestamp Feature (FATE#323952,
  FATE#322506).
- nvme: define NVME_NSID_ALL (FATE#323952, FATE#322506).
- nvme: add support for FW activation without reset (FATE#323952,
  FATE#322506).
- blk-mq: Make blk_mq_reinit_tagset() calls easier to read
  (FATE#323952, FATE#322506).
- nvmem: include linux/err.h from header (FATE#323952,
  FATE#322506).
- nvmem: core: Add nvmem_cell_read_u32 (FATE#323952, FATE#322506).
- nvmet-rdma: remove redundant empty device add callout
  (FATE#323952, FATE#322506).
- nvme-rdma: remove redundant empty device add callout
  (FATE#323952, FATE#322506).
- nvme-rdma: use intelligent affinity based queue mappings
  (FATE#323952, FATE#322506).
- block: Add rdma affinity based queue mapping helper
  (FATE#323952, FATE#322506).
- commit 747cb11
* Wed Oct 25 2017 jthumshirn@suse.de
- scripts/git_sort/git_sort.py: Add upstream NVMe repository
- commit 7a0ab79
* Wed Oct 25 2017 tbogendoerfer@suse.de
- bnxt_en: Fix possible corruption in DCB parameters from firmware
  (bsc#1050242 FATE#322914).
- bnxt_en: Fix possible corrupted NVRAM parameters from firmware
  response (bsc#1050242 FATE#322914).
- bnxt_en: Fix VF resource checking (bsc#1050242 FATE#322914).
- bnxt_en: Fix VF PCIe link speed and width logic (bsc#1050242
  FATE#322914).
- bnxt_en: Don't use rtnl lock to protect link change logic in
  workqueue (bsc#1050242 FATE#322914).
- bnxt_en: Improve VF/PF link change logic (bsc#1050242
  FATE#322914).
- commit 99e5c52
* Tue Oct 24 2017 oneukum@suse.com
- power: supply: Fix power_supply_am_i_supplied to return -ENODEV
  when apropriate (bsc#1064870).
- commit 36c0450
* Tue Oct 24 2017 msuchanek@suse.de
- Blacklist build fixes for configurations we don't use
  7e7dc66adcf4 powerpc/mm: Build fix for non SPARSEMEM_VMEMAP config
- commit 65839a0
* Tue Oct 24 2017 oneukum@suse.com
- bcma: gpio: Correct number of GPIOs for BCM53573 (bsc#1048185).
- commit b622f9e
* Tue Oct 24 2017 msuchanek@suse.de
- Blacklist fixes for unsupported ppc platforms
  3c29b6038828 powerpc/8xx: fix mpc8xx_get_irq() return on no irq
  8d046759f6ad powerpc/44x: Fix mask and shift to zero bug
  c65540453e15 powerpc/83xx: Use sizeof correct type when ioremapping
- commit bc9210e
* Tue Oct 24 2017 oneukum@suse.com
- iwlwifi: nvm: set the correct offsets to 3168 series
  (FATE#322675).
- commit 012cc15
* Tue Oct 24 2017 oneukum@suse.com
- blacklist.conf: just removes an unused constant
- commit 41edaf8
* Tue Oct 24 2017 oneukum@suse.com
- blacklist.conf: We do not use m-bus
- commit 0028f53
* Tue Oct 24 2017 oneukum@suse.com
- pinctrl: check ops->pin_config_set in pinconf_set_config()
  (bsc#1064862).
- commit 7ffeae7
* Tue Oct 24 2017 oneukum@suse.com
- iwlwifi: mvm: return -ENODATA when reading the temperature
  with the FW down (FATE#322675).
- commit 82b7e03
* Tue Oct 24 2017 oneukum@suse.com
- blacklist.conf: Totally unused
- commit c8b4062
* Tue Oct 24 2017 mcgrof@suse.com
- supported.conf: add CONFIG_TEST_LKM=m on kselftests-kmp
- Update config files.
  The kselftests-kmp fails to build on vanilla as no modules
  are present. We add the test_module just so that kselftests-kmp
  is never empty on any flavor.
- commit 88d2cfb
* Mon Oct 23 2017 msuchanek@suse.de
- Remove remaining RPi3 patches.
  The post-4.12 patches modify only devicetree and we don't use the
  devicetree from kernel.
- commit c65306e
* Mon Oct 23 2017 dbueso@suse.de
- locking/rwsem-xadd: Fix missed wakeup due to reordering of load (bsc#1050549).
- commit 16013be
* Mon Oct 23 2017 msuchanek@suse.de
- Refresh metadata on rpi3 enablement patches.
- commit 39ba7ab
* Mon Oct 23 2017 dmulder@suse.com
- CIFS: fix circular locking dependency (bsc#1064701).
- commit 0d88f5f
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 81c882d
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 363694d
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit c1f6612
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 48d23a2
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 865ea84
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5da7287
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 87aae5f
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5d96e28
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 55132f5
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 75c2056
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 3eb65cd
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do noy use the driver. It is not even compiled.
- commit 973ce20
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit ae3cfa6
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit cb9514c
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 93eb95b
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use thwe driver. It is not even compiled.
- commit 1fc6071
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit cc3ae21
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 7deff52
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 8db603c
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5e82dac
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 17fddcc
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit 5ec0458
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: We do not use the driver. It is not even compiled.
- commit ded0aea
* Mon Oct 23 2017 oneukum@suse.com
- blacklist.conf: we do not use the driver. It is not even compiled.
- commit d4a32ec
* Mon Oct 23 2017 tbogendoerfer@suse.de
- net/sched: cls_flower: Set egress_dev mark when calling into
  the HW driver (bsc#1056787).
- commit 7276c25
* Mon Oct 23 2017 ohering@suse.de
- vmbus: hvsock: add proper sync for
  vmbus_hvsock_device_unregister() (fate#323887).
- commit b1aee9d
* Mon Oct 23 2017 bpoirier@suse.com
- Refresh patches.suse/0001-ipc-sem-drop-sem_checkid-helper.patch.
- Refresh
  patches.suse/0001-rbtree-cache-leftmost-node-internally.patch.
- Refresh
  patches.suse/0002-ipc-sem-play-nicer-with-large-nsops-allocations.patch.
- Refresh
  patches.suse/0002-rbtree-optimize-root-check-during-rebalancing-loop.patch.
- Refresh
  patches.suse/0003-rbtree-add-some-additional-comments-for-rebalancing-.patch.
- Refresh
  patches.suse/0008-sched-deadline-replace-earliest-dl-and-rq-leftmost-c.patch.
- Refresh
  patches.suse/0009-locking-rtmutex-replace-top-waiter-and-pi_waiters-le.patch.
- Refresh
  patches.suse/0010-block-cfq-replace-cfq_rb_root-leftmost-caching.patch.
- Refresh
  patches.suse/0012-lib-interval-tree-correct-comment-wrt-generic-flavor.patch.
- Refresh
  patches.suse/0013-procfs-use-faster-rb_first_cached.patch.
- Refresh
  patches.suse/0014-fs-epoll-use-faster-rb_first_cached.patch.
- Refresh patches.suse/0015-mem-memcg-cache-rightmost-node.patch.
- Refresh
  patches.suse/0016-block-cfq-cache-rightmost-rb_node.patch.
- Refresh patches.suse/0039-efi-Add-EFI_SECURE_BOOT-bit.patch.
- Refresh
  patches.suse/0040-Add-the-ability-to-lock-down-access-to-the-running-k.patch.
- Refresh
  patches.suse/0041-efi-Lock-down-the-kernel-if-booted-in-secure-boot-mo.patch.
- Refresh
  patches.suse/0042-Enforce-module-signatures-if-the-kernel-is-locked-do.patch.
- Refresh
  patches.suse/0043-Restrict-dev-mem-and-dev-kmem-when-the-kernel-is-loc.patch.
- Refresh
  patches.suse/0045-kexec-Disable-at-runtime-if-the-kernel-is-locked-dow.patch.
- Refresh
  patches.suse/0046-Copy-secure_boot-flag-in-boot-params-across-kexec-re.patch.
- Refresh
  patches.suse/0047-kexec_file-Disable-at-runtime-if-securelevel-has-bee.patch.
- Refresh
  patches.suse/0048-hibernate-Disable-when-the-kernel-is-locked-down.patch.
- Refresh
  patches.suse/0049-uswsusp-Disable-when-the-kernel-is-locked-down.patch.
- Refresh
  patches.suse/0050-PCI-Lock-down-BAR-access-when-the-kernel-is-locked-d.patch.
- Refresh
  patches.suse/0051-x86-Lock-down-IO-port-access-when-the-kernel-is-lock.patch.
- Refresh
  patches.suse/0052-x86-Restrict-MSR-access-when-the-kernel-is-locked-do.patch.
- Refresh
  patches.suse/0053-asus-wmi-Restrict-debugfs-interface-when-the-kernel-.patch.
- Refresh
  patches.suse/0054-ACPI-Limit-access-to-custom_method-when-the-kernel-i.patch.
- Refresh
  patches.suse/0055-acpi-Ignore-acpi_rsdp-kernel-param-when-the-kernel-h.patch.
- Refresh
  patches.suse/0056-acpi-Disable-ACPI-table-override-if-the-kernel-is-lo.patch.
- Refresh
  patches.suse/0057-acpi-Disable-APEI-error-injection-if-the-kernel-is-l.patch.
  These patches are tagged with Git-commit ids which are not actually found
  in the respective Git-repo. Udate the tags accordingly.
- commit bad2721
* Fri Oct 20 2017 mkubecek@suse.cz
- packet: in packet_do_bind, test fanout with bind_lock held
  (CVE-2017-15649 bsc#1064388).
- packet: hold bind lock when rebinding to fanout hook
  (CVE-2017-15649 bsc#1064388).
- commit d09ce18
* Fri Oct 20 2017 mkubecek@suse.cz
- series.conf: refresh
  (just ran scripts/series_sort.py)
- commit 1be1653
* Fri Oct 20 2017 tbogendoerfer@suse.de
- i40iw: Fix port number for query QP (bsc#1058659 FATE#322535).
- i40iw: Add missing memory barriers (bsc#1058659 FATE#322535).
- IB/hfi1: On error, fix use after free during user context setup
  (bsc#1060463 FATE#323043).
- Revert "IB/ipoib: Update broadcast object if PKey value was
  changed in index 0" (bsc#1046307 FATE#322941).
- IB/hfi1: Return correct value in general interrupt handler
  (bsc#1060463 FATE#323043).
- IB/hfi1: Only reset QSFP after link up and turn off AOC TX
  (bsc#1060463 FATE#323043).
- IB/hfi1: Turn off AOC TX after offline substates (bsc#1060463
  FATE#323043).
- IB/ipoib: Fix inconsistency with free_netdev and
  free_rdma_netdev (bsc#1046307 FATE#322941).
- IB: Correct MR length field to be 64-bit (bsc#1046306
  FATE#322942).
- commit e86f670
* Fri Oct 20 2017 tbogendoerfer@suse.de
- drivers: net: xgene: Remove return statement from void function
  (bsc#1064426).
- drivers: net: xgene: Configure tx/rx delay for ACPI
  (bsc#1064426).
- drivers: net: xgene: Read tx/rx delay for ACPI (bsc#1064426).
- drivers: net: xgene: Correct probe sequence handling
  (bsc#1064426).
- xgene: Always get clk source, but ignore if it's missing for
  SGMII ports (bsc#1048501).
- xgene: Don't fail probe, if there is no clk resource for SGMII
  interfaces (bsc#1048501).
- commit 5124b20
* Fri Oct 20 2017 msuchanek@suse.de
- Refresh metadata on ibmvnic patches.
- commit 2625b9d
* Fri Oct 20 2017 msuchanek@suse.de
- Blacklist unsupported architectures.
- commit e2b7413
* Fri Oct 20 2017 jkosina@suse.cz
- Update config files.
- commit 7e76d8c
* Fri Oct 20 2017 ohering@suse.de
- x86/hyperv: Fix hypercalls with extended CPU ranges for TLB
  flushing (fate#323887).
- x86/hyperv: Don't use percpu areas for pcpu_flush/pcpu_flush_ex
  structures (fate#323887).
- x86/hyperv: Clear vCPU banks between calls to avoid flushing
  unneeded vCPUs (fate#323887).
- Drivers: hv: vmbus: Fix bugs in rescind handling (fate#323887).
- Drivers: hv: fcopy: restore correct transfer length
  (fate#323887).
- vmbus: don't acquire the mutex in
  vmbus_hvsock_device_unregister() (fate#323887).
- hv_netvsc: fix send buffer failure on MTU change (fate#323887).
- netvsc: increase default receive buffer size (fate#323887).
- x86/hyper-v: Remove duplicated
  HV_X64_EX_PROCESSOR_MASKS_RECOMMENDED definition (fate#323887).
- hv_netvsc: avoid unnecessary wakeups on subchannel creation
  (fate#323887).
- hv_netvsc: fix deadlock on hotplug (fate#323887).
- hv_netvsc: Fix the channel limit in netvsc_set_rxfh()
  (fate#323887).
- hv_netvsc: Simplify the limit check in netvsc_set_channels()
  (fate#323887).
- hv_netvsc: Simplify num_chn checking in
  rndis_filter_device_add() (fate#323887).
- hv_netvsc: Clean up an unused parameter in
  rndis_filter_set_rss_param() (fate#323887).
- netvsc: allow driver to be removed even if VF is present
  (fate#323887).
- netvsc: cleanup datapath switch (fate#323887).
- tracing/hyper-v: Trace hyperv_mmu_flush_tlb_others()
  (fate#323887).
- x86/hyper-v: Support extended CPU ranges for TLB flush
  hypercalls (fate#323887).
- scsi: storvsc: fix memory leak on ring buffer busy
  (fate#323887).
- hv_netvsc: Fix rndis_filter_close error during netvsc_remove
  (fate#323887).
- hv_netvsc: Add ethtool handler to set and get UDP hash levels
  (fate#323887).
- hv_netvsc: Clean up unused parameter from
  netvsc_get_rss_hash_opts() (fate#323887).
- hv_netvsc: Clean up unused parameter from netvsc_get_hash()
  (fate#323887).
- vmbus: remove unused vmbus_sendpacket_ctl (fate#323887).
- vmbus: remove unused vmubs_sendpacket_pagebuffer_ctl
  (fate#323887).
- vmbus: remove unused vmbus_sendpacket_multipagebuffer
  (fate#323887).
- Drivers: hv: vmbus: Fix rescind handling issues (fate#323887).
- Tools: hv: update buffer handling in hv_fcopy_daemon
  (fate#323887).
- Tools: hv: fix snprintf warning in kvp_daemon (fate#323887).
- Drivers: hv: kvp: Use MAX_ADAPTER_ID_SIZE for translating
  adapter id (fate#323887).
- Drivers: hv: balloon: Initialize last_post_time on startup
  (fate#323887).
- Drivers: hv: balloon: Show the max dynamic memory assigned
  (fate#323887).
- Drivers: hv: balloon: Correctly update onlined page count
  (fate#323887).
- Tools: hv: vss: Skip freezing filesystems backed by loop
  (fate#323887).
- netvsc: keep track of some non-fatal overload conditions
  (fate#323887).
- netvsc: allow controlling send/recv buffer size (fate#323887).
- netvsc: remove unnecessary check for NULL hdr (fate#323887).
- netvsc: remove unnecessary cast of void pointer (fate#323887).
- netvsc: whitespace cleanup (fate#323887).
- netvsc: no need to allocate send/receive on numa node
  (fate#323887).
- netvsc: check error return when restoring channels and mtu
  (fate#323887).
- netvsc: propagate MAC address change to VF slave (fate#323887).
- netvsc: don't signal host twice if empty (fate#323887).
- netvsc: delay setup of VF device (fate#323887).
- x86/hyper-v: Use hypercall for remote TLB flush (fate#323887).
- hyper-v: Globalize vp_index (fate#323887).
- x86/hyper-v: Implement rep hypercalls (fate#323887).
- hyper-v: Use fast hypercall for HVCALL_SIGNAL_EVENT
  (fate#323887).
- x86/hyper-v: Introduce fast hypercall implementation
  (fate#323887).
- x86/hyper-v: Make hv_do_hypercall() inline (fate#323887).
- x86/hyper-v: Include hyperv/ only when CONFIG_HYPERV is set
  (fate#323887).
- netvsc: fix race on sub channel creation (fate#323887).
- PCI: hv: Do not sleep in compose_msi_msg() (fate#323887).
- netvsc: remove bonding setup script (fate#323887).
- netvsc: Initialize 64-bit stats seqcount (fate#323887).
- Revert "x86/hyper-v: include hyperv/ only when CONFIG_HYPERV
  is set" (fate#323887).
- x86/hyper-v: stash the max number of virtual/logical processor
  (fate#323887).
- x86/hyper-v: include hyperv/ only when CONFIG_HYPERV is set
  (fate#323887).
- vmbus: add prefetch to ring buffer iterator (fate#323887).
- vmbus: more host signalling avoidance (fate#323887).
- vmbus: eliminate duplicate cached index (fate#323887).
- vmbus: refactor hv_signal_on_read (fate#323887).
- vmbus: drop unused ring_buffer_info elements (fate#323887).
- vmbus: simplify hv_ringbuffer_read (fate#323887).
- tools: hv: ignore a NIC if it has been configured (fate#323887).
- commit 6f087bf
* Fri Oct 20 2017 jthumshirn@suse.de
- scsi: pm80xx: corrected linkrate value (FATE#322890,
  bsc#1049518).
- scsi: pm80xx: panic on ncq error cleaning up the read log
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: corrected SATA abort handling sequence
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: modified port reset timer value for PM8006 card
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: cleanup in pm8001_abort_task function
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: tag allocation for phy control request
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: Different SAS addresses for phys (FATE#322890,
  bsc#1049518).
- scsi: pm80xx: ILA and inactive firmware version through sysfs
  (FATE#322890, bsc#1049518).
- scsi: pm80xx: redefine sas_identify_frame structure
  (FATE#322890, bsc#1049518).
- scsi: pm8001: fix double free in pm8001_pci_probe (FATE#322890,
  bsc#1049518).
- commit e741c37
* Fri Oct 20 2017 mgorman@suse.de
- mm, page_alloc: simplify list handling in rmqueue_bulk()
  (bsc#1060256).
- commit 14e8830
* Fri Oct 20 2017 mgorman@suse.de
- mm, pagevec: rename pagevec drained field (bsc#1060256).
- commit ec03f35
* Fri Oct 20 2017 jkosina@suse.cz
- series.conf: reorder to reflect upstream merges
- Refresh
  patches.drivers/scsi-qla2xxx-Allow-MBC_GET_PORT_DATABASE-to-query-an.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-Changes-to-support-N2N-logins.patch.
- Refresh
  patches.drivers/scsi-qla2xxx-don-t-break-the-bsg-lib-abstractions.patch.
- commit 7f799ea
* Fri Oct 20 2017 lduncan@suse.com
- scsi: be2iscsi: Fix boot flags in sysfs (bsc#1050253).
- scsi: be2iscsi: Fix return value in mgmt_open_connection
  (bsc#1050253).
- scsi: be2iscsi: Free msi_name and disable HW intr (bsc#1050253).
- scsi: be2iscsi: Fix _modify_eq_delay buffer overflow
  (bsc#1050253).
- scsi: be2iscsi: Fix _get_initname buffer overflow (bsc#1050253).
- scsi: be2iscsi: Modify IOCTL to fetch user configured IQN
  (bsc#1050253).
- scsi: be2iscsi: Add cmd to set host data (bsc#1050253).
- scsi: be2iscsi: Fix misc static analysis errors (bsc#1050253).
- scsi: be2iscsi: Remove A-circumflex character in copyright
  marking (bsc#1050253).
- scsi: be2iscsi: Update driver version (bsc#1050253).
- commit c2fd5a6
* Fri Oct 20 2017 mcgrof@suse.com
- blacklist.conf: add test_kmod blacklist
  CONFIG_TEST_KMOD=n is currently set. When and if we enable it
  then we will need it, otherwise we don't.
- commit 4ceac95
* Thu Oct 19 2017 mgorman@suse.de
- mm: remove __GFP_COLD (bsc#1060256).
- Refresh
  patches.drivers/net-ena-add-support-for-out-of-order-rx-buffers-refi.patch.
- Refresh
  patches.drivers/net-mlx4_en-Improve-receive-data-path.patch.
- mm: remove cold parameter from free_hot_cold_page*
  (bsc#1060256).
- mm: remove cold parameter for release_pages (bsc#1060256).
- mm, pagevec: remove cold parameter for pagevecs (bsc#1060256).
- mm: only drain per-cpu pagevecs once per pagevec usage
  (bsc#1060256).
- mm, truncate: remove all exceptional entries from pagevec
  under one lock (bsc#1060256).
- mm, truncate: do not check mapping for every page being
  truncated (bsc#1060256).
- mm, page_alloc: enable/disable IRQs once when freeing a list
  of pages (bsc#1060256).
- commit af4a6ea
* Thu Oct 19 2017 tiwai@suse.de
- Enable CONFIG_DRM_VC4 again for arm64 with dependencies (bsc#1060104)
- commit ca643c4
* Thu Oct 19 2017 tiwai@suse.de
- Bluetooth: Add support for Intel Bluetooth device 9460/9560
  [8087:0aaa] (bsc#1064235).
- commit a7785ae
* Thu Oct 19 2017 jack@suse.cz
- mm: Batch radix tree operations when truncating pages
  (bsc#1060256).
- mm: Factor out checks and accounting from
  __delete_from_page_cache() (bsc#1060256).
- mm: Move clearing of page->mapping to page_cache_tree_delete()
  (bsc#1060256).
- mm: Move accounting updates before page_cache_tree_delete()
  (bsc#1060256).
- mm: Factor out page cache page freeing into a separate function
  (bsc#1060256).
- mm: Refactor truncate_complete_page() (bsc#1060256).
- mm: Speedup cancel_dirty_page() for clean pages (bsc#1060256).
- mm: hugetlb: return immediately for hugetlb page in
  __delete_from_page_cache() (bsc#1060256).
- commit b25574b
* Thu Oct 19 2017 jlee@suse.com
- efi: Add an EFI signature blob parser (fate#314508).
- Update config files.
- Delete
  patches.suse/0002-Add-an-EFI-signature-blob-parser-and-key-loader.patch.
- commit 50111a7
* Thu Oct 19 2017 jlee@suse.com
- modsign: Use secondary trust keyring for module signing
  (fate#314508).
- commit f04a6b3
* Thu Oct 19 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add David Howell's linux-fs.git
- commit 0a669c1
* Thu Oct 19 2017 jlee@suse.com
- MODSIGN: Allow the "db" UEFI variable to be suppressed
  (fate#314508).
- Delete
  patches.suse/0005-MODSIGN-Support-not-importing-certs-from-db.patch.
- commit fefd1b5
* Thu Oct 19 2017 jlee@suse.com
- Update config files.
- Update
  patches.suse/0004-MODSIGN-Import-certificates-from-UEFI-Secure-Boot.patch
  (fate#314508).
- commit b7a5639
* Thu Oct 19 2017 jlee@suse.com
- efi: Add EFI signature data types (fate#314508).
- Delete patches.suse/0001-Add-EFI-signature-data-types.patch.
- commit a22dd23
* Thu Oct 19 2017 jlee@suse.com
- KEYS: Allow unrestricted boot-time addition of keys to secondary
  keyring (fate#314508).
- commit 01ed74a
* Thu Oct 19 2017 jlee@suse.com
- Delete
  patches.suse/0003-KEYS-Add-a-system-blacklist-keyring.patch.
  This patch already replaced by 734114f87 and 436529562 in v4.12
  kernel.
  734114f87	KEYS: Add a system blacklist keyring
  436529562	X.509: Allow X.509 certs to be blacklisted
- commit 9855c97
* Wed Oct 18 2017 jslaby@suse.cz
- x86/mm: Disable various instrumentations of mm/mem_encrypt.c
  and mm/tlb.c (fate#322123).
- commit bc2e6c5
* Wed Oct 18 2017 mcgrof@suse.com
- mac80211: accept key reinstall without changing anything (CVE-2017-13080 bsc#1063667).
- commit 33c9018
* Wed Oct 18 2017 vbabka@suse.cz
- mm, page_owner: skip unnecessary stack_trace entries (VM
  Functionality, bsc#1063512).
- commit 019f21f
* Wed Oct 18 2017 yousaf.kaukab@suse.com
- supported.conf: enable dw_mmc-rockchip driver
  References: bsc#1064064
- commit 33b440c
* Wed Oct 18 2017 tiwai@suse.de
- ALSA: hda - Add model string for Intel reference board quirk
  (bsc#1064043).
- ALSA: hda/realtek - Enable jack detection function for Intel
  ALC700 (bsc#1064043).
- commit 0c8702a
* Wed Oct 18 2017 tiwai@suse.de
- x86/mm: Use pr_cont() in dump_pagetable() (bsc#1064024).
- commit 379bbd8
* Wed Oct 18 2017 tiwai@suse.de
- ALSA: hda: Abort capability probe at invalid register read
  (bsc#1064017).
- commit d9d62b1
* Wed Oct 18 2017 jlee@suse.com
- Add the ability to lock down access to the running kernel image
  (fate#314486).
- Update config files.
- Delete
  patches.suse/0001-Add-BSD-style-securelevel-support.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit f7f8bf3
* Wed Oct 18 2017 mcgrof@suse.com
- xfs: handle error if xfs_btree_get_bufs fails (bsc#1059863).
- commit 2689e7f
* Tue Oct 17 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add Michal Petersen's SCSI tree
- commit 42c245c
* Tue Oct 17 2017 jthumshirn@suse.de
- scsi: qla2xxx: don't break the bsg-lib abstractions
  (FATE#322910).
- scsi: qla2xxx: Query FC4 type during RSCN processing
  (FATE#322910).
- scsi: qla2xxx: Use ql2xnvmeenable to enable Q-Pair for FC-NVMe
  (FATE#322910).
- scsi: qla2xxx: Update driver version to 10.00.00.02-k
  (FATE#322910).
- scsi: qla2xxx: Changes to support N2N logins (FATE#322910).
- scsi: qla2xxx: Allow MBC_GET_PORT_DATABASE to query and save
  the port states (FATE#322910).
- scsi: qla2xxx: Add ATIO-Q processing for INTx mode
  (FATE#322910).
- scsi: qla2xxx: Reinstate module parameter ql2xenablemsix
  (FATE#322910).
- scsi: qla2xxx: Cocci spatch "pool_zalloc-simple" (FATE#322910).
- scsi: qla2xxx: Reset the logo flag, after target re-login
  (FATE#322910).
- scsi: qla2xxx: Fix slow mem alloc behind lock (FATE#322910).
- scsi: qla2xxx: Clear fc4f_nvme flag (FATE#322910).
- scsi: qla2xxx: Handle PCIe error for driver (FATE#322910).
- commit 641d8fb
* Tue Oct 17 2017 mkubecek@suse.cz
- ipv4: Fix traffic triggered IPsec connections (bsc#1061739).
- ipv6: Fix traffic triggered IPsec connections (bsc#1061739).
- net: prevent dst uses after free (bsc#1061739).
- ipv4: Don't override return code from ip_route_input_noref()
  (bsc#1061739).
- net: xfrm: don't double-hold dst when sk_policy in use
  (bsc#1061739).
- ipv6: release rt6->rt6i_idev properly during ifdown
  (bsc#1061739).
- commit 173c05a
* Tue Oct 17 2017 mkubecek@suse.cz
- tcp: tcp_data_queue() cleanup (bsc#1061739).
- tcp: remove unused mib counters (bsc#1061739).
- tcp: remove low_latency sysctl (bsc#1061739).
- tcp: reindent two spots after prequeue removal (bsc#1061739).
- tcp: remove prequeue support (bsc#1061739).
- tcp: better validation of received ack sequences (bsc#1061739).
- commit 6c0fdbb
* Tue Oct 17 2017 mkubecek@suse.cz
- net: add debug atomic_inc_not_zero() in dst_hold()
  (bsc#1061739).
- net: reorder all the dst flags (bsc#1061739).
- net: remove DST_NOCACHE flag (bsc#1061739).
- net: remove DST_NOGC flag (bsc#1061739).
- net: remove dst gc related code (bsc#1061739).
- decnet: take dst->__refcnt when struct dn_route is created
  (bsc#1061739).
- xfrm: take refcnt of dst when creating struct xfrm_dst bundle
  (bsc#1061739).
- ipv6: get rid of icmp6 dst garbage collector (bsc#1061739).
- ipv6: mark DST_NOGC and remove the operation of dst_free()
  (bsc#1061739).
- ipv6: call dst_hold_safe() properly (bsc#1061739).
- ipv6: call dst_dev_put() properly (bsc#1061739).
- ipv6: take dst->__refcnt for insertion into fib6 tree
  (bsc#1061739).
- ipv4: mark DST_NOGC and remove the operation of dst_free()
  (bsc#1061739).
- ipv4: call dst_hold_safe() properly (bsc#1061739).
- ipv4: call dst_dev_put() properly (bsc#1061739).
- ipv4: take dst->__refcnt when caching dst in fib (bsc#1061739).
- net: introduce a new function dst_dev_put() (bsc#1061739).
- net: introduce DST_NOGC in dst_release() to destroy dst based
  on refcnt (bsc#1061739).
- net: use loopback dev when generating blackhole route
  (bsc#1061739).
- udp: call dst_hold_safe() in udp_sk_rx_set_dst() (bsc#1061739).
- ipv6: remove unnecessary dst_hold() in ip6_fragment()
  (bsc#1061739).
- commit f97eac8
* Tue Oct 17 2017 jthumshirn@suse.de
- scsi: libfc: fix a deadlock in fc_rport_work (bsc#1063695).
- fs/mpage.c: fix mpage_writepage() for pages with buffers
  (bsc#1050471).
- commit d0711a1
* Tue Oct 17 2017 jkosina@suse.cz
- scripts/git_sort/git_sort.py: add md.git tree
- commit d2c30da
* Tue Oct 17 2017 jlee@suse.com
- Delete
  patches.suse/0001-Remove-BSD-style-securelevel-sysfs-file.patch.
  David Howells's lock down patch set doesn't provide sysfs interface
  anymore.
- commit 7180bdf
* Tue Oct 17 2017 jlee@suse.com
- acpi: Disable APEI error injection if the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/acpi_Disable_APEI_error_injection_if_securelevel_is_set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 69a1c63
* Tue Oct 17 2017 jlee@suse.com
- acpi: Disable ACPI table override if the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/acpi-Disable_ACPI_table_override_when_UEFI_Secure_Boot_is.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 6ef9921
* Tue Oct 17 2017 jlee@suse.com
- acpi: Ignore acpi_rsdp kernel param when the kernel has been
  locked down (fate#314486).
- Delete
  patches.suse/0007-acpi-Ignore-acpi_rsdp-kernel-parameter-when-securele.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 10e6554
* Tue Oct 17 2017 jlee@suse.com
- ACPI: Limit access to custom_method when the kernel is locked
  down (fate#314486).
- Delete
  patches.suse/0006-acpi-Limit-access-to-custom_method-if-securelevel-is.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 62d1f7d
* Tue Oct 17 2017 jlee@suse.com
- asus-wmi: Restrict debugfs interface when the kernel is locked
  down (fate#314486).
- Delete
  patches.suse/0011-asus-wmi-Restrict-debugfs-interface-when-securelevel.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit e2ab47b
* Tue Oct 17 2017 jlee@suse.com
- x86: Restrict MSR access when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0010-x86-Restrict-MSR-access-when-securelevel-is-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 3909643
* Tue Oct 17 2017 jlee@suse.com
- x86: Lock down IO port access when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0004-x86-Lock-down-IO-port-access-when-securelevel-is-ena.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 1762c3f
* Tue Oct 17 2017 jlee@suse.com
- PCI: Lock down BAR access when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0003-PCI-Lock-down-BAR-access-when-securelevel-is-enabled.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 9fdfbff
* Tue Oct 17 2017 jlee@suse.com
- uswsusp: Disable when the kernel is locked down (fate#314486).
- Delete
  patches.suse/0009-uswsusp-Disable-when-securelevel-is-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit a084ec6
* Tue Oct 17 2017 jlee@suse.com
- hibernate: Disable when the kernel is locked down (fate#314486).
- Delete
  patches.suse/0014-hibernate-Disable-when-securelevel-is-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 33abf1b
* Tue Oct 17 2017 jlee@suse.com
- Copy secure_boot flag in boot params across kexec reboot
  (fate#314486).
- Delete
  patches.suse/0015-kexec-uefi-copy-secure_boot-flag-in-boot-params-acro.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 8f6bfe2
* Tue Oct 17 2017 jlee@suse.com
- kexec: Disable at runtime if the kernel is locked down
  (fate#314486).
- kexec_file: Disable at runtime if securelevel has been set
  (fate#314486).
- Delete
  patches.suse/0008-kexec-Disable-at-runtime-if-securelevel-has-been-set.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 3ec1db3
* Tue Oct 17 2017 jlee@suse.com
- Restrict /dev/mem and /dev/kmem when the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0005-Restrict-dev-mem-and-dev-kmem-when-securelevel-is-se.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 9d8716c
* Tue Oct 17 2017 jlee@suse.com
- Enforce module signatures if the kernel is locked down
  (fate#314486).
- Delete
  patches.suse/0001-Enforce-module-signatures-when-securelevel-is-greate.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit 96ad4fa
* Tue Oct 17 2017 jlee@suse.com
- efi: Lock down the kernel if booted in secure boot mode
  (fate#314486).
- Update config files.
- Delete
  patches.suse/0012-Add-option-to-automatically-set-securelevel-when-in-.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit c339fd5
* Tue Oct 17 2017 jlee@suse.com
- efi: Add EFI_SECURE_BOOT bit (fate#314486).
- Delete patches.suse/0014-efi-Add-EFI_SECURE_BOOT-bit.patch.
  Replaced by the patch in David Howells's linux-fs git repo.
- commit aff4b1b
* Tue Oct 17 2017 bpoirier@suse.com
- Refresh patch order in sorted section
- commit a59e716
* Mon Oct 16 2017 bp@suse.de
- EDAC, pnd2: Return proper error value from apl_rd_reg()
  (bsc#1056989).
- EDAC, pnd2: Make function sbi_send() static (bsc#1056989).
- EDAC, pnd2: Fix Apollo Lake DIMM detection (bsc#1056989).
- i2c: i801: Restore the presence state of P2SB PCI device after
  reading BAR (bsc#1056989).
- EDAC, pnd2: Build in a minimal sideband driver for Apollo Lake
  (bsc#1056989).
- EDAC, pnd2: Mask off the lower four bits of a BAR (bsc#1056989).
- EDAC, pnd2: Conditionally unhide/hide the P2SB PCI device to
  read BAR (bsc#1056989).
- EDAC, pnd2: Properly toggle hidden state for P2SB PCI device
  (bsc#1056989).
- Refresh
  patches.drivers/07-edac-add-owner-check-to-the-x86-platform-drivers.patch.
- commit 9dd1f7f
* Mon Oct 16 2017 oneukum@suse.com
- iwlwifi: mvm: disable dbg data collect when fw isn't alive
  (FATE#322675).
- iwlwifi: mvm: flush per station for DQA mode (FATE#322675).
- iwlwifi: mvm: support getting nvm data from firmware
  (FATE#322675).
- iwlwifi: refactor out paging code (FATE#322675).
- iwlwifi: mvm: support old method of NVM parsing (FATE#322675).
- iwlwifi: refactor shared mem parsing (FATE#322675).
- iwlwifi: mvm: fix endianness in lq_cmd declaration
  (FATE#322675).
- iwlwifi: track current firmware image in common code
  (FATE#322675).
- iwlwifi: mvm: document which group enums are used with which
  group ID (FATE#322675).
- iwlwifi: refactor firmware debug code (FATE#322675).
- iwlwifi: mvm: use proper sta_addr in firmware API (FATE#322675).
- iwlwifi: reorganize firmware API (FATE#322675).
- iwlwifi: fw api: fix various kernel-doc warnings (FATE#322675).
- iwlwifi: mvm: fix MCC endianness bug (FATE#322675).
- iwlwifi: mvm: add and use iwl_mvm_has_unified_ucode()
  (FATE#322675).
- iwlwifi: mvm: use u8 for reserved fields (FATE#322675).
- iwlwifi: mvm: check family instead of new TX API for workarounds
  (FATE#322675).
- iwlwifi: mvm: disentangle paging command structs (FATE#322675).
- iwlwifi: mvm: add documentation to some WoWLAN commands
  (FATE#322675).
- iwlwifi: mvm: byte-swap constant instead of variable
  (FATE#322675).
- iwlwifi: dvm: remove unused defines (FATE#322675).
- iwlwifi: mvm: wait for the flushed queue only (FATE#322675).
- iwlwifi: mvm: fix some kernel-doc (FATE#322675).
- iwlwifi: mvm: refactor beacon template command code
  (FATE#322675).
- iwlwifi: mvm: add documentation links to various fields
  (FATE#322675).
- iwlwifi: mvm: fix the FIFO numbers in A000 devices
  (FATE#322675).
- iwlwifi: mvm: fix uninitialized var while waiting for queues
  to empty (FATE#322675).
- iwlwifi: update device ID for a000 family (FATE#322675).
- iwlwifi: mvm: disentangle binding command versions
  (FATE#322675).
- iwlwifi: pcie: fix A-MSDU on gen2 devices (FATE#322675).
- iwlwifi: mvm: create/name various enums (FATE#322675).
- iwlwifi: mvm: support fw reading empty OTP (FATE#322675).
- iwlwifi: implement fseq version mismatch warning (FATE#322675).
- iwlwifi: mvm: document structures used by commands
  (FATE#322675).
- iwlwifi: mvm: add compile-time option to disable EBS
  (FATE#322675).
- iwlwifi: mvm: remove wrt support of page dumps in gen2
  (FATE#322675).
- iwlwifi: pcie: rename iwl_trans_check_hw_rf_kill() to pcie
  (FATE#322675).
- iwlwifi: pcie: support page dumping in wrt in gen2
  (FATE#322675).
- iwlwifi: Add fw_name_pre_rf_next_step to support different rf
  steps (FATE#322675).
- iwlwifi: mvm: require AP_LINK_PS for TVQM (FATE#322675).
- iwlwifi: mvm: remove unused TX_CMD_NEXT_FRAME_* (FATE#322675).
- iwlwifi: mvm: simplify bufferable MMPDU check (FATE#322675).
- iwlwifi: kernel-doc: make proper links (FATE#322675).
- iwlwifi: mvm: rename p2p-specific sta functions to include
  p2p in the names (FATE#322675).
- iwlwifi: mvm: fix many kernel-doc warnings (FATE#322675).
- iwlwifi: mvm: remove non-DQA mode (FATE#322675).
- iwlwifi: add wait for tx queue empty (FATE#322675).
- iwlwifi: mvm: don't retake the pointer to skb's CB
  (FATE#322675).
- iwlwifi: mvm: add AMSDU flag to offload assist (FATE#322675).
- iwlwifi: mvm: remove useless condition in LED code
  (FATE#322675).
- iwlwifi: mvm: document RX structures (FATE#322675).
- iwlwifi: mvm: use firmware LED command where applicable
  (FATE#322675).
- iwlwifi: mvm: add const to thermal_cooling_device_ops structure
  (FATE#322675).
- iwlwifi: pcie: add AMSDU to gen2 (FATE#322675).
- iwlwifi: cleanup references to 8000 family in NVM code
  (FATE#322675).
- iwlwifi: mvm: add debugfs to force CT-kill (FATE#322675).
- iwlwifi: change functions that can only return 0 to void
  (FATE#322675).
- iwlwifi: remove references to 8000 B-step devices (FATE#322675).
- iwlwifi: add dbgc_supported to transport configuration
  (FATE#322675).
- iwlwifi: fix a few instances of misaligned kerneldoc parameters
  (FATE#322675).
- iwlwifi: add support of FPGA fw (FATE#322675).
- iwlwifi: mvm: add TLV for NAN API differentiation (FATE#322675).
- iwlwifi: fix a000 RF_ID define (FATE#322675).
- iwlwifi: mvm: support init flow debugging (FATE#322675).
- iwlwifi: add 9000 and A000 device families (FATE#322675).
- iwlwifi: dump smem configuration when firmware crashes
  (FATE#322675).
- iwlwifi: mvm: move a000 device NVM retrieval to a common place
  (FATE#322675).
- iwlwifi: pcie: support dumping FH in a000 hw (FATE#322675).
- iwlwifi: mvm: disable prph collection in a000 hw (FATE#322675).
- iwlwifi: mvm: set the default cTDP budget (FATE#322675).
- iwlwifi: mvm: add and use iwl_mvm_device_running()
  (FATE#322675).
- iwlwifi: mvm: support new beacon template command (FATE#322675).
- iwlwifi: mvm: check firmware is up in debugfs (FATE#322675).
- iwlwifi: mvm: don't send CTDP commands via debugfs if not
  supported (FATE#322675).
- iwlwifi: mvm: add station before allocating a queue
  (FATE#322675).
- iwlwifi: mvm: use schedule_delayed_work() (FATE#322675).
- iwlwifi: mvm: convert ucode_loaded to a status bit
  (FATE#322675).
- iwlwifi: pcie: don't init a Tx queue with an SSN > size of
  the queue (FATE#322675).
- iwlwifi: fix nmi triggering from host (FATE#322675).
- iwlwifi: mvm: clear firmware running bit earlier (FATE#322675).
- iwlwifi: fix a kernel-doc tag (FATE#322675).
- iwlwifi: remove references to unsupported HW (FATE#322675).
- iwlwifi: pcie: free the TSO page when a Tx queue is unmapped
  on A000 devices (FATE#322675).
- iwlwifi: split firmware API from iwl-trans.h (FATE#322675).
- iwlwifi: mvm: fix the coex firmware API (FATE#322675).
- iwlwifi: mvm: link queue cmd docs to A000 command structs
  (FATE#322675).
- iwlwifi: mvm: document structures used for BEACON_TEMPLATE_CMD
  (FATE#322675).
- iwlwifi: mvm: remove the corunning support (FATE#322675).
- iwlwifi: mvm: consider RFKILL during INIT as success
  (FATE#322675).
- iwlwifi: mvm: link to TX commands in documentation
  (FATE#322675).
- iwlwifi: call iwl_remove_notification from iwl_wait_notification
  (FATE#322675).
- iwlwifi: mvm: remove SCAN_GROUP (FATE#322675).
- iwlwifi: fw-api: cleanup cycle includes (FATE#322675).
- iwlwifi: mvm: support new Coex firmware API (FATE#322675).
- iwlwifi: pcie: support short Tx queues for A000 device family
  (FATE#322675).
- iwlwifi: remove unnecessary code in iwl_trans_alloc_tx_cmd
  (FATE#322675).
- commit 833689044e13a3fb8c6c03ad868375670d97010b
  Merge: 63a2f310d040 0ae0bb3f409d Author: Kalle Valo
  <kvalo@codeaurora.org> Date:   Mon Jun 12 19:29:39 2017 +0300
  (FATE#322675).
- iwlwifi: mvm: add command name for FRAME_RELEASE (FATE#322675).
- iwlwifi: mvm: group all dummy SAR function declarations together
  (FATE#322675).
- iwlwifi: mvm: remove txq EMPTYING_DELBA state for DQA
  (FATE#322675).
- iwlwifi: mvm: use mvmsta consistently in rs.c (FATE#322675).
- iwlwifi: remove resp_pkt NULL checks (FATE#322675).
- iwlwifi: mvm: Enable security on new TX API (FATE#322675).
- iwlwifi: mvm: update the firmware API in TX (FATE#322675).
- iwlwifi: mvm: avoid unnecessary cache trashing in Tx path
  (FATE#322675).
- iwlwifi: mvm: remove session protection to allow channel switch
  (FATE#322675).
- iwlwifi: mvm: don't send BAR on flushed frames (FATE#322675).
- iwlwifi: mvm: remove pointless num_stored condition
  (FATE#322675).
- iwlwifi: move BT_MBOX_PRINT macro to common header
  (FATE#322675).
- iwlwifi: mvm: avoid variable shadowing (FATE#322675).
- iwlwifi: Demote messages about fw flags size to info
  (FATE#322675).
- iwlwifi: mvm: use scnprintf() instead of snprintf()
  (FATE#322675).
- iwlwifi: mvm: Fix channel switch in case of count <= 1
  (FATE#322675).
- iwlwifi: use bitfield.h for some registers (FATE#322675).
- iwlwifi: distinguish different RF modules in A000 devices
  (FATE#322675).
- iwlwifi: mvm: track and report IBSS manager status to mac80211
  (FATE#322675).
- iwlwifi: mvm: make D0I3_END_CMD sync during system resume
  (FATE#322675).
- iwlwifi: update channel flags parser (FATE#322675).
- iwlwifi: mvm: change open and close criteria of a BA session
  (FATE#322675).
- iwlwifi: mvm: support D0I3_END_CMD at the start of resume
  (FATE#322675).
- iwlwifi: add workaround to disable wide channels in 5GHz
  (FATE#322675).
- iwlwifi: mvm: make iwl_mvm_update_mcc() easier to follow
  (FATE#322675).
- iwlwifi: fw: fix lar_enabled endian problem in iwl_fw_get_nvm
  (FATE#322675).
- iwlwifi: mvm: rs: add logs for the wrong antenna case
  (FATE#322675).
- iwlwifi: mvm: remove useless argument in iwl_nvm_init()
  (FATE#322675).
- iwlwifi: pcie: pull out common rfkill IRQ handling code
  (FATE#322675).
- iwlwifi: mvm: remove useless check for mvm->cfg in
  iwl_parse_nvm_section() (FATE#322675).
- iwlwifi: pcie: add fake RF-kill to debugfs (FATE#322675).
- iwlwifi: mvm: don't warn in queue sync on RF-kill (FATE#322675).
- iwlwifi: use big-endian for the hw section of the nvm
  (FATE#322675).
- iwlwifi: mvm: Avoid deferring non bufferable frames
  (FATE#322675).
- iwlwifi: pcie: don't report RF-kill enabled while shutting down
  (FATE#322675).
- iwlwifi: mvm: bump API to 34 for 8000 and up (FATE#322675).
- iwlwifi: pcie: remove pointless debugfs parsing for csr file
  (FATE#322675).
- iwlwifi: mvm: document status bits (FATE#322675).
- iwlwifi: mvm: only send LEDS_CMD when the FW supports it
  (FATE#322675).
- iwlwifi: mvm: support aggregations on A000 HW (FATE#322675).
- iwlwifi: pcie: use kstrtou32_from_user() (FATE#322675).
- iwlwifi: mvm: better link scan notification results length
  (FATE#322675).
- iwlwifi: mvm: docs: fix enum link, provide TX response link
  (FATE#322675).
- iwlwifi: mvm: fix fw monitor 7000 HW recollecting (FATE#322675).
- iwlwifi: mvm: disentangle union in TX status struct
  (FATE#322675).
- iwlwifi: mvm: add documentation for enum iwl_debug_cmds
  (FATE#322675).
- iwlwifi: document transmit buffer bits better (FATE#322675).
- iwlwifi: remove useless iwl_free_nvm_data() function
  (FATE#322675).
- iwlwifi: mvm: fix nvm_data leak (FATE#322675).
- iwlwifi: pcie: don't disable bh when handling FW errors
  (FATE#322675).
- iwlwifi: mvm: reset the HW before dumping if HW error is
  detected (FATE#322675).
- iwlwifi: mvm: don't mark TIDs that are not idle wrt BA as
  inactive (FATE#322675).
- iwlwifi: add a W/A for a scheduler hardware bug (FATE#322675).
- iwlwifi: pcie: make iwl_pcie_apm_stop_master() return void
  (FATE#322675).
- iwlwifi: mvm: set assoc_beacon_arrive_time (FATE#322675).
- iwlwifi: mvm: support new flush API (FATE#322675).
- iwlwifi: mvm: document assoc_beacon_arrive_time (FATE#322675).
- iwlwifi: mvm: print base HW address during init (FATE#322675).
- iwlwifi: pcie: reduce unwanted noise in the logs (FATE#322675).
- iwlwifi: pcie: delete the Tx queue timer earlier upon firmware
  crash (FATE#322675).
- iwlwifi: mvm: fix typo in CTDP_CMD_OPERATION_REPORT description
  (FATE#322675).
- iwlwifi: pcie: work around suspend/resume issue (FATE#322675).
- iwlwifi: mvm: support TX on MONITOR iface (FATE#322675).
- iwlwifi: mvm: refactor geo init (FATE#322675).
- iwlwifi: mvm: Add debugfs entry to retrieve SAR geographic
  profile (FATE#322675).
- iwlwifi: mvm: remove some CamelCase from firmware API
  (FATE#322675).
- iwlwifi: mvm: fix various "Excess ... description" kernel-doc
  warnings (FATE#322675).
- iwlwifi: mvm: remove various unused command IDs/structs
  (FATE#322675).
- iwlwifi: mvm: use __le16 even for reserved fields (FATE#322675).
- iwlwifi: mvm: add documentation for all command IDs
  (FATE#322675).
- iwlwifi: mvm: fix a bunch of kernel-doc warnings (FATE#322675).
- iwlwifi: dvm: use macros for format strings (FATE#322675).
- iwlwifi: pcie: only apply retention workaround on 9000-series
  A-step (FATE#322675).
- iwlwifi: pcie: fix 9000-series RF-kill interrupt propagation
  (FATE#322675).
- iwlwifi: mvm: simplify CHECK_MLME_TRIGGER macro (FATE#322675).
- iwlwifi: add the new a000_2ax series (FATE#322675).
- iwlwifi: add twelve new 9560 series PCI IDs (FATE#322675).
- iwlwifi: mvm: use proper CDB check in PHY context modify
  (FATE#322675).
- iwlwifi: pcie: improve "invalid queue" warning (FATE#322675).
- iwlwifi: mvm: support aggs of 64 frames in A000 family
  (FATE#322675).
- iwlwifi: pcie: improve debug in iwl_pcie_rx_handle_rb()
  (FATE#322675).
- iwlwifi: mvm: change when the BT_COEX is sent (FATE#322675).
- iwlwifi: mvm: support multi tid ba notif (FATE#322675).
- iwlwifi: unify external & internal modparam names (FATE#322675).
- iwlwifi: pcie: make ctxt-info free idempotent (FATE#322675).
- iwlwifi: pcie: warn if paging is already initialized during init
  (FATE#322675).
- iwlwifi: mvm: rename iwl_shared_mem_cfg_v1 to the correct _v2
  (FATE#322675).
- iwlwifi: create new subdirectory for FW interaction
  (FATE#322675).
- iwlwifi: move notification wait into fw/ (FATE#322675).
- iwlwifi: move configuration into sub-directory (FATE#322675).
- iwlwifi: mvm: remove version 2 of paging command (FATE#322675).
- iwlwifi: pcie: add MSI-X interrupt tracing (FATE#322675).
- iwlwifi: mvm: properly enable IP header checksumming
  (FATE#322675).
- iwlwifi: mvm: map cab_queue to real one earlier (FATE#322675).
- iwlwifi: mvm: fix mac80211's hw_queue in DQA mode (FATE#322675).
- iwlwifi: mvm: remove DQA non-STA client mode special case
  (FATE#322675).
- iwlwifi: mvm: update rx statistics cmd api (FATE#322675).
- iwlwifi: pcie: propagate iwl_pcie_apm_init's status
  (FATE#322675).
- iwlwifi: pcie: wait longer after device reset (FATE#322675).
- iwlwifi: bump MAX API for 8000/9000/A000 to 33 (FATE#322675).
- iwlwifi: pcie: fix unused txq NULL pointer dereference
  (FATE#322675).
- iwlwifi: mvm: defer setting IWL_MVM_STATUS_IN_HW_RESTART
  (FATE#322675).
- iwlwifi: add TLV for MLME offload firmware capability
  (FATE#322675).
- iwlwifi: split the regulatory rules when the bandwidth flags
  require it (FATE#322675).
- iwlwifi: mvm: set A-MPDU bit upon empty BA notification from FW
  (FATE#322675).
- iwlwifi: mvm: rs: fix TLC statistics collection (FATE#322675).
- iwlwifi: fix fw_pre_next_step to apply also for C step
  (FATE#322675).
- iwlwifi: add the new 9000 series PCI IDs (FATE#322675).
- iwlwifi: mvm: Fix a memory leak in an error handling path in
  'iwl_mvm_sar_get_wgds_table()' (FATE#322675).
- iwlwifi: mvm: start mac queues when deferred tx frames are
  purged (FATE#322675).
- iwlwifi: mvm: don't WARN when a legit race happens in A-MPDU
  (FATE#322675).
- mac80211: add api to start ba session timer expired flow
  (FATE#322675).
- iwlwifi: mvm: send delba upon rx ba session timeout
  (FATE#322675).
- iwlwifi: pcie: move rx workqueue initialization to
  iwl_trans_pcie_alloc() (FATE#322675).
- Refresh
  patches.drivers/iwlwifi-mvm-don-t-warn-in-queue-sync-on-RF-kill.
- Refresh
  patches.drivers/iwlwifi-mvm-fix-a-NULL-pointer-dereference-of-error-.
- Refresh patches.drivers/iwlwifi-mvm-fix-mac80211-queue-tracking.
- Refresh
  patches.drivers/iwlwifi-mvm-quietly-accept-non-sta-disassoc-frames.
- Refresh
  patches.drivers/iwlwifi-mvm-remove-DQA-non-STA-client-mode-special-c.
- Refresh
  patches.drivers/iwlwifi-pcie-fix-TVQM-queue-ID-range-check.
- Refresh
  patches.drivers/iwlwifi-pcie-fix-command-completion-name-debug.
- Refresh
  patches.drivers/iwlwifi-pcie-reconfigure-MSI-X-HW-on-resume.
- Refresh patches.suse/iwlwifi-expose-default-fallback-ucode-api.
- Delete
  patches.drivers/iwlwifi-mvm-reset-the-fw_dump_desc-pointer-after-ASS.
- commit 318dcaf
* Mon Oct 16 2017 jslaby@suse.cz
- arm64: futex: Fix undefined behaviour with FUTEX_OP_OPARG_SHIFT usage
  (bnc#1005915).
- commit f68b002
* Mon Oct 16 2017 jslaby@suse.cz
- futex: Remove duplicated code and fix undefined behaviour
  (bnc#1005915).
- commit 3ab315a
* Mon Oct 16 2017 mhocko@suse.cz
- mm: page_vma_mapped: ensure pmd is loaded with READ_ONCE
  outside of lock (bnc#1063517).
- commit f9d9f6b
* Mon Oct 16 2017 mhocko@suse.cz
- mm: meminit: mark init_reserved_page as __meminit (bnc#1063509).
- commit f1081d0
* Mon Oct 16 2017 mhocko@suse.cz
- mm/memory_hotplug: define find_{smallest|biggest}_section_pfn
  as unsigned long (bnc#1063520).
- commit 5a4bbdf
* Mon Oct 16 2017 mhocko@suse.cz
- blacklist.conf: blacklist pure doc update
- commit 44bb57c
* Mon Oct 16 2017 mhocko@suse.cz
- mm/memory_hotplug: change pfn_to_section_nr/section_nr_to_pfn
  macro to inline function (bnc#1063501).
- commit 093a972
* Mon Oct 16 2017 mhocko@suse.cz
- mm/backing-dev.c: fix an error handling path in 'cgwb_create()'
  (bnc#1063475).
- commit 5def433
* Mon Oct 16 2017 mgorman@suse.de
- Refresh
  patches.suse/mm-mempolicy-fix-numa_interleave_hit-counter.patch.
- commit 6574465
* Fri Oct 13 2017 msuchanek@suse.de
- Revert "rpm/constraints.in: Lower default disk space requirement from 25G to 24G"
  This reverts commit 406abda1467c038842febffe264faae1fa2e3c1d.
  ok, did not wait long enough to see the failure.
- commit ed99981
* Fri Oct 13 2017 msuchanek@suse.de
- rpm/constraints.in: Lower default disk space requirement from 25G to 24G
  25G is rejected by the build service on ARM.
- commit 406abda
* Fri Oct 13 2017 bpoirier@suse.com
- Add marker for the end of the sorted section.
- commit 5add254
* Fri Oct 13 2017 jlee@suse.com
- Delete
  patches.suse/0001-MODSIGN-Support-the-old-style-signature-format.patch.
  SLE15 kernel only suppports PKCS#7 signature for module.
- commit 8f5ab3d
* Fri Oct 13 2017 jlee@suse.com
- Delete
  patches.fixes/0001-X.509-Fix-test-for-self-signed-certificate.patch.
  This patches did not accept by kernel mainline but David Howells's
  6c2dc5ae4 patch in v4.7-rc1 has similar logic to fix issue.
- commit 6fa04b9
* Fri Oct 13 2017 jlee@suse.com
- Delete
  patches.drivers/0001-acpi-nfit-treat-virtual-spa-region-as-r-v4.patch.
  This patch was merged in v4.8-rc1 on upstream.
- commit b8a49c5
* Fri Oct 13 2017 jlee@suse.com
- Refresh
  patches.suse/0003-Add-external-no-support-as-bad-taint-module.patch.
- commit 5af8e7d
* Fri Oct 13 2017 colyli@suse.de
- md/raid5: preserve STRIPE_ON_UNPLUG_LIST in
  break_stripe_batch_list (fate#323095).
- md: notify about new spare disk in the container (fate#323095).
- md: Runtime support for multiple ppls (fate#323095).
- raid5-ppl: Recovery support for multiple partial parity logs
  (fate#323095).
- raid5-ppl: don't resync after rebuild (fate#323095).
- raid5-ppl: check recovery_offset when performing ppl recovery
  (fate#323095).
- commit cf8b210
* Thu Oct 12 2017 jkosina@suse.cz
- series.conf: drop already merged printk patch from patches marked for review
- commit 48eb86a
* Thu Oct 12 2017 pmladek@suse.com
- printk/console: Enhance the check for consoles using init memory
  (bsc#1063026).
- printk/console: Always disable boot consoles that use init
  memory before it is freed (bsc#1063026).
- commit 39bffbf
* Thu Oct 12 2017 pmladek@suse.com
- Refresh and enable
  patches.suse/printk-console-Correctly-mark-console-that-is-used-w.patch
  printk/console: Correctly mark console that is used when
  opening /dev/console (bsc#1040020).
- commit 1f1f97c
* Thu Oct 12 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit de6c979
* Thu Oct 12 2017 msuchanek@suse.de
- ibmvnic: Set state UP (bsc#1062962).
- commit d037007
* Thu Oct 12 2017 jthumshirn@suse.de
- scsi: mpt3sas: Bump mpt3sas driver version to v16.100.00.00
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Adding support for SAS3616 HBA device
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fix possibility of using invalid Enclosure Handle
  for SAS device after host reset (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Display chassis slot information of the drive
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Updated MPI headers to v2.00.48
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fix IO error occurs on pulling out
  a drive from RAID1 volume created on two SATA drive
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fix removal and addition of vSES device during
  host reset (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Reduce memory footprint in kdump kernel
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Fixed memory leaks in driver
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: Processing of Cable Exception events
  (bsc#1049527,FATE#322938).
- scsi: mpt3sas: remove redundant copy_from_user in
  _ctl_getiocinfo (bsc#1049527,FATE#322938).
- scsi: mpt3sas: fix pr_info message continuation
  (bsc#1049527,FATE#322938).
- commit 51e999e
* Thu Oct 12 2017 lduncan@suse.com
- fs: fix kernel_write prototype (fate#323946).
- tcmu: free old string on reconfig (fate#323946).
- tcmu: Fix possible to/from address overflow when doing the
  memcpy (fate#323946).
- tcmu: clean up the code and with one small fix (fate#323946).
- target: export lio pgr/alua support as device attr
  (fate#323946).
- target: Fix return sense reason in target_scsi3_emulate_pr_out
  (fate#323946).
- target: Fix cmd size for PR-OUT in passthrough_parse_cdb
  (fate#323946).
- tcmu: Fix dev_config_store (fate#323946).
- target: pscsi: Introduce TYPE_ZBC support (fate#323946).
- target: Use macro for WRITE_VERIFY_32 operation codes
  (fate#323946).
- target: fix SAM_STAT_BUSY/TASK_SET_FULL handling (fate#323946).
- target: remove transport_complete (fate#323946).
- pscsi: finish cmd processing from pscsi_req_done (fate#323946).
- tcmu: fix sense handling during completion (fate#323946).
- target: add helper to copy sense to se_cmd buffer (fate#323946).
- target: do not require a transport_complete for
  SCF_TRANSPORT_TASK_SENSE (fate#323946).
- target: make device_mutex and device_list static (fate#323946).
- tcmu: fix multiple uio open/close sequences (fate#323946).
- tcmu: drop configured check in destroy (fate#323946).
- target: remove g_device_list (fate#323946).
- xcopy: loop over devices using idr helper (fate#323946).
- target: add helper to iterate over devices (fate#323946).
- tcmu: perfom device add, del and reconfig synchronously
  (fate#323946).
- target: add helper to find se_device by dev_index (fate#323946).
- target: use idr for se_device dev index (fate#323946).
- target: break up free_device callback (fate#323946).
- tcmu: reconfigure netlink attr changes (fate#323946).
- tcmu: make array tcmu_attrib_attrs static const (fate#323946).
- tcmu: Fix module removal due to stuck unmap_thread thread again
  (fate#323946).
- tcmu: Add Type of reconfig into netlink (fate#323946).
- tcmu: Make dev_config configurable (fate#323946).
- tcmu: Make dev_size configurable via userspace (fate#323946).
- tcmu: Add netlink for device reconfiguration (fate#323946).
- tcmu: Support emulate_write_cache (fate#323946).
- target/iscsi: Remove dead code from iscsit_process_scsi_cmd()
  (fate#323946).
- target/iscsi: Simplify iscsit_free_cmd() (fate#323946).
- target/iscsi: Remove second argument of __iscsit_free_cmd()
  (fate#323946).
- target/tcm_loop: Make TMF processing slightly faster
  (fate#323946).
- target/tcm_loop: Use target_submit_tmr() instead of open-coding
  this function (fate#323946).
- target/tcm_loop: Replace a waitqueue and a counter by a
  completion (fate#323946).
- target/tcm_loop: Merge struct tcm_loop_cmd and struct
  tcm_loop_tmr (fate#323946).
- target: Introduce a function that shows the command state
  (fate#323946).
- iscsi-target: Kill left-over iscsi_target_do_cleanup
  (fate#323946).
- target: Fix a deadlock between the XCOPY code and iSCSI session
  shutdown (fate#323946).
- target: Use {get,put}_unaligned_be*() instead of open coding
  these functions (fate#323946).
- target: Fix transport_init_se_cmd() (fate#323946).
- target: Remove se_device.dev_list (fate#323946).
- target: Use symbolic value for WRITE_VERIFY_16 (fate#323946).
- target: Add TARGET_SCF_LOOKUP_LUN_FROM_TAG support for
  ABORT_TASK (fate#323946).
- target: Add support for TMR percpu reference counting
  (fate#323946).
- target: reject COMPARE_AND_WRITE if emulate_caw is not set
  (fate#323946).
- iscsi: ensure RNG is seeded before use (fate#323946).
- random: add get_random_{bytes,u32,u64,int,long,once}_wait family
  (fate#323946).
- random: add wait_for_random_bytes() API (fate#323946).
- iscsi-target: Avoid holding ->tpg_state_lock during param update
  (fate#323946).
- target/configfs: Kill se_lun->lun_link_magic (fate#323946).
- target/configfs: Kill se_device->dev_link_magic (fate#323946).
- target/iblock: Convert WRITE_SAME to blkdev_issue_zeroout
  (fate#323946).
- target: remove dead code (fate#323946).
- commit 7cc5b73
* Thu Oct 12 2017 bpoirier@suse.com
- Update subsystem names
  They are now generated automatically from the remote url and branch name.
- commit 3f61bda
* Thu Oct 12 2017 bpoirier@suse.com
- Refresh
  patches.drivers/0008-Revert-commit-1a8b6d76dc5b-net-add-one-common-config.patch.
- net: ixgbe: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- commit 90521fa
* Wed Oct 11 2017 mwilck@suse.com
- scsi: sd: Do not override max_sectors_kb sysfs setting
  (bsc#1025461).
- commit ddec827
* Wed Oct 11 2017 bp@suse.de
- Refresh
  patches.drivers/03-edac-ghes-remove-symbol-exports.patch.
- Refresh
  patches.drivers/04-edac-ghes-model-a-single-logical-memory-controller.patch.
- Refresh patches.drivers/05-edac-ghes-add-platform-check.patch.
- Refresh
  patches.drivers/06-edac-add-helper-which-returns-the-loaded-platform-driver.patch.
- Refresh
  patches.drivers/07-edac-add-owner-check-to-the-x86-platform-drivers.patch.
- commit 25bfcf5
* Wed Oct 11 2017 mwilck@suse.com
- Fix patch ordering in "scsi for-next" section
- commit fa6ad69
* Wed Oct 11 2017 jlee@suse.com
- Update config files. (bsc#1049122)
- Enabling module signature verification for PKCS#7 support. (bsc#1049122)
- Enabling module signature verification on ARM64.
- commit f366940
* Wed Oct 11 2017 bp@suse.de
- ACPI / blacklist: add acpi_match_platform_list() (bsc#1042420).
- commit a2737a9
* Wed Oct 11 2017 msuchanek@suse.de
- powerpc/64s: Use emergency stack for kernel TM Bad Thing
  program checks (CVE-2017-1000255 bsc#1061633).
- commit bf589f7
* Wed Oct 11 2017 tiwai@suse.de
- ALSA: seq: Fix use-after-free at creating a port
  (CVE-2017-15265, bsc#1062520).
- commit fd32f35
* Wed Oct 11 2017 jthumshirn@suse.de
- mtip32xx: quiesce request queues to make sure no submissions
  are inflight (FATE#322582).
- commit 5051e53
* Tue Oct 10 2017 mfleming@suse.de
- sched/core: Address more wake_affine() regressions
  (bsc#1061593).
- sched/core: Fix wake_affine() performance regression
  (bsc#1061593).
- sched/fair: Fix wake_affine_llc() balancing rules (bsc#1061593).
- sched/fair: Fix wake_affine() for !NUMA_BALANCING (bsc#1061593).
- commit 2d3e2a7
* Tue Oct 10 2017 mkubecek@suse.cz
- config: drop obsolete network drivers (fate#323372)
  CONFIG_PCNET32        - AMD PCnet32
  CONFIG_ATL2           - Atheros L2
  CONFIG_NET_VENDOR_DEC - DEC Tulip family
  CONFIG_NE2K_PCI       - PCI NE2000 and clones
  CONFIG_ATP            - AT-LAN-TEC/Realtek pocket adapter
  CONFIG_SIS900         - SiS 900
  CONFIG_EPIC100        - SMC EtherPower II
  CONFIG_HAPPYMEAL      - Sun Happy Meal
- commit 09e0cef
* Tue Oct 10 2017 mkubecek@suse.cz
- Refresh
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- update upstream reference
- move to net-next section
- commit 0c27bbf
* Tue Oct 10 2017 mkubecek@suse.cz
- series.conf: restore repository names
  (just executed series_sort.py)
- commit fcbee0f
* Tue Oct 10 2017 mkubecek@suse.cz
- Update patches.fixes/inetpeer-fix-RCU-lookup-again.patch
  upstream reference and move it to sorted section
- commit fe35cb6
* Mon Oct  9 2017 tbogendoerfer@suse.de
- RDMA/iwpm: Properly mark end of NL messages (bsc#1046306
  FATE#322942).
- commit 8db3fd1
* Mon Oct  9 2017 tbogendoerfer@suse.de
- RDMA/qedr: Parse VLAN ID correctly and ignore the value of zero
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Parse vlan priority as sl (bsc#1050545 FATE#322893).
- Refresh
  patches.drivers/RDMA-qedr-Rename-the-qedr_cm-file-as-a-preparation-f.patch.
- commit 49c1725
* Mon Oct  9 2017 msuchanek@suse.de
- cxl: Add support for POWER9 DD2 (bsc#1055014).
- commit c6a99b3
* Mon Oct  9 2017 vbabka@suse.cz
- Fix series.conf whitespace.
- commit a7d3388
* Mon Oct  9 2017 vbabka@suse.cz
- mm: memcontrol: fix NULL pointer crash in
  test_clear_page_writeback() (VM Functionality, bsc#1061849).
- commit 0cd7f9e
* Mon Oct  9 2017 tbogendoerfer@suse.de
- IB/mlx5: Fix label order in error path handling (bsc#1046305
  FATE#322943).
- net/mlx5: Fix wrong indentation in enable SRIOV code
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix static checker warning on steering tracepoints
  code (bsc#1046303 FATE#322944).
- net/mlx5e: Fix calculated checksum offloads counters
  (bsc#1046303 FATE#322944).
- net/mlx5e: Don't add/remove 802.1ad rules when changing 802.1Q
  VLAN filter (bsc#1046303 FATE#322944).
- net/mlx5e: Print netdev features correctly in error message
  (bsc#1046303 FATE#322944).
- net/mlx5e: Check encap entry state when offloading tunneled
  flows (bsc#1046303 FATE#322944).
- net/mlx5e: Disallow TC offloading of unsupported match/action
  combinations (bsc#1046303 FATE#322944).
- net/mlx5e: Fix erroneous freeing of encap header buffer
  (bsc#1046303 FATE#322944).
- net/mlx5: Check device capability for maximum flow counters
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix FPGA capability location (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Fix access to invalid memory address
  (bsc#1046303 FATE#322944).
- IB/mlx5: Simplify mlx5_ib_cont_pages (bsc#1046305 FATE#322943).
- commit 14b0a3d
* Mon Oct  9 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit 1999b85
* Mon Oct  9 2017 jthumshirn@suse.de
- nvme: fix visibility of "uuid" ns attribute (FATE#323952,
  FATE#322506).
- commit ca3cd08
* Mon Oct  9 2017 hare@suse.de
- Remove obsolete patches
- Delete patches.fixes/ch-add-refcounting.patch.
- Delete
  patches.fixes/ses-Fix-racy-cleanup-of-sys-in-remove_dev.patch.
- commit f705316
* Mon Oct  9 2017 hare@suse.de
- scsi: Rework handling of scsi_device.vpd_pg8[03] (bsc#1061782).
- scsi: Rework the code for caching Vital Product Data (VPD)
  (bsc#1061782).
- scsi: rcu: Introduce rcu_swap_protected() (bsc#1061782).
- commit aec4a2a
* Fri Oct  6 2017 mwilck@suse.com
- watchdog: Revert "iTCO_wdt: all versions count down twice"
  (bsc#1061556).
- commit dd4ee65
* Fri Oct  6 2017 rgoldwyn@suse.com
- apparmor: Add socket, mount, signal mediation (FATE#323500)
- apparmor: Fix shadowed local variable in unpack_trans_table()
  (FATE#323500).
- apparmor: Fix logical error in verify_header() (FATE#323500).
- apparmor: Fix an error code in aafs_create() (FATE#323500).
- apparmor: Redundant condition: prev_ns. in [label.c:1498]
  (FATE#323500).
- apparmor: add the ability to mediate signals (FATE#323500).
- apparmor: add mount mediation (FATE#323500).
- apparmor: cleanup conditional check for label in label_print
  (FATE#323500).
- apparmor: add support for absolute root view based labels
  (FATE#323500).
- apparmor: make policy_unpack able to audit different info
  messages (FATE#323500).
- apparmor: add more debug asserts to apparmorfs (FATE#323500).
- apparmor: add base infastructure for socket mediation
  (FATE#323500).
- apparmor: move new_null_profile to after profile lookup fns()
  (FATE#323500).
- apparmor: fix race condition in null profile creation
  (FATE#323500).
- apparmor: ensure unconfined profiles have dfas initialized
  (FATE#323500).
- apparmor: fix incorrect type assignment when freeing proxies
  (FATE#323500).
- apparmor: fix build failure on sparc caused by undeclared
  signals (FATE#323500).
- apparmor: fix apparmorfs DAC access permissions (FATE#323500).
- Delete
  patches.apparmor/apparmor-basic-networking-rules-4.11-rc1.patch.
- Delete patches.apparmor/apparmor-basic-networking-rules.patch.
- Delete
  patches.apparmor/apparmor-fix-quieting-of-audit-messages-for-network-mediation.patch.
- commit f4b43e1
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: add the kernel-binary dependencies to
  kernel-binary-base (bsc#1060333).
- commit 955681c
* Fri Oct  6 2017 hare@suse.de
- scsi: ses: Fix racy cleanup of /sys in remove_dev()
  (bsc#1061782).
- scsi: ch: add refcounting (bsc#1061782).
- scsi: ses: make page2 support optional (bsc#1061782).
- scsi: ses: Fixup error message 'failed to get diagnostic page
  0xffffffea' (bsc#1061782).
- scsi: ses: check return code from ses_recv_diag() (bsc#1061782).
- scsi: ses: Fix wrong page error (bsc#1061782).
- commit 26418a1
* Fri Oct  6 2017 hare@suse.de
- Drop obsolete hpsa patches
- Delete
  patches.drivers/hpsa-allow-hpsa-to-claim-compaq-smartarray-devices.
- Delete
  patches.drivers/hpsa-handle-unsupported-devices-more-gracefully.
- Delete
  patches.drivers/hpsa-mark-older-boards-as-unsupported.patch.
- commit a441a63
* Fri Oct  6 2017 hare@suse.de
- Update config files to remove cciss driver
- commit e1fae76
* Fri Oct  6 2017 hare@suse.de
- scsi: hpsa: remove the smp_handler stub
  (bsc#1049517,FATE#322892).
- scsi: hpsa: fix the device_id in hpsa_update_device_info()
  (bsc#1049517,FATE#322892).
- scsi: hpsa: Remove 'hpsa_allow_any' module option
  (bsc#1049517,FATE#322892).
- scsi: cciss: Drop obsolete driver
  (bsc#1049517,FATE#322892,FATE#323833).
- scsi: hpsa: do not print errors for unsupported report luns
  format (bsc#1049517,FATE#322892).
- scsi: hpsa: Ignore errors for unsupported LV_DEVICE_ID VPD page
  (bsc#1049517,FATE#322892).
- scsi: hpsa: disable volume status check for legacy boards
  (bsc#1049517,FATE#322892).
- scsi: hpsa: add support for legacy boards
  (bsc#1049517,FATE#322892).
- commit a5fea5d
* Fri Oct  6 2017 msuchanek@suse.de
- powerpc/64s: Implement system reset idle wakeup reason
  (bsc#1055121).
- commit 4c3f65a
* Fri Oct  6 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: Require xmlto unconditionally.
  Getting the condition right is too challenging it seems.
- commit fa08731
* Fri Oct  6 2017 msuchanek@suse.de
- powerpc/64s/idle: Process interrupts from system reset wakeup
  (bsc#1055121).
- commit 68b4938
* Fri Oct  6 2017 jthumshirn@suse.de
- libnvdimm, namespace: fix btt claim class crash (FATE#323731).
- libnvdimm, namespace: record 'lbasize' for pmem namespaces
  (FATE#323731).
- commit 285bf96
* Fri Oct  6 2017 jthumshirn@suse.de
- libnvdimm, btt: rework error clearing (FATE#323731).
- libnvdimm: fix potential deadlock while clearing errors
  (FATE#323731).
- libnvdimm, btt: cache sector_size in arena_info (FATE#323731).
- libnvdimm, btt: ensure that flags were also unchanged during
  a map_read (FATE#323731).
- libnvdimm, btt: refactor map entry operations with macros
  (FATE#323731).
- libnvdimm, btt: fix a missed NVDIMM_IO_ATOMIC case in the
  write path (FATE#323731).
- libnvdimm, btt: check memory allocation failure (FATE#323731).
- libnvdimm, btt: BTT updates for UEFI 2.7 format (FATE#323731).
- libnvdimm, label: switch to using v1.2 labels by default
  (FATE#323731).
- libnvdimm, label: add address abstraction identifiers
  (FATE#323731).
- libnvdimm, label: add v1.2 label checksum support (FATE#323731).
- libnvdimm, label: update 'nlabel' and 'position' handling for
  local namespaces (FATE#323731).
- libnvdimm, label: populate 'isetcookie' for blk-aperture
  namespaces (FATE#323731).
- libnvdimm, label: populate the type_guid property for v1.2
  namespaces (FATE#323731).
- libnvdimm, label: honor the lba size specified in v1.2 labels
  (FATE#323731).
- libnvdimm, label: add v1.2 interleave-set-cookie algorithm
  (FATE#323731).
- libnvdimm, label: add v1.2 nvdimm label definitions
  (FATE#323731).
- commit 9d14158
* Fri Oct  6 2017 pmladek@suse.com
- Delete
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch.
  The change is not longer needed with PVOPS Xen (bsc#873195).
- commit 7b3f924
* Fri Oct  6 2017 jthumshirn@suse.de
- scsi: smartpqi: update driver version to 1.1.2-126
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: cleanup raid map warning message
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: update controller ids (FATE#323891,bsc#1049514).
- scsi: smartpqi: remove the smp_handler stub
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: change driver version to 1.1.2-125
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: add in new controller ids
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: update kexec and power down support
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: cleanup doorbell register usage
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: update pqi passthru ioctl
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: enhance BMIC cache flush
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: add pqi reset quiesce support
  (FATE#323891,bsc#1049514).
- scsi: smartpqi: mark PM functions as __maybe_unused
  (FATE#323891,bsc#1049514).
- commit 1882c7b
* Fri Oct  6 2017 jthumshirn@suse.de
- Re-sorted series.conf to the correct order of lpfc patches.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-receiving-ELS-while-detaching-dr.patch.
- Refresh
  patches.drivers/scsi-lpfc-Make-ktime-sampling-more-accurate.patch.
- Refresh
  patches.drivers/scsi-lpfc-Move-CQ-processing-to-a-soft-IRQ.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-timer-management.patch.
- Refresh
  patches.drivers/scsi-lpfc-remove-redundant-null-check-on-eqe.patch.
- commit d1bbb42
* Thu Oct  5 2017 msuchanek@suse.de
- Refresh configs.
- commit 1eb97f0
* Thu Oct  5 2017 msuchanek@suse.de
- Add ARMv7 configs.
- commit 97f0e22
* Thu Oct  5 2017 msuchanek@suse.de
- README: branch name
- commit e68e42d
* Thu Oct  5 2017 msuchanek@suse.de
- Build in Leap project.
- commit e6f1ae6
* Thu Oct  5 2017 bpoirier@suse.com
- sfc: Add ethtool -m support for QSFP modules (bsc#1058169
  FATE#322922).
- commit acd2839
* Thu Oct  5 2017 bpoirier@suse.com
- Refresh
  patches.drivers/scsi-lpfc-Cocci-spatch-pool_zalloc-simple.patch.
- Refresh
  patches.drivers/scsi-lpfc-Ensure-io-aborts-interlocked-with-the-targ.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-in-lpfc_nvme_fcp_io_submit-durin.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-crash-receiving-ELS-while-detaching-dr.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-lpfc-nvme-host-rejecting-IO-with-Not-R.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-oops-if-nvmet_fc_register_targetport-f.patch.
- Refresh
  patches.drivers/scsi-lpfc-Fix-warning-messages-when-NVME_TARGET_FC-n.patch.
- Refresh
  patches.drivers/scsi-lpfc-Make-ktime-sampling-more-accurate.patch.
- Refresh
  patches.drivers/scsi-lpfc-Move-CQ-processing-to-a-soft-IRQ.patch.
- Refresh
  patches.drivers/scsi-lpfc-PLOGI-failures-during-NPIV-testing.patch.
- Refresh
  patches.drivers/scsi-lpfc-Reduce-log-spew-on-controller-reconnects.patch.
- Refresh
  patches.drivers/scsi-lpfc-change-version-to-11.4.0.4.patch.
- Refresh
  patches.drivers/scsi-lpfc-correct-nvme-sg-segment-count-check.patch.
- Refresh
  patches.drivers/scsi-lpfc-fix-pci-hot-plug-crash-in-timer-management.patch.
- Refresh
  patches.drivers/scsi-lpfc-remove-redundant-null-check-on-eqe.patch.
  Johannes reported that when a subsystem repository is not listed in
  git_sort.py head_names, the patches for it are silently not ordered by
  qdoit. The problem is avoided for now by adding this scsi tree to
  head_names. A more general solution will be needed later.
  I've reordered the patches and refreshed them. There is no difference in
  the expanded tree.
- commit 949fce3
* Thu Oct  5 2017 jeffm@suse.com
- Delete patches.rpmify/cloneconfig.diff.
- commit 3aaafe7
* Thu Oct  5 2017 colyli@suse.de
- block: fix integer overflow in __blkdev_sectors_to_bio_pages()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 249ef28
* Thu Oct  5 2017 colyli@suse.de
- md/r5cache: call mddev_lock/unlock() in r5c_journal_mode_set
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit c74127c
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/64s: Add workaround for P9 vector CI load issue
  (bsc#1055117).
- powerpc/mce: Move 64-bit machine check code into mce.c
  (bsc#1055117).
- powerpc/64s: Machine check handle ifetch from foreign real
  address for POWER9 (bsc#1055117).
- commit e6af293
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc: Fix action argument for cpufeatures-based TLB flush
  (bsc#1055117).
- powerpc: Fix workaround for spurious MCE on POWER9
  (bsc#1055117).
- powerpc: Handle MCE on POWER9 with only DSISR bit 30 set
  (bsc#1055117).
- commit 783697a
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/powernv: Fix local TLB flush for boot and MCE on POWER9
  (bsc#1055117).
- commit df999ef
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/powernv: Use early_radix_enabled in POWER9 tlb flush
  (bsc#1055117).
- commit b5bc2ee
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/xive: Clear XIVE internal structures when a CPU is
  removed (fate#322438).
- commit 12dbb32
* Thu Oct  5 2017 msuchanek@suse.de
- powerpc/xive: Fix IPI reset (fate#322438).
- commit 6f5e307
* Thu Oct  5 2017 tiwai@suse.de
- Update cherry-picked drm/i915 ids
  blacklist.conf
  patches.drivers/drm-i915-Initialize-data-in-intel_dsi_dcs_backlight.
- commit 3e26bd9
* Thu Oct  5 2017 tiwai@suse.de
- drm/i915: Add __rcu to radix tree slot pointer (bsc#1051510).
- commit 73cdd3f
* Thu Oct  5 2017 tiwai@suse.de
- iwlwifi: mvm: set the RTS_MIMO_PROT bit in flag mask when
  sending sta to fw (bsc#1051510).
- iwlwifi: mvm: fix TCP CSUM offload with WEP and A000 series
  (bsc#1051510).
- iwlwifi: mvm: don't warn in queue sync on RF-kill (bsc#1051510).
- commit a8def16
* Thu Oct  5 2017 tiwai@suse.de
- drm/i915: remove unused function declaration (bsc#1051510).
- drm/i915/bxt: set min brightness from VBT (bsc#1051510).
- drm/i915: Suppress switch_mm emission between the same
  aliasing_ppgtt (bsc#1051510).
- drm/i915: Quietly cancel FBC activation if CRTC is turned off
  before worker (bsc#1051510).
- drm/i915: Initialize 'data' in intel_dsi_dcs_backlight.c
  (bsc#1051510).
- drm/i915: Always wake the device to flush the GTT (bsc#1051510).
- Revert "drm/i915/bxt: Disable device ready before shutdown
  command" (bsc#1051510).
- commit a5aceb8
* Thu Oct  5 2017 tiwai@suse.de
- ALSA: hda/ca0132 - Fix memory leak at error path (bsc#1052235).
- ALSA: hda: Fix regression of hdmi eld control created based
  on invalid pcm (bsc#1052235).
- commit c5a6ca0
* Thu Oct  5 2017 msuchanek@suse.de
- cxl: Fix memory page not handled (bsc#1055014).
- commit 904cf45
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S: Fix server always zero from
  kvmppc_xive_get_xive() (bsc#1061840).
- commit a04c301
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Fix bug causing host SLB to be restored
  incorrectly (bsc#1061840).
- commit fcb992f
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't access XIVE PIPR register using
  byte accesses (bsc#1061840).
- commit 6a8e0e7
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Add missing barriers to XIVE code and
  document them (bsc#1061840).
- commit 5efae32
* Thu Oct  5 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Workaround POWER9 DD1.0 bug causing IPB
  bit loss (bsc#1061840).
- commit f582f45
* Thu Oct  5 2017 msuchanek@suse.de
- ibmveth: Support to enable LSO/CSO for Trunk VEA (bsc#1061843).
- commit e982073
* Thu Oct  5 2017 jroedel@suse.de
- PCI: Mark Broadcom HT2100 Root Port Extended Tags as broken
  (bsc#1061880).
- commit d31f3a4
* Thu Oct  5 2017 jroedel@suse.de
- x86/ldt: Fix off by one in get_segment_base() (bsc#1061872).
- x86/ldt: Rename ldt_struct::size to ::nr_entries (bsc#1061872).
- commit aaef532
* Thu Oct  5 2017 bpoirier@suse.com
- Refresh patch order in sorted section
  In case of absent remotes, series_sort reordered and renamed subsystem
  sections. This should now be fixed as long as the subsystem is listed in
  series_sort.py head_names.
- commit 0257dde
* Thu Oct  5 2017 tiwai@suse.de
- Refresh QXL fixes: they've been upstreamed
  patches.drivers/qxl-fix-pinning.patch
  patches.drivers/qxl-fix-primary-surface-handling.patch
- commit 133bed7
* Thu Oct  5 2017 tbogendoerfer@suse.de
- Refresh
  patches.drivers/net-mlx5-Introduce-trigger_health_work-function.patch.
- commit f064ef2
* Thu Oct  5 2017 hare@suse.de
- libata: check for trusted computing in IDENTIFY DEVICE data
  (bsc#1061782).
- libata: implement SECURITY PROTOCOL IN/OUT (bsc#1061782).
- libata: factor out a ata_identify_page_supported helper
  (bsc#1061782).
- libata: clarify log page naming / grouping (bsc#1061782).
- libata: factor out a ata_log_supported helper (bsc#1061782).
- libata: move ata_read_log_page to libata-core.c (bsc#1061782).
- commit 37e3e92
* Thu Oct  5 2017 vbabka@suse.cz
- mm/page_alloc.c: apply gfp_allowed_mask before the first
  allocation attempt (VM Functionality, git fixes).
- commit 9d48e99
* Thu Oct  5 2017 hare@suse.de
- scsi: scsi-sysfs: Adjust error returned for adapter reset
  request (bsc#1061782).
- scsi: make 'state' device attribute pollable (bsc#1061782).
- scsi: scsi_lib: rework scsi_internal_device_unblock_nowait()
  (bsc#1061782).
- scsi: fc: start decoupling fc_block_scsi_eh from scsi_cmnd
  (bsc#1061782).
- scsi: remove DRIVER_ATTR() usage (bsc#1061782).
- scsi: sd_zbc: Write unlock zone from sd_uninit_cmnd()
  (bsc#1061782).
- scsi: isci: fix typo in function names (bsc#1061782).
- scsi: sas: scsi_queue_work can fail, so make callers aware
  (bsc#1061782).
- scsi: sd: Use sysfs_match_string() (bsc#1061782).
- scsi: scsi_dh_alua: remove synchronous STPG support
  (bsc#1061782).
- scsi: remove various unused blist flags (bsc#1061782).
- scsi: xen-scsifront: Remove code that zeroes driver-private
  command data (bsc#1061782).
- scsi: virtio_scsi: Remove code that zeroes driver-private
  command data (bsc#1061782).
- scsi: snic: Remove code that zeroes driver-private command data
  (bsc#1061782).
- scsi: Make scsi_mq_prep_fn() call scsi_init_command()
  (bsc#1061782).
- scsi: Introduce scsi_mq_sgl_size() (bsc#1061782).
- scsi: Only add commands to the device command list if required
  by the LLD (bsc#1061782).
- commit 4360116
* Thu Oct  5 2017 hare@suse.de
- scsi: Make __scsi_remove_device go straight from BLOCKED to DEL
  (bsc#1061782).
- commit e9b1984
* Thu Oct  5 2017 hare@suse.de
- scsi: Introduce scsi_start_queue() (bsc#1061782).
- scsi: Protect SCSI device state changes with a mutex
  (bsc#1061782).
- commit e63b6b2
* Thu Oct  5 2017 hare@suse.de
- scsi: Create two versions of scsi_internal_device_unblock()
  (bsc#1061782).
- commit e74af46
* Thu Oct  5 2017 hare@suse.de
- scsi: Split scsi_internal_device_block() (bsc#1061782).
- commit 31782b2
* Thu Oct  5 2017 hare@suse.de
- sd: add support for TCG OPAL self encrypting disks
  (bsc#1061782).
- commit db34dbf
* Thu Oct  5 2017 tbogendoerfer@suse.de
- RDMA/qedr: Fix rdma_type initialization (bsc#1050545
  FATE#322893).
- IB: Move PCI dependency from root KConfig to HW's KConfigs
  (bsc#1046306 FATE#322942).
- RDMA/qedr: fix build error without ipv6 (bsc#1050545
  FATE#322893).
- RDMA/qedr: Missing error code in qedr_init_user_queue()
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Add support for iWARP in user space (bsc#1050545
  FATE#322893).
- RDMA/qedr: Add iWARP connection management functions
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Add iWARP connection management qp related callbacks
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Add support for read with invalidate, supported in
  iWARP (bsc#1050545 FATE#322893).
- RDMA/qedr: Add iWARP support in existing verbs (bsc#1050545
  FATE#322893).
- RDMA/qedr: Add support for registering an iWARP device
  (bsc#1050545 FATE#322893).
- RDMA/qedr: Rename the qedr_cm file as a preparation for iWARP
  support (bsc#1050545 FATE#322893).
- commit 1e6b3ed
* Thu Oct  5 2017 tbogendoerfer@suse.de
- re-sorted series.conf
- commit d2e8138
* Thu Oct  5 2017 jroedel@suse.de
- KVM: x86: Fix immediate_exit handling for uninitialized AP
  (bsc#1061813).
- commit 4ed06fa
* Thu Oct  5 2017 jroedel@suse.de
- iommu/amd: pr_err() strings should end with newlines
  (bsc#1043261).
- commit 2281132
* Thu Oct  5 2017 hare@suse.de
- scsi: aacraid: error: testing array offset 'bus' after use
  (bsc#1049519,FATE#322889).
- scsi: aacraid: Fix command send race condition
  (bsc#1049519,FATE#322889).
- scsi: aacraid: report -ENOMEM to upper layer from
  aac_convert_sgraw2() (bsc#1049519,FATE#322889).
- scsi: aacraid: get rid of one level of indentation
  (bsc#1049519,FATE#322889).
- scsi: aacraid: fix indentation errors (bsc#1049519,FATE#322889).
- scsi: aacraid: complete all commands during bus reset
  (bsc#1049519,FATE#322889).
- scsi: aacraid: add fib flag to mark scsi command callback
  (bsc#1049519,FATE#322889).
- scsi: aacraid: enable sending of TMFs from aac_hba_send()
  (bsc#1049519,FATE#322889).
- scsi: aacraid: use aac_tmf_callback for reset fib
  (bsc#1049519,FATE#322889).
- scsi: aacraid: split off device, target, and bus reset
  (bsc#1049519,FATE#322889).
- scsi: aacraid: split off host reset (bsc#1049519,FATE#322889).
- scsi: aacraid: split off functions to generate reset FIB
  (bsc#1049519,FATE#322889).
- commit 8d89ea9
* Thu Oct  5 2017 jkosina@suse.cz
- series.conf: restore upstream ordering which I broke by mistake
- commit 1757725
* Thu Oct  5 2017 hare@suse.de
- Reshuffle series.conf to include scsi-misc branch
- commit 9845e26
* Thu Oct  5 2017 vbabka@suse.cz
- mm: fix data corruption caused by lazyfree page (VM
  Functionality, bsc#1061775).
- mm: avoid marking swap cached page as lazyfree (VM
  Functionality, bsc#1061775).
- commit 791a9bf
* Thu Oct  5 2017 hare@suse.de
- scsi: megaraid_mbox: drop duplicate bus reset and device reset
  function (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: driver version upgrade
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: call megasas_dump_frame with correct IO
  frame size (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: modified few prints in OCR and IOC INIT path
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: replace internal FALSE/TRUE definitions
  with false/true (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Return pended IOCTLs with
  cmd_status MFI_STAT_WRONG_STATE in case adapter is dead
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: use vmalloc for crash dump buffers and
  driver's local RAID map (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Use SMID for Task abort case only
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Check valid aen class range to avoid kernel
  panic (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Fix endianness issues in DCMD handling
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Do not re-fire shutdown DCMD after OCR
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Call megasas_complete_cmd_dpc_fusion
  every 1 second while there are pending commands
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: Use synchronize_irq in target reset case
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: set minimum value of resetwaittime to be
  1 secs (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: mismatch of allocated MFI frame
  size and length exposed in MFI MPT pass through command
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: fix allocate instance->pd_info twice
  (bsc#1049528,FATE#322937).
- scsi: megaraid: fix format-overflow warning
  (bsc#1049528,FATE#322937).
- scsi: megaraid: Replace PCI pool old API
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: fix error handle in megasas_probe_one
  (bsc#1049528,FATE#322937).
- scsi: megaraid_sas: fix memleak in megasas_alloc_cmdlist_fusion
  (bsc#1049528,FATE#322937).
- scsi: megaraid: Fix a sleep-in-atomic bug
  (bsc#1049528,FATE#322937).
- commit 83ffcac
* Thu Oct  5 2017 ohering@suse.de
- add mainline tags to hyperv patches
- commit 529ce16
* Thu Oct  5 2017 mkubecek@suse.cz
- inetpeer: fix RCU lookup() again (bsc#1061739).
- inetpeer: fix RCU lookup() (bsc#1061739).
- inetpeer: remove AVL implementation in favor of RB tree
  (bsc#1061739).
- net: convert inet_peer.refcnt from atomic_t to refcount_t
  (bsc#1061739).
- commit 3cca9a9
* Thu Oct  5 2017 tbogendoerfer@suse.de
- Update config files.
- commit d121c2b
* Thu Oct  5 2017 tbogendoerfer@suse.de
- net/mlx5e: Distribute RSS table among all RX rings (bsc#1046305
  FATE#322943).
- net/mlx5e: Stop NAPI when irq balancer changes affinity
  (bsc#1046305 FATE#322943).
- net/mlx5e: Use kernel's mechanism to avoid missing NAPIs
  (bsc#1046305 FATE#322943).
- net/mlx5e: Slightly increase RX page-cache size (bsc#1046305
  FATE#322943).
- net/mlx5e: Don't recycle page if moved to far NUMA (bsc#1046305
  FATE#322943).
- net/mlx5e: Remove unnecessary fields in ICO SQ (bsc#1046305
  FATE#322943).
- net/mlx5e: Type-specific optimizations for RX post WQEs function
  (bsc#1046305 FATE#322943).
- net/mlx5e: Non-atomic RQ state indicator for UMR WQE in progress
  (bsc#1046305 FATE#322943).
- net/mlx5e: Non-atomic indicator for ring enabled state
  (bsc#1046305 FATE#322943).
- net/mlx5e: Refactor data-path lro header function (bsc#1046305
  FATE#322943).
- net/mlx5e: Early-return on empty completion queues (bsc#1046305
  FATE#322943).
- net/mlx5e: NAPI busy-poll when UMR post is in progress
  (bsc#1046305 FATE#322943).
- net/mlx5e: Small enhancements for RX MPWQE allocation and free
  (bsc#1046305 FATE#322943).
- net/mlx5e: Use memset to init skbs_frags array to zeros
  (bsc#1046305 FATE#322943).
- net/mlx5e: Remove unnecessary wqe_sz field from RQ buffer
  (bsc#1046305 FATE#322943).
- net/mlx5e: Replace multiplication by stride size with a shift
  (bsc#1046305 FATE#322943).
- net/mlx5e: Reorganize struct mlx5e_rq (bsc#1046305 FATE#322943).
- net/mlx5e: Support RSS for GRE tunneled packets (bsc#1046305
  FATE#322943).
- net/mlx5e: Support TSO and TX checksum offloads for GRE tunnels
  (bsc#1046305 FATE#322943).
- net/mlx5e: Use IP version matching to classify IP traffic
  (bsc#1046305 FATE#322943).
- net/mlx5: Add tracepoints (bsc#1046305 FATE#322943).
- net/mlx5: Add hash table for flow groups in flow table
  (bsc#1046305 FATE#322943).
- net/mlx5: Add hash table to search FTEs in a flow-group
  (bsc#1046305 FATE#322943).
- net/mlx5: Don't store reserved part in FTEs and FGs (bsc#1046305
  FATE#322943).
- net/mlx5: Convert linear search for free index to ida
  (bsc#1046305 FATE#322943).
- net/mlx5e: Fix wrong code indentation in conditional statement
  (bsc#1046305 FATE#322943).
- net/mlx5: Remove a leftover unused variable (bsc#1046305
  FATE#322943).
- net/mlx5: Add a blank line after declarations V2 (bsc#1046305
  FATE#322943).
- net/mlx5e: make mlx5e_profile const (bsc#1046305 FATE#322943).
- net/mlx5e: Use size_t to store byte offset in statistics
  descriptors (bsc#1046305 FATE#322943).
- net/mlx5e: Use kernel types instead of uint*_t in ethtool
  callbacks (bsc#1046305 FATE#322943).
- net/mlx5e: Place constants on the right side of comparisons
  (bsc#1046305 FATE#322943).
- net/mlx5e: Avoid using multiple blank lines (bsc#1046305
  FATE#322943).
- net/mlx5e: Properly indent within conditional statements
  (bsc#1046305 FATE#322943).
- net/mlx5: Add a blank line after declarations (bsc#1046305
  FATE#322943).
- net/mlx5: Avoid blank lines after/before open/close brace
  (bsc#1046305 FATE#322943).
- net/mlx5e: Add outbound PCI buffer overflow counter (bsc#1046305
  FATE#322943).
- net/mlx5e: Add RX buffer fullness counters (bsc#1046305
  FATE#322943).
- net/mlx5: Add RX buffer fullness counters infrastructure
  (bsc#1046305 FATE#322943).
- net/mlx5e: Add PCIe outbound stalls counters (bsc#1046305
  FATE#322943).
- net/mlx5: Add PCIe outbound stalls counters infrastructure
  (bsc#1046305 FATE#322943).
- net/mlx5e: IPoIB, Add support for get_link_ksettings in ethtool
  (bsc#1046305 FATE#322943).
- net/mlx5e: Send PAOS command on interface up/down (bsc#1046305
  FATE#322943).
- mlx5: ensure 0 is returned when vport is zero (bsc#1046305
  FATE#322943).
- mlx5: remove unnecessary pci_set_drvdata() (bsc#1046305
  FATE#322943).
- net/mlx5: Increase the maximum flow counters supported
  (bsc#1046305 FATE#322943).
- net/mlx5: Fix counter list hardware structure (bsc#1046305
  FATE#322943).
- net/mlx5: Delay events till ib registration ends (bsc#1046305
  FATE#322943).
- net/mlx5: Add CONFIG_MLX5_ESWITCH Kconfig (bsc#1046305
  FATE#322943).
- net/mlx5: Separate between E-Switch and MPFS (bsc#1046305
  FATE#322943).
- net/mlx5: Unify vport manager capability check (bsc#1046305
  FATE#322943).
- net/mlx5e: NIC netdev init flow cleanup (bsc#1046305
  FATE#322943).
- net/mlx5e: Rearrange netdevice ops structures (bsc#1046305
  FATE#322943).
- commit 16606b3
* Thu Oct  5 2017 jthumshirn@suse.de
- scsi: lpfc: PLOGI failures during NPIV testing
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix oops of nvme host during driver unload
  (bsc#1050239,FATE#322918).
- scsi: lpfc: change version to 11.4.0.4 (FATE#324028).
- scsi: lpfc: Fix secure firmware updates
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix lpfc nvme host rejecting IO with Not Ready
  message (bsc#1050239,FATE#322918).
- scsi: lpfc: fix pci hot plug crash in list_add call
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix warning messages when NVME_TARGET_FC not defined
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Cocci spatch "pool_zalloc-simple"
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Ensure io aborts interlocked with the target
  (bsc#1050239,FATE#322918).
- scsi: lpfc: remove redundant null check on eqe (bsc#1050239,
  FATE#322918).
- scsi: lpfc: Extend RDP support (bsc#1050239,FATE#322918).
- scsi: lpfc: Set missing abort context (bsc#1050239,FATE#322918).
- scsi: lpfc: Disable NPIV support if NVME is enabled
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix FCP hba_wqidx assignment
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix pci hot plug crash in timer management routines
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Revise NVME module parameter descriptions for
  better clarity (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix oops if nvmet_fc_register_targetport fails
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash receiving ELS while detaching driver
  (bsc#1050239,FATE#322918).
- scsi: lpfc: correct nvme sg segment count check
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Make ktime sampling more accurate
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Move CQ processing to a soft IRQ
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Reduce log spew on controller reconnects
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash in lpfc_nvme_fcp_io_submit during LIP
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Don't return internal MBXERR_ERROR code from probe
  function (bsc#1050239,FATE#322918).
- scsi: lpfc: avoid false-positive gcc-8 warning
  (bsc#1050239,FATE#322918).
- scsi: lpfc: avoid an unused function warning
  (bsc#1050239,FATE#322918).
- scsi: lpfc: lpfc version bump 11.4.0.3
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix "integer constant too large" error on 32bit
  archs (bsc#1050239,FATE#322918).
- scsi: lpfc: Add Buffer to Buffer credit recovery support
  (bsc#1050239,FATE#322918).
- scsi: lpfc: remove console log clutter
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix bad sgl reposting after 2nd adapter reset
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme target failure after 2nd adapter reset
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix relative offset error on large nvmet target ios
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix MRQ > 1 context list handling
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Limit amount of work processed in IRQ
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Correct issues with FAWWN and FDISCs
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix NVME PRLI handling during RSCN
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash in lpfc nvmet when fc port is reset
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix duplicate NVME rport entries and namespaces
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix handling of FCP and NVME FC4 types in Pt2Pt
  topology (bsc#1050239,FATE#322918).
- scsi: lpfc: Correct return error codes to align with nvme_fc
  transport (bsc#1050239,FATE#322918).
- scsi: lpfc: convert info messages to standard messages
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix oops when NVME Target is discovered in a
  nonNVME environment (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix rediscovery on switch blade pull
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix loop mode target discovery
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix plogi collision that causes illegal state
  transition (bsc#1050239,FATE#322918).
- scsi: lpfc: remove useless code in lpfc_sli4_bsg_link_diag_test
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Replace PCI pool old API (bsc#1050239,FATE#322918).
- lpfc: support nvmet_fc defer_rcv callback
  (bsc#1050239,FATE#322918).
- scsi: lpfc: don't double count abort errors
  (bsc#1050239,FATE#322918).
- scsi: lpfc: spin_lock_irq() is not nestable
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix refcount error on node list
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme io stoppage after link bounce
  (bsc#1050239,FATE#322918).
- scsi: lpfc: update to revision to 11.4.0.1
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Driver responds LS_RJT to Beacon Off ELS - Linux
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash in lpfc_sli_ringtxcmpl_put when nvmet
  gets an abort request (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash doing IO with resets
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash after firmware flash when IO is running
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix SLI3 drivers attempting NVME ELS commands
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Break up IO ctx list into a separate get and put
  list (bsc#1050239,FATE#322918).
- scsi: lpfc: Reduce time spent in IRQ for received NVME commands
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Vport creation is failing with "Link Down" error
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme_info sysfs output to be consistent
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix system panic when express lane enabled
  (bsc#1050239,FATE#322918).
- scsi: lpfc: update to revision to 11.4.0.0
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Add auto EQ delay logic (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix defects reported by Coverity Scan
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix vports not logging into target
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix PRLI retry handling when target rejects it
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Null pointer dereference when log_verbose is set
  to 0xffffffff (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix System panic after loading the driver
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix crash on powering off BFS VM with passthrough
  device (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix return value of board_mode store routine in
  case of online failure (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix counters so outstandng NVME IO count is accurate
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix Port going offline after multiple resets
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvmet node ref count handling
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix Lun Priority level shown as NA
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Add changes to assist in NVMET debugging
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Fix nvme port role handling in sysfs and debugfs
  handlers (bsc#1050239,FATE#322918).
- commit 5d26711
* Thu Oct  5 2017 vbabka@suse.cz
- mm: oom: let oom_reap_task and exit_mmap run concurrently
  (VM Functionality, bsc#1061755).
- mm, hugetlb: do not allocate non-migrateable gigantic pages
  from movable zones (bsc#1061756, bnc#1027153, bnc#1030659,
  fate#323634).
- commit 60f16a2
* Thu Oct  5 2017 mkubecek@suse.cz
- udp: remove unreachable ufo branches (bsc#1061739).
- net: Kill NETIF_F_UFO and SKB_GSO_UDP (bsc#1061739).
- inet: Remove software UFO fragmenting code (bsc#1061739).
- net: Remove all references to SKB_GSO_UDP (bsc#1061739).
- inet: Stop generating UFO packets (bsc#1061739).
- net: Remove references to NETIF_F_UFO from ethtool
  (bsc#1061739).
- net: Remove references to NETIF_F_UFO in netdev_fix_features()
  (bsc#1061739).
- virtio_net: Remove references to NETIF_F_UFO (bsc#1061739).
- dummy: Remove references to NETIF_F_UFO (bsc#1061739).
- tun/tap: Remove references to NETIF_F_UFO (bsc#1061739).
- macvlan/macvtap: Remove NETIF_F_UFO advertisement (bsc#1061739).
- ipvlan: Stop advertising NETIF_F_UFO support (bsc#1061739).
- macb: Remove bogus reference to NETIF_F_UFO (bsc#1061739).
- s2io: Remove UFO support (bsc#1061739).
- commit e43998f
* Thu Oct  5 2017 hare@suse.de
- scsi: csiostor: Avoid content leaks and casts (FATE#322932).
- scsi: csiostor: Replace PCI pool old API (FATE#322932).
- scsi: csiostor: add check for supported fw version
  (FATE#322932).
- scsi: csiostor: add support for Chelsio T6 adapters
  (FATE#322932).
- scsi: csiostor: fail probe if fw does not support FCoE
  (FATE#322932).
- scsi: csiostor: update module version (FATE#322932).
- scsi: fcoe: Fix few small typos in fcoe.c (FATE#322932).
- scsi: fcoe: Remove an extra out label in _fcoe_create function
  (FATE#322932).
- scsi: fix typos and grammar in comments of scsi_transport_fc.c
  (FATE#322918).
- scsi: fnic: Zero io_cmpl_skip on fw reset completion
  (FATE#322783).
- scsi: fnic: added timestamp reporting in fnic debug stats
  (FATE#322783).
- scsi: fnic: correct speed display and add support for 25,40
  and 100G (FATE#322783).
- scsi: fnic: fix format string overflow warning (FATE#322783).
- scsi: libfc: pass an error pointer to fc_disc_error()
  (FATE#322783).
- commit ac9dc66
* Thu Oct  5 2017 jthumshirn@suse.de
- scsi: lpfc: Fix transition nvme-i rport handling to nport only
  (bsc#1050239,FATE#322918).
- scsi: lpfc: Add nvme initiator devloss support
  (bsc#1050239,FATE#322918).
- scsi: lpfc: make a couple of functions static
  (bsc#1050239,FATE#322918).
- scsi: lpfc: fix spelling mistake "entrys" -> "entries"
  (bsc#1050239,FATE#322918).
- lpfc debugfs: get rid of pointless access_ok()
  (bsc#1050239,FATE#322918).
- commit cfc608f
* Thu Oct  5 2017 vbabka@suse.cz
- mm/sparse.c: fix typo in online_mem_sections (bnc#1027153,
  bnc#1030659, fate#323634).
- commit 4d2d8e0
* Thu Oct  5 2017 tbogendoerfer@suse.de
- Re-sorted sorted section
- commit d20aa5b
* Thu Oct  5 2017 oneukum@suse.com
- xhci: set missing SuperSpeedPlus Link Protocol bit in roothub
  descriptor (bsc#1060807).
- commit c584666
* Thu Oct  5 2017 mhocko@suse.cz
- memremap: add scheduling point to devm_memremap_pages
  (bnc#1057079).
- mm, page_alloc: add scheduling point to memmap_init_zone
  (bnc#1057079).
- mm, memory_hotplug: add scheduling point to __add_pages
  (bnc#1057079).
- commit 7fdee39
* Thu Oct  5 2017 neilb@suse.com
- NFS: Fix NFSv2 security settings (git-fixes).
- commit dc322d2
* Thu Oct  5 2017 dchang@suse.com
- be2net: fix TSO6/GSO issue causing TX-stall on Lancer/BEx
  (bsc#1050252 FATE#322920).
- benet: fix set but not used warning (bsc#1050252 FATE#322920).
- commit a8eb98a
* Thu Oct  5 2017 dchang@suse.com
- tg3: clean up redundant initialization of tnapi (bsc#1050260
  FATE#322917).
- tg3: Be drop monitor friendly (bsc#1050260 FATE#322917).
- commit 8771a11
* Thu Oct  5 2017 dchang@suse.com
- qlge: fix duplicated code for different branches (bsc#1050529
  FATE#322902).
- commit 69f8b35
* Thu Oct  5 2017 dchang@suse.com
- qlcnic: remove redundant zero check on retries counter
  (bsc#1050540 FATE#322896).
- qlogic: make device_attribute const (bsc#1050540 FATE#322896).
- qlcnic: add const to bin_attribute structure (bsc#1050540
  FATE#322896).
- qlcnic: remove unnecessary static in qlcnic_dump_fw()
  (bsc#1050540 FATE#322896).
- commit 544316b
* Wed Oct  4 2017 bpoirier@suse.com
- igb: support BCM54616 PHY (bsc#1056651 FATE#322191 bsc#1056643
  FATE#322192).
- igbvf: convert msleep to mdelay in atomic context (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igbvf: after mailbox write, wait for reply (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igbvf: add lock around mailbox ops (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: do not drop PF mailbox lock after read of VF message
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: expose mailbox unlock method (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: add argument names to mailbox op function declarations
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: Remove incorrect "unexpected SYS WRAP" log message
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: protect TX timestamping from API misuse (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igb: Fix error of RX network flow classification (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- commit 89da50e
* Wed Oct  4 2017 bpoirier@suse.com
- i40e SLE15 update, part 2
- i40e: 25G FEC status improvements (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: Detect ATR HW Evict NVM issue and disable the feature
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: Fix a bug with VMDq RSS queue allocation (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Fix for trace found with S4 state (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: Fix for unused value issue found by static analysis
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: Handle admin Q timeout when releasing NVM (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Store the requested FEC information (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Update state variable for adminq subtask (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Use correct flag to enable egress traffic for unicast
  promisc (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: display correct UDP tunnel type name (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix incorrect variable assignment (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: fix odd formatting and indent (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: fix up 32 bit timespec references (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: force VMDQ device name truncation (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: handle setting administratively set MAC address back to
  zero (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: adjust packet size to account for double VLANs
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: avoid dynamic ITR updates when polling or low
  packet rate (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: make IPv6 ATR code clearer (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e/i40evf: remove ULTRA latency mode (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e/i40evf: remove mismatched type warnings (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: rename vf_offload_flags to vf_cap_flags in struct
  virtchnl_vf_resource (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- i40e/i40evf: support for VF VLAN tag stripping control
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: use cmpxchg64 when updating private flags in
  ethtool (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: initialize our affinity_mask based on cpu_possible_mask
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: invert logic for checking incorrect cpu vs irq affinity
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: move check for avoiding VID=0 filters into
  i40e_vsi_add_vlan (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- i40e: move enabling icr0 into i40e_update_enable_itr
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: prevent changing ITR if adaptive-rx/tx enabled
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: prevent snprintf format specifier truncation (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: remove WQ_UNBOUND and the task limit of our workqueue
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: remove workaround for Open Firmware MAC address
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: remove workaround for resetting XPS (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: report BPF prog id during XDP_QUERY_PROG (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: separate hw_features from runtime changing flags
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: synchronize nvmupdate command and adminq subtask
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: use cpumask_copy instead of direct assignment (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40evf: Use le32_to_cpu before evaluating HW desc fields
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: add some missing includes (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: fix possible snprintf truncation of q_vector->name
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: prevent VF close returning before state transitions
  to DOWN (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: remove unnecessary __packed (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: use netdev variable in reset task (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- Refresh
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- Refresh
  patches.drivers/i40e-avoid-NVM-acquire-deadlock-during-NVM-update.patch.
- Refresh
  patches.drivers/i40e-point-wb_desc-at-the-nvm_wb_desc-during-i40e_re.patch.
- commit 8d65ed4
* Wed Oct  4 2017 bpoirier@suse.com
- ixgbe: Disable flow control for XFI (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- ixgbe: Do not support flow control autonegotiation for X553
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Update NW_MNG_IF_SEL support for X553 (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Enable LASI interrupts for X552 devices (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Ensure MAC filter was added before setting MACVLAN
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: NULL xdp_tx rings on resource cleanup (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- commit ae3ddc3
* Wed Oct  4 2017 bpoirier@suse.com
- e1000e: Initial Support for IceLake (bsc#1056664 FATE#322185).
- e1000e: add check on e1e_wphy() return value (bsc#1056664
  FATE#322185).
- commit 875d96b
* Wed Oct  4 2017 yousaf.kaukab@suse.com
- arm64: cn99xx: drop iort/smmu workaround
  References: bsc#1039695
- Delete
  patches.drivers/0007-iommu-arm-smmu-ACPI-Enable-Cavium-SMMU-v2.patch.
- Delete
  patches.drivers/0008-iommu-arm-smmu-ACPI-Enable-Cavium-SMMU-v3.patch.
- Delete
  patches.drivers/0009-acpi-iort-thunderx2-enable-smmu-resource-size-errata.patch.
- commit 8768934
* Wed Oct  4 2017 tbogendoerfer@suse.de
- s390/diag: add diag26c support (bsc#1061024 FATE#323301).
- commit 829f7d6
* Wed Oct  4 2017 tbogendoerfer@suse.de
- qeth: VNIC Characteristics support (bsc#1061024 FATE#323301).
- commit 014a65c
* Wed Oct  4 2017 tbogendoerfer@suse.de
- s390/qeth: add VNICC get/set timeout support (bsc#1061024
  FATE#323301).
- s390/qeth: add VNICC enable/disable support (bsc#1061024
  FATE#323301).
- s390/qeth: add basic VNICC support (bsc#1061024 FATE#323301).
- s390/qeth: use skb_cow_head() for L2 OSA xmit (bsc#1061024
  FATE#323301).
- s390/qeth: unify code to build header elements (bsc#1061024
  FATE#323301).
- s390/qeth: pass full IQD header length to fill_buffer()
  (bsc#1061024 FATE#323301).
- s390/qeth: pass TSO data offset to fill_buffer() (bsc#1061024
  FATE#323301).
- s390/qeth: pass TSO header length to fill_buffer() (bsc#1061024
  FATE#323301).
- s390/qeth: pass full data length to l2_fill_header()
  (bsc#1061024 FATE#323301).
- s390/qeth: split L2 xmit paths (bsc#1061024 FATE#323301).
- s390/qeth: fix using of ref counter for rxip addresses
  (bsc#1061024 FATE#323301).
- s390/qeth: fix trace-messages for deleting rxip addresses
  (bsc#1061024 FATE#323301).
- s390/qeth: reject multicast rxip addresses (bsc#1061024
  FATE#323301).
- s390/qeth: extract bridgeport cmd builder (bsc#1061024
  FATE#323301).
- s390/net: reduce inlining (bsc#1061024 FATE#323301).
- s390/qeth: make more use of skb API (bsc#1061024 FATE#323301).
- s390/qeth: clean up fill_buffer() offset logic (bsc#1061024
  FATE#323301).
- s390/qeth: straighten out fill_buffer() interface (bsc#1061024
  FATE#323301).
- s390/qeth: simplify fragment type selection (bsc#1061024
  FATE#323301).
- s390/qeth: remove extra L3 adapterparms query (bsc#1061024
  FATE#323301).
- s390/qeth: remove extra L2 adapterparms query (bsc#1061024
  FATE#323301).
- s390/qeth: don't access skb after transmission (bsc#1061024
  FATE#323301).
- s390/qeth: constify attribute_group structures (bsc#1061024
  FATE#323301).
- s390/qeth: fix L3 next-hop in xmit qeth hdr (bsc#1061024
  FATE#323301).
- drivers: s390: move static and inline before return type
  (bsc#1061024 FATE#323301).
- s390/qeth: use diag26c to get MAC address on L2 (bsc#1061024
  FATE#323301).
- s390/qeth: fix packing buffer statistics (bsc#1061024
  FATE#323301).
- s390/qeth: add ipa return codes for bridgeport (bsc#1061024
  FATE#323301).
- s390/qeth: do early device setup for z/VM IQD NICs (bsc#1061024
  FATE#323301).
- s390/qeth: add support for early L3 device setup (bsc#1061024
  FATE#323301).
- s390/qeth: silence qeth_fix_features() (bsc#1061024
  FATE#323301).
- s390/qeth: consolidate pack buffer flushing (bsc#1061024
  FATE#323301).
- s390/qeth: add missing strings for IPA return codes (bsc#1061024
  FATE#323301).
- s390/qeth: log bridgeport capabilities (bsc#1061024
  FATE#323301).
- s390/qeth: query IPv6 IPA support on HiperSockets (bsc#1061024
  FATE#323301).
- s390/qeth: remove skb_is_nonlinear() check on IQD (bsc#1061024
  FATE#323301).
- s390/qeth: remove support for IPA_IP_FRAGMENTATION (bsc#1061024
  FATE#323301).
- s390: drivers: convert to use DRIVER_ATTR_RO/WO (bsc#1061024
  FATE#323301).
- commit 7d25fa3
* Wed Oct  4 2017 mfleming@suse.de
- sched/cpuset/pm: Fix cpuset vs. suspend-resume bugs
  (bsc#1061593).
- commit 8f70090
* Wed Oct  4 2017 jeffm@suse.com
- Delete patches.fixes/block-copy-bi_vcnt-in-_bio_clone_fast.
- commit 471096c
* Wed Oct  4 2017 hare@suse.de
- scsi: bnx2fc: Update version number to 2.11.8 (FATE#322911).
- scsi: bnx2fc: Make rport_terminate_io callback a NOOP
  (FATE#322911).
- scsi: bnx2fc: If IO is still in cleanup then do not return to
  SCSI layer (FATE#322911).
- scsi: bnx2fc: Adjust bnx2fc_npiv_create_vports for WWNNs from
  NVRAM that are zero (FATE#322911).
- scsi: bnx2fc: Update copyright for 2017 (FATE#322911).
- scsi: bnx2fc: Check for connection offload before sending RRQ
  (FATE#322911).
- scsi: bnx2fc: Add filters to the non-offload FCoE receive path
  (FATE#322911).
- commit 68f3019
* Wed Oct  4 2017 jthumshirn@suse.de
- libnvdimm, nfit: export an 'ecc_unit_size' sysfs attribute
  (FATE#324028).
- mm, devm_memremap_pages: use multi-order radix for ZONE_DEVICE
  lookups (FATE#324028).
- commit 1cd0d92
* Wed Oct  4 2017 hare@suse.de
- Move iSCSI and FCoE patches to ordered section
- commit 222f486
* Wed Oct  4 2017 hare@suse.de
- Move device-mapper and MD patches to ordered section
- commit b850033
* Wed Oct  4 2017 jslaby@suse.cz
- orc: mark it as reliable (bnc#1058115).
- Update config files.
- commit cb41042
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Use register variable to get stack pointer value
  (bnc#1058115).
- commit 7e6a014
* Wed Oct  4 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for GCC 4.4
  (bnc#1058115).
- commit 98f2e81
* Wed Oct  4 2017 hare@suse.de
- Delete patches.fixes/sd_liberal_28_sense_invalid.diff.
- Delete patches.suse/dm-emulate-blkrrpart-ioctl.
- commit 0422451
* Wed Oct  4 2017 mgorman@suse.de
- mm/mempolicy: fix NUMA_INTERLEAVE_HIT counter (VM Performance,
  bnc#959436).
- commit 7934624
* Wed Oct  4 2017 lduncan@suse.com
- scsi: scsi_transport_iscsi: fix the issue that iscsi_if_rx
  doesn't parse nlmsg properly (bsc#1059051 CVE-2017-14489).
- commit 180de31
* Wed Oct  4 2017 agraf@suse.de
- Delete patches.arch/arm-OMAP-Fix-missing-usb.h-include.patch.
  (no longer needed)
- Delete patches.arch/arm-arndale-usb.patch. (no longer needed)
- Delete
  patches.arch/arm64-0006-arm64-Select-reboot-driver-for-X-Gene-platform.patch.
  (not needed, our config already includes the driver)
- Delete patches.arch/ppc64le-build-vmlinux.patch. (no longer needed)
- commit 986bfef
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.suse/binutils2_26.patch.
  The issue addressed by this patch should be handled via upstream
  commit 6d92bc9d483 (x86/build: Build compressed x86 kernels as PIE).
- commit 4e90692
* Tue Oct  3 2017 msuchanek@suse.de
- ctcm_fsms: Convert skb->user accesses to refcount_t (fix
  s390x build).
- commit 3dd2c06
* Tue Oct  3 2017 jeffm@suse.com
- Delete
  patches.suse/btrfs-account-for-pinned-bytes-in-should_alloc_chunk.patch.
- commit bc115ae
* Tue Oct  3 2017 msuchanek@suse.de
- Refresh vanilla config.
- commit e14f2e8
* Tue Oct  3 2017 mgorman@suse.de
- Delete patches.suse/connector-read-mostly.
- commit 038f6d3
* Tue Oct  3 2017 jeffm@suse.com
- series.conf: remove commented out lines for removed patches
- commit 2bff591
* Tue Oct  3 2017 mkubecek@suse.cz
- config: merge openSUSE configs from stable branch
- commit 2ed2011
* Tue Oct  3 2017 jeffm@suse.com
- Delete patches.arch/arm-refresh-mach-types.diff.
  It was marked for refresh in 12/2016 and hasn't been updated.
- commit d18cac1
* Tue Oct  3 2017 neilb@suse.com
- getcwd: Close race with d_move called by lustre (bsc#1052593).
- commit 930e552
* Mon Oct  2 2017 tbogendoerfer@suse.de
- qed: remove unnecessary call to memset (bsc#1050536
  FATE#322898).
- scsi: qedi: off by one in qedi_get_cmd_from_tid() (bsc#1050534
  FATE#322899).
- scsi: qedf: drop bus reset handler (bsc#1050530 FATE#322901).
- scsi: qedf: Update driver version to 8.20.5.0 (bsc#1050530
  FATE#322901).
- scsi: qedf: Fix up modinfo parameter name for 'debug' in
  modinfo output (bsc#1050530 FATE#322901).
- scsi: qedf: Covert single-threaded workqueues to regular
  workqueues (bsc#1050530 FATE#322901).
- scsi: qedf: Corrent VLAN tag insertion in fallback VLAN case
  (bsc#1050530 FATE#322901).
- scsi: qedf: Use granted MAC from the FCF for the FCoE source
  address if it is available (bsc#1050530 FATE#322901).
- scsi: qedf: Set WWNN and WWPN based on values from qed
  (bsc#1050530 FATE#322901).
- scsi: qedi: Limit number for CQ queues (bsc#1050534
  FATE#322899).
- qed: fix spelling mistake: "calescing" -> "coalescing"
  (bsc#1050536 FATE#322898).
- qed: enhanced per queue max coalesce value (bsc#1050536
  FATE#322898).
- qed: Read per queue coalesce from hardware (bsc#1050536
  FATE#322898).
- qed: Add support for vf coalesce configuration (bsc#1050536
  FATE#322898).
- qede: Add ethtool support for Energy efficient ethernet
  (bsc#1050538 FATE#322897).
- qed: Add support for Energy efficient ethernet (bsc#1050536
  FATE#322898).
- qed/qede: Add setter APIs support for RX flow classification
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qede: Add getter APIs support for RX flow classification
  (bsc#1050538 FATE#322897).
- RDMA/qedr: fix spelling mistake: "invlaid" -> "invalid"
  (bsc#1050545 FATE#322893).
- RDMA/qedr: notify user application of supported WIDs
  (bsc#1050545 FATE#322893).
- RDMA/qedr: notify user application if DPM is supported
  (bsc#1050545 FATE#322893).
- commit a0c198b
* Mon Oct  2 2017 msuchanek@suse.de
- powerpc/eeh: Create PHB PEs after EEH is initialized
  (bsc#1055120, git-fixes 5cb1f8fdddb7).
- commit d07b84d
* Mon Oct  2 2017 tbogendoerfer@suse.de
- net: sched: cls_flower: fix ndo_setup_tc type for stats call
  (bsc#1056787).
- commit f625cbb
* Mon Oct  2 2017 msuchanek@suse.de
- powerpc/perf: Factor out PPMU_ONLY_COUNT_RUN check code from
  power8 (fate#321438, git-fixes efe881afdd999, bsc#1056686).
- commit 9850b2a
* Mon Oct  2 2017 jslaby@suse.cz
- driver core: platform: fix race condition with driver_override
  (bnc#1060662).
- RDMA/uverbs: Check port number supplied by user verbs cmds
  (bnc#1060662).
- usb: dwc3: replace %%p with %%pK (bnc#1060662).
- USB: serial: cp210x: add ID for CEL EM3588 USB ZigBee stick
  (bnc#1060662).
- usb: usbip: set buffer pointers to NULL after free
  (bnc#1060662).
- Add USB quirk for HVR-950q to avoid intermittent device resets
  (bnc#1060662).
- usb: Fix typo in the definition of Endpoint[out]Request
  (bnc#1060662).
- USB: core: fix device node leak (bnc#1060662).
- USB: serial: option: add two Longcheer device ids (bnc#1060662).
- USB: serial: qcserial: new Sierra Wireless EM7305 device ID
  (bnc#1060662).
- xhci: Limit USB2 port wake support for AMD Promontory hosts
  (bnc#1060662).
- gfs2: Fix glock rhashtable rcu bug (bnc#1060662).
- Add "shutdown" to "struct class" (bnc#1060662).
- tpm: Issue a TPM2_Shutdown for TPM2 devices (bnc#1060662).
- tpm: fix a kernel memory leak in tpm-sysfs.c (bnc#1060662).
- powerpc/powernv: Fix CPU_HOTPLUG=n idle.c compile error
  (bnc#1060662).
- x86/uaccess: Optimize copy_user_enhanced_fast_string() for
  short strings (bnc#1060662).
- sched/fair, cpumask: Export for_each_cpu_wrap() (bnc#1060662).
- sched/core: Implement new approach to scale select_idle_cpu()
  (bnc#1060662).
- sched/numa: Use down_read_trylock() for the mmap_sem
  (bnc#1060662).
- sched/numa: Override part of migrate_degrades_locality()
  when idle balancing (bnc#1060662).
- sched/fair: Simplify wake_affine() for the single socket case
  (bnc#1060662).
- sched/numa: Implement NUMA node level wake_affine()
  (bnc#1060662).
- sched/fair: Remove effective_load() (bnc#1060662).
- sched/numa: Hide numa_wake_affine() from UP build (bnc#1060662).
- xen: avoid deadlock in xenbus driver (bnc#1060662).
- crypto: drbg - Fixes panic in wait_for_completion call
  (bnc#1060662).
- Linux 4.12.1 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.1.
  Expand 4.12.1.
- commit 4505d70
* Mon Oct  2 2017 jslaby@suse.cz
- mqueue: fix a use-after-free in sys_mq_notify() (bnc#1060662).
- imx-serial: RX DMA startup latency (bnc#1060662).
- proc: Fix proc_sys_prune_dcache to hold a sb reference
  (bnc#1060662).
- locking/rwsem-spinlock: Fix EINTR branch in
  __down_write_common() (bnc#1060662).
- staging: vt6556: vnt_start Fix missing call to
  vnt_key_init_table (bnc#1060662).
- staging: comedi: fix clean-up of comedi_class in comedi_init()
  (bnc#1060662).
- crypto: caam - fix gfp allocation flags (part I) (bnc#1060662).
- crypto: rsa-pkcs1pad - use constant time memory comparison
  for MACs (bnc#1060662).
- ext4: check return value of kstrtoull correctly in
  reserved_clusters_store (bnc#1060662).
- x86/mm/pat: Don't report PAT on CPUs that don't support it
  (bnc#1060662).
- Linux 4.12.2 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.1-2.
  Expand 4.12.2.
- commit ead2cb8
* Mon Oct  2 2017 jslaby@suse.cz
- staging: android: uapi: drop definitions of removed
  ION_IOC_{FREE,SHARE} ioctls (bnc#1060662).
- net/mlx5: Fix driver load error flow when firmware is stuck
  (bnc#1060662).
- net/mlx5: Cancel delayed recovery work when unloading the driver
  (bnc#1060662).
- net/mlx5e: Fix TX carrier errors report in get stats ndo
  (bnc#1060662).
- ipv6: dad: don't remove dynamic addresses if link is down
  (bnc#1060662).
- vxlan: fix hlist corruption (bnc#1060662).
- geneve: fix hlist corruption (bnc#1060662).
- net: core: Fix slab-out-of-bounds in netdev_stats_to_stats64
  (bnc#1060662).
- liquidio: fix bug in soft reset failure detection (bnc#1060662).
- net: ipv6: Compare lwstate in detecting duplicate nexthops
  (bnc#1060662).
- vrf: fix bug_on triggered by rx when destroying a vrf
  (bnc#1060662).
- virtio-net: fix leaking of ctx array (bnc#1060662).
- rds: tcp: use sock_create_lite() to create the accept socket
  (bnc#1060662).
- net/mlx5e: Initialize CEE's getpermhwaddr address buffer to 0xff
  (bnc#1060662).
- cxgb4: fix BUG() on interrupt deallocating path of ULD
  (bnc#1060662).
- tap: convert a mutex to a spinlock (bnc#1060662).
- bridge: mdb: fix leak on complete_info ptr on fail path
  (bnc#1060662).
- brcmfmac: fix possible buffer overflow in
  brcmf_cfg80211_mgmt_tx() (bnc#1060662 CVE-2017-7541
  bsc#1049645).
- sfc: don't read beyond unicast address list (bnc#1060662).
- Adding asm-prototypes.h for genksyms to generate crc
  (bnc#1060662).
- sed regex in Makefile.build requires line break between exported
  symbols (bnc#1060662).
- Adding the type of exported symbols (bnc#1060662).
- sparc64: Fix gup_huge_pmd (bnc#1060662).
- brcmfmac: Fix a memory leak in error handling path in
  'brcmf_cfg80211_attach' (bnc#1060662).
- brcmfmac: Fix glom_skb leak in brcmf_sdiod_recv_chain
  (bnc#1060662).
- efi: Process the MEMATTR table only if EFI_MEMMAP is enabled
  (bnc#1060662).
- cfg80211: Define nla_policy for
  NL80211_ATTR_LOCAL_MESH_POWER_MODE (bnc#1060662).
- cfg80211: Validate frequencies nested in
  NL80211_ATTR_SCAN_FREQUENCIES (bnc#1060662).
- cfg80211: Check if PMKID attribute is of expected size
  (bnc#1060662).
- cfg80211: Check if NAN service ID is of expected size
  (bnc#1060662).
- drm/amdgpu/gfx6: properly cache mc_arb_ramcfg (bnc#1060662).
- KVM: ARM64: fix phy counter access failure in guest
  (bnc#1060662).
- KVM: PPC: Book3S: Fix typo in XICS-on-XIVE state saving code
  (bnc#1060662).
- kvm-vfio: Decouple only when we match a group (bnc#1060662).
- irqchip/gic-v3: Fix out-of-bound access in gic_set_affinity
  (bnc#1060662).
- parisc: Report SIGSEGV instead of SIGBUS when running out of
  stack (bnc#1060662).
- parisc: use compat_sys_keyctl() (bnc#1060662).
- parisc: DMA API: return error instead of BUG_ON for dma ops
  on non dma devs (bnc#1060662).
- parisc/mm: Ensure IRQs are off in switch_mm() (bnc#1060662).
- tools/lib/lockdep: Reduce MAX_LOCK_DEPTH to avoid overflowing
  lock_chain/: Depth (bnc#1060662).
- compiler, clang: always inline when CONFIG_OPTIMIZE_INLINING
  is disabled (bnc#1060662).
- thp, mm: fix crash due race in MADV_FREE handling (bnc#1060662).
- kernel/extable.c: mark core_kernel_text notrace (bnc#1060662).
- mm/list_lru.c: fix list_lru_count_node() to be race free
  (bnc#1060662).
- fs/dcache.c: fix spin lockup issue on nlru->lock (bnc#1060662).
- checkpatch: silence perl 5.26.0 unescaped left brace warnings
  (bnc#1060662).
- binfmt_elf: use ELF_ET_DYN_BASE only for PIE (bnc#1060662).
- arm: move ELF_ET_DYN_BASE to 4MB (bnc#1060662).
- arm64: move ELF_ET_DYN_BASE to 4GB / 4MB (bnc#1060662).
- powerpc: move ELF_ET_DYN_BASE to 4GB / 4MB (bnc#1060662).
- s390: reduce ELF_ET_DYN_BASE (bnc#1060662).
- exec: Limit arg stack to at most 75%% of _STK_LIM (bnc#1060662).
- powerpc/kexec: Fix radix to hash kexec due to IAMR/AMOR
  (bnc#1060662).
- ARM64: dts: marvell: armada37xx: Fix timer interrupt specifiers
  (bnc#1060662).
- arm64: Preventing READ_IMPLIES_EXEC propagation (bnc#1060662).
- vt: fix unchecked __put_user() in tioclinux ioctls
  (bnc#1060662).
- rcu: Add memory barriers for NOCB leader wakeup (bnc#1060662).
- nvmem: core: fix leaks on registration errors (bnc#1060662).
- Drivers: hv: vmbus: Close timing hole that can corrupt per-cpu
  page (bnc#1060662).
- mnt: In umount propagation reparent in a separate pass
  (bnc#1060662).
- mnt: In propgate_umount handle visiting mounts in any order
  (bnc#1060662).
- mnt: Make propagate_umount less slow for overlapping mount
  propagation trees (bnc#1060662).
- selftests/capabilities: Fix the test_execve test (bnc#1060662).
- mm: fix overflow check in expand_upwards() (bnc#1060662).
- crypto: talitos - Extend max key length for SHA384/512-HMAC
  and AEAD (bnc#1060662).
- crypto: atmel - only treat EBUSY as transient if backlog
  (bnc#1060662).
- crypto: sha1-ssse3 - Disable avx2 (bnc#1060662).
- crypto: caam - properly set IV after {en,de}crypt (bnc#1060662).
- crypto: caam - fix signals handling (bnc#1060662).
- KEYS: DH: validate __spare field (bnc#1060662).
- sched/headers/uapi: Fix linux/sched/types.h userspace
  compilation errors (bnc#1060662).
- sched/topology: Fix building of overlapping sched-groups
  (bnc#1060662).
- sched/topology: Optimize build_group_mask() (bnc#1060662).
- sched/topology: Fix overlapping sched_group_mask (bnc#1060662).
- PM / wakeirq: Convert to SRCU (bnc#1060662).
- pstore: Fix leaked pstore_record in pstore_get_backend_records()
  (bnc#1060662).
- ALSA: x86: Clear the pdata.notify_lpe_audio pointer before
  teardown (bnc#1060662).
- ALSA: hda/realtek - change the location for one of two front
  microphones (bnc#1060662).
- PM / QoS: return -EINVAL for bogus strings (bnc#1060662).
- kvm: vmx: Do not disable intercepts for BNDCFGS (bnc#1060662).
- kvm: x86: Guest BNDCFGS requires guest MPX support
  (bnc#1060662).
- kvm: vmx: Check value written to IA32_BNDCFGS (bnc#1060662).
- kvm: vmx: allow host to access guest MSR_IA32_BNDCFGS
  (bnc#1060662).
- Linux 4.12.3 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.2-3.
  Expand 4.12.3.
- commit bebe2f3
* Mon Oct  2 2017 tbogendoerfer@suse.de
- Update config files.
- commit 7cd64fe
* Mon Oct  2 2017 tbogendoerfer@suse.de
- bnxt_re: Don't issue cmd to delete GID for QP1 GID entry before
  the QP is destroyed (bsc#1050244 FATE#322915).
- bnxt_re: Fix memory leak in FRMR path (bsc#1050244 FATE#322915).
- bnxt_re: Remove RTNL lock dependency in bnxt_re_query_port
  (bsc#1050244 FATE#322915).
- bnxt_re: Fix race between the netdev register and unregister
  events (bsc#1050244 FATE#322915).
- bnxt_re: Free up devices in module_exit path (bsc#1050244
  FATE#322915).
- bnxt_re: Fix compare and swap atomic operands (bsc#1050244
  FATE#322915).
- bnxt_re: Stop issuing further cmds to FW once a cmd times out
  (bsc#1050244 FATE#322915).
- bnxt_re: Fix update of qplib_qp.mtu when modified (bsc#1050244
  FATE#322915).
- IB/bnxt_re: Fix frame stack compilation warning (bsc#1050244
  FATE#322915).
- commit 28ebe60
* Mon Oct  2 2017 tbogendoerfer@suse.de
- bnxt_en: check for ingress qdisc in flower offload (bsc#1050242
  FATE#32291).
- bnxt_en: add a dummy definition for bnxt_vf_rep_get_fid()
  (bsc#1050242 FATE#32291).
- bnxt_en: add code to query TC flower offload stats (bsc#1050242
  FATE#32291).
- bnxt_en: add TC flower offload flow_alloc/free FW cmds
  (bsc#1050242 FATE#32291).
- bnxt_en: bnxt: add TC flower filter offload support (bsc#1050242
  FATE#32291).
- bnxt_en: Reduce default rings on multi-port cards (bsc#1050242
  FATE#32291).
- bnxt_en: Improve -ENOMEM logic in NAPI poll loop (bsc#1050242
  FATE#32291).
- bnxt: initialize board_info values with proper enums
  (bsc#1050242 FATE#32291).
- bnxt: Add PCIe device IDs for bcm58802/bcm58808 (bsc#1050242
  FATE#32291).
- bnxt_en: assign CPU affinity hints to bnxt_en IRQs (bsc#1050242
  FATE#322914).
- bnxt_en: Improve tx ring reservation logic (bsc#1050242
  FATE#322914).
- bnxt_en: Update firmware interface spec. to 1.8.1.4 (bsc#1050242
  FATE#322914).
- bnxt_en: fix spelling mistake: "swtichdev" -> "switchdev"
  (bsc#1050242 FATE#322914).
- commit a61ddf9
* Mon Oct  2 2017 jslaby@suse.cz
- disable new gcc-7.1.1 warnings for now (bnc#1060662).
- ir-core: fix gcc-7 warning on bool arithmetic (bnc#1060662).
- s5p-jpeg: don't return a random width/height (bnc#1060662).
- thermal: max77620: fix device-node reference imbalance
  (bnc#1060662).
- thermal: cpu_cooling: Avoid accessing potentially freed
  structures (bnc#1060662).
- ath9k: fix tx99 use after free (bnc#1060662).
- ath9k: fix tx99 bus error (bnc#1060662).
- ath9k: fix an invalid pointer dereference in ath9k_rng_stop()
  (bnc#1060662).
- iwlwifi: mvm: fix the recovery flow while connecting
  (bnc#1060662).
- NFC: fix broken device allocation (bnc#1060662).
- NFC: nfcmrvl_uart: add missing tty-device sanity check
  (bnc#1060662).
- NFC: nfcmrvl: do not use device-managed resources (bnc#1060662).
- NFC: nfcmrvl: use nfc-device for firmware download
  (bnc#1060662).
- NFC: nfcmrvl: fix firmware-management initialisation
  (bnc#1060662).
- nfc: Ensure presence of required attributes in the
  activate_target handler (bnc#1060662).
- nfc: Fix the sockaddr length sanitization in llcp_sock_connect
  (bnc#1060662).
- NFC: Add sockaddr length checks before accessing sa_family in
  bind handlers (bnc#1060662).
- perf intel-pt: Move decoder error setting into one condition
  (bnc#1060662).
- perf intel-pt: Improve sample timestamp (bnc#1060662).
- perf intel-pt: Fix missing stack clear (bnc#1060662).
- perf intel-pt: Ensure IP is zero when state is
  INTEL_PT_STATE_NO_IP (bnc#1060662).
- perf intel-pt: Fix last_ip usage (bnc#1060662).
- perf intel-pt: Ensure never to set 'last_ip' when packet
  'count' is zero (bnc#1060662).
- perf intel-pt: Use FUP always when scanning for an IP
  (bnc#1060662).
- perf intel-pt: Clear FUP flag on error (bnc#1060662).
- Bluetooth: use constant time memory comparison for secret values
  (bnc#1060662).
- wlcore: fix 64K page support (bnc#1060662).
- pstore: Don't warn if data is uncompressed and type is not
  PSTORE_TYPE_DMESG (bnc#1060662).
- mwifiex: fixup error cases in mwifiex_add_virtual_intf()
  (bnc#1060662).
- Btrfs: fix invalid extent maps due to hole punching
  (bnc#1060662).
- btrfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- Btrfs: incremental send, fix invalid memory access
  (bnc#1060662).
- igb: Explicitly select page 0 at initialization (bnc#1060662).
- spi: atmel: fix corrupted data issue on SAM9 family SoCs
  (bnc#1060662).
- ASoC: zx-i2s: flip I2S master/slave mode (bnc#1060662).
- ASoC: compress: Derive substream from stream based on direction
  (bnc#1060662).
- ASoC: atmel: tse850: fix off-by-one in the "ANA" enumeration
  count (bnc#1060662).
- PM / Domains: Fix unsafe iteration over modified list of device
  links (bnc#1060662).
- PM / Domains: Fix unsafe iteration over modified list of domain
  providers (bnc#1060662).
- PM / Domains: Fix unsafe iteration over modified list of domains
  (bnc#1060662).
- scsi: ses: do not add a device to an enclosure if
  enclosure_add_links() fails (bnc#1060662).
- scsi: virtio_scsi: let host do exception handling (bnc#1060662).
- scsi: qla2xxx: Allow ABTS, PURX, RIDA on ATIOQ for ISP83XX/27XX
  (bnc#1060662).
- scsi: Add STARGET_CREATED_REMOVE state to scsi_target_state
  (bnc#1060662).
- scsi: Avoid that scsi_exit_rq() triggers a use-after-free
  (bnc#1060662).
- iscsi-target: Add login_keys_workaround attribute for non RFC
  initiators (bnc#1060662).
- xen/scsiback: Fix a TMR related use-after-free (bnc#1060662).
- scsi: virtio_scsi: always read VPD pages for multiqueue too
  (bnc#1060662).
- powerpc/mm/radix: Only add X for pages overlapping kernel text
  (bnc#1060662).
- powerpc/pseries: Fix passing of pp0 in updatepp() and
  updateboltedpp() (bnc#1060662).
- powerpc/mm/radix: Fix execute permissions for interrupt_vectors
  (bnc#1060662).
- powerpc/64: Fix atomic64_inc_not_zero() to return an int
  (bnc#1060662).
- powerpc: Fix emulation of mcrf in emulate_step() (bnc#1060662).
- powerpc: Fix emulation of mfocrf in emulate_step()
  (bnc#1060662).
- powerpc/asm: Mark cr0 as clobbered in mftb() (bnc#1060662).
- powerpc/mm/radix: Properly clear process table entry
  (bnc#1060662).
- powerpc/perf: Fix SDAR_MODE value for continous sampling on
  Power9 (bnc#1060662).
- xen/x86: fix cpu hotplug (bnc#1060662).
- PCI: vmd: Move SRCU cleanup after bus, child device removal
  (bnc#1060662).
- PCI: Work around poweroff & suspend-to-RAM issue on Macbook
  Pro 11 (bnc#1060662).
- PCI: rockchip: Use normal register bank for config accessors
  (bnc#1060662).
- PCI/PM: Restore the status of PCI devices across hibernation
  (bnc#1060662).
- PCI/MSI: Ignore affinity if pre/post vector count is more than
  min_vecs (bnc#1060662).
- usb: xhci: fix spinlock recursion for USB2 test mode
  (bnc#1060662).
- xhci: fix memleak in xhci_run() (bnc#1060662).
- xhci: fix 20000ms port resume timeout (bnc#1060662).
- xhci: Fix NULL pointer dereference when cleaning up streams
  for removed host (bnc#1060662).
- xhci: Bad Ethernet performance plugged in ASM1042A host
  (bnc#1060662).
- mxl111sf: Fix driver to use heap allocate buffers for USB
  messages (bnc#1060662).
- usb: storage: return on error to avoid a null pointer
  dereference (bnc#1060662).
- USB: cdc-acm: add device-id for quirky printer (bnc#1060662).
- usb: renesas_usbhs: fix usbhsc_resume() for
  !USBHSF_RUNTIME_PWCTRL (bnc#1060662).
- usb: renesas_usbhs: gadget: disable all eps when the driver
  stops (bnc#1060662).
- HID: multitouch: do not blindly set EV_KEY or EV_ABS bits
  (bnc#1060662).
- md: don't use flush_signals in userspace processes
  (bnc#1060662).
- md: fix deadlock between mddev_suspend() and md_write_start()
  (bnc#1060662).
- x86/xen: allow userspace access during hypercalls (bnc#1060662).
- cx88: Fix regression in initial video standard setting
  (bnc#1060662).
- rc-core: fix input repeat handling (bnc#1060662).
- tools/testing/nvdimm: fix nfit_test buffer overflow
  (bnc#1060662).
- libnvdimm, btt: fix btt_rw_page not returning errors
  (bnc#1060662).
- libnvdimm: fix the clear-error check in nsio_rw_bytes
  (bnc#1060662).
- libnvdimm: fix badblock range handling of ARS range
  (bnc#1060662).
- ext2: Don't clear SGID when inheriting ACLs (bnc#1060662).
- dm raid: stop using BUG() in __rdev_sectors() (bnc#1060662).
- Raid5 should update rdev->sectors after reshape (bnc#1060662).
- s390/syscalls: Fix out of bounds arguments access (bnc#1060662).
- drm/amdgpu/gfx8: drop per-APU CU limits (bnc#1060662).
- drm/amdgpu: fix vblank_time when displays are off (bnc#1060662).
- drm/amdgpu/cgs: always set reference clock in mode_info
  (bnc#1060662).
- drm/amd/amdgpu: Return error if initiating read out of range
  on vram (bnc#1060662).
- drm/amdgpu: fix the memory corruption on S3 (bnc#1060662).
- drm/amdgpu: Don't call amd_powerplay_destroy() if we don't
  have powerplay (bnc#1060662).
- drm/radeon/ci: disable mclk switching for high refresh rates
  (v2) (bnc#1060662).
- drm/radeon: Fix eDP for single-display iMac10,1 (v2)
  (bnc#1060662).
- drm/ttm: Fix use-after-free in ttm_bo_clean_mm (bnc#1060662).
- drm/etnaviv: Expose our reservation object when exporting a
  dmabuf (bnc#1060662).
- ipmi: use rcu lock around call to intf->handlers->sender()
  (bnc#1060662).
- ipmi:ssif: Add missing unlock in error branch (bnc#1060662).
- xfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- CIFS: Reconnect expired SMB sessions (bnc#1060662).
- f2fs: load inode's flag from disk (bnc#1060662).
- f2fs: wake up all waiters in f2fs_submit_discard_endio
  (bnc#1060662).
- f2fs: sanity check checkpoint segno and blkoff (bnc#1060662).
- f2fs: try to freeze in gc and discard threads (bnc#1060662).
- f2fs: Do not issue small discards in LFS mode (bnc#1060662).
- f2fs: sanity check size of nat and sit cache (bnc#1060662).
- f2fs: use spin_{,un}lock_irq{save,restore} (bnc#1060662).
- f2fs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- serial: st-asc: Potential error pointer dereference
  (bnc#1060662).
- serial: sh-sci: Uninitialized variables in sysfs files
  (bnc#1060662).
- ovl: mark parent impure on ovl_link() (bnc#1060662).
- ovl: fix random return value on mount (bnc#1060662).
- drm/amd/powerplay: fix memory leak in cz_hwmgr backend
  (bnc#1060662).
- drm/i915: Disable MSI for all pre-gen5 (bnc#1060662).
- vfio: Fix group release deadlock (bnc#1060662).
- vfio: New external user group/file match (bnc#1060662).
- vfio: Remove unnecessary uses of vfio_container.group_lock
  (bnc#1060662).
- nvme-rdma: remove race conditions from IB signalling
  (bnc#1060662).
- ftrace: Fix uninitialized variable in match_records()
  (bnc#1060662).
- iommu/arm-smmu: Plumb in new ACPI identifiers (bnc#1060662).
- drm/i915/gvt: Fix inconsistent locks holding sequence
  (bnc#1060662).
- drm/atomic: Add missing drm_atomic_state_clear to
  atomic_remove_fb (bnc#1060662).
- MIPS: Fix mips_atomic_set() retry condition (bnc#1060662).
- MIPS: Fix mips_atomic_set() with EVA (bnc#1060662).
- MIPS: Negate error syscall return in trace (bnc#1060662).
- mtd: nand: tango: Fix incorrect use of SEQIN command
  (bnc#1060662).
- ubifs: Correctly evict xattr inodes (bnc#1060662).
- ubifs: Don't leak kernel memory to the MTD (bnc#1060662).
- ubifs: Don't encrypt special files on creation (bnc#1060662).
- ubifs: Set double hash cookie also for RENAME_EXCHANGE
  (bnc#1060662).
- ACPI / EC: Drop EC noirq hooks to fix a regression
  (bnc#1060662).
- Revert "ACPI / EC: Enable event freeze mode..." to fix a
  regression (bnc#1060662).
- x86/acpi: Prevent out of bound access caused by broken ACPI
  tables (bnc#1060662 CVE-2017-11473 bsc#1049603).
- x86/ioapic: Pass the correct data to unmask_ioapic_irq()
  (bnc#1060662).
- MIPS: Fix MIPS I ISA /proc/cpuinfo reporting (bnc#1060662).
- MIPS: Save static registers before sysmips (bnc#1060662).
- MIPS: Actually decode JALX in `__compute_return_epc_for_insn'
  (bnc#1060662).
- MIPS: Fix unaligned PC interpretation in `compute_return_epc'
  (bnc#1060662).
- MIPS: math-emu: Prevent wrong ISA mode instruction emulation
  (bnc#1060662).
- MIPS: Send SIGILL for BPOSGE32 in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Rename `sigill_r6' to `sigill_r2r6' in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Send SIGILL for linked branches in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Send SIGILL for R6 branches in
  `__compute_return_epc_for_insn' (bnc#1060662).
- MIPS: Fix a typo: s/preset/present/ in r2-to-r6 emulation
  error message (bnc#1060662).
- Input: i8042 - fix crash at boot time (bnc#1060662).
- IB/iser: Fix connection teardown race condition (bnc#1060662).
- IB/core: Namespace is mandatory input for address resolution
  (bnc#1060662).
- sunrpc: use constant time memory comparison for mac
  (bnc#1060662).
- net/sunrpc/xprt_sock: fix regression in connection error
  reporting (bnc#1060662).
- NFS: Fix initialization of nfs_page_array->npages (bnc#1060662).
- PNFS fix EACCESS on commit to DS handling (bnc#1060662).
- NFS: only invalidate dentrys that are clearly invalid
  (bnc#1060662 bsc#1047118).
- udf: Fix races with i_size changes during readpage
  (bnc#1060662).
- udf: Fix deadlock between writeback and udf_setsize()
  (bnc#1060662).
- target: Fix COMPARE_AND_WRITE caw_sem leak during se_cmd quiesce
  (bnc#1060662).
- iser-target: Avoid isert_conn->cm_id dereference in
  isert_login_recv_done (bnc#1060662).
- perf annotate: Fix broken arrow at row 0 connecting jmp
  instruction to its target (bnc#1060662).
- perf/core: Fix scheduling regression of pinned groups
  (bnc#1060662).
- Revert "perf/core: Drop kernel samples even though :u is
  specified" (bnc#1060662).
- staging: rtl8188eu: add TL-WN722N v2 support (bnc#1060662).
- staging: comedi: ni_mio_common: fix AO timer off-by-one
  regression (bnc#1060662).
- staging: sm750fb: avoid conflicting vesafb (bnc#1060662).
- staging: lustre: ko2iblnd: check copy_from_iter/copy_to_iter
  return code (bnc#1060662).
- ceph: fix race in concurrent readdir (bnc#1060662).
- RDMA/uverbs: Fix the check for port number (bnc#1060662).
- RDMA/core: Initialize port_num in qp_attr (bnc#1060662).
- drm/mst: Fix error handling during MST sideband message
  reception (bnc#1060662).
- drm/mst: Avoid dereferencing a NULL mstb in
  drm_dp_mst_handle_up_req() (bnc#1060662).
- drm/mst: Avoid processing partially received up/down message
  transactions (bnc#1060662).
- drm/i915: Make DP-MST connector info work (bnc#1060662).
- mlx5: Avoid that mlx5_ib_sg_to_klms() overflows the klms[]
  array (bnc#1060662).
- hfsplus: Don't clear SGID when inheriting ACLs (bnc#1060662).
- vtime, sched/cputime: Remove vtime_account_user() (bnc#1060662
  bnc#978907).
- sched/cputime: Always set tsk->vtime_snap_whence after
  accounting vtime (bnc#1060662 bnc#978907).
- sched/cputime: Rename vtime fields (bnc#1060662 bnc#978907).
- sched/cputime: Move the vtime task fields to their own struct
  (bnc#1060662 bnc#978907).
- sched/cputime: Accumulate vtime on top of nsec clocksource
  (bnc#1060662 bnc#978907).
- sched/fair: Fix load_balance() affinity redo path (bnc#1060662
  bnc#978907).
- percpu_counter: Rename __percpu_counter_add to
  percpu_counter_add_batch (bnc#1060662 bnc#971975).
- writeback: rework wb_[dec|inc]_stat family of functions
  (bnc#1060662 bnc#971975).
- kernel/fork.c: virtually mapped stacks: do not disable
  interrupts (bnc#1060662 bnc#978907).
- acpi/nfit: Fix memory corruption/Unregister mce decoder on
  failure (bnc#1060662).
- vmbus: re-enable channel tasklet (bnc#1060662).
- cpufreq: intel_pstate: Correct the busy calculation for KNL
  (bnc#1060662).
- spmi: Include OF based modalias in device uevent (bnc#1060662).
- reiserfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- device-dax: fix sysfs duplicate warnings (bnc#1060662).
- drm/imx: parallel-display: Accept drm_of_find_panel_or_bridge
  failure (bnc#1060662).
- PM / Domains: defer dev_pm_domain_set() until genpd->attach_dev
  succeeds if present (bnc#1060662).
- tracing: Fix kmemleak in instance_rmdir (bnc#1060662).
- drm/i915/fbdev: Check for existence of ifbdev->vma before
  operations (bnc#1060662).
- drm/i915: Hold RPM wakelock while initializing OA buffer
  (bnc#1060662).
- drm/i915: reintroduce VLV/CHV PFI programming power domain
  workaround (bnc#1060662).
- smp/hotplug: Move unparking of percpu threads to the control
  CPU (bnc#1060662).
- smp/hotplug: Replace BUG_ON and react useful (bnc#1060662).
- alarmtimer: don't rate limit one-shot timers (bnc#1060662).
- sched/cputime: Don't use smp_processor_id() in preemptible
  context (bnc#1060662).
- Linux 4.12.4 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.3-4.
  Expand 4.12.4.
- commit 9cb5903
* Mon Oct  2 2017 jthumshirn@suse.de
- scsi: qla2xxx: add missing includes for qla_isr (FATE#322910).
  Refresh
  patches.drivers/0036-scsi-qla2xxx-Add-FC-NVMe-command-handling.patch.
- commit 474a2df
* Mon Oct  2 2017 jthumshirn@suse.de
- scsi: aacraid: Add a small delay after IOP reset (FATE#322889,
  bsc#1049519).
- commit 2a43d5a
* Mon Oct  2 2017 jthumshirn@suse.de
- series.conf: fix patch ordering
- commit affbdfb
* Mon Oct  2 2017 jslaby@suse.cz
- jfs: Don't clear SGID when inheriting ACLs (bnc#1060662).
- ALSA: fm801: Initialize chip after IRQ handler is registered
  (bnc#1060662 bsc#1051510).
- ALSA: hda - Add missing NVIDIA GPU codec IDs to patch table
  (bnc#1060662).
- ALSA: hda - Add mute led support for HP ProBook 440 G4
  (bnc#1060662).
- parisc: Prevent TLB speculation on flushed pages on CPUs that
  only support equivalent aliases (bnc#1060662).
- parisc: Extend disabled preemption in copy_user_page
  (bnc#1060662).
- parisc: Suspend lockup detectors before system halt
  (bnc#1060662).
- powerpc/pseries: Fix of_node_put() underflow during reconfig
  remove (bnc#1060662).
- mmc: sunxi: Keep default timing phase settings for new timing
  mode (bnc#1060662).
- NFS: invalidate file size when taking a lock (bnc#1060662).
- NFSv4.1: Fix a race where CB_NOTIFY_LOCK fails to wake a waiter
  (bnc#1060662).
- scripts/dtc: dtx_diff - update include dts paths to match build
  (bnc#1060662).
- crypto: brcm - Fix SHA3-512 algorithm failure (bnc#1060662).
- crypto: brcm - remove BCM_PDC_MBOX dependency in Kconfig
  (bnc#1060662).
- crypto: authencesn - Fix digest_null crash (bnc#1060662).
- KVM: PPC: Book3S HV: Enable TM before accessing TM registers
  (bnc#1060662).
- KVM: PPC: Book3S HV: Fix host crash on changing HPT size
  (bnc#1060662).
- dm integrity: fix inefficient allocation of journal space
  (bnc#1060662).
- dm integrity: test for corrupted disk format during table load
  (bnc#1060662).
- md: remove 'idx' from 'struct resync_pages' (bnc#1060662
  bsc#1049599).
- md/raid1: fix writebehind bio clone (bnc#1060662).
- md/raid5: add thread_group worker async_tx_issue_pending_all
  (bnc#1060662).
- drm/vmwgfx: Fix gcc-7.1.1 warning (bnc#1060662).
- drm/vmwgfx: Limit max desktop dimensions to 8Kx8K (bnc#1060662).
- drm/nouveau/disp/nv50-: bump max chans to 21 (bnc#1060662).
- drm/nouveau/bar/gf100: fix access to upper half of BAR2
  (bnc#1060662).
- drm/i915: Fix scaler init during CRTC HW state readout
  (bnc#1060662).
- isdn/i4l: fix buffer overflow (bnc#1060662).
- ipmi/watchdog: fix watchdog timeout set on reboot (bnc#1060662).
- dentry name snapshots (bnc#1060662 bsc#1049483).
- mmc: tmio-mmc: fix bad pointer math (bnc#1060662).
- Linux 4.12.5 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.4-5.
  Expand 4.12.5.
- commit d481b6d
* Mon Oct  2 2017 jeffm@suse.com
- Moved powerpc-Blacklist-GCC-5.4-6.1-and-6.2.patch to patches.rpmify.
  It's a compiler blacklist addition and should be applied to vanilla too.
- commit cfc7e71
* Mon Oct  2 2017 tbogendoerfer@suse.de
- iw_cxgb4: remove the stid on listen create failure (bsc#1046543
  FATE#322927).
- iw_cxgb4: drop listen destroy replies if no ep found
  (bsc#1046543 FATE#322927).
- iw_cxgb4: put ep reference in pass_accept_req() (bsc#1046543
  FATE#322927).
- commit b8f72a3
* Mon Oct  2 2017 jslaby@suse.cz
- parisc: Increase thread and stack size to 32kb (bnc#1060662).
- parisc: Handle vma's whose context is not current in
  flush_cache_range (bnc#1060662).
- scsi: lpfc: fix linking against modular NVMe support
  (bnc#1060662).
- ACPI / LPSS: Only call pwm_add_table() for the first PWM
  controller (bnc#1060662).
- cgroup: don't call migration methods if there are no tasks to
  migrate (bnc#1060662).
- cgroup: create dfl_root files on subsys registration
  (bnc#1060662).
- cgroup: fix error return value from cgroup_subtree_control()
  (bnc#1060662).
- libata: array underflow in ata_find_dev() (bnc#1060662).
- workqueue: restore WQ_UNBOUND/max_active==1 to be ordered
  (bnc#1060662).
- iwlwifi: dvm: prevent an out of bounds access (bnc#1060662).
- brcmfmac: fix memleak due to calling brcmf_sdiod_sgtable_alloc()
  twice (bnc#1060662).
- NFSv4: Fix EXCHANGE_ID corrupt verifier issue (bnc#1060662).
- mmc: sdhci-of-at91: force card detect value for non removable
  devices (bnc#1060662).
- mmc: core: Use device_property_read instead of of_property_read
  (bnc#1060662).
- mmc: dw_mmc: Use device_property_read instead of
  of_property_read (bnc#1060662).
- mm, mprotect: flush TLB if potentially racing with a parallel
  reclaim leaving stale TLB entries (bnc#1060662).
- mm/hugetlb.c: __get_user_pages ignores certain
  follow_hugetlb_page errors (bnc#1060662).
- userfaultfd: non-cooperative: notify about unmap of destination
  during mremap (bnc#1060662).
- userfaultfd_zeropage: return -ENOSPC in case mm has gone
  (bnc#1060662).
- userfaultfd: non-cooperative: flush event_wqh at release time
  (bnc#1060662).
- cpuset: fix a deadlock due to incomplete patching of
  cpusets_enabled() (bnc#1060662).
- ocfs2: don't clear SGID when inheriting ACLs (bnc#1060662).
- ALSA: hda - Fix speaker output from VAIO VPCL14M1R
  (bnc#1060662).
- drm/amdgpu: fix header on gfx9 clear state (bnc#1060662).
- drm/amdgpu: Fix undue fallthroughs in golden registers
  initialization (bnc#1060662).
- ASoC: fix pcm-creation regression (bnc#1060662).
- ASoC: ux500: Restore platform DAI assignments (bnc#1060662).
- ASoC: do not close shared backend dailink (bnc#1060662).
- KVM: arm/arm64: Handle hva aging while destroying the vm
  (bnc#1060662).
- KVM: async_pf: make rcu irq exit if not triggered from idle task
  (bnc#1060662).
- timers: Fix overflow in get_next_timer_interrupt (bnc#1060662).
- powerpc/tm: Fix saving of TM SPRs in core dump (bnc#1060662).
- powerpc/64: Fix __check_irq_replay missing decrementer interrupt
  (bnc#1060662).
- iommu/amd: Enable ga_log_intr when enabling guest_mode
  (bnc#1060662 bsc#1052533).
- ARM64: dts: marvell: armada-37xx: Fix the number of GPIO on
  south bridge (bnc#1060662).
- gpiolib: skip unwanted events, don't convert them to opposite
  edge (bnc#1060662).
- ext4: fix SEEK_HOLE/SEEK_DATA for blocksize < pagesize
  (bnc#1060662).
- ext4: fix overflow caused by missing cast in ext4_resize_fs()
  (bnc#1060662).
- MIPS: ralink: Fix build error due to missing header
  (bnc#1060662).
- clk: sunxi-ng: sun5i: Add clk_set_rate_parent to the CPU clock
  (bnc#1060662).
- ARM: mvebu: use __pa_symbol in the mv98dx3236 platform SMP code
  (bnc#1060662).
- ARM: dts: armada-38x: Fix irq type for pca955 (bnc#1060662).
- ARM: dts: tango4: Request RGMII RX and TX clock delays
  (bnc#1060662).
- media: pulse8-cec: persistent_config should be off by default
  (bnc#1060662).
- media: lirc: LIRC_GET_REC_RESOLUTION should return microseconds
  (bnc#1060662).
- media: platform: davinci: return -EINVAL for
  VPFE_CMD_S_CCDC_RAW_PARAMS ioctl (bnc#1060662).
- ir-spi: Fix issues with lirc API (bnc#1060662).
- tcmu: Fix flushing cmd entry dcache page (bnc#1060662).
- tcmu: Fix possbile memory leak / OOPs when recalculating cmd
  base size (bnc#1060662).
- ext4: preserve i_mode if __ext4_set_acl() fails (bnc#1060662).
- ext4: Don't clear SGID when inheriting ACLs (bnc#1060662).
- Btrfs: fix early ENOSPC due to delalloc (bnc#1060662).
- blk-mq: Include all present CPUs in the default queue mapping
  (bnc#1060662).
- blk-mq: Create hctx for each present CPU (bnc#1060662).
- block: disable runtime-pm for blk-mq (bnc#1060662).
- saa7164: fix double fetch PCIe access condition (bnc#1060662
  CVE-2017-8831 bsc#1037994).
- sctp: fix an array overflow when all ext chunks are set
  (bnc#1060662).
- tcp_bbr: cut pacing rate only if filled pipe (bnc#1060662).
- tcp_bbr: introduce bbr_bw_to_pacing_rate() helper (bnc#1060662).
- tcp_bbr: introduce bbr_init_pacing_rate_from_rtt() helper
  (bnc#1060662).
- tcp_bbr: remove sk_pacing_rate=0 transient during init
  (bnc#1060662).
- tcp_bbr: init pacing rate on first RTT sample (bnc#1060662).
- ipv4: ipv6: initialize treq->txhash in cookie_v[46]_check()
  (bnc#1060662).
- wireless: wext: terminate ifr name coming from userspace
  (bnc#1060662).
- net: Zero terminate ifr_name in dev_ifname() (bnc#1060662).
- net: dsa: mv88e6xxx: Enable CMODE config support for 6390X
  (bnc#1060662).
- Revert "rtnetlink: Do not generate notifications for CHANGEADDR
  event" (bnc#1060662).
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (bnc#1060662 CVE-2017-7542 bsc#1049882).
- net: dsa: b53: Add missing ARL entries for BCM53125
  (bnc#1060662).
- ipv4: initialize fib_trie prior to register_netdev_notifier call
  (bnc#1060662).
- rtnetlink: allocate more memory for dev_set_mac_address()
  (bnc#1060662).
- net: bonding: Fix transmit load balancing in balance-alb mode
  (bnc#1060662).
- mcs7780: Fix initialization when CONFIG_VMAP_STACK is enabled
  (bnc#1060662).
- openvswitch: fix potential out of bound access in parse_ct
  (bnc#1060662).
- packet: fix use-after-free in prb_retire_rx_blk_timer_expired()
  (bnc#1060662).
- ipv6: Don't increase IPSTATS_MIB_FRAGFAILS twice in
  ip6_fragment() (bnc#1060662).
- net: ethernet: nb8800: Handle all 4 RGMII modes identically
  (bnc#1060662).
- bonding: commit link status change after propose (bnc#1060662).
- dccp: fix a memleak that dccp_ipv6 doesn't put reqsk properly
  (bnc#1060662).
- dccp: fix a memleak that dccp_ipv4 doesn't put reqsk properly
  (bnc#1060662).
- dccp: fix a memleak for dccp_feat_init err process
  (bnc#1060662).
- net/mlx5: Consider tx_enabled in all modes on remap
  (bnc#1060662).
- net/mlx5: Fix command completion after timeout access invalid
  structure (bnc#1060662).
- net/mlx5: Fix command bad flow on command entry allocation
  failure (bnc#1060662).
- sctp: don't dereference ptr before leaving _sctp_walk_{params,
  errors}() (bnc#1060662).
- sctp: fix the check for _sctp_walk_params and _sctp_walk_errors
  (bnc#1060662).
- net/mlx5e: IPoIB, Modify add/remove underlay QPN flows
  (bnc#1060662).
- net/mlx5e: Fix outer_header_zero() check size (bnc#1060662).
- net/mlx5: Fix mlx5_ifc_mtpps_reg_bits structure size
  (bnc#1060662).
- net/mlx5e: Add field select to MTPPS register (bnc#1060662).
- net/mlx5e: Fix broken disable 1PPS flow (bnc#1060662).
- net/mlx5e: Change 1PPS out scheme (bnc#1060662).
- net/mlx5e: Add missing support for PTP_CLK_REQ_PPS request
  (bnc#1060662).
- net/mlx5e: Fix wrong delay calculation for overflow check
  scheduling (bnc#1060662).
- net/mlx5e: Schedule overflow check work to mlx5e workqueue
  (bnc#1060662).
- net/mlx5: Fix mlx5_add_flow_rules call with correct num of dests
  (bnc#1060662).
- udp6: fix socket leak on early demux (bnc#1060662).
- net: phy: Correctly process PHY_HALTED in phy_stop_machine()
  (bnc#1060662).
- workqueue: implicit ordered attribute should be overridable
  (bnc#1060662).
- ipv4: fib: Fix NULL pointer deref during fib_sync_down_dev()
  (bnc#1060662).
- virtio_net: fix truesize for mergeable buffers (bnc#1060662).
- sparc64: Measure receiver forward progress to avoid send mondo
  timeout (bnc#1060662).
- sparc64: Prevent perf from running during super critical
  sections (bnc#1060662).
- sparc64: Register hugepages during arch init (bnc#1060662).
- sparc64: Fix exception handling in UltraSPARC-III memcpy
  (bnc#1060662).
- drm/vmwgfx: Fix cursor hotspot issue with Wayland on Fedora
  (bnc#1060662).
- Linux 4.12.6 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.5-6.
  Expand 4.12.6.
- commit c435580
* Mon Oct  2 2017 tbogendoerfer@suse.de
- cxgb4: Ignore MPS_TX_INT_CAUSE for T6 (bsc#1046540 FATE#322930).
- cxgb4: Fix pause frame count in t4_get_port_stats (bsc#1046540
  FATE#322930).
- cxgb4: fix memory leak (bsc#1046540 FATE#322930).
- cxgb4/cxgbvf: Handle 32-bit fw port capabilities (bsc#1046540
  FATE#322930 bsc#1046542 FATE#322928).
- cxgb4: Clear On FLASH config file after a FW upgrade
  (bsc#1046540 FATE#322930).
- commit 9ed00a3
* Mon Oct  2 2017 tbogendoerfer@suse.de
- net/sched: Fix the logic error to decide the ingress qdisc
  (bsc#1056787).
- net: sched: use newly added classid identity helpers
  (bsc#1056787).
- net: sched: propagate classid down to offload drivers
  (bsc#1056787).
- net: sched: Add helpers to identify classids (bsc#1056787).
- net: sched: get rid of struct tc_to_netdev (bsc#1056787).
- net: sched: change return value of ndo_setup_tc for driver
  supporting mqprio only (bsc#1056787).
- commit 3fa59d0
* Mon Oct  2 2017 jslaby@suse.cz
- ppp: Fix false xmit recursion detect with two ppp devices
  (bnc#1060662).
- ppp: fix xmit recursion detection on ppp channels (bnc#1060662).
- tcp: avoid setting cwnd to invalid ssthresh after cwnd reduction
  states (bnc#1060662).
- net: fix keepalive code vs TCP_FASTOPEN_CONNECT (bnc#1060662).
- ipv6: set rt6i_protocol properly in the route when it is
  installed (bnc#1060662).
- bpf, s390: fix jit branch offset related to ldimm64
  (bnc#1060662).
- net/mlx4_en: don't set CHECKSUM_COMPLETE on SCTP packets
  (bnc#1060662).
- net: sched: set xt_tgchk_param par.net properly in
  ipt_init_target (bnc#1060662).
- net: sched: set xt_tgchk_param par.nft_compat as 0 in
  ipt_init_target (bnc#1060662).
- tcp: fastopen: tcp_connect() must refresh the route
  (bnc#1060662).
- qmi_wwan: fix NULL deref on disconnect (bnc#1060662).
- net: avoid skb_warn_bad_offload false positives on UFO
  (bnc#1060662).
- igmp: Fix regression caused by igmp sysctl namespace code
  (bnc#1060662).
- udp: consistently apply ufo or fragmentation (bnc#1060662).
- packet: fix tp_reserve race in packet_set_ring (bnc#1060662).
- scsi: sg: only check for dxfer_len greater than 256M
  (bnc#1060662).
- btrfs: Remove false alert when fiemap range is smaller than
  on-disk extent (bnc#1060662).
- Linux 4.12.7 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.6-7.
  Expand 4.12.7.
- commit 8cebe24
* Mon Oct  2 2017 jslaby@suse.cz
- mm: ratelimit PFNs busy info message (bnc#1060662).
- mm: fix list corruptions on shmem shrinklist (bnc#1060662).
- futex: Remove unnecessary warning from get_futex_key
  (bnc#1060662).
- xtensa: fix cache aliasing handling code for WT cache
  (bnc#1060662).
- xtensa: mm/cache: add missing EXPORT_SYMBOLs (bnc#1060662).
- xtensa: don't limit csum_partial export by CONFIG_NET
  (bnc#1060662).
- xfs: Fix leak of discard bio (bnc#1060662).
- pinctrl: armada-37xx: Fix number of pin in south bridge
  (bnc#1060662).
- mtd: nand: atmel: Fix DT backward compatibility in pmecc.c
  (bnc#1060662).
- mtd: nand: Fix timing setup for NANDs that do not support SET
  FEATURES (bnc#1060662).
- mtd: nand: Declare tBERS, tR and tPROG as u64 to avoid integer
  overflow (bnc#1060662).
- iscsi-target: fix memory leak in iscsit_setup_text_cmd()
  (bnc#1060662).
- iscsi-target: Fix iscsi_np reset hung task during parallel
  delete (bnc#1060662).
- usb-storage: fix deadlock involving host lock and scsi_done
  (bnc#1060662).
- target: Fix node_acl demo-mode + uncached dynamic shutdown
  regression (bnc#1060662).
- fuse: initialize the flock flag in fuse_file on allocation
  (bnc#1060662).
- i2c: designware: Some broken DSTDs use 1MiHz instead of 1MHz
  (bnc#1060662).
- nand: fix wrong default oob layout for small pages using soft
  ecc (bnc#1060662).
- mmc: mmc: correct the logic for setting HS400ES signal voltage
  (bnc#1060662).
- nfs/flexfiles: fix leak of nfs4_ff_ds_version arrays
  (bnc#1060662).
- drm/bridge: tc358767: fix probe without attached output node
  (bnc#1060662).
- drm/etnaviv: Fix off-by-one error in reloc checking
  (bnc#1060662).
- drm/i915: Fix out-of-bounds array access in bdw_load_gamma_lut
  (bnc#1060662).
- USB: serial: option: add D-Link DWM-222 device ID (bnc#1060662).
- USB: serial: cp210x: add support for Qivicon USB ZigBee dongle
  (bnc#1060662).
- USB: serial: pl2303: add new ATEN device id (bnc#1060662).
- usb: musb: fix tx fifo flush handling again (bnc#1060662).
- USB: hcd: Mark secondary HCD as dead if the primary one died
  (bnc#1060662).
- staging:iio:resolver:ad2s1210 fix negative IIO_ANGL_VEL read
  (bnc#1060662).
- iio: aspeed-adc: wait for initial sequence (bnc#1060662).
- iio: accel: st_accel: add SPI-3wire support (bnc#1060662).
- iio: accel: bmc150: Always restore device to normal mode after
  suspend-resume (bnc#1060662).
- iio: pressure: st_pressure_core: disable multiread by default
  for LPS22HB (bnc#1060662).
- iio: light: tsl2563: use correct event code (bnc#1060662).
- iio: adc: Revert "axp288: Drop bogus AXP288_ADC_TS_PIN_CTRL
  register modifications" (bnc#1060662).
- staging: comedi: comedi_fops: do not call blocking ops when
  !TASK_RUNNING (bnc#1060662).
- uas: Add US_FL_IGNORE_RESIDUE for Initio Corporation INIC-3069
  (bnc#1060662).
- firmware: fix batched requests - wake all waiters (bnc#1060662).
- firmware: fix batched requests - send wake up on failure on
  direct lookups (bnc#1060662).
- firmware: avoid invalid fallback aborts by using killable wait
  (bnc#1060662).
- block: Make blk_mq_delay_kick_requeue_list() rerun the queue
  at a quiet time (bnc#1060662).
- usb: gadget: udc: renesas_usb3: Fix
  usb_gadget_giveback_request() calling (bnc#1060662).
- usb: renesas_usbhs: Fix UGCTRL2 value for R-Car Gen3
  (bnc#1060662).
- USB: Check for dropped connection before switching to full speed
  (bnc#1060662).
- usb: core: unlink urbs from the tail of the endpoint's urb_list
  (bnc#1060662).
- usb: quirks: Add no-lpm quirk for Moshi USB to Ethernet Adapter
  (bnc#1060662).
- usb:xhci:Add quirk for Certain failing HP keyboard on reset
  after resume (bnc#1060662).
- PCI: Protect pci_error_handlers->reset_notify() usage with
  device_lock() (bnc#1060662).
- PCI: Remove __pci_dev_reset() and pci_dev_reset() (bnc#1060662).
- PCI: Add pci_reset_function_locked() (bnc#1060662).
- xhci: Reset Renesas uPD72020x USB controller for 32-bit DMA
  issue (bnc#1060662).
- iio: adc: vf610_adc: Fix VALT selection value for REFSEL bits
  (bnc#1060662).
- pnfs/blocklayout: require 64-bit sector_t (bnc#1060662).
- pinctrl: cherryview: Add Setzer models to the Chromebook DMI
  quirk (bnc#1060662).
- pinctrl: sunxi: add a missing function of A10/A20 pinctrl driver
  (bnc#1060662).
- pinctrl: intel: merrifield: Correct UART pin lists
  (bnc#1060662).
- pinctrl: uniphier: fix WARN_ON() of pingroups dump on LD11
  (bnc#1060662).
- pinctrl: uniphier: fix WARN_ON() of pingroups dump on LD20
  (bnc#1060662).
- pinctrl: samsung: Remove bogus irq_[un]mask from resource
  management (bnc#1060662).
- pinctrl: meson-gxbb: Add missing GPIODV_18 pin entry
  (bnc#1060662).
- pinctrl: meson-gxl: Add missing GPIODV_18 pin entry
  (bnc#1060662).
- MIPS: DEC: Fix an int-handler.S CPU_DADDI_WORKAROUNDS regression
  (bnc#1060662).
- Revert "MIPS: Don't unnecessarily include kmalloc.h into
  <asm/cache.h>." (bnc#1060662).
- MIPS: Octeon: Fix broken EDAC driver (bnc#1060662).
- powerpc: Fix /proc/cpuinfo revision for POWER9 DD2 (bnc#1060662
  bsc#1046789).
- Linux 4.12.8 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.7-8.
  Expand 4.12.8.
- commit e01e9dd
* Mon Oct  2 2017 bpoirier@suse.com
- Update marker for sorted section in series.conf
  The section now contains patches related to more than just networking.
- commit 987899b
* Mon Oct  2 2017 bpoirier@suse.com
- Refresh
  patches.apparmor/0024-apparmor-speed-up-transactional-queries.patch.
- Refresh
  patches.apparmor/0030-apparmor-cleanup-__find_child.patch.
- Refresh
  patches.apparmor/0031-apparmor-add-namespace-lookup-fns.patch.
- Refresh
  patches.drivers/0009-thunderbolt-Convert-switch-to-a-device.patch.
  Fix broken Git-commit tags
- commit 4f9ee19
* Mon Oct  2 2017 jslaby@suse.cz
- audit: Fix use after free in audit_remove_watch_rule()
  (bnc#1060662).
- parisc: pci memory bar assignment fails with 64bit kernels on
  dino/cujo (bnc#1060662).
- crypto: ixp4xx - Fix error handling path in 'aead_perform()'
  (bnc#1060662).
- crypto: x86/sha1 - Fix reads beyond the number of blocks passed
  (bnc#1060662).
- drm/i915: Perform an invalidate prior to executing golden
  renderstate (bnc#1060662).
- drm/amdgpu: save list length when fence is signaled
  (bnc#1060662).
- Input: elan_i2c - add ELAN0608 to the ACPI table (bnc#1060662).
- Input: elan_i2c - Add antoher Lenovo ACPI ID for upcoming
  Lenovo NB (bnc#1060662).
- md: fix test in md_write_start() (bnc#1060662).
- md: always clear ->safemode when md_check_recovery gets the
  mddev lock (bnc#1060662).
- MD: not clear ->safemode for external metadata array
  (bnc#1060662).
- ALSA: seq: 2nd attempt at fixing race creating a queue
  (bnc#1060662).
- ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
  (bnc#1060662 bsc#1052580).
- ALSA: usb-audio: Add mute TLV for playback volumes on C-Media
  devices (bnc#1060662).
- ALSA: usb-audio: add DSD support for new Amanero PID
  (bnc#1060662).
- mm: discard memblock data later (bnc#1060662).
- slub: fix per memcg cache leak on css offline (bnc#1060662).
- mm: fix double mmap_sem unlock on MMF_UNSTABLE enforced SIGBUS
  (bnc#1060662).
- mm/cma_debug.c: fix stack corruption due to sprintf usage
  (bnc#1060662).
- mm/mempolicy: fix use after free when calling get_mempolicy
  (bnc#1060662).
- mm/vmalloc.c: don't unconditonally use __GFP_HIGHMEM
  (bnc#1060662).
- mm: revert x86_64 and arm64 ELF_ET_DYN_BASE base changes
  (bnc#1060662).
- xen: fix bio vec merging (bnc#1060662).
- ARM: dts: imx6qdl-nitrogen6_som2: fix PCIe reset (bnc#1060662).
- blk-mq-pci: add a fallback when pci_irq_get_affinity returns
  NULL (bnc#1060662).
- powerpc: Fix VSX enabling/flushing to also test MSR_FP and
  MSR_VEC (bnc#1060662).
- xen-blkfront: use a right index when checking requests
  (bnc#1060662).
- perf/x86: Fix RDPMC vs. mm_struct tracking (bnc#1060662).
- x86/asm/64: Clear AC on NMI entries (bnc#1060662).
- x86: Fix norandmaps/ADDR_NO_RANDOMIZE (bnc#1060662).
- x86/elf: Remove the unnecessary ADDR_NO_RANDOMIZE checks
  (bnc#1060662).
- irqchip/atmel-aic: Fix unbalanced of_node_put() in
  aic_common_irq_fixup() (bnc#1060662).
- irqchip/atmel-aic: Fix unbalanced refcount in
  aic_common_rtc_irq_fixup() (bnc#1060662).
- genirq: Restore trigger settings in irq_modify_status()
  (bnc#1060662).
- genirq/ipi: Fixup checks against nr_cpu_ids (bnc#1060662).
- kernel/watchdog: Prevent false positives with turbo modes
  (bnc#1060662).
- Sanitize 'move_pages()' permission checks (bnc#1060662).
- pids: make task_tgid_nr_ns() safe (bnc#1060662).
- debug: Fix WARN_ON_ONCE() for modules (bnc#1060662 bnc#1049599).
- usb: optimize acpi companion search for usb port devices
  (bnc#1060662).
- usb: qmi_wwan: add D-Link DWM-222 device ID (bnc#1060662).
- Linux 4.12.9 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.8-9.
  Expand 4.12.9.
- commit 87e5f9e
* Mon Oct  2 2017 jslaby@suse.cz
- sparc64: remove unnecessary log message (bnc#1060662).
- bonding: require speed/duplex only for 802.3ad, alb and tlb
  (bnc#1060662).
- bonding: ratelimit failed speed/duplex update warning
  (bnc#1060662).
- af_key: do not use GFP_KERNEL in atomic contexts (bnc#1060662).
- dccp: purge write queue in dccp_destroy_sock() (bnc#1060662).
- dccp: defer ccid_hc_tx_delete() at dismantle time (bnc#1060662).
- ipv4: fix NULL dereference in free_fib_info_rcu() (bnc#1060662).
- net_sched/sfq: update hierarchical backlog when drop packet
  (bnc#1060662).
- net_sched: remove warning from qdisc_hash_add (bnc#1060662).
- bpf: fix bpf_trace_printk on 32 bit archs (bnc#1060662).
- net: igmp: Use ingress interface rather than vrf device
  (bnc#1060662).
- openvswitch: fix skb_panic due to the incorrect actions attrlen
  (bnc#1060662).
- ptr_ring: use kmalloc_array() (bnc#1060662 bsc#1055945).
- ipv4: better IP_MAX_MTU enforcement (bnc#1060662).
- nfp: fix infinite loop on umapping cleanup (bnc#1060662).
- tun: handle register_netdevice() failures properly
  (bnc#1060662).
- sctp: fully initialize the IPv6 address in sctp_v6_to_addr()
  (bnc#1060662).
- tipc: fix use-after-free (bnc#1060662).
- ipv6: reset fn->rr_ptr when replacing route (bnc#1060662).
- ipv6: repair fib6 tree in failure case (bnc#1060662).
- tcp: when rearming RTO, if RTO time is in past then fire RTO
  ASAP (bnc#1060662).
- net/mlx4_core: Enable 4K UAR if SRIOV module parameter is not
  enabled (bnc#1060662).
- irda: do not leak initialized list.dev to userspace
  (bnc#1060662).
- net: sched: fix NULL pointer dereference when action calls
  some targets (bnc#1060662).
- net_sched: fix order of queue length updates in qdisc_replace()
  (bnc#1060662).
- bpf, verifier: add additional patterns to evaluate_reg_imm_alu
  (bnc#1060662).
- bpf: fix mixed signed/unsigned derived min/max value bounds
  (bnc#1060662 bsc#1050081).
- bpf/verifier: fix min/max handling in BPF_SUB (bnc#1060662
  bsc#1050081).
- Input: trackpoint - add new trackpoint firmware ID
  (bnc#1060662).
- Input: elan_i2c - add ELAN0602 ACPI ID to support Lenovo Yoga310
  (bnc#1060662).
- Input: ALPS - fix two-finger scroll breakage in right side on
  ALPS touchpad (bnc#1060662 bsc#1050582).
- KVM: s390: sthyi: fix sthyi inline assembly (bnc#1060662).
- KVM: s390: sthyi: fix specification exception detection
  (bnc#1060662).
- KVM: x86: simplify handling of PKRU (bnc#1060662 bsc#1055935).
- KVM, pkeys: do not use PKRU value in vcpu->arch.guest_fpu.state
  (bnc#1060662 bsc#1055935).
- KVM: x86: block guest protection keys unless the host has them
  enabled (bnc#1060662 bsc#1055935).
- ALSA: usb-audio: Add delay quirk for H650e/Jabra 550a USB
  headsets (bnc#1060662).
- ALSA: core: Fix unexpected error at replacing user TLV
  (bnc#1060662).
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bnc#1060662 bsc#1020657).
- ALSA: firewire: fix NULL pointer dereference when releasing
  uninitialized data of iso-resource (bnc#1060662).
- ALSA: firewire-motu: destroy stream data surely at failure of
  card initialization (bnc#1060662).
- ARCv2: SLC: Make sure busy bit is set properly for region ops
  (bnc#1060662).
- ARCv2: PAE40: Explicitly set MSB counterpart of SLC region
  ops addresses (bnc#1060662).
- ARCv2: PAE40: set MSB even if !CONFIG_ARC_HAS_PAE40 but PAE
  exists in SoC (bnc#1060662).
- PM/hibernate: touch NMI watchdog when creating snapshot
  (bnc#1060662).
- mm, shmem: fix handling
  /sys/kernel/mm/transparent_hugepage/shmem_enabled (bnc#1060662).
- dax: fix deadlock due to misaligned PMD faults (bnc#1060662).
- i2c: designware: Fix system suspend (bnc#1060662).
- mm/madvise.c: fix freeing of locked page with MADV_FREE
  (bnc#1060662).
- fork: fix incorrect fput of ->exe_file causing use-after-free
  (bnc#1060662).
- mm/memblock.c: reversed logic in memblock_discard()
  (bnc#1060662).
- arm64: fpsimd: Prevent registers leaking across exec
  (bnc#1060662).
- drm: Fix framebuffer leak (bnc#1060662).
- drm: Release driver tracking before making the object available
  again (bnc#1060662).
- drm/sun4i: Implement drm_driver lastclose to restore fbdev
  console (bnc#1060662).
- drm/atomic: Handle -EDEADLK with out-fences correctly
  (bnc#1060662).
- drm/atomic: If the atomic check fails, return its value first
  (bnc#1060662).
- drm/i915/vbt: ignore extraneous child devices for a port
  (bnc#1060662).
- drm/i915/gvt: Fix the kernel null pointer error (bnc#1060662).
- Revert "drm/amdgpu: fix vblank_time when displays are off"
  (bnc#1060662).
- ACPI: device property: Fix node lookup in
  acpi_graph_get_child_prop_value() (bnc#1060662).
- tracing: Call clear_boot_tracer() at lateinit_sync
  (bnc#1060662).
- tracing: Missing error code in tracer_alloc_buffers()
  (bnc#1060662).
- tracing: Fix kmemleak in tracing_map_array_free() (bnc#1060662).
- tracing: Fix freeing of filter in create_filter() when set_str
  is false (bnc#1060662).
- RDMA/uverbs: Initialize cq_context appropriately (bnc#1060662).
- kbuild: linker script do not match C names unless
  LD_DEAD_CODE_DATA_ELIMINATION is configured (bnc#1060662).
- cifs: Fix df output for users with quota limits (bnc#1060662).
- cifs: return ENAMETOOLONG for overlong names in
  cifs_open()/cifs_lookup() (bnc#1060662).
- nfsd: Limit end of page list when decoding NFSv4 WRITE
  (bnc#1060662).
- ring-buffer: Have ring_buffer_alloc_read_page() return error
  on offline CPU (bnc#1060662).
- virtio_pci: fix cpu affinity support (bnc#1060662).
- ftrace: Check for null ret_stack on profile function graph
  entry function (bnc#1060662).
- perf/core: Fix group {cpu,task} validation (bnc#1060662).
- timers: Fix excessive granularity of new timers after a nohz
  idle (bnc#1060662).
- x86/mm: Fix use-after-free of ldt_struct (bnc#1060662).
- net: sunrpc: svcsock: fix NULL-pointer exception (bnc#1060662).
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1060662 bnc#1048935).
- netfilter: nat: fix src map lookup (bnc#1060662).
- netfilter: nfnetlink: Improve input length sanitization in
  nfnetlink_rcv (bnc#1060662).
- Bluetooth: hidp: fix possible might sleep error in
  hidp_session_thread (bnc#1060662 bnc#1014351).
- Bluetooth: cmtp: fix possible might sleep error in cmtp_session
  (bnc#1060662).
- Bluetooth: bnep: fix possible might sleep error in bnep_session
  (bnc#1060662).
- Revert "android: binder: Sanity check at binder ioctl"
  (bnc#1060662).
- binder: use group leader instead of open thread (bnc#1060662).
- binder: Use wake up hint for synchronous transactions
  (bnc#1060662).
- ANDROID: binder: fix proc->tsk check (bnc#1060662).
- iio: imu: adis16480: Fix acceleration scale factor for adis16480
  (bnc#1060662).
- iio: hid-sensor-trigger: Fix the race with user space powering
  up sensors (bnc#1060662).
- iio: magnetometer: st_magn: fix status register address for
  LSM303AGR (bnc#1060662).
- iio: magnetometer: st_magn: remove ihl property for LSM303AGR
  (bnc#1060662).
- staging: rtl8188eu: add RNX-N150NUB support (bnc#1060662).
- iommu: Fix wrong freeing of iommu_device->dev (bnc#1060662).
- Clarify (and fix) MAX_LFS_FILESIZE macros (bnc#1060662).
- ntb: ntb_test: ensure the link is up before trying to configure
  the mws (bnc#1060662).
- ntb: transport shouldn't disable link due to bogus values in
  SPADs (bnc#1060662).
- ACPI: APD: Fix HID for Hisilicon Hip07/08 (bnc#1060662).
- ACPI: EC: Fix regression related to wrong ECDT initialization
  order (bnc#1060662).
- powerpc/mm: Ensure cpumask update is ordered (bnc#1060662).
- Linux 4.12.10 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.9-10.
  Expand 4.12.10.
- commit 6b3564b
* Mon Oct  2 2017 jslaby@suse.cz
- arm64: mm: abort uaccess retries upon fatal signal
  (bnc#1060662).
- x86/io: Add "memory" clobber to insb/insw/insl/outsb/outsw/outsl
  (bnc#1060662).
- irqchip: mips-gic: SYNC after enabling GIC region (bnc#1060662).
- Input: synaptics - fix device info appearing different on
  reconnect (bnc#1060662).
- Input: xpad - fix PowerA init quirk for some gamepad models
  (bnc#1060662).
- crypto: chacha20 - fix handling of chunked input (bnc#1060662).
- i2c: ismt: Don't duplicate the receive length for block reads
  (bnc#1060662).
- i2c: ismt: Return EMSGSIZE for block reads with bogus length
  (bnc#1060662).
- crypto: algif_skcipher - only call put_page on referenced and
  used pages (bnc#1060662).
- mm, uprobes: fix multiple free of ->uprobes_state.xol_area
  (bnc#1060662).
- mm, madvise: ensure poisoned pages are removed from per-cpu
  lists (bnc#1060662).
- ceph: fix readpage from fscache (bnc#1060662).
- cpumask: fix spurious cpumask_of_node() on non-NUMA multi-node
  configs (bnc#1060662).
- cpuset: Fix incorrect memory_pressure control file mapping
  (bnc#1060662).
- alpha: uapi: Add support for __SANE_USERSPACE_TYPES__
  (bnc#1060662).
- CIFS: Fix maximum SMB2 header size (bnc#1060662 bsc#1056185).
- CIFS: remove endian related sparse warning (bnc#1060662).
- dm mpath: do not lock up a CPU with requeuing activity
  (bnc#1060662).
- drm/vmwgfx: Fix F26 Wayland screen update issue (bnc#1060662).
- wl1251: add a missing spin_lock_init() (bnc#1060662).
- mmc: sdhci-xenon: add set_power callback (bnc#1060662).
- lib/mpi: kunmap after finishing accessing buffer (bnc#1060662).
- xfrm: policy: check policy direction value (bnc#1060662).
- drm/ttm: Fix accounting error when fail to get pages for pool
  (bnc#1060662).
- nvme: fix the definition of the doorbell buffer config support
  bit (bnc#1060662).
- drm/nouveau/i2c/gf119-: add support for address-only
  transactions (bnc#1060662).
- epoll: fix race between ep_poll_callback(POLLFREE) and
  ep_free()/ep_remove() (bnc#1060662).
- Linux 4.12.11 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.10-11.
  Expand 4.12.11.
- commit b96a777
* Mon Oct  2 2017 jslaby@suse.cz
- usb: quirks: add delay init quirk for Corsair Strafe RGB
  keyboard (bnc#1060662).
- USB: serial: option: add support for D-Link DWM-157 C1
  (bnc#1060662).
- usb: Add device quirk for Logitech HD Pro Webcam C920-C
  (bnc#1060662).
- usb:xhci:Fix regression when ATI chipsets detected
  (bnc#1060662).
- USB: musb: fix external abort on suspend (bnc#1060662).
- ANDROID: binder: add padding to binder_fd_array_object
  (bnc#1060662).
- ANDROID: binder: add hwbinder,vndbinder to BINDER_DEVICES
  (bnc#1060662).
- USB: core: Avoid race of async_completed() w/ usbdev_release()
  (bnc#1060662).
- staging/rts5208: fix incorrect shift to extract upper nybble
  (bnc#1060662).
- iio: adc: ti-ads1015: fix incorrect data rate setting update
  (bnc#1060662).
- iio: adc: ti-ads1015: fix scale information for ADS1115
  (bnc#1060662).
- iio: adc: ti-ads1015: enable conversion when CONFIG_PM is not
  set (bnc#1060662).
- iio: adc: ti-ads1015: avoid getting stale result after runtime
  resume (bnc#1060662).
- iio: adc: ti-ads1015: don't return invalid value from buffer
  setup callbacks (bnc#1060662).
- iio: adc: ti-ads1015: add adequate wait time to get correct
  conversion (bnc#1060662).
- driver core: bus: Fix a potential double free (bnc#1060662).
- HID: wacom: Do not completely map WACOM_HID_WD_TOUCHRINGSTATUS
  usage (bnc#1060662).
- binder: free memory on error (bnc#1060662).
- crypto: caam/qi - fix compilation with
  CONFIG_DEBUG_FORCE_WEAK_PER_CPU=y (bnc#1060662).
- crypto: caam/qi - fix compilation with DEBUG enabled
  (bnc#1060662).
- fpga: altera-hps2fpga: fix multiple init of l3_remap_lock
  (bnc#1060662).
- intel_th: pci: Add Cannon Lake PCH-H support (bnc#1060662
  FATE#321195).
- intel_th: pci: Add Cannon Lake PCH-LP support (bnc#1060662
  FATE#321195).
- ath10k: fix memory leak in rx ring buffer allocation
  (bnc#1060662).
- Input: trackpoint - assume 3 buttons when buttons detection
  fails (bnc#1060662).
- rtlwifi: rtl_pci_probe: Fix fail path of _rtl_pci_find_adapter
  (bnc#1060662).
- Bluetooth: Add support of 13d3:3494 RTL8723BE device
  (bnc#1060662).
- iwlwifi: pci: add new PCI ID for 7265D (bnc#1060662).
- dlm: avoid double-free on error path in
  dlm_device_{register,unregister} (bnc#1060662).
- mwifiex: correct channel stat buffer overflows (bnc#1060662).
- MCB: add support for SC31 to mcb-lpc (bnc#1060662).
- s390/mm: avoid empty zero pages for KVM guests to avoid postcopy
  hangs (bnc#1060662).
- s390/mm: fix BUG_ON in crst_table_upgrade (bnc#1060662).
- drm/nouveau/pci/msi: disable MSI on big-endian platforms by
  default (bnc#1060662).
- drm/nouveau: Fix error handling in nv50_disp_atomic_commit
  (bnc#1060662).
- workqueue: Fix flag collision (bnc#1060662).
- ahci: don't use MSI for devices with the silly Intel NVMe
  remapping scheme (bnc#1060662).
- cs5536: add support for IDE controller variant (bnc#1060662).
- scsi: sg: protect against races between mmap() and
  SG_SET_RESERVED_SIZE (bnc#1060662).
- scsi: sg: recheck MMAP_IO request length with lock held
  (bnc#1060662).
- of/device: Prevent buffer overflow in of_device_modalias()
  (bnc#1060662).
- rtlwifi: Fix memory leak when firmware request fails
  (bnc#1060662).
- rtlwifi: Fix fallback firmware loading (bnc#1060662).
- Linux 4.12.12 (bnc#1060662).
- Delete patches.kernel.org/patch-4.12.11-12.
  Expand 4.12.12.
- commit 2a3fe1e
* Mon Oct  2 2017 tbogendoerfer@suse.de
- net: sched: move prio into cls_common (bsc#1056787).
- net: sched: push cls related args into cls_common structure
  (bsc#1056787).
- nfp: change flows in apps that offload ndo_setup_tc
  (bsc#1055968).
- dsa: push cls_matchall setup_tc processing into a separate
  function (bsc#1056787).
- mlxsw: spectrum: rename cls arg in matchall processing
  (bsc#1056787).
- mlxsw: spectrum: push cls_flower and cls_matchall setup_tc
  processing into separate functions (bsc#1056787).
- mlx5e_rep: push cls_flower setup_tc processing into a separate
  function (bsc#1046303 FATE#322944).
- mlx5e: push cls_flower and mqprio setup_tc processing into
  separate functions (bsc#1046303 FATE#322944).
- ixgbe: push cls_u32 and mqprio setup_tc processing into separate
  functions (bsc#1056657 FATE#322189).
- cxgb4: push cls_u32 setup_tc processing into a separate function
  (bsc#1046540 FATE#322930).
- net: sched: make egress_dev flag part of flower offload struct
  (bsc#1056787).
- net: sched: rename TC_SETUP_MATCHALL to TC_SETUP_CLSMATCHALL
  (bsc#1056787).
- net: sched: make type an argument for ndo_setup_tc
  (bsc#1056787).
- net: sched: change names of action number helpers to be aligned
  with the rest (bsc#1056787).
- commit ed4a685
* Mon Oct  2 2017 yousaf.kaukab@suse.com
- config: arm64: enable xgene pmu
  References: bsc#1036737
- commit c789476
* Mon Oct  2 2017 tbogendoerfer@suse.de
- resorted sorted section
- commit 053446a
* Mon Oct  2 2017 tbogendoerfer@suse.de
- Delete
  patches.drivers/0007-RDMA-bnxt_re-Fix-race-between-netdev-register-and-un.patch.
- Delete
  patches.drivers/0012-RDMA-bnxt_re-Add-vlan-tag-for-untagged-RoCE-traffic-.patch.
- Delete
  patches.drivers/0018-RDMA-bnxt_re-Update-the-driver-version.patch.
- Delete
  patches.drivers/0020-RDMA-bnxt_re-Allow-posting-when-QPs-are-in-error.patch.
- commit 99f359a
* Mon Oct  2 2017 tiwai@suse.de
- Update config files: set CONFIG_SND_SOC=m for arm64 (bsc#1060104).
- commit 880aeac
* Mon Oct  2 2017 tiwai@suse.de
- Update config files: update to 4.12.4
- commit 4e103ba
* Mon Oct  2 2017 jslaby@suse.cz
- x86/head: Add unwind hint annotations (bnc#1058115).
- x86/xen: Add unwind hint annotations (bnc#1058115).
- x86/xen: Fix xen head ELF annotations (bnc#1058115).
- x86/boot: Annotate verify_cpu() as a callable function
  (bnc#1058115).
- x86/head: Fix head ELF function annotations (bnc#1058115).
- x86/head: Remove unused 'bad_address' code (bnc#1058115).
- x86/head: Remove confusing comment (bnc#1058115).
- objtool: Don't report end of section error after an empty
  unwind hint (bnc#1058115).
- commit d144576
* Mon Oct  2 2017 jslaby@suse.cz
- crypto: x86/twofish - Fix RBP usage (bnc#1058115).
- crypto: sha512-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha256-avx - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-ssse3 - Fix RBP usage (bnc#1058115).
- crypto: x86/sha1-avx2 - Fix RBP usage (bnc#1058115).
- crypto: x86/des3_ede - Fix RBP usage (bnc#1058115).
- crypto: x86/cast6 - Fix RBP usage (bnc#1058115).
- crypto: x86/cast5 - Fix RBP usage (bnc#1058115).
- crypto: x86/camellia - Fix RBP usage (bnc#1058115).
- crypto: x86/blowfish - Fix RBP usage (bnc#1058115).
- commit 51691cb
* Sat Sep 30 2017 gqjiang@suse.com
- md/bitmap: disable bitmap_resize for file-backed bitmaps
  (bsc#1061174).
- commit a897895
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Unsuccessful PCIe caps tuning should not fail driver
  load (bsc#1060463 FATE#323043).
- IB/hfi1: Check eeprom config partition validity (bsc#1060463
  FATE#323043).
- IB/mlx5: Fix NULL deference on mlx5_ib_update_xlt failure
  (bsc#1046305 FATE#322943).
- IB/ipoib: Fix sysfs Pkey create<->remove possible deadlock
  (bsc#1046307 FATE#322941).
- IB/core: Fix qp_sec use after free access (bsc#1046306
  FATE#322942).
- IB/core: Fix typo in the name of the tag-matching cap struct
  (bsc#1046306 FATE#322942).
- IB/mlx5: fix debugfs cleanup (bsc#1046305 FATE#322943).
- bnxt_en: fix clearing devlink ptr from bnxt struct (bsc#1050242
  FATE#322914).
- bnxt_re: add MAY_USE_DEVLINK dependency (bsc#1050242
  FATE#322914).
- commit ea21d80
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/mlx5: Support IB_SRQT_TM (bsc#1046305 FATE#322943).
- net/mlx5: Add XRQ support (bsc#1046303 FATE#322944).
- IB/mlx5: Fill XRQ capabilities (bsc#1046305 FATE#322943).
- commit 3ba7f43
* Fri Sep 29 2017 tbogendoerfer@suse.de
- i40iw: Add support for port reuse on active side connections
  (bsc#1058659 FATE#322535).
- i40iw: Add missing VLAN priority (bsc#1058659 FATE#322535).
- i40iw: Call i40iw_cm_disconn on modify QP to disconnect
  (bsc#1058659 FATE#322535).
- i40iw: Prevent multiple netdev event notifier registrations
  (bsc#1058659 FATE#322535).
- i40iw: Fail open if there are no available MSI-X vectors
  (bsc#1058659 FATE#322535).
- i40iw: make some structures const (bsc#1058659 FATE#322535).
- RDMA/i40iw: Remove unused argument (bsc#1058659 FATE#322535).
- i40iw: Improve CQP timeout logic (bsc#1058659 FATE#322535).
- i40iw: fix spelling mistake: "allloc_buf" -> "alloc_buf"
  (bsc#1058659 FATE#322535).
- i40iw: Fixes for static checker warnings (bsc#1058659
  FATE#322535).
- i40iw: Simplify code (bsc#1058659 FATE#322535).
- commit 3ae25bf
* Fri Sep 29 2017 tbogendoerfer@suse.de
- Update config files.
- commit 28fee52
* Fri Sep 29 2017 tbogendoerfer@suse.de
- RDMA/vmw_pvrdma: Fix reporting correct opcodes for completion
  (bsc#1046306 FATE#322942).
- IB/ocrdma: fix incorrect fall-through on switch statement
  (bsc#1058513 FATE#322520).
- IB/ipoib: Suppress the retry related completion errors
  (bsc#1046307 FATE#322941).
- rdma core: Add rdma_rw_mr_payload() (bsc#1046306 FATE#322942).
- RDMA/netlink: clean up message validity array initializer
  (bsc#1046306 FATE#322942).
- RDAM/netlink: Fix out-of-bound access while checking message
  validity (bsc#1046306 FATE#322942).
- IB/core: Expose ioctl interface through experimental Kconfig
  (bsc#1046306 FATE#322942).
- IB/core: Assign root to all drivers (bsc#1046306 FATE#322942).
- IB/core: Add completion queue (cq) object actions (bsc#1046306
  FATE#322942).
- IB/core: Add legacy driver's user-data (bsc#1046306
  FATE#322942).
- IB/core: Export ioctl enum types to user-space (bsc#1046306
  FATE#322942).
- IB/core: Explicitly destroy an object while keeping uobject
  (bsc#1046306 FATE#322942).
- IB/core: Add macros for declaring methods and attributes
  (bsc#1046306 FATE#322942).
- IB/core: Add uverbs merge trees functionality (bsc#1046306
  FATE#322942).
- IB/core: Add DEVICE object and root tree structure (bsc#1046306
  FATE#322942).
- IB/core: Declare an object instead of declaring only type
  attributes (bsc#1046306 FATE#322942).
- IB/core: Add new ioctl interface (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Fix a signedness (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Report network header type in WC (bsc#1046306
  FATE#322942).
- IB/core: Add might_sleep() annotation to ib_init_ah_from_wc()
  (bsc#1046306 FATE#322942).
- IB/cm: Fix sleeping in atomic when RoCE is used (bsc#1046306
  FATE#322942).
- IB/core: Add support to finalize objects in one transaction
  (bsc#1046306 FATE#322942).
- IB/core: Add a generic way to execute an operation on a uobject
  (bsc#1046306 FATE#322942).
- IB/uverbs: Expose XRQ capabilities (bsc#1046306 FATE#322942).
- IB/uverbs: Add new SRQ type IB_SRQT_TM (bsc#1046306
  FATE#322942).
- IB/uverbs: Add XRQ creation parameter to UAPI (bsc#1046306
  FATE#322942).
- IB/core: Add new SRQ type IB_SRQT_TM (bsc#1046306 FATE#322942).
- IB/core: Add XRQ capabilities (bsc#1046306 FATE#322942).
- IB/usnic: check for allocation failure (bsc#1046306
  FATE#322942).
- commit 0db1996
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/rxe: Handle NETDEV_CHANGE events (bsc#1050662 FATE#323951).
- IB/rxe: Avoid ICRC errors by copying into the skb first
  (bsc#1050662 FATE#323951).
- IB/rxe: Remove unneeded initialization in prepare6()
  (bsc#1050662 FATE#323951).
- IB/rxe: Fix up rxe_qp_cleanup() (bsc#1050662 FATE#323951).
- IB/rxe: Add dst_clone() in prepare_ipv6_hdr() (bsc#1050662
  FATE#323951).
- IB/rxe: Fix destination cache for IPv6 (bsc#1050662
  FATE#323951).
- IB/rxe: Fix up the responder's find_resources() function
  (bsc#1050662 FATE#323951).
- IB/rxe: Remove dangling prototype (bsc#1050662 FATE#323951).
- IB/rxe: Disable completion upcalls when a CQ is destroyed
  (bsc#1050662 FATE#323951).
- commit a819614
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/rdmavt: Handle dereg of inuse MRs properly (bsc#1058717
  FATE#322789).
- IB/qib: Convert qp_stats debugfs interface to use new iterator
  API (bsc#1027067 FATE#322649).
- IB/hfi1: Convert qp_stats debugfs interface to use new iterator
  API (bsc#1060463 FATE#323043).
- IB/hfi1: Convert hfi1_error_port_qps() to use new QP iterator
  (bsc#1060463 FATE#323043).
- IB/rdmavt: Add QP iterator API for QPs (bsc#1058717
  FATE#322789).
- IB/hfi1: Use accessor to determine ring size (bsc#1060463
  FATE#323043).
- IB/qib: Stricter bounds checking for copy to buffer (bsc#1027067
  FATE#322649).
- IB/hif1: Remove static tracing from SDMA hot path (bsc#1060463
  FATE#323043).
- IB/hfi1: Acquire QSFP cable information on loopback (bsc#1060463
  FATE#323043).
- IB/hfi1: constify vm_operations_struct (bsc#1060463
  FATE#323043).
- IB/hfi1: Add opcode states to qp_stats (bsc#1060463
  FATE#323043).
- IB/hfi1: Add received request info to qp_stats (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix whitespace alignment issue for MAD (bsc#1060463
  FATE#323043).
- IB/hfi1: Move structure and MACRO definitions in user_sdma.c
  to user_sdma.h (bsc#1060463 FATE#323043).
- IB/hfi1: Move structure definitions from user_exp_rcv.c to
  user_exp_rcv.h (bsc#1060463 FATE#323043).
- IB/hfi1: Remove duplicate definitions of num_user_pages()
  function (bsc#1060463 FATE#323043).
- IB/hfi1: Fix the bail out code in pin_vector_pages() function
  (bsc#1060463 FATE#323043).
- IB/hfi1: Clean up pin_vector_pages() function (bsc#1060463
  FATE#323043).
- IB/hfi1: Clean up user_sdma_send_pkts() function (bsc#1060463
  FATE#323043).
- IB/hfi1: Clean up hfi1_user_exp_rcv_setup function (bsc#1060463
  FATE#323043).
- IB/hfi1: Improve local kmem_cache_alloc performance (bsc#1060463
  FATE#323043).
- IB/hfi1: Ratelimit prints from sdma_interrupt (bsc#1060463
  FATE#323043).
- IB/qib: Stricter bounds checking for copy and array access
  (bsc#1027067 FATE#322649).
- IB/qib: Remove unnecessary memory allocation for boardname
  (bsc#1027067 FATE#322649).
- IB/{qib, hfi1}: Avoid flow control testing for RDMA write
  operation (bsc#1060463 FATE#323043 bsc#1027067 FATE#322649).
- IB/rdmavt: Use rvt_put_swqe() in rvt_clear_mr_ref() (bsc#1058717
  FATE#322789).
- commit 983d8f2
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/mlx4: Remove redundant attribute in mlx4_ib_create_qp_rss
  struct (bsc#1046302 FATE#322945).
- RDMA/mlx4: Fix create qp command alignment (bsc#1046302
  FATE#322945).
- commit fbdeecb
* Fri Sep 29 2017 bp@suse.de
- x86/mm: Make the SME mask a u64 (fate#322123).
- commit 2c6cff6
* Fri Sep 29 2017 tbogendoerfer@suse.de
- net/mlx4_core: Use ARRAY_SIZE macro (bsc#1046300 FATE#322946).
- net/mlx4_core: fix incorrect size allocation for
  dev->caps.spec_qps (bsc#1046300 FATE#322946).
- net/mlx4_core: fix memory leaks on error exit path (bsc#1046300
  FATE#322946).
- net/mlx4: Add user mac FW update support (bsc#1046300
  FATE#322946).
- net/mlx4_core: Fix misplaced brackets of sizeof (bsc#1046300
  FATE#322946).
- net/mlx4_core: Make explicit conversion to 64bit value
  (bsc#1046300 FATE#322946).
- net/mlx4_core: Dynamically allocate structs at mlx4_slave_cap
  (bsc#1046300 FATE#322946).
- net/mlx4_core: make mlx4_profile const (bsc#1046300
  FATE#322946).
- net/mlx4: fix spelling mistake: "availible" -> "available"
  (bsc#1046300 FATE#322946).
- mlx4: sizeof style usage (bsc#1046300 FATE#322946).
- mlx4: remove unnecessary pci_set_drvdata() (bsc#1046300
  FATE#322946).
- mlx4_en: remove unnecessary error check (bsc#1046299
  FATE#322947).
- mlx4_en: remove unnecessary returned value (bsc#1046299
  FATE#322947).
- commit 1ab797e
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/mlx4: fix sprintf format warning (bsc#1046302 FATE#322945).
- RDMA/mlx4: Properly annotate link layer variable (bsc#1046302
  FATE#322945).
- IB/mlx4: Check that reserved fields in mlx4_ib_create_qp_rss
  are zero (bsc#1046302 FATE#322945).
- IB/mlx4: Fix struct mlx4_ib_create_wq alignment (bsc#1046302
  FATE#322945).
- IB/mlx4: Fix RSS QP type in creation verb (bsc#1046302
  FATE#322945).
- IB/mlx4: Fix some spelling mistakes (bsc#1046302 FATE#322945).
- RDMA/mlx4: Remove gfp_mask argument from acquire_group call
  (bsc#1046302 FATE#322945).
- RDMA/mlx4: Don't use uninitialized variable (bsc#1046302
  FATE#322945).
- IB/mlx4: use kvmalloc_array to allocate wrid (bsc#1046302
  FATE#322945).
- commit 104a064
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/core: Separate CQ handle in SRQ context (bsc#1046306
  FATE#322942).
- net/mlx5: Update HW layout definitions (bsc#1046303
  FATE#322944).
- IB/mlx5: Report mlx5 enhanced multi packet WQE capability
  (bsc#1046305 FATE#322943).
- IB/mlx5: Allow posting multi packet send WQEs if hardware
  supports (bsc#1046305 FATE#322943).
- IB/mlx5: Add support for multi underlay QP (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix integer overflow when page_shift == 31 (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix memory leak in clean_mr error path (bsc#1046305
  FATE#322943).
- IB/mlx5: Decouple MR allocation and population flows
  (bsc#1046305 FATE#322943).
- IB/mlx5: Enable UMR for MRs created with reg_create (bsc#1046305
  FATE#322943).
- IB/mlx5: Expose software parsing for Raw Ethernet QP
  (bsc#1046305 FATE#322943).
- RDMA/mlx5: Limit scope of get vector affinity local function
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add necessary delay drop assignment (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix some spelling mistakes (bsc#1046305 FATE#322943).
- IB/mlx5: use kvmalloc_array for mlx5_ib_wq (bsc#1046305
  FATE#322943).
- mlx5: Replace PCI pool old API (bsc#1046303 FATE#322944).
- mlx5: support ->get_vector_affinity (bsc#1046305 FATE#322943).
- mlx5: move affinity hints assignments to generic code
  (bsc#1046303 FATE#322944).
- mlx5e: don't assume anything on the irq affinity mappings of
  the device (bsc#1046303 FATE#322944).
- mlx5: convert to generic pci_alloc_irq_vectors (bsc#1046303
  FATE#322944).
- commit 24ced8f
* Fri Sep 29 2017 tbogendoerfer@suse.de
- RDMA/nes: Remove zeroed parameter from port query callback
  (bsc#1046306 FATE#322942).
- IB/rxe: Make rxe_counter_name static (bsc#1050662 FATE#323951).
- IB/ipoib: Sync between remove_one to sysfs calls that use
  rtnl_lock (bsc#1046307 FATE#322941).
- RDMA/mthca: Make explicit conversion to 64bit value (bsc#1046306
  FATE#322942).
- RDMA/usnic: Fix remove address space warning (bsc#1046306
  FATE#322942).
- RDMA/core: Refactor get link layer wrapper (bsc#1046306
  FATE#322942).
- RDMA/core: Delete BUG() from unreachable flow (bsc#1046306
  FATE#322942).
- RDMA/core: Cleanup device capability enum (bsc#1046306
  FATE#322942).
- RDMA/(core, ulp): Convert register/unregister event handler
  to be void (bsc#1046306 FATE#322942).
- IB/uverbs: Introduce and use helper functions to copy ah
  attributes (bsc#1046306 FATE#322942).
- IB/cma: Fix erroneous validation of supported default GID type
  (bsc#1046306 FATE#322942).
- IB: Avoid ib_modify_port() failure for RoCE devices (bsc#1046306
  FATE#322942).
- RDMA/vmw_pvrdma: Update device query parameters and port caps
  (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Add RoCEv2 support (bsc#1046306 FATE#322942).
- IB/ipoib: Enable ioctl for to IPoIB rdma netdevs (bsc#1046307
  FATE#322941).
- rdma: Autoload netlink client modules (bsc#1046306 FATE#322942).
- rdma: Allow demand loading of NETLINK_RDMA (bsc#1046306
  FATE#322942).
- IB/pvrdma: Remove unused function (bsc#1046306 FATE#322942).
- IB/mthca: Replace PCI pool old API (bsc#1046306 FATE#322942).
- infiniband: avoid overflow warning (bsc#1046306 FATE#322942).
- IB/rxe: Remove unneeded check (bsc#1050662 FATE#323951).
- IB/rxe: Convert pr_info to pr_warn (bsc#1050662 FATE#323951).
- commit 88ef93a
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Add kernel receive context info to debugfs (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove HFI1_VERBS_31BIT_PSN option (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove pstate from hfi1_pportdata (bsc#1060463
  FATE#323043).
- IB/hfi1: Stricter bounds checking of MAD trap index (bsc#1060463
  FATE#323043).
- IB/hfi1: Load fallback platform configuration per HFI device
  (bsc#1060463 FATE#323043).
- IB/hfi1: Add flag for platform config scratch register read
  (bsc#1060463 FATE#323043).
- IB/hfi1: Document phys port state bits not used in IB
  (bsc#1060463 FATE#323043).
- IB/hfi1: Check xchg returned value for queuing link down entry
  (bsc#1060463 FATE#323043).
- IB/hfi1: fix spelling mistake: "Maximim" -> "Maximum"
  (bsc#1060463 FATE#323043).
- IB/hfi1: Enable RDMA_CAP_OPA_AH in hfi driver to support
  extended LIDs (bsc#1060463 FATE#323043).
- IB/hfi1: Enhance PIO/SDMA send for 16B (bsc#1060463
  FATE#323043).
- IB/hfi1: Add 16B RC/UC support (bsc#1060463 FATE#323043).
- IB/rdmavt, hfi1, qib: Enhance rdmavt and hfi1 to use 32 bit lids
  (bsc#1060463 FATE#323043 bsc#1027067 FATE#322649 bsc#1058717
  FATE#322789).
- IB/hfi1: Add 16B trace support (bsc#1060463 FATE#323043).
- IB/hfi1: Add 16B UD support (bsc#1060463 FATE#323043).
- IB/hfi1: Determine 9B/16B L2 header type based on Address handle
  (bsc#1060463 FATE#323043).
- IB/hfi1: Add support to process 16B header errors (bsc#1060463
  FATE#323043).
- IB/hfi1: Add support to send 16B bypass packets (bsc#1060463
  FATE#323043).
- IB/hfi1: Add support to receive 16B bypass packets (bsc#1060463
  FATE#323043).
- IB/rdmavt, hfi1, qib: Modify check_ah() to account for
  extended LIDs (bsc#1060463 FATE#323043 bsc#1027067 FATE#322649
  bsc#1058717 FATE#322789).
- IB/hf1: User context locking is inconsistent (bsc#1060463
  FATE#323043).
- IB/hfi1: Protect context array set/clear with spinlock
  (bsc#1060463 FATE#323043).
- IB/hfi1: Use host_link_state to read state when DC is shut down
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove lstate from hfi1_pportdata (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove pmtu from the QP structure (bsc#1060463
  FATE#323043).
- IB/hfi1: Revert egress pkey check enforcement (bsc#1060463
  FATE#323043).
- IB/hfi1: add const to bin_attribute structures (bsc#1060463
  FATE#323043).
- IB/qib: add const to bin_attribute structures (bsc#1027067
  FATE#322649).
- IB/hfi1: fix spelling mistake in variable name continious
  (bsc#1060463 FATE#323043).
- IB/qib: fix spelling mistake: "failng" -> "failing" (bsc#1027067
  FATE#322649).
- commit 043fee2
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/core: Fix input len in multiple user verbs (bsc#1046306
  FATE#322942).
- Add OPA extended LID support (bsc#1046306 FATE#322942).
- infiniband: pvrdma: constify pci_device_id (bsc#1046306
  FATE#322942).
- infiniband: nes: constify pci_device_id (bsc#1046306
  FATE#322942).
- infiniband: mthca: constify pci_device_id (bsc#1046306
  FATE#322942).
- PCI/IB: add support for pci driver attribute groups (bsc#1046306
  FATE#322942).
- iwcm: Don't allocate iwcm workqueue with WQ_MEM_RECLAIM
  (bsc#1046306 FATE#322942).
- cm: Don't allocate ib_cm workqueue with WQ_MEM_RECLAIM
  (bsc#1046306 FATE#322942).
- RDMA/core: make ib_device.add method optional (bsc#1046306
  FATE#322942).
- RDMA/netlink: Export node_type (bsc#1046306 FATE#322942).
- RDMA/netlink: Provide port state and physical link state
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Export LID mask control (LMC) (bsc#1046306
  FATE#322942).
- RDMA/netink: Export lids and sm_lids (bsc#1046306 FATE#322942).
- RDMA/netlink: Advertise IB subnet prefix (bsc#1046306
  FATE#322942).
- RDMA/netlink: Export node_guid and sys_image_guid (bsc#1046306
  FATE#322942).
- RDMA/netlink: Export FW version (bsc#1046306 FATE#322942).
- RDMA: Simplify get firmware interface (bsc#1046306 FATE#322942).
- RDMA/netlink: Expose device and port capability masks
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Implement nldev port doit callback (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add nldev port dumpit implementation (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add nldev device doit implementation (bsc#1046306
  FATE#322942).
- RDMA/netlink: Implement nldev device dumpit calback (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add nldev initialization flows (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add netlink device definitions to UAPI
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Update copyright (bsc#1046306 FATE#322942).
- RDMA/netlink: Convert LS to doit callback (bsc#1046306
  FATE#322942).
- RDMA/netlink: Reduce indirection access to cb_table (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add and implement doit netlink callback
  (bsc#1046306 FATE#322942).
- RDMA/core: Add and expose static device index (bsc#1046306
  FATE#322942).
- RDMA/core: Add iterator over ib_devices (bsc#1046306
  FATE#322942).
- RDMA/netlink: Rename netlink callback struct (bsc#1046306
  FATE#322942).
- RDMA/netlink: Simplify and rename ibnl_chk_listeners
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Rename and remove redundant parameter from
  ibnl_multicast (bsc#1046306 FATE#322942).
- RDMA/netlink: Rename and remove redundant parameter from
  ibnl_unicast* (bsc#1046306 FATE#322942).
- RDMA/netlink: Simplify the put_msg and put_attr (bsc#1046306
  FATE#322942).
- RDMA/netlink: Add flag to consolidate common handling
  (bsc#1046306 FATE#322942).
- RDMA/iwcm: Remove extra EXPORT_SYMBOLS (bsc#1046306
  FATE#322942).
- RDMA/iwcm: Remove useless check of netlink client validity
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Avoid double pass for RDMA netlink messages
  (bsc#1046306 FATE#322942).
- RDMA/netlink: Remove redundant owner option for netlink
  callbacks (bsc#1046306 FATE#322942).
- RDMA/netlink: Remove netlink clients infrastructure (bsc#1046306
  FATE#322942).
- RDMA/core: Add wait/retry version of ibnl_unicast (bsc#1046306
  FATE#322942).
- RDMA/core: expose affinity mappings per completion vector
  (bsc#1046306 FATE#322942).
- IB/CM: Set appropriate slid and dlid when handling CM request
  (bsc#1046306 FATE#322942).
- IB/CM: Create appropriate path records when handling CM request
  (bsc#1046306 FATE#322942).
- IB/CM: Add OPA Path record support to CM (bsc#1046306
  FATE#322942).
- IB/core: Change wc.slid from 16 to 32 bits (bsc#1046306
  FATE#322942).
- IB/core: Change port_attr.sm_lid from 16 to 32 bits (bsc#1046306
  FATE#322942).
- IB/core: Change port_attr.lid size from 16 to 32 bits
  (bsc#1046306 FATE#322942).
- IB/mad: Change slid in RMPP recv from 16 to 32 bits (bsc#1046306
  FATE#322942).
- IB/IPoIB: Increase local_lid to 32 bits (bsc#1046306
  FATE#322942).
- IB/srpt: Increase lid and sm_lid to 32 bits (bsc#1046306
  FATE#322942).
- IB/core: Convert ah_attr from OPA to IB when copying to user
  (bsc#1046306 FATE#322942).
- IB: nes: convert to use DRIVER_ATTR_RW (bsc#1046306
  FATE#322942).
- commit 0b03922
* Fri Sep 29 2017 jroedel@suse.de
- iommu/vt-d: Avoid calling virt_to_phys() on null pointer
  (bsc#1061067).
- commit 1047702
* Fri Sep 29 2017 tbogendoerfer@suse.de
- Delete
  patches.drivers/RDMA-Simplify-get-firmware-interface.patch.
- commit 60fa778
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/hfi1: Always perform offline transition (bsc#1060463
  FATE#323043).
- IB/hfi1: Prevent link down request double queuing (bsc#1060463
  FATE#323043).
- IB/hfi1: Create workqueue for link events (bsc#1060463
  FATE#323043).
- IB/hfi1: Disambiguate corruption and uninitialized error cases
  (bsc#1060463 FATE#323043).
- IB/hfi1: Only set fd pointer when base context is completely
  initialized (bsc#1060463 FATE#323043).
- IB/hfi1: Do not enable disabled port on cable insert
  (bsc#1060463 FATE#323043).
- IB/hfi1: Harden state transition to Armed and Active
  (bsc#1060463 FATE#323043).
- IB/hfi1: Split copy_to_user data copy for better security
  (bsc#1060463 FATE#323043).
- IB/hfi1: Verify port data VLs credits on transition to Armed
  (bsc#1060463 FATE#323043).
- IB/hfi1: Move saving PCI values to a separate function
  (bsc#1060463 FATE#323043).
- IB/hfi1: Fix initialization failure for debug firmware
  (bsc#1060463 FATE#323043).
- IB/hfi1: Fix code consistency for if/else blocks in chip.c
  (bsc#1060463 FATE#323043).
- IB/hfi1: Send MAD traps until repressed (bsc#1060463
  FATE#323043).
- IB/hfi1: Pass the context pointer rather than the index
  (bsc#1060463 FATE#323043).
- IB/hfi1: Use context pointer rather than context index
  (bsc#1060463 FATE#323043).
- IB/hfi1: Size rcd array index correctly and consistently
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove unused user context data members (bsc#1060463
  FATE#323043).
- IB/hfi1: Assign context does not clean up file descriptor
  correctly on error (bsc#1060463 FATE#323043).
- IB/hfi1: Serve the most starved iowait entry first (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix bar0 mapping to use write combining (bsc#1060463
  FATE#323043).
- IB/hfi1: Check return values from PCI config API calls
  (bsc#1060463 FATE#323043).
- IB/hfi1: Add receiving queue info to qp_stats (bsc#1060463
  FATE#323043).
- IB/qib: remove duplicate code (bsc#1027067 FATE#322649).
- commit 6163efb
* Fri Sep 29 2017 jroedel@suse.de
- PCI: pciehp: Report power fault only once until we clear it
  (bsc#1061046).
- commit c7e1a71
* Fri Sep 29 2017 tbogendoerfer@suse.de
- bnxt_en: fix switchdev port naming for external-port-rep and
  vf-reps (bsc#1050242 FATE#322914).
- bnxt_en: use SWITCHDEV_SET_OPS() for setting
  vf_rep_switchdev_ops (bsc#1050242 FATE#322914).
- bnxt_en: include bnxt_vfr.c code under CONFIG_BNXT_SRIOV switch
  (bsc#1050242 FATE#322914).
- bnxt: fix unused variable warnings (bsc#1050242 FATE#322914).
- bnxt: fix unsigned comparsion with 0 (bsc#1050242 FATE#322914).
- bnxt_en: Use SWITCHDEV_SET_OPS() (bsc#1050242 FATE#322914).
- bnxt_en: add support for port_attr_get and and
  get_phys_port_name (bsc#1050242 FATE#322914).
- bnxt_en: add vf-rep RX/TX and netdev implementation (bsc#1050242
  FATE#322914).
- bnxt_en: add support to enable VF-representors (bsc#1050242
  FATE#322914).
- bnxt_en: Set ETS min_bw parameter for older firmware
  (bsc#1050242 FATE#322914).
- bnxt_en: Report firmware DCBX agent (bsc#1050242 FATE#322914).
- bnxt_en: Allow the user to set ethtool stats-block-usecs to 0
  (bsc#1050242 FATE#322914).
- bnxt_en: Add bnxt_get_num_stats() to centrally get the number
  of ethtool stats (bsc#1050242 FATE#322914).
- bnxt_en: Implement ndo_bridge_{get|set}link methods (bsc#1050242
  FATE#322914).
- bnxt_en: Retrieve the hardware bridge mode from the firmware
  (bsc#1050242 FATE#322914).
- bnxt_en: Update firmware interface spec to 1.8.0 (bsc#1050242
  FATE#322914).
- commit aa23996
* Fri Sep 29 2017 tbogendoerfer@suse.de
- RDMA/bnxt_re: remove unnecessary call to memset (bsc#1050244
  FATE#322915).
- RDMA: Fix return value check for ib_get_eth_speed() (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Implement the alloc/get_hw_stats callback
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Allocate multiple notification queues (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: fix spelling mistake: "Deallocte" -> "Deallocate"
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Allow posting when QPs are in error (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Add vlan tag for untagged RoCE traffic when PFC
  is configured (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Delete unsupported modify_port function
  (bsc#1050244 FATE#322915).
- commit 94e058a
* Fri Sep 29 2017 tbogendoerfer@suse.de
- IB/cma: Fix default RoCE type setting (bsc#1046306 FATE#322942).
- IB/core: Add generic function to extract IB speed from netdev
  (bsc#1046306 FATE#322942).
- IB/usnic: Implement get_netdev hook (bsc#1046306 FATE#322942).
- IB/cma: Set default gid type to RoCEv2 (bsc#1046306
  FATE#322942).
- commit 1582933
* Fri Sep 29 2017 tbogendoerfer@suse.de
- mlx4: Replace PCI pool old API (bsc#1046300 FATE#322946).
- IB/mlx4: Expose RSS capabilities (bsc#1046302 FATE#322945).
- IB/mlx4: Add support for RSS QP (bsc#1046302 FATE#322945).
- IB/mlx4: Add support for WQ indirection table related verbs
  (bsc#1046302 FATE#322945).
- IB/mlx4: Add support for WQ related verbs (bsc#1046302
  FATE#322945).
- (IB, net)/mlx4: Add resource utilization support (bsc#1046302
  FATE#322945 bsc#1046300 FATE#322946 bsc#1046299 FATE#322947).
- IB/mlx4: Add inline-receive support (bsc#1046302 FATE#322945).
- commit 8e2d33f
* Fri Sep 29 2017 tbogendoerfer@suse.de
- net/mlx5: fix spelling mistake: "alloated" -> "allocated"
  (bsc#1046303 FATE#322944).
- IB/mlx5: Expose extended error counters (bsc#1046305
  FATE#322943).
- IB/mlx5: Fix cached MR allocation flow (bsc#1046305
  FATE#322943).
- IB/mlx5: Report RX checksum capabilities for IPoIB (bsc#1046305
  FATE#322943).
- net/mlx5: Report enhanced capabilities for IPoIB (bsc#1046303
  FATE#322944).
- IB/mlx5: Add multicast flow steering support for underlay QP
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add support for QP with a given source QPN (bsc#1046305
  FATE#322943).
- IB/mlx5: Add delay drop configuration and statistics
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add support to dropless RQ (bsc#1046305 FATE#322943).
- net/mlx5: Introduce general notification event (bsc#1046303
  FATE#322944).
- net/mlx5: Introduce set delay drop command (bsc#1046303
  FATE#322944).
- IB/mlx5: Restore IB guid/policy for virtual functions
  (bsc#1046305 FATE#322943).
- IB/mlx5: Add debug control parameters for congestion control
  (bsc#1046305 FATE#322943).
- IB/mlx5: Change logic for dispatching IB events for port state
  (bsc#1046305 FATE#322943).
- net/mlx5e: Enable local loopback in loopback selftest
  (bsc#1046303 FATE#322944).
- IB/mlx5: Add raw ethernet local loopback support (bsc#1046305
  FATE#322943).
- net/mlx5: Add raw ethernet local loopback firmware command
  (bsc#1046303 FATE#322944).
- commit 08c6c4f
* Fri Sep 29 2017 jroedel@suse.de
- KVM: VMX: do not change SN bit in vmx_update_pi_irte()
  (bsc#1061017).
- KVM: nVMX: Update vmcs12->guest_linear_address on nested VM-exit
  (bsc#1061017).
- KVM: async_pf: Fix #DF due to inject "Page not Present" and
  "Page Ready" exceptions simultaneously (bsc#1061017).
- KVM: VMX: remove WARN_ON_ONCE in
  kvm_vcpu_trigger_posted_interrupt (bsc#1061017).
- KVM: SVM: Add a missing 'break' statement (bsc#1061017).
- commit 037fe31
* Fri Sep 29 2017 jroedel@suse.de
- Delete patches.arch/0002-KVM-Don-t-accept-obviously-wrong-gsi-values-via-KVM_.patch.
  Patch was reverted upstream.
- commit b3eafff
* Fri Sep 29 2017 jroedel@suse.de
- Refresh patches.arch/0001-KVM-VMX-Do-not-BUG-on-out-of-bounds-guest-IRQ.patch.
  Add upstream commit-id and Patch-mainline information.
- commit 546cb89
* Thu Sep 28 2017 mgorman@suse.de
- Update config files.
- commit e7bab09
* Wed Sep 27 2017 dbueso@suse.de
- kvm,mips: Fix potential swait_active() races (bsc#1060747).
- kvm,powerpc: Serialize wq active checks in ops->vcpu_kick
  (bsc#1060747).
- kvm: Serialize wq active checks in kvm_vcpu_wake_up()
  (bsc#1060747).
- kvm,x86: Fix apf_task_wake_one() wq serialization (bsc#1060747).
- kvm,lapic: Justify use of swait_active() (bsc#1060747).
- kvm,async_pf: Use swq_has_sleeper() (bsc#1060747).
- sched/wait: Add swq_has_sleeper() (bsc#1060747).
- swait: Add idle variants which don't contribute to load average
  (bsc#1060747).
- commit e57f3cb
* Wed Sep 27 2017 jslaby@suse.cz
- Linux 4.12.14 (bnc#1060662).
- ipv6: accept 64k - 1 packet length in ip6_find_1stfragopt()
  (bnc#1060662).
- ipv6: add rcu grace period before freeing fib6_node
  (bnc#1060662).
- ipv6: fix sparse warning on rt6i_node (bnc#1060662).
- macsec: add genl family module alias (bnc#1060662).
- udp: on peeking bad csum, drop packets even if not at head
  (bnc#1060662).
- bpf: fix map value attribute for hash of maps (bnc#1060662).
- fsl/man: Inherit parent device and of_node (bnc#1060662).
- sctp: Avoid out-of-bounds reads from address storage
  (bnc#1060662).
- tipc: Fix tipc_sk_reinit handling of -EAGAIN (bnc#1060662).
- net: systemport: Be drop monitor friendly (bnc#1060662).
- net: bcmgenet: Be drop monitor friendly (bnc#1060662).
- net: systemport: Free DMA coherent descriptors on errors
  (bnc#1060662).
- netvsc: fix deadlock betwen link status and removal
  (bnc#1060662).
- udp6: set rx_dst_cookie on rx_dst updates (bnc#1060662).
- net: mvpp2: fix the mac address used when using PPv2.2
  (bnc#1060662).
- ipv6: set dst.obsolete when a cached route has expired
  (bnc#1060662).
- ipv6: do not set sk_destruct in IPV6_ADDRFORM sockopt
  (bnc#1060662).
- packet: Don't write vnet header beyond end of buffer
  (bnc#1060662).
- kcm: do not attach PF_KCM sockets to avoid deadlock
  (bnc#1060662).
- net: dsa: bcm_sf2: Fix number of CFP entries for BCM7278
  (bnc#1060662).
- Revert "net: phy: Correctly process PHY_HALTED in
  phy_stop_machine()" (bnc#1060662).
- net: fec: Allow reception of frames bigger than 1522 bytes
  (bnc#1060662).
- mlxsw: spectrum: Forbid linking to devices that have uppers
  (bnc#1060662).
- bridge: switchdev: Clear forward mark when transmitting packet
  (bnc#1060662).
- Revert "net: use lib/percpu_counter API for fragmentation mem
  accounting" (bnc#1060662).
- Revert "net: fix percpu memory leaks" (bnc#1060662).
- gianfar: Fix Tx flow control deactivation (bnc#1060662).
- vhost_net: correctly check tx avail during rx busy polling
  (bnc#1060662).
- ip6_gre: update mtu properly in ip6gre_err (bnc#1060662).
- ipv6: fix memory leak with multiple tables during netns
  destruction (bnc#1060662).
- ipv6: fix typo in fib6_net_exit() (bnc#1060662).
- sctp: fix missing wake ups in some situations (bnc#1060662).
- f2fs: let fill_super handle roll-forward errors (bnc#1060662).
- f2fs: check hot_data for roll-forward recovery (bnc#1060662).
- x86/fsgsbase/64: Fully initialize FS and GS state in
  start_thread_common (bnc#1060662).
- x86/fsgsbase/64: Report FSBASE and GSBASE correctly in core
  dumps (bnc#1060662).
- x86/switch_to/64: Rewrite FS/GS switching yet again to fix
  AMD CPUs (bnc#1060662).
- fuse: allow server to run in different pid_ns (bnc#1060662).
- idr: remove WARN_ON_ONCE() when trying to replace negative ID
  (bnc#1060662).
- md/raid1/10: reset bio allocated from mempool (bnc#1060662).
- md/raid5: release/flush io in raid5_do_work() (bnc#1060662).
- ipv6: Fix may be used uninitialized warning in rt6_check
  (bnc#1060662).
- Refresh
  patches.drivers/net-sock-factor-out-dequeue-peek-with-offset-code.patch.
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- commit ffd2366
* Wed Sep 27 2017 mgorman@suse.de
- mm: hugetlb: clear target sub-page last when clearing huge page
  (bnc#971975 VM performance -- thp).
- commit ba31982
* Wed Sep 27 2017 jack@suse.cz
- Disable CONFIG_DEBUG_LIST (bsc#1060256)
  CONFIG_DEBUG_LIST adds some consistency checks into list handling
  operations. Additional fetches resulting from this are visible in the
  perf profile accounting for about 3.5%% of the pagecache truncation path.
  Disable the option to avoid the overhead as it was enabled more or less
  inadvertedly.
  We also have to disable CONFIG_BUG_ON_DATA_CORRUPTION as that selects
  CONFIG_DEBUG_LIST.
- commit 1748d9c
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/core: Fix for core panic (bsc#1046306 FATE#322942).
- IB/{rdmavt, hfi1, qib}: Fix panic with post receive and SGE
  compression (bsc#1058717 FATE#322789).
- commit 92c6c71
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/uverbs: Enable QP creation with a given source QP number
  (bsc#1046306 FATE#322942).
- IB/core: Enable QP creation with a given source QP number
  (bsc#1046306 FATE#322942).
- IB/core: Add support for RoCEv2 multicast (bsc#1046306
  FATE#322942).
- IB/core: Set RoCEv2 MGID according to spec (bsc#1046306
  FATE#322942).
- IB/core: Fix the validations of a multicast LID in attach or
  detach operations (bsc#1046306 FATE#322942).
- IB/core: Introduce delay drop for a WQ (bsc#1046306
  FATE#322942).
- commit 4537464
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/rxe: Constify static rxe_vm_ops (bsc#1050662 FATE#323951).
- IB/rxe: Use __func__ to print function's name (bsc#1050662
  FATE#323951).
- IB/rxe: Use DEVICE_ATTR_RO macro to show parent field
  (bsc#1050662 FATE#323951).
- IB/rxe: Prefer 'unsigned int' to bare use of 'unsigned'
  (bsc#1050662 FATE#323951).
- IB/rxe: Use "foo *bar" instead of "foo * bar" (bsc#1050662
  FATE#323951).
- commit fab70b3
* Tue Sep 26 2017 tbogendoerfer@suse.de
- IB/hfi1: Handle missing magic values in config file (bsc#1060463
  FATE#323043).
- IB/hfi1: Resolve kernel panics by reference counting receive
  contexts (bsc#1060463 FATE#323043).
- IB/hfi1: Initialize TID lists to avoid crash on cleanup
  (bsc#1060463 FATE#323043).
- IB/qib: Replace deprecated pci functions with new API
  (bsc#1027067 FATE#322649).
- IB/hfi1: Add traces for TID operations (bsc#1060463
  FATE#323043).
- IB/hfi1: Use a template for tid reg/unreg (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove reading platform configuration from EFI variable
  (bsc#1060463 FATE#323043).
- IB/hfi1: Create common expected receive verbs/PSM code
  (bsc#1060463 FATE#323043).
- IB/hfi1: Set proper logging levels on QSFP cable error events
  (bsc#1060463 FATE#323043).
- IB/hfi1: Fix DC 8051 host info flag array (bsc#1060463
  FATE#323043).
- IB/hfi1,qib: Do not send QKey trap for UD qps (bsc#1060463
  FATE#323043).
- IB/hfi1: Modify handling of physical link state by Host Driver
  (bsc#1060463 FATE#323043).
- IB/core: Allow QP state transition from reset to error
  (bsc#1046306 FATE#322942).
- IB/hfi1: Add error checking for buffer overrun in OPA aggregate
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove subtraction of uninitialized value (bsc#1060463
  FATE#323043).
- IB/hfi1: Use QPN mask to avoid overflow (bsc#1060463
  FATE#323043).
- IB/hfi1: Fix spelling mistake in linkdown reason (bsc#1060463
  FATE#323043).
- IB/rdmavt: Remove duplicated functions (bsc#1058717
  FATE#322789).
- IB/hfi1: Fix up sdma_init function comment (bsc#1060463
  FATE#323043).
- IB/hfi1: Reclassify type of messages printed for platform
  config logic (bsc#1060463 FATE#323043).
- IB/hfi1: Remove atomic SDMA_REQ_HAS_ERROR bit operation
  (bsc#1060463 FATE#323043).
- IB/hfi1: Remove atomic SDMA_REQ_SEND_DONE bit operation
  (bsc#1060463 FATE#323043).
- IB/core,rdmavt,hfi1,opa-vnic: Send OPA cap_mask3 in trap
  (bsc#1060463 FATE#323043 bsc#1058717 FATE#322789 bsc#1046306
  FATE#322942).
- IB/hfi1: Replace deprecated pci functions with new API
  (bsc#1060463 FATE#323043).
- IB/hfi1: Name function prototype parameters for affinity module
  (bsc#1060463 FATE#323043).
- IB/hfi1: Optimize cachelines for user SDMA request structure
  (bsc#1060463 FATE#323043).
- IB/hfi1: Don't remove RB entry when not needed (bsc#1060463
  FATE#323043).
- IB/rdmavt: Compress adjacent SGEs in rvt_lkey_ok() (bsc#1058717
  FATE#322789).
- IB/hfi1: Setup common IB fields in hfi1_packet struct
  (bsc#1060463 FATE#323043).
- IB/hfi1: Separate input/output header tracing (bsc#1060463
  FATE#323043).
- IB/hfi1: Add functions to parse BTH/IB headers (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove unused mk_qpn function (bsc#1060463
  FATE#323043).
- IB/hfi1: Remove unnecessary initialization from tx request
  (bsc#1060463 FATE#323043).
- commit 0a0be08
* Tue Sep 26 2017 bp@suse.de
- EDAC: Add owner check to the x86 platform drivers (bsc#1042420).
- Update config files.
- EDAC: Add helper which returns the loaded platform driver
  (bsc#1042420).
- EDAC, ghes: Add platform check (bsc#1042420).
- EDAC, ghes: Model a single, logical memory controller
  (bsc#1042420).
- EDAC, ghes: Remove symbol exports (bsc#1042420).
- intel_pstate: convert to use acpi_match_platform_list()
  (bsc#1042420).
- commit 0ef43b8
* Tue Sep 26 2017 tonyj@suse.de
- Refresh
  patches.arch/perf-vendor-events-powerpc-remove-duplicate-events.patch.
- commit 7117699
* Tue Sep 26 2017 tbogendoerfer@suse.de
- nfp: only use direct firmware requests (bsc#1055968).
- nfp: look for firmware image by device serial number and PCI
  name (bsc#1055968).
- nfp: remove the probe deferral when FW not present
  (bsc#1055968).
- nfp: set config bit (ifup/ifdown) on netdev open/close
  (bsc#1055968).
- commit 2e0e280
* Tue Sep 26 2017 tbogendoerfer@suse.de
- cxgb4: ethtool forward error correction management support
  (bsc#1046540 FATE#322930).
- cxgb4: core hardware/firmware support for Forward Error
  Correction on a link (bsc#1046540 FATE#322930).
- net: ethtool: add support for forward error correction modes
  (bsc#1046540 FATE#322930).
- cxgb4: display serial config and vpd versions (bsc#1046540
  FATE#322930).
- cxgb4: Update register ranges of T4/T5/T6 adapters (bsc#1046540
  FATE#322930).
- cxgb4: Remove some dead code (bsc#1046540 FATE#322930).
- commit 8b2ccca
* Tue Sep 26 2017 tbogendoerfer@suse.de
- RDMA: Simplify get firmware interface (bsc#1046543 FATE#322927).
- RDMA: Remove useless MODULE_VERSION (bsc#1046543 FATE#322927).
- commit 28a0467
* Tue Sep 26 2017 jthumshirn@suse.de
- fs/fcntl: use copy_to/from_user() for u64 types (FATE#323952,
  FATE#322506).
- commit aa1d84c
* Mon Sep 25 2017 jslaby@suse.cz
- x86/asm: Fix inline asm call constraints for Clang
  (bnc#1058115).
- objtool: Handle another GCC stack pointer adjustment bug
  (bnc#1058115).
- commit a2e1012
* Mon Sep 25 2017 jslaby@suse.cz
- Linux 4.12.13 (bnc#1060662).
- mtd: nand: make Samsung SLC NAND usable again (bnc#1060662).
- mtd: nand: hynix: add support for 20nm NAND chips (bnc#1060662).
- mtd: nand: mxc: Fix mxc_v1 ooblayout (bnc#1060662).
- mtd: nand: qcom: fix read failure without complete bootchain
  (bnc#1060662).
- mtd: nand: qcom: fix config error for BCH (bnc#1060662).
- nvme-fabrics: generate spec-compliant UUID NQNs (bnc#1060662).
- btrfs: resume qgroup rescan on rw remount (bnc#1060662).
- rtlwifi: btcoexist: Fix breakage of ant_sel for rtl8723be
  (bnc#1060662).
- radix-tree: must check __radix_tree_preload() return value
  (bnc#1060662).
- selftests/x86/fsgsbase: Test selectors 1, 2, and 3
  (bnc#1060662).
- mm: kvfree the swap cluster info if the swap file is
  unsatisfactory (bnc#1060662).
- mm/swapfile.c: fix swapon frontswap_map memory leak on error
  (bnc#1060662).
- mm/memory.c: fix mem_cgroup_oom_disable() call missing
  (bnc#1060662).
- ALSA: msnd: Optimize / harden DSP and MIDI loops (bnc#1060662).
- KVM: SVM: Limit PFERR_NESTED_GUEST_PAGE error_code check to
  L1 guest (bnc#1060662).
- Bluetooth: Properly check L2CAP config option output buffer
  length (bnc#1060662 bnc#1057389 CVE-2017-1000251).
- ARM64: dts: marvell: armada-37xx: Fix GIC maintenance interrupt
  (bnc#1060662).
- ARM: 8692/1: mm: abort uaccess retries upon fatal signal
  (bnc#1060662).
- NFS: Fix 2 use after free issues in the I/O code (bnc#1060662).
- NFS: Sync the correct byte range during synchronous writes
  (bnc#1060662).
- NFSv4: Fix up mirror allocation (bnc#1060662).
- xfs: XFS_IS_REALTIME_INODE() should be false if no rt device
  present (bnc#1060662).
- commit 5f5d623
* Mon Sep 25 2017 jthumshirn@suse.de
- PCI: Split ->reset_notify() method into ->reset_prepare()
  and ->reset_done() (FATE#323952, FATE#322506).
- fs: add fcntl() interface for setting/getting write life time
  hints (FATE#323952, FATE#322506).
- lightnvm: propagate right error code to target (FATE#323952,
  FATE#322506).
- nvme: Allocate queues for all possible CPUs (FATE#323952,
  FATE#322506).
- nvme: Don't allow to reset a reconnecting controller
  (FATE#323952, FATE#322506).
- nvme: Makefile: remove dead build rule (FATE#323952,
  FATE#322506).
- nvme: Move transports to use nvme-core workqueue (FATE#323952,
  FATE#322506).
- nvme: Quirks for PM1725 controllers (FATE#323952, FATE#322506).
- nvme: Remove SCSI translations (FATE#323952, FATE#322506,
  FATE#323537).
- nvme: add fields into identify controller data structure
  (FATE#323952, FATE#322506).
- nvme: add hostid token to fabric options (FATE#323952,
  FATE#322506).
- nvme: add support for streams and directives (FATE#323952,
  FATE#322506).
- nvme: also provide a UUID in the WWID sysfs attribute
  (FATE#323952, FATE#322506).
- nvme: don't hard code size of struct t10_pi_tuple (FATE#323952,
  FATE#322506).
- nvme: explicitly disable APST on quirked devices (FATE#323952,
  FATE#322506).
- nvme: fabrics commands should use the fctype field for data
  direction (FATE#323952, FATE#322506).
- nvme-fabrics: fix reporting of unrecognized options
  (FATE#323952, FATE#322506).
- nvme-fabrics: verify that a controller returns the correct NQN
  (FATE#323952, FATE#322506).
- nvme-fc: address target disconnect race conditions in fcp io
  submit (FATE#323952, FATE#322506).
- nvme-fc: don't override opts->nr_io_queues (FATE#323952,
  FATE#322506).
- nvme-fc: merge init_request methods (FATE#323952, FATE#322506).
- nvme-fc: quiesce/unquiesce admin_q instead of start/stop its
  hw queues (FATE#323952, FATE#322506).
- nvme-fc: revise TRADDR parsing (FATE#323952, FATE#322506).
- nvme-fc: update tagset nr_hw_queues after queues reinit
  (FATE#323952, FATE#322506).
- nvme-fc: use blk_mq_delay_run_hw_queue instead of open-coding it
  (FATE#323952, FATE#322506).
- nvme: fix byte swapping in the streams code (FATE#323952,
  FATE#322506).
- nvme: fix directive command numd calculation (FATE#323952,
  FATE#322506).
- nvme: fix nvme reset command timeout handling (FATE#323952,
  FATE#322506).
- nvme: get list of namespace descriptors (FATE#323952,
  FATE#322506).
- nvme: host: unquiesce queue in nvme_kill_queues() (FATE#323952,
  FATE#322506).
- nvme: implement NS Optimal IO Boundary from 1.3 Spec
  (FATE#323952, FATE#322506).
- nvme: introduce NVMe Namespace Identification Descriptor
  structures (FATE#323952, FATE#322506).
- nvme: kick requeue list when requeueing a request instead of
  when starting the queues (FATE#323952, FATE#322506).
- nvme-lightnvm: use blk_execute_rq in nvme_nvm_submit_user_cmd
  (FATE#323952, FATE#322506).
- nvme-loop: get rid of unused controller lock (FATE#323952,
  FATE#322506).
- nvme-loop: merge init_request methods (FATE#323952,
  FATE#322506).
- nvme-loop: quiesce/unquiesce admin_q instead of start/stop
  its hw queues (FATE#323952, FATE#322506).
- nvme-loop: update tagset nr_hw_queues after
  reconnecting/resetting (FATE#323952, FATE#322506).
- nvme: mark shutdown_timeout static (FATE#323952, FATE#322506).
- nvme: move ctrl cap to struct nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: move nr_reconnects to nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: move protection information check into nvme_setup_rw
  (FATE#323952, FATE#322506).
- nvme: move queue_count to the nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: move reset workqueue handling to common code (FATE#323952,
  FATE#322506).
- nvme: no need to wait for the reset when keepalive fails
  (FATE#323952, FATE#322506).
- nvme-pci: Fix an error handling path in 'nvme_probe()'
  (FATE#323952, FATE#322506).
- nvme-pci: Introduce nvme_ring_cq_doorbell (FATE#323952,
  FATE#322506).
- nvme-pci: Remove nvme_setup_prps BUG_ON (FATE#323952,
  FATE#322506).
- nvme-pci: Remove watchdog timer (FATE#323952, FATE#322506).
- nvme-pci: add another device ID with stripe quirk (FATE#323952,
  FATE#322506).
- nvme-pci: add module parameter for io queue depth (FATE#323952,
  FATE#322506).
- nvme-pci: compile warnings in nvme_alloc_host_mem()
  (FATE#323952, FATE#322506).
- nvme-pci: factor out cqe handling into a dedicated routine
  (FATE#323952, FATE#322506).
- nvme-pci: factor out the cqe reading mechanics from
  __nvme_process_cq (FATE#323952, FATE#322506).
- nvme-pci: fix CMB sysfs file removal in reset path (FATE#323952,
  FATE#322506).
- nvme-pci: fix HMB size calculation (FATE#323952, FATE#322506).
- nvme-pci: implement host memory buffer support (FATE#323952,
  FATE#322506).
- nvme-pci: merge init_request methods (FATE#323952, FATE#322506).
- nvme-pci: open-code polling logic in nvme_poll (FATE#323952,
  FATE#322506).
- nvme-pci: quiesce/unquiesce admin_q instead of start/stop its
  hw queues (FATE#323952, FATE#322506).
- nvme-pci: remap BAR0 to cover admin CQ doorbell for large stride
  (FATE#323952, FATE#322506).
- nvme-pci: remove redundant includes (FATE#323952, FATE#322506).
- nvme-pci: rename to nvme_pci_configure_admin_queue (FATE#323952,
  FATE#322506).
- nvme-pci: set cqe_seen on polled completions (FATE#323952,
  FATE#322506).
- nvme-pci: use dma memory for the host memory buffer descriptors
  (FATE#323952, FATE#322506).
- nvme: provide UUID value to userspace (FATE#323952,
  FATE#322506).
- nvme: queue ns scanning and async request from nvme_wq
  (FATE#323952, FATE#322506).
- nvme-rdma: Don't rearm the CQ when polling directly
  (FATE#323952, FATE#322506).
- nvme-rdma: Get rid of CONNECTED state (FATE#323952,
  FATE#322506).
- nvme-rdma: Make queue flags bit numbers and not shifts
  (FATE#323952, FATE#322506).
- nvme-rdma: default MR page size to 4k (FATE#323952,
  FATE#322506).
- nvme-rdma: fix error code in nvme_rdma_create_ctrl()
  (FATE#323952, FATE#322506).
- nvme-rdma: get rid of unused ctrl lock (FATE#323952,
  FATE#322506).
- nvme-rdma: make nvme_rdma_[create|destroy]_queue_ib symmetrical
  (FATE#323952, FATE#322506).
- nvme-rdma: merge init_request and exit_request methods
  (FATE#323952, FATE#322506).
- nvme-rdma: quiesce/unquiesce admin_q instead of start/stop
  its hw queues (FATE#323952, FATE#322506).
- nvme-rdma: rework rdma connection establishment error path
  (FATE#323952, FATE#322506).
- nvme-rdma: unconditionally recycle the request mr (FATE#323952,
  FATE#322506).
- nvme-rdma: update tagset nr_hw_queues after
  reconnecting/resetting (FATE#323952, FATE#322506).
- nvme: read the subsystem NQN from Identify Controller
  (FATE#323952, FATE#322506).
- nvme: remove a misleading comment on struct nvme_ns
  (FATE#323952, FATE#322506).
- nvme: rename uuid to nguid in nvme_ns (FATE#323952,
  FATE#322506).
- nvme: save hmpre and hmmin in struct nvme_ctrl (FATE#323952,
  FATE#322506).
- nvme: simplify nvme_dev_attrs_are_visible (FATE#323952,
  FATE#322506).
- nvme: split nvme_uninit_ctrl into stop and uninit (FATE#323952,
  FATE#322506).
- nvme: strip trailing 0-bytes in wwid_show (FATE#323952,
  FATE#322506).
- nvme: switch to uuid_t (FATE#323952, FATE#322506).
- nvme: use a single NVME_AQ_DEPTH and relax it to 32
  (FATE#323952, FATE#322506).
- nvme: use ctrl->device consistently for logging (FATE#323952,
  FATE#322506).
- nvme: validate admin queue before unquiesce (FATE#323952,
  FATE#322506).
- nvme.h: add dword 12 - 15 fields to struct nvme_features
  (FATE#323952, FATE#322506).
- nvme.h: add struct nvme_host_mem_buf_desc and HMB flags
  (FATE#323952, FATE#322506).
- nvme_fc: Fix crash when nvme controller connection fails
  (FATE#323952, FATE#322506).
- nvme_fc: fix double calls to nvme_cleanup_cmd() (FATE#323952,
  FATE#322506).
- nvme_fc: fix error recovery on link down (FATE#323952,
  FATE#322506).
- nvme_fc/nvmet_fc: revise Create Association descriptor length
  (FATE#323952, FATE#322506).
- nvme_fc: replace ioabort msleep loop with completion
  (FATE#323952, FATE#322506).
- nvmet: Move serial number from controller to subsystem
  (FATE#323952, FATE#322506).
- nvmet: add uuid field to nvme_ns and populate via configfs
  (FATE#323952, FATE#322506).
- nvmet: allow overriding the NVMe VS via configfs (FATE#323952,
  FATE#322506).
- nvmet: avoid unneeded assignment of submit_bio return value
  (FATE#323952, FATE#322506).
- nvmet: don't overwrite identify sn/fr with 0-bytes (FATE#323952,
  FATE#322506).
- nvmet: don't report 0-bytes in serial number (FATE#323952,
  FATE#322506).
- nvmet-fc: Remove a set-but-not-used variable (FATE#323952,
  FATE#322506).
- nvmet-fc: correct use after free on list teardown (FATE#323952,
  FATE#322506).
- nvmet-fc: eliminate incorrect static markers on local variables
  (FATE#323952, FATE#322506).
- nvmet-fc: fix byte swapping in nvmet_fc_ls_create_association
  (FATE#323952, FATE#322506).
- nvmet: implement namespace identify descriptor list
  (FATE#323952, FATE#322506).
- nvmet: prefix version configfs file with attr (FATE#323952,
  FATE#322506).
- nvmet: preserve controller serial number between reboots
  (FATE#323952, FATE#322506).
- nvmet-rdma: register ib_client to not deadlock in device removal
  (FATE#323952, FATE#322506).
- nvmet: use NVME_IDENTIFY_DATA_SIZE (FATE#323952, FATE#322506).
- nvmet_fc: Accept variable pad lengths on Create Association LS
  (FATE#323952, FATE#322506).
- nvmet_fc: add defer_req callback for deferment of cmd buffer
  return (FATE#323952, FATE#322506).
- nvmet_fc: fix crashes on bad opcodes (FATE#323952, FATE#322506).
- nvmf: keep track of nvmet connect error status (FATE#323952,
  FATE#322506).
- scatterlist: add sg_zero_buffer() helper (FATE#323952,
  FATE#322506).
- Delete
  patches.suse/0001-lightnvme-fix-compiling-error-for-blk_status_t.patch.
- commit b7fe62e
* Mon Sep 25 2017 mgorman@suse.de
- cpufreq, ondemand: Set default up_threshold to 40 on multi-core
  systems (bnc#464461,bnc#981838).
- commit 91e0473
* Mon Sep 25 2017 jthumshirn@suse.de
- series.conf: Move block-layer patches into sorted patch section
  Refresh
  patches.suse/0004-cfq-iosched-Delete-unused-function-min_vdisktime.patch.
- commit fec2137
* Mon Sep 25 2017 jthumshirn@suse.de
- series.conf: Let SCSI patches follow the upstream order and place them
  into the ordered section of series.conf
- commit 7b4f251
* Sun Sep 24 2017 msuchanek@suse.de
- rpm/kernel-binary.spec.in: only rewrite modules.dep if non-zero in size
  (bsc#1056979).
- commit 75691fd
* Sat Sep 23 2017 agraf@suse.de
- supported.conf: follow upstream rename of bcm2835-sdio to bcm2835
- commit e19f882
* Fri Sep 22 2017 tbogendoerfer@suse.de
- nfp: add whitelist of supported flow dissector (bsc#1055968).
- commit b6ed7d2
* Fri Sep 22 2017 tbogendoerfer@suse.de
- net_sched: fix reference counting of tc filter chain
  (bsc#1056787).
- commit 157c20a
* Fri Sep 22 2017 tbogendoerfer@suse.de
- move pcie relaxed order patches to sorted section for cxgb4
- commit 1ddb2fb
* Fri Sep 22 2017 lduncan@suse.com
- scsi: be2iscsi: Replace PCI pool old API (bsc#1050253).
- commit c409c57
* Thu Sep 21 2017 lduncan@suse.com
- scsi: bnx2i: Simplify cpu hotplug code (bsc#1050314).
- scsi: bnx2i: Prevent recursive cpuhotplug locking (bsc#1050314).
- commit 6746c96
* Thu Sep 21 2017 jroedel@suse.de
- KVM: SVM: Add irqchip_split() checks before enabling AVIC
  (bsc#1044503).
- KVM: Add struct kvm_vcpu pointer parameter to get_enable_apicv()
  (bsc#1044503).
- KVM: SVM: Refactor AVIC vcpu initialization into
  avic_init_vcpu() (bsc#1044503).
- commit ffdf86f
* Thu Sep 21 2017 jroedel@suse.de
- iommu/amd: Fix section mismatch warning (bsc#1043261).
- iommu/amd: Fix compiler warning in copy_device_table()
  (bsc#1043261).
- iommu/amd: Check if domain is NULL in get_domain() and return
  - EBUSY (bsc#1043261).
- iommu/amd: Disable iommu only if amd_iommu=off is specified
  (bsc#1043261).
- iommu/amd: Don't copy GCR3 table root pointer (bsc#1043261).
- iommu/amd: Allocate memory below 4G for dev table if translation
  pre-enabled (bsc#1043261).
- iommu/amd: Use is_attach_deferred call-back (bsc#1043261).
- iommu: Add is_attach_deferred call-back to iommu-ops
  (bsc#1043261).
- iommu/amd: Do sanity check for address translation and irq
  remap of old dev table entry (bsc#1043261).
- iommu/amd: Copy old trans table from old kernel (bsc#1043261).
- iommu/amd: Add function copy_dev_tables() (bsc#1043261).
- iommu/amd: Define bit fields for DTE particularly (bsc#1043261).
- Revert "iommu/amd: Suppress IO_PAGE_FAULTs in kdump kernel"
  (bsc#1043261).
- iommu/amd: Add several helper functions (bsc#1043261).
- iommu/amd: Detect pre enabled translation (bsc#1043261).
- commit 655c694
* Wed Sep 20 2017 mcgrof@suse.com
- xfs: XFS_IS_REALTIME_INODE() should be false if no rt device present (bsc#1058524).
- commit 72f8d25
* Wed Sep 20 2017 mcgrof@suse.com
- nl80211: check for the required netlink attributes presence (bsc#1058410 CVE-2017-12153).
- commit 8769ee8
* Wed Sep 20 2017 oneukum@suse.com
- ACPI / scan: Enable GPEs before scanning the namespace
  (FATE#323948).
- ACPICA: Dispatch active GPEs at init time (FATE#323948).
- ACPICA: Make it possible to enable runtime GPEs earlier
  (FATE#323948).
- Refresh patches.suse/0001-cpuidle-Fix-idle-time-tracking.patch.
- commit 029df21
* Wed Sep 20 2017 jroedel@suse.de
- KVM: SVM: delete avic_vm_id_bitmap (2 megabyte static array)
  (bsc#1059500).
- commit 6783c4c
* Wed Sep 20 2017 jroedel@suse.de
- KVM: SVM: Enable Virtual GIF feature (fate#323405).
- KVM: SVM: Add Virtual GIF feature definition (fate#323405).
- KVM: SVM: suppress unnecessary NMI singlestep on GIF=0 and
  nested exit (fate#323405).
- KVM: SVM: don't NMI singlestep over event injection
  (fate#323405).
- KVM: SVM: hide TF/RF flags used by NMI singlestep (fate#323405).
- KVM: nSVM: do not forward NMI window singlestep VM exits to L1
  (fate#323405).
- KVM: SVM: introduce disable_nmi_singlestep helper (fate#323405).
- commit 82b8a75
* Wed Sep 20 2017 jroedel@suse.de
- PCI: Restore PRI and PASID state after Function-Level Reset
  (fate#322865).
- PCI: Cache PRI and PASID bits in pci_dev (fate#322865).
- commit 085d4a7
* Wed Sep 20 2017 tiwai@suse.de
- qxl: fix pinning (bsc#1057241,bsc#1057123).
- qxl: fix primary surface handling (bsc#1057241,bsc#1057123).
- commit 7c6173e
* Tue Sep 19 2017 jslaby@suse.cz
- objtool: Fix object file corruption (bnc#1058115).
- objtool: Do not retrieve data from empty sections (bnc#1058115).
- objtool: Fix memory leak in elf_create_rela_section()
  (bnc#1058115).
- commit 964c24f
* Mon Sep 18 2017 jthumshirn@suse.de
- Update
  patches.suse/0123-blk-mq-map-all-HWQ-also-in-hyperthreaded-system.patch
  (FATE#1054937).
  The patch has a FATE entry for itself, tag it correctly.
- commit 822ef07
* Mon Sep 18 2017 jack@suse.cz
- orangefs: Don't clear SGID when inheriting ACLs (bsc#1052766).
- commit a58e862
* Mon Sep 18 2017 colyli@suse.de
- Delete patches.drivers/0003-dm-integrity-test-for-corrupted-disk-format-during-t.patch,
  it is in patches.kernel.org/patch-4.12.4-5 already.
- commit cbab9c7
* Sun Sep 17 2017 colyli@suse.de
- lightnvme: fix compiling error for blk_status_t
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 12a6d58
* Sat Sep 16 2017 mcgrof@suse.com
- supported.conf: add test_firmware to new kselftests-kmp package FATE#323821
  This test drivers is present on vanilla so we also enable it there.
- Update config files.
- supported.conf:
- commit cd2246a
* Sat Sep 16 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- Update config files.
- rpm/package-descriptions:
- supported.conf:
- commit 40c878b
* Sat Sep 16 2017 mcgrof@suse.com
- test_firmware: add batched firmware tests (FATE#323821).
- commit b825e51
* Sat Sep 16 2017 mcgrof@suse.com
- test_firmware: add test case for SIGCHLD on sync fallback (FATE#323821).
- commit 616e12d
* Sat Sep 16 2017 mcgrof@suse.com
- firmware: enable a debug print for batched requests (FATE#323821).
- commit 9d0e61c
* Sat Sep 16 2017 mcgrof@suse.com
- firmware: define pr_fmt (FATE#323821).
- commit b59ec48
* Sat Sep 16 2017 mcgrof@suse.com
- firmware: send -EINTR on signal abort on fallback mechanism (FATE#323821).
- commit 47321c2
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: fix sysctl.sh by making it executable (FATE#323821).
- commit 7287239
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: test against int proc_dointvec() array support (FATE#323821).
- commit 291f702
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add simple proc_douintvec() case (FATE#323821).
- commit 3e388c4
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add simple proc_dointvec() case (FATE#323821).
- commit 12b82e3
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: test against PAGE_SIZE for int (FATE#323821).
- commit 59a85c2
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add generic script to expand on tests (FATE#323821).
- commit c47b649
* Sat Sep 16 2017 mcgrof@suse.com
- test_sysctl: add dedicated proc sysctl test driver (FATE#323821).
- commit e27658a
* Sat Sep 16 2017 mcgrof@suse.com
- tools/testing/selftests/sysctl: Add pre-check to the value of writes_strict (FATE#323821).
- commit 784faa7
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: add unsigned int range support (FATE#323821).
- commit 9ccbe48
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: simplify unsigned int support (bsc#1048893).
- commit 5e5055c
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: fold sysctl_writes_strict checks into helper (bsc#1048893).
- commit c687140
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: kdoc'ify sysctl_writes_strict (bsc#1048893).
- commit 1c8d7a1
* Sat Sep 16 2017 mcgrof@suse.com
- sysctl: fix lax sysctl_check_table() sanity check (bsc#1048893).
- commit 626023a
* Fri Sep 15 2017 jroedel@suse.de
- kvm: nVMX: Don't allow L2 to access the hardware CR8
  (bsc#1058507, CVE-2017-12154).
- KVM: Don't accept obviously wrong gsi values via KVM_IRQFD
  (bsc#1058038, CVE-2017-1000252).
- KVM: VMX: Do not BUG() on out-of-bounds guest IRQ (bsc#1058038,
  CVE-2017-1000252).
- commit 7aeea59
* Fri Sep 15 2017 jslaby@suse.cz
- objtool: Assume unannotated UD2 instructions are dead ends
  (bnc#1058115).
- objtool: Fix gcov check for older versions of GCC (bnc#1058115).
- objtool: Fix objtool fallthrough detection with function padding
  (bnc#1058115).
- objtool: Fix validate_branch() return codes (bnc#1058115).
- objtool: Handle GCC stack pointer adjustment bug (bnc#1058115).
- x86/asm: Add ASM_UNREACHABLE (bnc#1058115).
- x86/asm: Fix UNWIND_HINT_REGS macro for older binutils
  (bnc#1058115).
- x86/asm: Make objtool unreachable macros independent from GCC
  version (bnc#1058115).
- objtool: Skip unreachable warnings for 'alt' instructions
  (bnc#1058115).
- objtool: Track DRAP separately from callee-saved registers
  (bnc#1058115).
- objtool: Fix '-mtune=atom' decoding support in objtool 2.0
  (bnc#1058115).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
  Take all ORC upstream patches to be up-to-date.
- commit 5dc7bd3
* Fri Sep 15 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-Fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-Fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-Add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-Add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Delete
  patches.suse/0001-linkage-new-macros-for-assembler-symbols.patch.
- Delete
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Delete
  patches.suse/0003-DWARF-EH-frame-based-stack-unwinding.patch.
- Delete patches.suse/stack-unwind-disable-kasan.patch.
  Update upstream status of ORC and drop already-disabled DWARF
  unwinder.
- commit 87cb5c8
* Fri Sep 15 2017 oneukum@suse.com
- thunderbolt: Fix reset response_type (FATE#323948).
- thunderbolt: Allow clearing the key (FATE#323948).
- thunderbolt: Make key root-only accessible (FATE#323948).
- thunderbolt: Remove superfluous check (FATE#323948).
- thunderbolt: Do not enumerate more ports from DROM than the
  controller has (FATE#323948).
- thunderbolt: icm: Ignore mailbox errors in icm_suspend()
  (FATE#323948).
- thunderbolt: Correct access permissions for active NVM contents
  (FATE#323948).
- thunderbolt: fix spelling mistake: "missmatch" -> "mismatch"
  (FATE#323948).
- thunderbolt: Add support for host and device NVM firmware
  upgrade (FATE#323948).
- thunderbolt: Add support for Internal Connection Manager (ICM)
  (FATE#323948).
- thunderbolt: Do not touch the hardware if the NHI is gone on
  resume (FATE#323948).
- thunderbolt: Add support for DMA configuration based mailbox
  (FATE#323948).
- thunderbolt: Store Thunderbolt generation in the switch
  structure (FATE#323948).
- thunderbolt: Add support for NHI mailbox (FATE#323948).
- thunderbolt: Add new Thunderbolt PCI IDs (FATE#323948).
- thunderbolt: Rework control channel to be more reliable
  (FATE#323948).
- thunderbolt: Let the connection manager handle all notifications
  (FATE#323948).
- thunderbolt: Expose make_header() to other files (FATE#323948).
- thunderbolt: Expose get_route() to other files (FATE#323948).
- thunderbolt: Move control channel messages to tb_msgs.h
  (FATE#323948).
- thunderbolt: Read vendor and device name from DROM
  (FATE#323948).
- thunderbolt: Refactor and fix parsing of port drom entries
  (FATE#323948).
- thunderbolt: Do not fail if DROM data CRC32 is invalid
  (FATE#323948).
- thunderbolt: Fail switch adding operation if reading DROM fails
  (FATE#323948).
- thunderbolt: Convert switch to a device (FATE#323948).
- thunderbolt: Introduce thunderbolt bus and connection manager
  (FATE#323948).
- thunderbolt: Allow passing NULL to tb_ctl_free() (FATE#323948).
- thunderbolt: Rework capability handling (FATE#323948).
- thunderbolt: Add MSI-X support (FATE#323948).
- thunderbolt: Do not warn about newer DROM versions
  (FATE#323948).
- thunderbolt: Do not try to read UID if DROM offset is read as 0
  (FATE#323948).
- commit dc02c6e
* Fri Sep 15 2017 oneukum@suse.com
- thunderbolt: No need to read UID of the root switch on resume
  (FATE#323948).
- thunderbolt: Use const buffer pointer in write operations
  (FATE#323948).
- commit 4cfbced
* Fri Sep 15 2017 mgorman@suse.de
- Refresh
  patches.suse/sched-wait-Break-up-long-wake-list-walk.patch.
- Refresh
  patches.suse/sched-wait-Introduce-wakeup-boomark-in-wake_up_page_bit.patch.
- commit 9f181ab
* Fri Sep 15 2017 mgorman@suse.de
- cpufreq, intel_pstate: Use setpoint of 40%% on servers (bnc#945201).
- commit d39e8fb
* Fri Sep 15 2017 bpoirier@suse.com
- Refresh
  patches.drivers/net-phy-Make-phy_ethtool_ksettings_get-return-void.patch.
  There was a tiny bit of whitespace difference with the upstream commit.
  Correct it in the interest of keeping the expected context.
- commit e744926
* Fri Sep 15 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit b2d9582
* Thu Sep 14 2017 tbogendoerfer@suse.de
- netpoll: shut up a kernel warning on refcount (bsc#1046306
  FATE#322942 bsc#1056787).
- commit 26241d7
* Thu Sep 14 2017 tbogendoerfer@suse.de
- Update config files.
  Enabled SECURITY_INFINIBAND
- commit 8c7c6ab
* Thu Sep 14 2017 tbogendoerfer@suse.de
- IB/hfi1: update to new mmu_notifier semantic (bsc#1046306
  FATE#322942).
- IB/umem: update to new mmu_notifier semantic (bsc#1046306
  FATE#322942).
- IB/core: Avoid accessing non-allocated memory when inferring
  port type (bsc#1046306 FATE#322942).
- IB/uverbs: Fix NULL pointer dereference during device removal
  (bsc#1046306 FATE#322942).
- IB/core: Protect sysfs entry on ib_unregister_device
  (bsc#1046306 FATE#322942).
- RDMA/vmw_pvrdma: Report CQ missed events (bsc#1046306
  FATE#322942).
- IB/ipoib: Notify on modify QP failure only when relevant
  (bsc#1046307 FATE#322941).
- Revert "IB/core: Allow QP state transition from reset to error"
  (bsc#1046306 FATE#322942).
- IB/ipoib: Remove double pointer assigning (bsc#1046307
  FATE#322941).
- IB/ipoib: Clean error paths in add port (bsc#1046307
  FATE#322941).
- IB/ipoib: Add get statistics support to SRIOV VF (bsc#1046307
  FATE#322941).
- IB/ipoib: Add multicast packets statistics (bsc#1046307
  FATE#322941).
- IB/ipoib: Set IPOIB_NEIGH_TBL_FLUSH after flushed completion
  initialization (bsc#1046307 FATE#322941).
- IB/ipoib: Prevent setting negative values to max_nonsrq_conn_qp
  (bsc#1046307 FATE#322941).
- IB/ipoib: Make sure no in-flight joins while leaving that mcast
  (bsc#1046307 FATE#322941).
- IB/ipoib: Use cancel_delayed_work_sync when needed (bsc#1046307
  FATE#322941).
- IB/ipoib: Fix race between light events and interface restart
  (bsc#1046307 FATE#322941).
- IB/uverbs: Fix device cleanup (bsc#1046306 FATE#322942).
- RDMA/uverbs: Prevent leak of reserved field (bsc#1046306
  FATE#322942).
- IB/core: Fix race condition in resolving IP to MAC (bsc#1046306
  FATE#322942).
- IB/cma: Fix reference count leak when no ipv4 addresses are set
  (bsc#1046306 FATE#322942).
- IB/rdmavt: Setting of QP timeout can overflow jiffies
  computation (bsc#1058717 FATE#322789).
- IB/core: Fix sparse warnings (bsc#1046306 FATE#322942).
- IB/IPoIB: Fix error code in ipoib_add_port() (bsc#1046307
  FATE#322941).
- IB/core: Allow QP state transition from reset to error
  (bsc#1046306 FATE#322942).
- IB/ipoib: Let lower driver handle get_stats64 call (bsc#1046307
  FATE#322941).
- IB/core: Add ordered workqueue for RoCE GID management
  (bsc#1046306 FATE#322942).
- IB/core: Remove NOIO QP create flag (bsc#1046306 FATE#322942).
- IB/{rdmavt, qib, hfi1}: Remove gfp flags argument (bsc#1046306
  FATE#322942 bsc#1027067 FATE#322649 bsc#1058717 FATE#322789).
- IB/IPoIB: Convert IPoIB to memalloc_noio_* calls (bsc#1046307
  FATE#322941).
- IB/IPoIB: Forward MTU change to driver below (bsc#1046307
  FATE#322941).
- IB/uverbs: Make use of ib_modify_qp variant to avoid resolving
  DMAC (bsc#1046306 FATE#322942).
- IB/core: Introduce modify QP operation with udata (bsc#1046306
  FATE#322942).
- IB/core: Don't resolve IP address to the loopback device
  (bsc#1046306 FATE#322942).
- RDMA/core: Document confusing code (bsc#1046306 FATE#322942).
- IB/hfi1: Ensure dd->gi_mask can not be overflowed (bsc#1046306
  FATE#322942).
- IB/srpt: Make a debug statement in srpt_abort_cmd() more
  informative (bsc#1046306 FATE#322942).
- IB/core: Fix static analysis warning in ib_policy_change_task
  (bsc#1046306 FATE#322942).
- IB/core: Fix uninitialized variable use in
  check_qp_port_pkey_settings (bsc#1046306 FATE#322942).
- IB/core, opa_vnic, hfi1, mlx5: Properly free rdma_netdev
  (bsc#1046306 FATE#322942 bsc#1046305 FATE#322943).
- IB/opa_vnic: Use spinlock instead of mutex for stats_lock
  (bsc#1046306 FATE#322942).
- IB/opa_vnic: Use GFP_ATOMIC while sending trap (bsc#1046306
  FATE#322942).
- net: convert sk_buff.users from atomic_t to refcount_t
  (bsc#1046306 FATE#322942 bsc#1056787).
- net: add netlink_ext_ack argument to rtnl_link_ops.changelink
  (bsc#1046306 FATE#322942 bsc#1056787).
- net: add netlink_ext_ack argument to rtnl_link_ops.newlink
  (bsc#1046306 FATE#322942 bsc#1056787).
- IB/core: Enforce security on management datagrams (bsc#1046306
  FATE#322942).
- selinux lsm IB/core: Implement LSM notification system
  (bsc#1046306 FATE#322942).
- IB/core: Enforce PKey security on QPs (bsc#1046306 FATE#322942).
- IB/core: IB cache enhancements to support Infiniband security
  (bsc#1046306 FATE#322942).
- commit 2779070
* Thu Sep 14 2017 tbogendoerfer@suse.de
- Delete
  patches.drivers/IB-core-opa_vnic-hfi1-mlx5-Properly-free-rdma_netdev.patch.
  Patch will be re-done during IBcore commits
- commit 080979b
* Thu Sep 14 2017 msuchanek@suse.de
- powerpc/perf: POWER9 PMU stops after idle workaround
  (bsc#1056686).
- commit e5b99d6
* Thu Sep 14 2017 acho@suse.com
- Bluetooth: Properly check L2CAP config option output buffer
  length (bsc#1057389 CVE-2017-1000251).
- commit 6e305d4
* Thu Sep 14 2017 tbogendoerfer@suse.de
- IB/cxgb3: Fix error codes in iwch_alloc_mr() (bsc#1046534
  FATE#322935).
- commit fb70667
* Thu Sep 14 2017 colyli@suse.de
- blacklist.conf: update not-backport commit id
- commit 65bc4e8
* Thu Sep 14 2017 colyli@suse.de
- dm mpath: retry BLK_STS_RESOURCE errors
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blacklist.conf: add not-backport commits
- dm: fix the second dec_pending()
  argument in __split_and_process_bio()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Fix two comments that refer to .queue_rq() return values
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 1bf9ecf
* Thu Sep 14 2017 tbogendoerfer@suse.de
- i40iw: Fix potential fcn_id_array out of bounds (bsc#1058659
  FATE#322535).
- i40iw: Use correct alignment for CQ0 memory (bsc#1058659
  FATE#322535).
- i40iw: Fix typecast of tcp_seq_num (bsc#1058659 FATE#322535).
- i40iw: Correct variable names (bsc#1058659 FATE#322535).
- i40iw: Fix parsing of query/commit FPM buffers (bsc#1058659
  FATE#322535).
- IB/i40iw: Fix error code in i40iw_create_cq() (bsc#1058659
  FATE#322535).
- i40iw: Free QP PBLEs when the QP is destroyed (bsc#1058659
  FATE#322535).
- i40iw: Avoid memory leak of CQP request objects (bsc#1058659
  FATE#322535).
- i40iw: Update list correctly (bsc#1058659 FATE#322535).
- i40iw: Add missing memory barrier (bsc#1058659 FATE#322535).
- i40iw: Free QP resources on CQP destroy QP failure (bsc#1058659
  FATE#322535).
- i40iw: Release cm_id ref on PCI function reset (bsc#1058659
  FATE#322535).
- i40iw: Utilize iwdev->reset during PCI function reset
  (bsc#1058659 FATE#322535).
- i40iw: Do not poll CCQ after it is destroyed (bsc#1058659
  FATE#322535).
- i40iw: Fix order of cleanup in close (bsc#1058659 FATE#322535).
- commit eebe943
* Thu Sep 14 2017 tbogendoerfer@suse.de
- Resorted network driver section
- commit c5fe18c
* Wed Sep 13 2017 colyli@suse.de
- MD: fix warnning for UP case
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: simplify code with bio_io_error
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: raid1-10: move raid1/raid10 common code into raid1-10.c
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: raid1/raid10: initialize bvec table via bio_add_page()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- raid5-ppl: use BIOSET_NEED_BVECS when creating bioset
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md/bitmap: don't read page from device with Bitmap_sync
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: add support for write hints in a bio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- MD: fix a null dereference
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit dbbe938
* Wed Sep 13 2017 colyli@suse.de
- series.conf: change patche apply order.
- move patches.suse/0036-md-cluster-remove-EXPERIMENTAL-info.patch to
  be applied after patches.fixes/0001-md-use-a-separate-bio_set-for-synchronous-IO.patch
- commit 2979567
* Wed Sep 13 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix a thinko for xmlto buildreq condition
- commit 9d160ac
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/perf: Update default sdar_mode value for power9
  (bsc#1056686).
- commit 5c31f3d
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/perf: Cleanup of PM_BR_CMPL vs. PM_BRU_CMPL in Power9
  event list (bsc#1056686).
- commit ad2bb5c
* Wed Sep 13 2017 jkosina@suse.cz
- Update config files: enable USB-C in -vanilla as well
  Fixes: 7e26cc6a2a52f439e815997690146c51503f56dd
- commit c5e1b9f
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/perf: Avoid spurious PMU interrupts after idle
  (bsc#1056686).
- commit 21fff50
* Wed Sep 13 2017 msuchanek@suse.de
- powerpc/64s: Invalidate ERAT on powersave wakeup for POWER9
  (bsc#1056686).
- commit 037cb86
* Wed Sep 13 2017 colyli@suse.de
- dm kcopyd: add sequential write feature
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm linear: add support for zoned block devices
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm flakey: add support for zoned block devices
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: introduce dm_remap_zone_report()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: fix REQ_OP_ZONE_REPORT bio handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: fix REQ_OP_ZONE_RESET bio handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm table: add zoned block devices validation
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm crypt: add big-endian variant of plain64 IV
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm bio prison: use rb_entry() rather than container_of()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm ioctl: report event number in DM_LIST_DEVICES
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm ioctl: add a new DM_DEV_ARM_POLL ioctl
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: add basic support for using the select or poll function
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm verity fec: fix GFP flags used with mempool_alloc()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: use GFP_NOIO in I/O path
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: remove test for impossible REQ_OP_FLUSH conditions
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: bump target version
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: avoid mddev->suspended access
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: fix activation check in validate_raid_redundancy()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm raid: remove WARN_ON() in raid10_md_layout_to_format()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm bufio: fix error code in dm_bufio_write_dirty_buffers()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm integrity: test for corrupted disk format during table load
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm integrity: WARN_ON if variables
  representing journal usage get out of sync
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm integrity: use plugging when writing the journal
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 1a13da0
* Wed Sep 13 2017 colyli@suse.de
- Allow a queue to request that timeouts don't get rounded up
  (bnc#768084).
- mtd: blkdevs: Fix mtd block write failure
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: only verify integrity on the lowest stacked
  driver (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: Fix regression if profile verify_fn is NULL
  (fate#322738,fate#322919,fate#322950,fate#323773).
- xen-blkfront: Fix handling of non-supported operations
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: map queues to all present CPUs
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: map all HWQ also in hyperthreaded system
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bcache.txt: standardize document format
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bfq: dispatch request to prevent queue
  stalling after the request completion
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bfq: fix typos in comments about B-WF2Q+ algorithm
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: call bio_uninit in bio_endio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Fix __blkdev_issue_zeroout loop
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: fix overflow when converting zone ID to sectors
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: fix boolreturn.cocci warnings
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: stop abusing bi_end_io
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: Restore original iterator on verify stage
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: remove the unused bio_to_phys macro
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio: add bvec_iter rewind API
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: guard bvec iteration logic
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: fold bio_integrity_enabled to bio_integrity_prep
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: fix interface for bio_integrity_trim
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: bio_integrity_advance must update integrity seed
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bio-integrity: bio_trim should truncate integrity vector
  accordingly (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-sched: fix performance regression of mq-deadline
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block, bfq: don't change ioprio class for a bfq_queue on a
  service tree (fate#322738,fate#322919,fate#322950,fate#323773).
- block, bfq: update wr_busy_queues if needed on a queue split
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: don't set bounce limit
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't set bounce limit in blk_init_queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't set bounce limit in blk_init_allocated_queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: don't bounce by default
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't bother with bounce limits for make_request drivers
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: remove the queue_bounce_pfn helper
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: move bounce declarations to block/blk.h
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-map: call blk_queue_bounce from blk_rq_append_bio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: expose write hints through debugfs
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm zoned: drive-managed zoned block device target
  (fate#322738,fate#322919,fate#322950,fate#323773).
  Update: add DM_ZONED (is not set) to configs due to pick the above patch.
- blk-mq: remove double set queue_num
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Make it safe to quiesce and unquiesce from an interrupt
  handler (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Fix off-by-one errors in
  blk_status_to_errno() and print_req_error()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Declare local symbols static
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Add fallthrough markers to switch statements
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Warn when attempting to run a hardware queue that is
  not mapped (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Constify disk_type
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Document locking assumptions
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Document what queue type each function is intended for
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Check locking assumptions at runtime
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Initialize .rq_flags in blk_mq_rq_ctx_init()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Change argument type of scsi_req_init()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Make most scsi_req_init() calls implicit
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Introduce request_queue.initialize_rq_fn()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Make request operation type argument declarations
  consistent (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: Reduce blk_mq_hw_ctx size
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: return on congested block device
  (fate#322738,fate#322919,fate#322950,fate#323773).
- Revert "blk-mq: don't use sync workqueue flushing from drivers"
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: clarify dispatch may not be drained/blocked by stopping
  queue (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: don't stop queue for quiescing
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: update comments on blk_mq_quiesce_queue()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: use QUEUE_FLAG_QUIESCED to quiesce queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: use the introduced blk_mq_unquiesce_queue()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: introduce blk_mq_unquiesce_queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: introduce blk_mq_quiesce_queue_nowait()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: move blk_mq_quiesce_queue() into include/linux/blk-mq.h
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: don't check for BIO_MAX_PAGES in blk_bio_segment_split()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: remove bio_clone() and all references
  (fate#322738,fate#322919,fate#322950,fate#323773).
- xen-blkfront: remove bio splitting
  (fate#322738,fate#322919,fate#322950,fate#323773).
- rbd: use bio_clone_fast() instead of bio_clone()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- drbd: use bio_clone_fast() instead of bio_clone()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: Check queue type before attaching to a queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: remove the call to blk_queue_bounce
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: use bio_clone_fast() instead of bio_clone()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- pktcdvd: use class_groups instead of class_attrs
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bcache: use kmalloc to allocate bio in bch_data_verify()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Improvements to bounce-buffer handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk: use non-rescuing bioset for q->bio_split
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk: make the bioset rescue_workqueue optional
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk: replace bioset_create_nobvec() with a flags arg to bioset_create()
  (fate#322738,fate#322919,fate#322950,fate#323773).
  Update: patches.fixes/0001-md-use-a-separate-bio_set-for-synchronous-IO.patch
  rebase this patch to follow change of bioset_create() from the above patch.
- blk: remove bio_set arg from blk_queue_split()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: remove __blk_mq_alloc_request
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-sched: unify request prepare methods
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: refactor blk_mq_sched_assign_ioc
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bfq-iosched: fix NULL ioc check in bfq_get_rq_private
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: streamline blk_mq_get_request
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: simplify blk_mq_free_request
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-sched: unify request finished methods
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: remove blk_mq_sched_{get,put}_rq_priv
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: move blk_mq_sched_{get,put}_request to blk-mq.c
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: mark blk_mq_rq_ctx_init static
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md: change the initialization value for
  a spare device spot to MD_DISK_ROLE_SPARE
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md/raid1: remove unused bio in sync_request_write
  (fate#322738,fate#322919,fate#322950,fate#323773).
- md/raid10: fix FailFast test for wrong device
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: swim3: make of_device_ids const
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: Dedicated error code fixups
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: missing break in process_queued_bios()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- x86, uaccess: introduce copy_from_iter_flushcache
  for pmem / cache-bypass operations
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: switch bios to blk_status_t
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: switch ->queue_rq return value to blk_status_t
  (fate#322738,fate#322919,fate#322950,fate#323773).
- fs: simplify dio_bio_complete
  (fate#322738,fate#322919,fate#322950,fate#323773).
- fs: remove the unused error argument to dio_end_io()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- gfs2: remove the unused sd_log_error field
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block_dev: propagate bio_iov_iter_get_pages
  error in __blkdev_direct_IO
  (fate#322738,fate#322919,fate#322950,fate#323773).
- nvme-rdma: fix merge error
  (fate#322738,fate#322919,fate#322950,fate#323773).
- block: introduce new block status code type
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: change ->end_io calling convention
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: don't return errnos from ->map
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm mpath: merge do_end_io_bio into multipath_end_io_bio
  (fate#322738,fate#322919,fate#322950,fate#323773).
- dm: fix REQ_RAHEAD handling
  (fate#322738,fate#322919,fate#322950,fate#323773).
- bsg: Check queue type before attaching to a queue
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 056fe48
* Wed Sep 13 2017 colyli@suse.de
- block: Introduce queue flag QUEUE_FLAG_SCSI_PASSTHROUGH
  (fate#322738,fate#322919,fate#322950,fate#323773).
- Refresh patches.drivers/0001-cciss-initialize-struct-scsi_req.patch.
- commit fe7d9b8
* Wed Sep 13 2017 colyli@suse.de
- blk-mq-debugfs: Add 'kick' operation
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-debugfs: Show busy requests
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-debugfs: Show requeue list
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq-debugfs: Show atomic request flags
  (fate#322738,fate#322919,fate#322950,fate#323773).
- cfq-iosched: Delete unused function min_vdisktime()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: make per-sw-queue bio merge as default .bio_merge
  (fate#322738,fate#322919,fate#322950,fate#323773).
- blk-mq: merge bio into sw queue before plugging
  (fate#322738,fate#322919,fate#322950,fate#323773).
- lib/raid6: Add log-of-2 table for RAID6 HW requiring disk
  position (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 63ce229
* Wed Sep 13 2017 colyli@suse.de
- mtip32xx: avoid to read HOST_CAP from HW in .queue_rq()
  (fate#322738,fate#322919,fate#322950,fate#323773).
- cciss: initialize struct scsi_req
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 865ae42
* Wed Sep 13 2017 colyli@suse.de
- btrfs: use new block error code
  (fate#322738,fate#322919,fate#322950,fate#323773).
- commit 4707260
* Wed Sep 13 2017 colyli@suse.de
- Prepare for SLE15 block layer backport, the following patches will be
  replaced in the backport patch set.
- Delete patches.suse/0007-block-return-on-congested-block-device.patch.
- Delete patches.suse/blk-timeout-no-round.
- commit 898bc16
* Wed Sep 13 2017 tbogendoerfer@suse.de
- IB/rxe: Another fix for broken receive queue draining
  (bsc#1050662 FATE#323951).
- IB/rxe: Move refcounting earlier in rxe_send() (bsc#1050662
  FATE#323951).
- commit 232e612
* Wed Sep 13 2017 tbogendoerfer@suse.de
- rxe: fix broken receive queue draining (bsc#1050662
  FATE#323951).
- IB/rxe: Set dma_mask and coherent_dma_mask (bsc#1050662
  FATE#323951).
- IB/rxe: Fix kernel panic from skb destructor (bsc#1050662
  FATE#323951).
- IB/rxe: do not copy extra stack memory to skb (bsc#1050662
  FATE#323951).
- commit 0a634d2
* Wed Sep 13 2017 tbogendoerfer@suse.de
- RDMA/ocrdma: Fix error codes in ocrdma_create_srq() (bsc#1058513
  FATE#322520).
- RDMA/ocrdma: Fix an error code in ocrdma_alloc_pd() (bsc#1058513
  FATE#322520).
- commit 1505b7c
* Wed Sep 13 2017 mkubecek@suse.cz
- config: disable IPX (fate#323372)
  Also drop the ipx line from supported.conf
- commit fd722f1
* Wed Sep 13 2017 dchang@suse.com
- bnx2x: fix format overflow warning (bsc#1050319 FATE#322906).
- net: broadcom: bnx2x: make a couple of const arrays static
  (bsc#1050319 FATE#322906).
- bnx2x: Remove open coded carrier check (bsc#1050319
  FATE#322906).
- commit 1244565
* Wed Sep 13 2017 dchang@suse.com
- net: phy: Make phy_ethtool_ksettings_get return void
  (bsc#1050260 FATE#322917).
- commit 6fbf90a
* Wed Sep 13 2017 jlee@suse.com
- Update config files. (fate#322251)
  Enabling CONFIG_IMA_KEXEC on ppc64le kernel. (fate#322251)
- commit a83dbdc
* Wed Sep 13 2017 dchang@suse.com
- be2net: Update the driver version to 11.4.0.0 (bsc#1050252
  FATE#322920).
- be2net: Fix UE detection logic for BE3 (bsc#1050252
  FATE#322920).
- commit 4374b1f
* Wed Sep 13 2017 dchang@suse.com
- netxen: fix incorrect loop counter decrement (bsc#1050526
  FATE#322905).
- netxen_nic: Remove unused pointer hdr in netxen_setup_minidump()
  (bsc#1050526 FATE#322905).
- netxen: remove writeq/readq function definitions (bsc#1050526
  FATE#322905).
- commit dba6746
* Wed Sep 13 2017 dchang@suse.com
- qlge: avoid memcpy buffer overflow (bsc#1050529 FATE#322902).
- commit 33f6a43
* Wed Sep 13 2017 dchang@suse.com
- Refresh patch order in network section
- commit e712677
* Wed Sep 13 2017 neilb@suse.com
- NFSv4.1: don't use machine credentials for CLOSE when using
  'sec=sys' (bsc#972003).
- Delete patches.fixes/nfs4_close.fix.
  Replace patch with slightly-improved upstream version.
- commit d4a102c
* Wed Sep 13 2017 neilb@suse.com
- md/raid5: fix a race condition in stripe batch (linux-stable).
- NFS: flush data when locking a file to ensure cache coherence
  for mmap (bsc#981309).
- commit 42452b8
* Tue Sep 12 2017 oneukum@suse.com
- Update config files. Readd CONFIG_UCSI
  It was killed by the type C FATEs (bsc#1058307)
- commit 4a9daca
* Tue Sep 12 2017 oneukum@suse.com
- Update config files. Drop ancient USB drivers (FATE#323891)
- commit f78046a
* Tue Sep 12 2017 msuchanek@suse.de
- rpm/kernel-docs.spec.in: make unpack scripts executable
- commit 1ba3766
* Tue Sep 12 2017 oneukum@suse.com
- usb:xhci:Fix regression when ATI chipsets detected
  (bsc#1055044).
- commit 8847613
* Tue Sep 12 2017 oneukum@suse.com
- Update config files. Kill analog TV (FATE#323883)
- commit 56e4a2a
* Tue Sep 12 2017 tbogendoerfer@suse.de
- bnxt_en: Do not setup MAC address in bnxt_hwrm_func_qcaps()
  (bsc#1050242 FATE#322914).
- bnxt_en: Free MSIX vectors when unregistering the device from
  bnxt_re (bsc#1050242 FATE#322914).
- bnxt_en: Fix .ndo_setup_tc() to include XDP rings (bsc#1050242
  FATE#322914).
- RDMA/bnxt_re: Fix the value reported for local ack delay
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: Report MISSED_EVENTS in req_notify_cq (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Fix return value of poll routine (bsc#1050244
  FATE#322915).
- RDMA/bnxt_re: Enable atomics only if host bios supports
  (bsc#1050244 FATE#322915).
- RDMA/bnxt_re: checking for NULL instead of IS_ERR() (bsc#1050244
  FATE#322915).
- bnxt_en: Fix SRIOV on big-endian architecture (bsc#1050242
  FATE#322914).
- bnxt_en: Fix bug in ethtool -L (bsc#1050242 FATE#322914).
- bnxt_en: Fix race conditions in .ndo_get_stats64() (bsc#1050242
  FATE#322914).
- bpf: bnxt: Report bpf_prog ID during XDP_QUERY_PROG (bsc#1050242
  FATE#322914).
- bnxt_en: Fix xmit_more with BQL (bsc#1050242 FATE#322914).
- bnxt_en: Pass in sh parameter to bnxt_set_dflt_rings()
  (bsc#1050242 FATE#322914).
- bnxt_en: Implement xmit_more (bsc#1050242 FATE#322914).
- bnxt_en: Optimize doorbell write operations for newer chips
  (bsc#1050242 FATE#322914).
- bnxt_en: Add additional chip ID definitions (bsc#1050242
  FATE#322914).
- bnxt_en: Add a callback to inform RDMA driver during PCI
  shutdown (bsc#1050242 FATE#322914).
- bnxt_en: Add PCI IDs for BCM57454 VF devices (bsc#1050242
  FATE#322914).
- bnxt_en: Support for Short Firmware Message (bsc#1050242
  FATE#322914).
- bnxt: add dma mapping attributes (bsc#1050242 FATE#322914).
- commit a791793
* Tue Sep 12 2017 tbogendoerfer@suse.de
- Moved bnxt_re patches into sorted network driver section
- commit e77ab1e
* Tue Sep 12 2017 jslaby@suse.cz
- blacklist.conf: add 2 more entries
- commit 93d993d
* Mon Sep 11 2017 lduncan@suse.com
- mtip32xx: fix up the checking for internal command failure
  (bsc#1058157).
- commit f712234
* Mon Sep 11 2017 bpoirier@suse.com
- sfc: don't try and read ef10 data on non-ef10 NIC (bsc#1058169
  FATE#322922).
- sfc: correct comment on efx_mcdi_process_event (bsc#1058169
  FATE#322922).
- sfc: change Unknown MCDI event message to print full event
  (bsc#1058169 FATE#322922).
- commit 55d76f6
* Mon Sep 11 2017 bpoirier@suse.com
- i40e: point wb_desc at the nvm_wb_desc during i40e_read_nvm_aq
  (bsc#1056658 FATE#322188).
- i40e: avoid NVM acquire deadlock during NVM update (bsc#1056658
  FATE#322188).
- commit 0715187
* Mon Sep 11 2017 tonyj@suse.de
- perf vendor events powerpc: Remove duplicate events
  (FATE#322450, bsc#1050145).
- commit ad444e5
* Mon Sep 11 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit ae6b192
* Mon Sep 11 2017 tbogendoerfer@suse.de
- scsi: qedf: Fix a potential NULL pointer dereference
  (bsc#1050530 FATE#322901).
- scsi: qedf: Limit number of CQs (bsc#1050530 FATE#322901).
- scsi: qedf: fix spelling mistake: "offlading" -> "offloading"
  (bsc#1050530 FATE#322901).
- scsi: qedf: Merge a few quoted strings split across lines
  (bsc#1050530 FATE#322901).
- scsi: qedf: Use 'dma_zalloc_coherent' to reduce code verbosity
  (bsc#1050530 FATE#322901).
- scsi: qedf: Fix a return value in case of error in
  'qedf_alloc_global_queues' (bsc#1050530 FATE#322901).
- commit 943143a
* Mon Sep 11 2017 tbogendoerfer@suse.de
- Moved qedf patches to sorted network section
- commit f5a68e3
* Mon Sep 11 2017 tbogendoerfer@suse.de
- qed: Fix a memory allocation failure test in
  'qed_mcp_cmd_init()' (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- scsi: qedi: Fix return code in qedi_ep_connect() (bsc#1050534
  FATE#322899).
- scsi: qedi: Add ISCSI_BOOT_SYSFS to Kconfig (bsc#1050534
  FATE#322899).
- RDMA/qedr: Prevent memory overrun in verbs' user responses
  (bsc#1050545 FATE#322893).
- scsi: qedi: fix another spelling mistake: "alloction" ->
  "allocation" (bsc#1050534 FATE#322899).
- scsi: qedi: Add support for Boot from SAN over iSCSI offload
  (bsc#1050534 FATE#322899).
- qed: Fix printk option passed when printing ipv6 addresses
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- scsi: qedi: Remove comparison of u16 idx with zero (bsc#1050534
  FATE#322899).
- qed: initialize ll2_syn_handle at start of function (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Add iWARP support for physical queue allocation
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add iWARP protocol support in context allocation
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: iWARP CM add error handling (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP implement disconnect flows (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP CM add active side connect (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP CM add passive side connect (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed: iWARP CM add listener functions and initial SYN processing
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: iWARP CM - setup a ll2 connection for handling SYN packets
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Add iWARP support in ll2 connections (bsc#1050536
  FATE#322898 bsc#1050545 FATE#322893).
- qed: Rename some ll2 related defines (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Implement iWARP initialization, teardown and qp operations
  (bsc#1050536 FATE#322898 bsc#1050545 FATE#322893).
- qed: Introduce iWARP personality (bsc#1050536 FATE#322898
  bsc#1050545 FATE#322893).
- qed*: Rename qed_roce_if.h to qed_rdma_if.h (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Split rdma content between qed_rdma and qed_roce
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qed: Duplicate qed_roce. to qed_rdma.[ch] (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Cleanup qed_roce before duplicating it (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: Fix compilation without QED_RDMA (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: SPQ async callback registration (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Wait for resources before FUNC_CLOSE (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed*: Set rdma generic functions prefix (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed*: qede_roce. -> qede_rdma.[ch] (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Disable RoCE dpm when DCBx change occurs (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: RoCE EDPM to honor PFC (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Chain support for external PBL (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- bpf: qede: Report bpf_prog ID during XDP_QUERY_PROG (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Fix an off by one bug (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: add qed_int_sb_init() stub function (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: collect GSI port statistics (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Call rx_release_cb() when flushing LL2 (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: No need for LL2 frags indication (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed*: LL2 callback operations (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: LL2 code relocations (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Cleaner seperation of LL2 inputs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Revise ll2 Rx completion (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: LL2 to use packed information for tx (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: VF XDP support (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: VF XDP support (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: VFs to try utilizing the doorbell bar (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Multiple qzone queues for VFs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: IOV db support multiple queues per qzone (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Make VF legacy a bitfield (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Assign a unique per-queue index to queue-cid (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Pass vf_params when creating a queue-cid (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed*: L2 interface to use the SB structures directly
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qed: Create L2 queue database (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Add bitmaps for VF CIDs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Add support for changing iSCSI mac (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Support NVM-image reading API (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Share additional information with qedf (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Correct order of wwnn and wwpn (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: No need to reset SBs on IOV init (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Reset IGU CAM to default on init (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Hold a single array for SBs (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Provide auxiliary for getting free VF SB (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Remove assumption on SB order in IGU (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Encapsulate interrupt counters in struct (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Add aux. function translating sb_id -> igu_sb_id
  (bsc#1050536 FATE#322898 bsc#1050538 FATE#322897).
- qed: Distinguish between sb_id and igu_sb_id (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: IGU read revised (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Minor refactoring in interrupt code (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Make qed_int_cau_conf_pi() static (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Cache alignemnt padding to match host (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Mask parities after occurance (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Print multi-bit attentions properly (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Diffrentiate adapter-specific attentions (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Get rid of the attention-arrays (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Support dynamic s-tag change (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: QL41xxx VF MSI-x table (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qed: Don't inherit RoCE DCBx for V2 (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Correct DCBx update scheme (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Add missing static/local dcbx info (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Replace set_id() api with set_name() (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: Log probe of PCI device (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Provide MBI information in dev_info (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Enable RoCE parser searching on fp init (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Flush slowpath tasklet on stop (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Remove BB_A0 references (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Drop the 's' from num_ports_in_engines (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Log incorrectly installed board (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: !main_ptt for tunnel configuration (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Align DP_ERR style with other DP macros (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: Fix sparse warnings (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- qede: Support 1G advertisment (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Fix setting of Management bitfields (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qede: qedr closure after setting state (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Correct print in iscsi error-flow (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Revise alloc/setup/free flow (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Don't use an internal MAC field (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Add missing Status-block free (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Honor user request for Tx buffers (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qede: Allow WoL to activate by default (bsc#1050536 FATE#322898
  bsc#1050538 FATE#322897).
- qed: Remove unused including <linux/version.h> (bsc#1050536
  FATE#322898 bsc#1050538 FATE#322897).
- qed: Utilize FW 8.20.0.0 (bsc#1050536 FATE#322898 bsc#1050538
  FATE#322897).
- commit 1d42a59
* Mon Sep 11 2017 tbogendoerfer@suse.de
- net: sched: fix memleak for chain zero (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190 bsc#1056787).
- commit 2088d61
* Mon Sep 11 2017 mgorman@suse.de
- Refresh
  patches.suse/audit-Reduce-overhead-using-a-coarse-clock.patch.
- Refresh
  patches.suse/mm-change-the-call-sites-of-numa-statistics-items.patch.
- Refresh
  patches.suse/mm-consider-the-number-in-local-CPUs-when-reading-NUMA-stats.patch.
- Refresh
  patches.suse/mm-update-NUMA-counter-threshold-size.patch.
- commit d6d62e5
* Mon Sep 11 2017 jthumshirn@suse.de
- scsi: aacraid: Fix out of bounds in aac_get_name_resp
  (FATE#322889, bsc#1049519).
- scsi: aacraid: reading out of bounds (FATE#322889, bsc#1049519).
- scsi: aacraid: Don't copy uninitialized stack memory to
  userspace (FATE#322889, bsc#1049519).
- scsi: aacraid: fix leak of data from stack back to userspace
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Update driver version to 50834 (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Remove reference to Series-9 (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Add reset debugging statements (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Enable ctrl reset for both hba and arc
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Make sure ioctl returns on controller reset
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Use correct function to get ctrl health
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Rework aac_src_restart (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Rework SOFT reset code (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Add periodic checks to see IOP reset status
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Rework IOP reset (FATE#322889, bsc#1049519).
- scsi: aacraid: Using single reset mask for IOP reset
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Print ctrl status before eh reset (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Log count info of scsi cmds before reset
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Change wait time for fib completion (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Remove reset support from check_health
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Set correct Queue Depth for HBA1000 RAW disks
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Added 32 and 64 queue depth for arc natives
  (FATE#322889, bsc#1049519).
- scsi: aacraid: Fix DMAR issues with iommu=pt (FATE#322889,
  bsc#1049519).
- scsi: aacraid: Remove __GFP_DMA for raw srb memory (FATE#322889,
  bsc#1049519).
- commit 4812863
* Mon Sep 11 2017 tbogendoerfer@suse.de
- supported.conf: mark mlxfw as supported
- commit 51723c1
* Mon Sep 11 2017 tbogendoerfer@suse.de
- net/mlx5e: IPoIB, Fix driver name retrieved by ethtool
  (bsc#1046303 FATE#322944).
- commit f0ce489
* Mon Sep 11 2017 tbogendoerfer@suse.de
- Update config files.
  New MLX5 config options
- commit f7e0715
* Mon Sep 11 2017 tbogendoerfer@suse.de
- net/mlx5e: Fix CQ moderation mode not set properly (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix inline header size for small packets (bsc#1046303
  FATE#322944).
- net/mlx5: E-Switch, Unload the representors in the correct order
  (bsc#1046303 FATE#322944).
- net/mlx5e: Properly resolve TC offloaded ipv6 vxlan tunnel
  source address (bsc#1046303 FATE#322944).
- net/mlx5e: Don't override user RSS upon set channels
  (bsc#1046303 FATE#322944).
- net/mlx5e: Fix dangling page pointer on DMA mapping error
  (bsc#1046303 FATE#322944).
- net/mlx5: Remove the flag MLX5_INTERFACE_STATE_SHUTDOWN
  (bsc#1046303 FATE#322944).
- net/mlx5: Skip mlx5_unload_one if mlx5_load_one fails
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix arm SRQ command for ISSI version 0 (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix DCB_CAP_ATTR_DCBX capability for DCBNL getcap
  (bsc#1046303 FATE#322944).
- net/mlx5e: Check for qos capability in dcbnl_initialize
  (bsc#1046303 FATE#322944).
- IB/mlx5: Always return success for RoCE modify port (bsc#1046303
  FATE#322944).
- IB/mlx5: Fix Raw Packet QP event handler assignment (bsc#1046303
  FATE#322944).
- RDMA/mlx5: Fix existence check for extended address vector
  (bsc#1046305 FATE#322943).
- net/mlx5: Clean SRIOV eswitch resources upon VF creation failure
  (bsc#1046303 FATE#322944).
- IB/mlx5: Fix a warning message (bsc#1046303 FATE#322944).
- IB/mlx5: Clean mr_cache debugfs in case of failure (bsc#1046303
  FATE#322944).
- net/mlx5: IPSec, fix 64-bit division correctly (bsc#1046303
  FATE#322944).
- net/mlx5: Add Makefiles for subdirectories (bsc#1046303
  FATE#322944).
- net/mlx5: Build wq.o even if MLX5_CORE_EN is not selected
  (bsc#1046303 FATE#322944).
- net/mlx5: FPGA, Fix datatype mismatch (bsc#1046303 FATE#322944).
- net/mlx5: FPGA, make mlx5_fpga_device_brb static (bsc#1046303
  FATE#322944).
- net/mlx5: IPSec, Fix 64-bit division on 32-bit builds
  (bsc#1046303 FATE#322944).
- net/mlx5: Add missing include in lib/gid.c (bsc#1046303
  FATE#322944).
- IB/core, opa_vnic, hfi1, mlx5: Properly free rdma_netdev
  (bsc#1046305 FATE#322943).
- net/mlxfw: Properly handle dependancy with non-loadable mlx5
  (bsc#1051858).
- net/mlx5: fix memcpy limit? (bsc#1046303 FATE#322944).
- net/mlx5: fix spelling mistake: "Allodating" -> "Allocating"
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPSec, Add IPSec ethtool stats (bsc#1046303
  FATE#322944).
- net/mlx5e: IPSec, Add Innova IPSec offload TX data path
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPSec, Add Innova IPSec offload RX data path
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPSec, Innova IPSec offload infrastructure
  (bsc#1046303 FATE#322944).
- net/mlx5: Accel, Add IPSec acceleration interface (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add SBU infrastructure (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add SBU bypass and reset flows (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add high-speed connection routines (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Add FW commands for FPGA QPs (bsc#1046303
  FATE#322944).
- net/mlx5: FPGA, Move FPGA init/cleanup to init_once (bsc#1046303
  FATE#322944).
- net/mlx5: Add QP WQ support (bsc#1046303 FATE#322944).
- net/mlx5: Make get_cqe routine not ethernet-specific
  (bsc#1046303 FATE#322944).
- IB/mlx5: Respect mlx5_core reserved GIDs (bsc#1046303
  FATE#322944).
- net/mlx5: Add support for multiple RoCE enable (bsc#1046303
  FATE#322944).
- net/mlx5: Add reserved-gids support (bsc#1046303 FATE#322944).
- net/mlx5: Set interface flags before cleanup in unload_one
  (bsc#1046303 FATE#322944).
- net/mlx5: Fix offset of hca cap reserved field (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Support the flash device ethtool callback
  (bsc#1046303 FATE#322944).
- net/mlx5e: Support the flash device ethtool callback
  (bsc#1046303 FATE#322944).
- net/mlx5: Add mlxfw callbacks (bsc#1046303 FATE#322944).
- net/mlx5: Add helper functions to set/query MCC/MCDA/MCQI
  registers (bsc#1046303 FATE#322944).
- net/mlx5: Enhance MCAM reg to allow query on access reg support
  (bsc#1046303 FATE#322944).
- net/mlx5: Add MCC (Management Component Control) register
  definitions (bsc#1046303 FATE#322944).
- mlxfw: Make the module selectable (bsc#1051858).
- net/mlx5e: Add header re-write offloading of IPv6 hop-limit
  (bsc#1046303 FATE#322944).
- net/mlx5e: Use macro for TC header re-write offload field
  mapping (bsc#1046303 FATE#322944).
- net/mlx5e: Offload TC matching on ip ttl (bsc#1046303
  FATE#322944).
- net/mlx5e: Relocate the TC match on ip tos offload code section
  (bsc#1046303 FATE#322944).
- net/mlx5e: Introduce RX Page-Reuse (bsc#1046303 FATE#322944).
- net/mlx5e: Enhance RX SKB headroom logic (bsc#1046303
  FATE#322944).
- net/mlx5e: Build SKB with exact frag_size (bsc#1046303
  FATE#322944).
- net/mlx5e: Use device ID defines (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Add ioctl support to IPoIB device driver
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Add PTP support to IPoIB device driver
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Get more TX statistics (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Handle change_mtu (bsc#1046303 FATE#322944).
- net/mlx5e: Use hard_mtu as part of the mlx5e_priv struct
  (bsc#1046303 FATE#322944).
- net/mlx5e: IPoIB, Change parameters default values (bsc#1046303
  FATE#322944).
- net/mlx5e: Add new profile function update_carrier (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Add ethtool support (bsc#1046303 FATE#322944).
- net/mlx5e: Prevent PFC call for non ethernet ports (bsc#1046303
  FATE#322944).
- net/mlx5e: IPoIB, Move to a separate directory (bsc#1046303
  FATE#322944).
- net/mlx5: Add fast unload support in shutdown flow (bsc#1046303
  FATE#322944).
- net/mlx5: Expose command polling interface (bsc#1046303
  FATE#322944).
- net/mlx5e: Optimize update stats work (bsc#1046303 FATE#322944).
- net/mlx5e: Move and optimize query out of buffer function
  (bsc#1046303 FATE#322944).
- net/mlx5e: Reduce number of heap allocated buffers for update
  stats (bsc#1046303 FATE#322944).
- net/mlx5e: Rename physical symbol errors counter (bsc#1046303
  FATE#322944).
- net/mlx5e: Fix typo in warning if CQ moderation is not supported
  (bsc#1046303 FATE#322944).
- net/mlx5e: Use function to map aRFS into traffic type
  (bsc#1046303 FATE#322944).
- net/mlx5: Undo LAG upon request to create virtual functions
  (bsc#1046303 FATE#322944).
- net/mlx5: Avoid space after casting (bsc#1046303 FATE#322944).
- net/mlx5: Align to match opening parenthesis (bsc#1046303
  FATE#322944).
- net/mlx5: Avoid blank lines before/after closing/opening braces
  (bsc#1046303 FATE#322944).
- net/mlx5: Avoid using multiple blank lines (bsc#1046303
  FATE#322944).
- net/mlx5: Fix some spelling mistakes (bsc#1046303 FATE#322944).
- net/mlx5: Update eqe_type_str() event names (bsc#1046303
  FATE#322944).
- bpf: mlx5e: Report bpf_prog ID during XDP_QUERY_PROG
  (bsc#1046303 FATE#322944).
- net/mlxfw: fix a NULL dereference (bsc#1051858).
- net/mlx5e: Fill advertised and supported port data from Hardware
  info (bsc#1046303 FATE#322944).
- net/mlx5e: Add support for reading connector type from PTYS
  (bsc#1046303 FATE#322944).
- net/mlx5: Update flow table commands layout (bsc#1046303
  FATE#322944).
- net/mlx5e: Support header re-write of partial fields in TC
  pedit offload (bsc#1046303 FATE#322944).
- net/mlx5e: Use modify header ID cache for offloaded TC NIC flows
  (bsc#1046303 FATE#322944).
- net/mlx5e: Use modify header ID cache for offloaded TC E-Switch
  flows (bsc#1046303 FATE#322944).
- net/mlx5e: Add cache for HW modify header IDs (bsc#1046303
  FATE#322944).
- net/mlx5e: Use short attribute form when adding/deleting
  offloaded TC flows (bsc#1046303 FATE#322944).
- net/mlx5e: Remove limitation of single NIC offloaded TC action
  per rule (bsc#1046303 FATE#322944).
- net/mlxfw: remove redundant goto on error check (bsc#1051858).
- net/mlx5e: Offload TC matching on ip tos / traffic-class
  (bsc#1046303 FATE#322944).
- net/mlx5e: Offload TC matching on tcp flags (bsc#1046303
  FATE#322944).
- net/mlxfw: select CONFIG_XZ_DEC (bsc#1051858).
- Add the mlxfw module for Mellanox firmware flash process
  (bsc#1051858).
- IB/mlx5: Bump driver version (bsc#1046303 FATE#322944).
- net/mlx5: Bump driver version (bsc#1046303 FATE#322944).
- net/mlx5: FPGA, Add basic support for Innova (bsc#1046303
  FATE#322944).
- net/mlx5: Introduce trigger_health_work function (bsc#1046303
  FATE#322944).
- net/mlx5: Update the list of the PCI supported devices
  (bsc#1046303 FATE#322944).
- {net, IB}/mlx5: Replace mlx5_vzalloc with kvzalloc (bsc#1046305
  FATE#322943).
- net/mlx5e: Fix possible memory leak (bsc#1046303 FATE#322944).
- commit eb483d0
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: build ARM on at least 2 cpus
- commit b7edeaf
* Mon Sep 11 2017 jslaby@suse.cz
- rpm/constraints.in: increase memory for kernel-syzkaller
  And see if it helps. If so, push it to packaging...
- commit 7193e65
* Sun Sep 10 2017 jslaby@suse.cz
- Linux 4.12.12 (FATE#321195 bnc#1012628).
- Delete
  patches.drivers/0001-intel_th-pci-Add-Cannon-Lake-PCH-LP-support.patch.
- Delete
  patches.drivers/0002-intel_th-pci-Add-Cannon-Lake-PCH-H-support.patch.
- commit 296e98a
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Turn off most RDT features on Skylake
  (fate#323965).
- commit 2a5c169
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Add command line options for resource director
  technology (fate#323965).
- commit f5e558a
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Move special case code for Haswell to a quirk
  function (fate#323965).
- commit c494255
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Remove redundant ternary operator on return
  (fate#323965).
- commit da06468
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Improve limbo list processing (fate#323965).
- commit d7dce5a
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Fix MBM overflow handler during CPU hotplug
  (fate#323965).
- commit a86f8e0
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Modify the intel_pqr_state for better performance
  (fate#323965).
- commit ab298d6
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Clear the default RMID during hotcpu
  (fate#323965).
- commit 3c14e89
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Show bitmask of shareable resource with other
  executing units (fate#323965).
- commit 0ccbd41
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Handle counter overflow (fate#323965).
- commit 94ce203
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Add mbm counter initialization (fate#323965).
- commit 32e11af
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/mbm: Basic counting of MBM events (total and
  local) (fate#323965).
- commit 12b1bc5
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Add CPU hotplug support (fate#323965).
- commit 71658b1
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt/cqm: Add sched_in support (fate#323965).
- commit 4198905
* Sat Sep  9 2017 bp@suse.de
- x86/intel_rdt: Introduce rdt_enable_key for scheduling
  (fate#323965).
- commit 16e00d5
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add mount,umount support (fate#323965).
- commit e56f8c1
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add rmdir support (fate#323965).
- commit bac5646
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Separate the ctrl bits from rmdir (fate#323965).
- commit 6ec17c9
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add mon_data (fate#323965).
- commit 16bb61c
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Prepare for RDT monitor data support
  (fate#323965).
- commit ebdd847
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add cpus file support (fate#323965).
- commit 11c3fd1
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Prepare to add RDT monitor cpus file support
  (fate#323965).
- commit 8229971
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add tasks file support (fate#323965).
- commit eebc71b
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Change closid type from int to u32 (fate#323965).
- commit 6a67176
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add mkdir support for RDT monitoring
  (fate#323965).
- commit bc3130b
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Prepare for RDT monitoring mkdir support
  (fate#323965).
- commit af2e795
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add info files for RDT monitoring
  (fate#323965).
- commit 18ae4be
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Simplify info and base file lists (fate#323965).
- commit ae6127b
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add RMID (Resource monitoring ID) management
  (fate#323965).
- commit e234239
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Add RDT monitoring initialization
  (fate#323965).
- commit 16f77e6
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Make rdt_resources_all more readable
  (fate#323965).
- commit 6a43549
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Cleanup namespace to support RDT monitoring
  (fate#323965).
- commit ace7458
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Mark rdt_root and closid_alloc as static
  (fate#323965).
- commit b46c4ec
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Change file names to accommodate RDT monitor code
  (fate#323965).
- commit a90473c
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt: Introduce a common compile option for RDT
  (fate#323965).
- commit 38084a6
* Fri Sep  8 2017 bp@suse.de
- x86/intel_rdt/cqm: Documentation for resctrl based RDT
  Monitoring (fate#323965).
- commit b231f22
* Fri Sep  8 2017 bp@suse.de
- x86/perf/cqm: Wipe out perf based cqm (fate#323965).
- commit 7619997
* Fri Sep  8 2017 bp@suse.de
- perf, bpf: Add BPF support to all perf_event types
  (fate#323965).
- commit db63802
* Fri Sep  8 2017 tbogendoerfer@suse.de
- net/mlx4_core: Fixes missing capability bit in flags2 capability
  dump (bsc#1046300 FATE#322946).
- net/mlx4_core: Fix namespace misalignment in QinQ VST support
  commit (bsc#1046300 FATE#322946).
- net/mlx4_core: Fix sl_to_vl_change bit offset in flags2 dump
  (bsc#1046300 FATE#322946).
- net/mlx4_en: Fix wrong indication of Wake-on-LAN (WoL) support
  (bsc#1046299 FATE#322947).
- IB/mlx4: Fix CM REQ retries in paravirt mode (bsc#1046302
  FATE#322945).
- mlx4_en: remove unnecessary returned value check (bsc#1046299
  FATE#322947).
- {net, IB}/mlx4: Remove gfp flags argument (bsc#1046302
  FATE#322945).
- IB: Convert msleep below 20ms to usleep_range (bsc#1046302
  FATE#322945).
- mlx4_en: make mlx4_log_num_mgm_entry_size static (bsc#1046299
  FATE#322947).
- net/mlx4_en: Do not allocate redundant TX queues when TC is
  disabled (bsc#1046299 FATE#322947).
- net/mlx4_en: Add dynamic variable to hold the number of user
  priorities (UP) (bsc#1046299 FATE#322947).
- net/mlx4: fix spelling mistake: "enforcment" -> "enforcement"
  (bsc#1046299 FATE#322947).
- net/mlx4: fix spelling mistake: "coalesing" -> "coalescing"
  (bsc#1046299 FATE#322947).
- bpf: mlx4: Report bpf_prog ID during XDP_QUERY_PROG (bsc#1046299
  FATE#322947).
- net/mlx4_en: Refactor mlx4_en_free_tx_desc (bsc#1046299
  FATE#322947).
- net/mlx4_en: Replace TXBB_SIZE multiplications with shift
  operations (bsc#1046299 FATE#322947).
- net/mlx4_en: Increase default TX ring size (bsc#1046299
  FATE#322947).
- net/mlx4_en: Poll XDP TX completion queue in RX NAPI
  (bsc#1046299 FATE#322947).
- net/mlx4_en: Improve XDP xmit function (bsc#1046299
  FATE#322947).
- net/mlx4_en: Improve stack xmit function (bsc#1046299
  FATE#322947).
- net/mlx4_en: Improve transmit CQ polling (bsc#1046299
  FATE#322947).
- net/mlx4_en: Improve receive data-path (bsc#1046299
  FATE#322947).
- net/mlx4_en: Optimized single ring steering (bsc#1046299
  FATE#322947).
- net/mlx4_en: Remove unused argument in TX datapath function
  (bsc#1046299 FATE#322947).
- IB/mlx4: Bump driver version (bsc#1046302 FATE#322945).
- net/mlx4_en: Bump driver version (bsc#1046299 FATE#322947).
- net/mlx4_core: Bump driver version (bsc#1046300 FATE#322946).
- commit 13e2dc6
* Fri Sep  8 2017 tbogendoerfer@suse.de
- Re-sorted network driver sorted section
- commit 011cd2d
* Fri Sep  8 2017 jslaby@suse.cz
- rpm/kernel-binary.spec.in: package ftrace-mod.o on arm64
  It is needed for building modules since 4.13:
  CC [M]  /suse/jslaby/a/aaa.o
  Building modules, stage 2.
  MODPOST 1 modules
  CC      /suse/jslaby/a/aaa.mod.o
  LD [M]  /suse/jslaby/a/aaa.ko
  ld: cannot find ./arch/arm64/kernel/ftrace-mod.o: No such file or directory
  ...
- commit 07da115
* Fri Sep  8 2017 msuchanek@suse.de
- net: ibm: ibmvnic: constify vio_device_id (fate#323285).
- ibmvnic: Add netdev_dbg output for debugging (fate#323285).
- ibmvnic: Clean up resources on probe failure (fate#323285).
- ibmvnic: Implement .get_channels (fate#323285).
- ibmvnic: Implement .get_ringparam (fate#323285).
- commit 1850d99
* Fri Sep  8 2017 msuchanek@suse.de
- ibmvnic: Convert vnic server reported statistics to cpu endian
  (fate#323285).
- ibmvnic: Implement per-queue statistics reporting (fate#323285).
- commit 1d86bd7
* Thu Sep  7 2017 bpoirier@suse.com
- net/{mii, smsc}: Make mii_ethtool_get_link_ksettings and
  smc_netdev_get_ecmd return void (bsc#1056666 FATE#322183).
- commit c133dc9
* Thu Sep  7 2017 bpoirier@suse.com
- igb: make a few local functions static (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: Remove useless argument (bsc#1056651 FATE#322191
  bsc#1056643 FATE#322192).
- igb: check for Tx timestamp timeouts during watchdog
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: add statistic indicating number of skipped Tx timestamps
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: avoid permanent lock of *_PTP_TX_IN_PROGRESS (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- igb: fix race condition with PTP_TX_IN_PROGRESS bits
  (bsc#1056651 FATE#322191 bsc#1056643 FATE#322192).
- igb: mark PM functions as __maybe_unused (bsc#1056651
  FATE#322191 bsc#1056643 FATE#322192).
- commit 846d7ef
* Thu Sep  7 2017 bpoirier@suse.com
- i40e backport for SLE15
  e3412575488a net: ethernet: update drivers to handle HWTSTAMP_FILTER_NTP_ALL (v4.13-rc1)
  already added as part of e1000e
  eb873fe4d31b i40evf: fix duplicate lines (v4.13-rc1)
  155b0f690051 i40evf: fix merge error in older patch (v4.13-rc1)
  Already applied with ref bsc#1024346 FATE#321239 bsc#1024373
  FATE#321247. Refreshed.
  9d68322e53e6 i40evf: disable unused flags (v4.13-rc1)
  bbc4e7d273b5 i40e: fix race condition with PTP_TX_IN_PROGRESS bits (v4.13-rc1)
  69077577af50 i40e: avoid permanent lock of *_PTP_TX_IN_PROGRESS (v4.13-rc1)
  2955faca0403 i40e: add statistic indicating number of skipped Tx timestamps (v4.13-rc1)
  61189556692e i40e: use pf data structure directly in i40e_ptp_rx_hang (v4.13-rc1)
  0bc0706b46cd i40e: check for Tx timestamp timeouts during watchdog (v4.13-rc1)
  0a4ecc2c5e04 i40e: Check for memory allocation failure (v4.13-rc1)
  392908033308 i40evf: drop i40e_type.h include (v4.13-rc1)
  681bdf80cff6 i40e/i40evf: create and use new unified header file (v4.13-rc1)
  55cdfd48f217 i40e: use new unified virtchnl header file (v4.13-rc1)
  310a2ad92e3f virtchnl: rename i40e to generic virtchnl (v4.13-rc1)
  260e93820ad6 virtchnl: move some code to core driver (v4.13-rc1)
  eedcfef85b15 virtchnl: convert to new macros (v4.13-rc1)
  764430ce6f8c i40e/virtchnl: refactor code for validate checks (v4.13-rc1)
  f0adc6e831ba i40evf/virtchnl: whitespace cleanups (v4.13-rc1)
  ff3f4cc267f6 virtchnl: finish conversion to virtchnl interface (v4.13-rc1)
  735e35c56bbc i40e/virtchnl: move function to virtchnl (v4.13-rc1)
  a33c83c4353b virtchnl: Add pad fields to a couple of structures (v4.13-rc1)
  73556269aab3 virtchnl: Add compile time static asserts to validate structure sizes (v4.13-rc1)
  abf709a1e731 i40evf: Add support for Adaptive Virtual Function (v4.13-rc1)
  a5fcf8a6c968 net: propagate tc filter chain index down the ndo_setup_tc call (v4.13-rc1)
  already applied as part of ixgbe
  4df864c1d9af networking: make skb_put & friends return void pointers (v4.13-rc1)
  already applied with ref bsc#1056787
  0c8493d90b6b i40e: add XDP support for pass and drop actions (v4.13-rc1)
  74608d17fe29 i40e: add support for XDP_TX action (v4.13-rc1)
  65c7006f234c i40evf: assign num_active_queues inside i40evf_alloc_queues (v4.13-rc1)
  7c32b1e65075 i40e/i40evf: update WOL and I40E_AQC_ADDR_VALID_MASK flags (v4.13-rc1)
  59e331e36ef9 i40e: use dev_dbg instead of dev_info when warning about missing routine (v4.13-rc1)
  15d23b4c361f i40e: comment that udp_port must be in host byte order (v4.13-rc1)
  1e99854715c7 i40e: Fix potential out of bound array access (v4.13-rc1)
  68fb13a76774 i40e: Support firmware CEE DCB UP to TC map re-definition (v4.13-rc1)
  83d14c595e01 i40e: Add message for unsupported MFP mode (v4.13-rc1)
  4fc8c6763957 i40e: genericize the partition bandwidth control (v4.13-rc1)
  5bbb2e204544 i40e: Add support for OEM firmware version (v4.13-rc1)
  e58872398684 i40e: fix disabling overflow promiscuous mode (v4.13-rc1)
  2e5c26ea0d08 i40e: clear only cause_ena bit (v4.13-rc1)
  7642984b0876 i40e: Handle PE_CRITERR properly with IWARP enabled (v4.13-rc1)
  dfc4ff644674 i40e: don't hold RTNL lock for the entire reset (v4.13-rc1)
  7d6d06779028 i40e: Initialize 64-bit statistics TX ring seqcount (v4.13-rc5)
- i40e: Add message for unsupported MFP mode (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Add support for OEM firmware version (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Check for memory allocation failure (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Fix potential out of bound array access (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Handle PE_CRITERR properly with IWARP enabled (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Initialize 64-bit statistics TX ring seqcount (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: Support firmware CEE DCB UP to TC map re-definition
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: add XDP support for pass and drop actions (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: add statistic indicating number of skipped Tx timestamps
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: add support for XDP_TX action (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: avoid permanent lock of *_PTP_TX_IN_PROGRESS (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: check for Tx timestamp timeouts during watchdog
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: clear only cause_ena bit (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40e: comment that udp_port must be in host byte order
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: don't hold RTNL lock for the entire reset (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix disabling overflow promiscuous mode (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: fix race condition with PTP_TX_IN_PROGRESS bits
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: genericize the partition bandwidth control (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: create and use new unified header file (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/i40evf: update WOL and I40E_AQC_ADDR_VALID_MASK flags
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: use dev_dbg instead of dev_info when warning about missing
  routine (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e: use new unified virtchnl header file (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e: use pf data structure directly in i40e_ptp_rx_hang
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40e/virtchnl: move function to virtchnl (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40e/virtchnl: refactor code for validate checks (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40evf: Add support for Adaptive Virtual Function (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- i40evf: assign num_active_queues inside i40evf_alloc_queues
  (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- i40evf: disable unused flags (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: drop i40e_type.h include (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- i40evf: fix duplicate lines (bsc#1056658 FATE#322188 bsc#1056662
  FATE#322186).
- i40evf/virtchnl: whitespace cleanups (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- virtchnl: Add compile time static asserts to validate structure
  sizes (bsc#1056658 FATE#322188 bsc#1056662 FATE#322186).
- virtchnl: Add pad fields to a couple of structures (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- virtchnl: convert to new macros (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- virtchnl: finish conversion to virtchnl interface (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- virtchnl: move some code to core driver (bsc#1056658 FATE#322188
  bsc#1056662 FATE#322186).
- virtchnl: rename i40e to generic virtchnl (bsc#1056658
  FATE#322188 bsc#1056662 FATE#322186).
- Refresh
  patches.drivers/i40evf-fix-merge-error-in-older-patch.patch.
- commit dd418e7
* Thu Sep  7 2017 tbogendoerfer@suse.de
- net: check type when freeing metadata dst (bsc#1056787).
- commit a09d253
* Thu Sep  7 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Expand kernel tree directly from sources (bsc#1057199)
- commit a61b4d9
* Thu Sep  7 2017 tbogendoerfer@suse.de
- cisco: enic: Fic an error handling path in
  'vnic_dev_init_devcmd2()' (bsc#1037697).
- enic: Fix format truncation warning (bsc#1037697).
- enic: unmask intr only when napi is complete (bsc#1037697).
- commit c00bce8
* Thu Sep  7 2017 mgorman@suse.de
- Refresh
  patches.suse/exports-from-rcu_idle_exit-and-rcu_idle_enter.patch.
- Refresh
  patches.suse/numa-sched-slow-down-scan-rate-if-shared-faults-dominate.patch.
- Refresh
  patches.suse/page-waitqueue-always-add-new-entries-at-the-end.patch.
- Refresh
  patches.suse/rcu_idle_enter-rely-on-callers-disabling-irqs.patch.
- Refresh
  patches.suse/sched-numa-scale-scan-period-with-tasks-in-group-and-shared-private.patch.
- commit 14198d9
* Thu Sep  7 2017 jack@suse.cz
- gfs2: Don't clear SGID when inheriting ACLs (bsc#1052766).
- commit 6e0baaf
* Thu Sep  7 2017 jack@suse.cz
- xfs: fix inobt inode allocation search optimization
  (bsc#1052766).
- commit d59b124
* Thu Sep  7 2017 oneukum@suse.com
- Update config files.
  Switch off radio support (FATE#323882)
- commit 9ff0bc2
* Thu Sep  7 2017 oneukum@suse.com
- intel_th: pci: Add Cannon Lake PCH-H support (FATE#321195).
- intel_th: pci: Add Cannon Lake PCH-LP support (FATE#321195).
- commit 9fe67df
* Thu Sep  7 2017 tiwai@suse.de
- drm/i915/cfl: Fix Workarounds (FATE#322643 bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake workarounds (FATE#322643
  bsc#1055900).
- drm/i915: Store 9 bits of PCI Device ID for platforms with a
  LP PCH (FATE#322643 bsc#1055900).
- drm/i915/cfl: Basic DDI plumbing for Coffee Lake (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Coffee Lake reuses Kabylake DMC (FATE#322643
  bsc#1055900).
- drm/i915/huc: Load HuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/guc: Load GuC on Coffee Lake (FATE#322643 bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for U Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for H Sku (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Add Coffee Lake PCI IDs for S Skus (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Display workarounds for Coffee Lake
  (FATE#322643 bsc#1055900).
- drm/i915/cfl: Coffee Lake uses CNP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cfl: Introduce Coffee Lake platform definition
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Cannonlake uses CNP PCH (FATE#322643 bsc#1055900).
- drm/i915/cnp: Panel Power sequence changes for CNP PCH
  (FATE#322643 bsc#1055900).
- drm/i915/cnl: Introduce Cannonlake platform defition
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: add CNP gmbus support (FATE#322643 bsc#1055900).
- drm/i915/cnp: Backlight support for CNP (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Get/set proper Raw clock frequency on CNP
  (FATE#322643 bsc#1055900).
- drm/i915/cnp: Add PCI ID for Cannonpoint LP PCH (FATE#322643
  bsc#1055900).
- drm/i915/cnp: Introduce Cannonpoint PCH (FATE#322643
  bsc#1055900).
- commit 602378e
* Thu Sep  7 2017 jslaby@suse.cz
- Linux 4.12.11 (bnc#1012628).
- commit bf7fb08
* Wed Sep  6 2017 mcgrof@suse.com
- supported.conf: add test_syctl to new kselftests-kmp package FATE#323821
  As per FATE#323821 we will require new FATE requests per each
  new selftest driver. We don't want to support these module on
  production runs but we do want to support them for QA / testing
  uses. The compromise is to package them into its own package,
  this will be the kselftests-kmp package.
  Selftests can also be used as proof of concept vehicle for issues
  by customers or ourselves.
  Vanilla kernels do not get test_sysctl given that driver was
  using built-in defaults, this also means we cannot run sefltests
  on config/s390x/zfcpdump which does not enable modules.
  Likeweise, since we had to *change* the kernel for test_syctl, it
  it also means we can't test test_syctl with vanilla kernels. It
  should be possible with other selftests drivers if they are
  present in vanilla kernels though.
- commit ae8069f
* Wed Sep  6 2017 bpoirier@suse.com
- Update config files.
  Needed because of the backport of 7edaeb6841df ("kernel/watchdog: Prevent
  false positives with turbo modes", v4.13-rc6) added in v4.12.9.
- commit 6d65043
* Wed Sep  6 2017 bpoirier@suse.com
- net: Fix parisc SCM_TIMESTAMPING_PKTINFO value (bsc#1056664
  FATE#322185).
- net: Define SCM_TIMESTAMPING_PKTINFO on all architectures
  (bsc#1056664 FATE#322185).
- commit ad597de
* Wed Sep  6 2017 bpoirier@suse.com
- ixgbe: Initialize 64-bit stats seqcounts (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- bpf: ixgbe: Report bpf_prog ID during XDP_QUERY_PROG
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: Add IFLA_XDP_PROG_ID (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbe: pci_set_drvdata must be called before register_netdev
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Resolve cppcheck format string warning (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: fix writes to PFQDE (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbevf: Bump version number (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- ixgbe: Bump version number (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbe: check for Tx timestamp timeouts during watchdog
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: add statistic indicating number of skipped Tx timestamps
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: avoid permanent lock of *_PTP_TX_IN_PROGRESS (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: fix race condition with PTP_TX_IN_PROGRESS bits
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: propagate tc filter chain index down the ndo_setup_tc call
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- bpf: Introduce bpf_prog ID (bsc#1056657 FATE#322189 bsc#1056653
  FATE#322190).
- ixgbe: fix incorrect status check (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- ixgbe: add missing configuration for rate select 1 (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: always call setup_mac_link for multispeed fiber
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: add write flush when configuring CS4223/7 (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: correct CS4223/7 PHY identification (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbevf: Resolve warnings for -Wimplicit-fallthrough
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbevf: Resolve truncation warning for q_vector->name
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Resolve warnings for -Wimplicit-fallthrough (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Resolve truncation warning for q_vector->name
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Add error checking to setting VF MAC (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Correct thermal sensor event check (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: enable L3/L4 filtering for Tx switched packets
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: Remove MAC X550EM_X 1Gbase-t led_[on|off] support
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe: initialize u64_stats_sync structures early at ixgbe_probe
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- ixgbe/ixgbevf: Enables TSO for MPLS encapsulated packets
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: add termination action to allow goto chain
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: push tp down to action init (bsc#1056657 FATE#322189
  bsc#1056653 FATE#322190).
- net: sched: introduce multichain support for filters
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: push chain dump to a separate function (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- net: sched: introduce helpers to work with filter chains
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: move TC_H_MAJ macro call into tcf_auto_prio
  (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: replace nprio by a bool to make the function more
  readable (bsc#1056657 FATE#322189 bsc#1056653 FATE#322190).
- net: sched: rename tcf_destroy_chain helper (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- net: sched: introduce tcf block infractructure (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- net: sched: move tc_classify function to cls_api.c (bsc#1056657
  FATE#322189 bsc#1056653 FATE#322190).
- commit fe2f3a3
* Wed Sep  6 2017 bpoirier@suse.com
- e1000e: Undo e1000e_pm_freeze if __e1000_shutdown fails
  (bsc#1056664 FATE#322185).
- e1000e: use disable_hardirq() also for MSIX vectors in
  e1000_netpoll() (bsc#1056664 FATE#322185).
- e1000e: add statistic indicating number of skipped Tx timestamps
  (bsc#1056664 FATE#322185).
- e1000e: fix race condition around skb_tstamp_tx() (bsc#1056664
  FATE#322185).
- net: ethernet: update drivers to make both SW and HW TX
  timestamps (bsc#1056664 FATE#322185).
- net: allow simultaneous SW and HW transmit timestamping
  (bsc#1056664 FATE#322185).
- net: fix documentation of struct scm_timestamping (bsc#1056664
  FATE#322185).
- net: add new control message for incoming HW-timestamped packets
  (bsc#1056664 FATE#322185).
- net: add function to retrieve original skb device using NAPI ID
  (bsc#1056664 FATE#322185).
- net: ethernet: update drivers to handle HWTSTAMP_FILTER_NTP_ALL
  (bsc#1056664 FATE#322185).
- net: define receive timestamp filter for NTP (bsc#1056664
  FATE#322185).
- commit ac365e2
* Wed Sep  6 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Re-add xmlto buildreq conditionally for SLE15 & co
- commit 259b49e
* Wed Sep  6 2017 mchandras@suse.de
- rpm/group-source-files.pl: Add arch/*/tools/* files to the devel package
  Commit b71c9ffb1405 ("powerpc: Add arch/powerpc/tools directory")
  introduced in v4.12-rc1 release, moved the scripts into the tools
  directory. However, this location is not considered for the kernel devel
  package and the following error occurs when building a kmp for powerpc
  make[2]: /usr/src/linux-4.12.9-1/arch/powerpc/tools/gcc-check-mprofile-kernel.sh: Command not found
- commit 5f1ff53
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.drivers/0002-hns-set-relation-between-hns_roce-and-hns_enet_drv.patch.
- commit 1532f7a
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.arch/arm64-1-5-arm64-perf-Basic-uncore-counter-support-for-Cavium-ThunderX.patch.
- Delete
  patches.arch/arm64-2-5-arm64-perf-Cavium-ThunderX-L2C-TAD-uncore-support.patch.
- Delete
  patches.arch/arm64-3-5-arm64-perf-Cavium-ThunderX-L2C-CBC-uncore-support.patch.
- Delete
  patches.arch/arm64-4-5-arm64-perf-Cavium-ThunderX-LMC-uncore-support.patch.
- Delete
  patches.arch/arm64-5-5-arm64-perf-Cavium-ThunderX-OCX-TLK-uncore-support.patch.
  Delete not upstreamed driver
- commit 68629cf
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.suse/arm64-0075-kdump-kexec-arm64-Add-kernel-parameter-to-enable-kexec.patch.
- commit 0bb01f6
* Tue Sep  5 2017 mbrugger@suse.com
- Delete
  patches.arch/arm64-0001-arm64-insn-Do-not-disable-irqs-during-patching.patch.
- Delete
  patches.arch/arm64-0002-arm64-Implement-IPI-based-TLB-invalidation.patch.
- Delete
  patches.arch/arm64-0003-KVM-arm-arm64-Check-for-broadcast-TLBI-support.patch.
- Delete
  patches.arch/arm64-0005-arm64-Add-workaround-for-Cavium-erratum-26026.patch.
  HW which needed this workaround is no longer supported
- commit bfc65a0
* Tue Sep  5 2017 jlee@suse.com
- Update config files. (fate#323414)
  Enable IMA kernel configuration on arm64 and s390x. (fate#323414)
- commit 39207d0
* Tue Sep  5 2017 jthumshirn@suse.de
- Update config files, enable NVMe on S/390x (FATE#323773).
- commit 6e56e74
* Tue Sep  5 2017 tbogendoerfer@suse.de
- cxgb4: Fix stack out-of-bounds read due to wrong size to
  t4_record_mbox() (bsc#1046540).
- iw_cxgb4: fix misuse of integer variable (bsc#1046543).
- iw_cxgb4: don't use WR keys/addrs for 0 byte reads
  (bsc#1046543).
- cxgb4: Fix error codes in c4iw_create_cq() (bsc#1046540).
- cxgb4: ptp_clock_register() returns error pointers (bsc#1046540
  bsc#1046648).
- cxgb4: add new T5 pci device id's (bsc#1046540).
- crypto: chcr - Avoid algo allocation in softirq (bsc#1046548).
- cxgb4: Support for get_ts_info ethtool method (bsc#1046540
  bsc#1046648).
- cxgb4: Add PTP Hardware Clock (PHC) support (bsc#1046540
  bsc#1046648).
- cxgb4: time stamping interface for PTP (bsc#1046540
  bsc#1046648).
- cxgb4: Use Firmware params to get buffer-group map
  (bsc#1046540).
- cxgb4: Update T6 Buffer Group and Channel Mappings
  (bsc#1046540).
- net: introduce __skb_put_[zero, data, u8] (bsc#1056787).
- cxgb4: add new T6 pci device id's (bsc#1046540).
- cxgb4: fix a NULL dereference (bsc#1046540).
- cxgb4: handle serial flash interrupt (bsc#1046540).
- cxgb4: fix memory leak in init_one() (bsc#1046540).
- cxgb4: handle interrupt raised when FW crashes (bsc#1046540).
- cxgb4: fix to bring link down after adapter crash (bsc#1046540).
- tcp: add a struct net parameter to tcp_parse_options()
  (bsc#1046543).
  Refresh
  patches.drivers/networking-make-skb_push-__skb_push-return-void-poin.patch.
- crypto: chcr - Select device in Round Robin fashion
  (bsc#1046548).
- crypto: chcr - Ensure Destination sg entry size less than 2k
  (bsc#1046548).
- chcr - Add debug counters (bsc#1046548).
- crypto: chcr - Add ctr mode and process large sg entries for
  cipher (bsc#1046548).
  Refresh
  patches.drivers/networking-make-skb_put-friends-return-void-pointers.patch.
- crypto: chcr - Avoid changing request structure (bsc#1046548).
- crypto: chcr - Return correct error code (bsc#1046548).
- crypto: chcr - Fix fallback key setting (bsc#1046548).
- crypto: chcr - Pass lcb bit setting to firmware (bsc#1046548).
- commit dd52566
* Tue Sep  5 2017 tiwai@suse.de
- drm/dp/mst: Handle errors from
  drm_atomic_get_private_obj_state() correctly (bsc#1055493).
- drm/i915: Track MST link bandwidth (bsc#1055493).
- drm/dp: Add DP MST helpers to atomically find and release vcpi
  slots (bsc#1055493).
- drm/dp: Introduce MST topology state to track available link
  bandwidth (bsc#1055493).
- drm: Add driver-private objects to atomic state (bsc#1055493).
- commit 5bd7bf1
* Tue Sep  5 2017 lduncan@suse.com
- cxgbit: fix sg_nents calculation (bsc#1046545).
- iscsi-target: fix invalid flags in text response (bsc#1046545).
- cxgbit: add missing __kfree_skb() (bsc#1046545).
- commit 053e1ff
* Tue Sep  5 2017 lduncan@suse.com
- RDMA/iser: don't send an rkey if all data is written as
  immadiate-data (bsc#1046647).
- IB/iser: Handle lack of memory management extentions correctly
  (bsc#1046647).
- commit e8af9ba
* Tue Sep  5 2017 dbueso@suse.de
- x86/nmi: Use raw lock (bsc#1050549).
- locking/rwsem-xadd: Add killable versions of
  rwsem_down_read_failed() (bsc#1050549).
- locking/rwsem-spinlock: Add killable versions of __down_read()
  (bsc#1050549).
- locking/pvqspinlock: Relax cmpxchg's to improve performance
  on some architectures (bsc#1050549).
- smp: Avoid using two cache lines for struct call_single_data
  (bsc#1050549).
- smp, cpumask: Use non-atomic cpumask_{set,clear}_cpu()
  (bsc#1050549).
- smp: Avoid sending needless IPI in smp_call_function_many()
  (bsc#1050549).
- commit 46ecda3
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: Fix section __init warning (fate#322438).
- commit fe47c32
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: improve debugging macros (fate#322438).
- powerpc/xive: add XIVE Exploitation Mode to CAS (fate#322438).
- powerpc/xive: introduce H_INT_ESB hcall (fate#322438).
- powerpc/xive: add the HW IRQ number under xive_irq_data
  (fate#322438).
- powerpc/xive: introduce xive_esb_write() (fate#322438).
- commit daa41de
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: rename xive_poke_esb() in xive_esb_read()
  (fate#322438).
- powerpc/xive: guest exploitation of the XIVE interrupt
  controller (fate#322438).
- powerpc/xive: introduce a common routine xive_queue_page_alloc()
  (fate#322438).
- powerpc/xmon: Exclude all of xmon from ftrace (fate#322438).
- commit 71dd0bb
* Mon Sep  4 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit 2da2414
* Mon Sep  4 2017 msuchanek@suse.de
- powerpc/xive: Fix the size of the cpumask used in
  xive_find_target_in_mask() (fate#322438).
- commit 956ce91
* Mon Sep  4 2017 tbogendoerfer@suse.de
- sch_sfq: fix null pointer dereference on init failure
  (bsc#1056787).
- sch_hfsc: fix null pointer deref and double free on init failure
  (bsc#1056787).
- net: sched: don't do tcf_chain_flush from tcf_chain_destroy
  (bsc#1056787).
- net: sched: fix use after free when tcf_chain_destroy is called
  multiple times (bsc#1056787).
- udp: make function udp_skb_dtor_locked static (bsc#1056787).
- commit a5094e3
* Mon Sep  4 2017 tbogendoerfer@suse.de
- nfp: double free on error in probe (bsc#1055968).
- nfp: remove incorrect mask check for vlan matching
  (bsc#1055968).
- nfp: fix supported key layers calculation (bsc#1055968).
- nfp: fix unchecked flow dissector use (bsc#1055968).
- nfp: avoid buffer leak when representor is missing
  (bsc#1055968).
- nfp: make sure representors are destroyed before their lower
  netdev (bsc#1055968).
- nfp: don't hold PF lock while enabling SR-IOV (bsc#1055968).
- commit 6f53b58
* Mon Sep  4 2017 tbogendoerfer@suse.de
- net: Define SCM_TIMESTAMPING_PKTINFO on all architectures
  (bsc#1056787).
- commit 502bfad
* Mon Sep  4 2017 tbogendoerfer@suse.de
- Update config files.
- commit 3eb3872
* Mon Sep  4 2017 tbogendoerfer@suse.de
- nfp: do not update MTU from BH in flower app (bsc#1055968).
- nfp: Initialize RX and TX ring 64-bit stats seqcounts
  (bsc#1055968).
- nfp: freeing the wrong variable (bsc#1055968).
- nfp: flower: add missing clean up call to avoid memory leaks
  (bsc#1055968).
- nfp: default to chained metadata prepend format (bsc#1055968).
- nfp: remove legacy MAC address lookup (bsc#1055968).
- nfp: improve order of interfaces in breakout mode (bsc#1055968).
- nfp: add control message passing capabilities to flower offloads
  (bsc#1055968).
- nfp: add a stats handler for flower offloads (bsc#1055968).
- nfp: add metadata to each flow offload (bsc#1055968).
- nfp: add basic action capabilities to flower offloads
  (bsc#1055968).
- nfp: extend flower matching capabilities (bsc#1055968).
- nfp: extend flower add flow offload (bsc#1055968).
- nfp: provide infrastructure for offloading flower based TC
  filters (bsc#1055968).
- nfp: add phys_switch_id support (bsc#1055968).
- nfp: flower: add Kconfig for flower app (bsc#1055968).
- nfp: allocate a private workqueue for driver work (bsc#1055968).
- nfp: reorder SR-IOV config and nfp_app SR-IOV callbacks
  (bsc#1055968).
- nfp: handle SR-IOV already enabled when driver is probing
  (bsc#1055968).
- nfp: wire get_phys_port_name on representors (bsc#1055968).
- nfp: allow converting representor's netdev into nfp_port
  (bsc#1055968).
- nfp: move representors' struct net_device_ops to shared code
  (bsc#1055968).
- nfp: make the representor get stats app-independent
  (bsc#1055968).
- nfp: spawn nfp_ports for PF and VF ports (bsc#1055968).
- nfp: add nfp_app cleanup callback and make flower use it
  (bsc#1055968).
- nfp: remove unused nfp_cpp_area_check_range() (bsc#1055968).
- nfp: add helper for mapping runtime symbols (bsc#1055968).
- nfp: move area mapping helper into nfpcore (bsc#1055968).
- nfp: explicitly check if application FW is loaded (bsc#1055968).
- nfp: add VF and PF representors to flower app (bsc#1055968).
- nfp: add flower app (bsc#1055968).
- nfp: add support for control messages for flower app
  (bsc#1055968).
- nfp: add support for tx/rx with metadata portid (bsc#1055968).
- nfp: provide nfp_port to of nfp_net_get_mac_addr()
  (bsc#1055968).
- nfp: app callbacks for SRIOV (bsc#1055968).
- nfp: add stats and xmit helpers for representors (bsc#1055968).
- nfp: general representor implementation (bsc#1055968).
- nfp: map mac_stats and vf_cfg BARs (bsc#1055968).
- nfp: move physical port init into a helper (bsc#1055968).
- nfp: devlink add support for getting eswitch mode (bsc#1055968).
- nfp: xdp: report if program is offloaded (bsc#1055968).
- nfp: bpf: add support for XDP_FLAGS_HW_MODE (bsc#1055968).
- nfp: bpf: release the reference on offloaded programs
  (bsc#1055968).
- nfp: bpf: don't offload XDP programs in DRV_MODE (bsc#1055968).
- nfp: xdp: move driver XDP setup into a separate function
  (bsc#1055968).
- nfp: add VLAN filtering support (bsc#1055968).
- bpf: nfp: Report bpf_prog ID during XDP_QUERY_PROG
  (bsc#1055968).
- nfp: report application FW build name in ethtool -i
  (bsc#1055968).
- nfp: keep MIP object around (bsc#1055968).
- nfp: remove automatic caching of HWInfo (bsc#1055968).
- nfp: remove automatic caching of RTsym table (bsc#1055968).
- nfp: make sure to cancel port refresh on the error path
  (bsc#1055968).
- commit 2a7c54a
* Mon Sep  4 2017 tbogendoerfer@suse.de
- net: sched: fix p_filter_chain check in tcf_chain_flush
  (bsc#1056787).
- net_sched: reset pointers to tcf blocks in classful qdiscs'
  destructors (bsc#1056787).
- net/sched/hfsc: allocate tcf block for hfsc root class
  (bsc#1056787).
- commit b26c3ec
* Mon Sep  4 2017 tbogendoerfer@suse.de
- net: switchdev: add SET_SWITCHDEV_OPS helper (bsc#1056787).
- net: store port/representator id in metadata_dst (bsc#1056787).
- xdp: add reporting of offload mode (bsc#1056787).
- xdp: add HW offload mode flag for installing programs
  (bsc#1056787).
- xdp: pass XDP flags into install handlers (bsc#1056787).
- net: Add IFLA_XDP_PROG_ID (bsc#1056787).
- bpf: Introduce bpf_prog ID (bsc#1056787).
- bpf: teach verifier to track stack depth (bsc#1056787).
- commit 5b751d3
* Mon Sep  4 2017 tbogendoerfer@suse.de
- networking: add and use skb_put_u8() (bsc#1056787).
- networking: make skb_push & __skb_push return void pointers
  (bsc#1056787).
- networking: make skb_pull & friends return void pointers
  (bsc#1056787).
- networking: make skb_put & friends return void pointers
  (bsc#1056787).
- networking: introduce and use skb_put_data() (bsc#1056787).
- networking: convert many more places to skb_put_zero()
  (bsc#1056787).
- net: sched: act_tunnel_key: make UDP checksum configurable
  (bsc#1056787).
- net: sched: act_tunnel_key: request UDP checksum by default
  (bsc#1056787).
- skbuff: make skb_put_zero() return void (bsc#1056787).
- net: use skb_unref() in napi_consume_skb() (bsc#1056787).
- bpf: permits narrower load from bpf program context fields
  (bsc#1056787).
- skbuff/mac80211: introduce and use skb_put_zero() (bsc#1056787).
- mac80211: mesh: support sending wide bandwidth CSA
  (bsc#1056787).
- net: factor out a helper to decrement the skb refcount
  (bsc#1056787).
- bpf: add bpf_set_hash helper for tc progs (bsc#1056787).
- bpf: remove cg_skb_func_proto and use sk_filter_func_proto
  directly (bsc#1056787).
- skbuff: only inherit relevant tx_flags (bsc#1056787).
- net: qrtr: Inform open sockets about new controller
  (bsc#1056787).
- net: qrtr: Broadcast DEL_CLIENT message when endpoint is closed
  (bsc#1056787).
- net: qrtr: Inject BYE on remote termination (bsc#1056787).
- net: qrtr: Refactor packet allocation (bsc#1056787).
- net: propagate tc filter chain index down the ndo_setup_tc call
  (bsc#1056787).
- net: sched: introduce a TRAP control action (bsc#1056787).
- net: sched: select cls when cls_act is enabled (bsc#1056787).
- neigh: Really delete an arp/neigh entry on "ip neigh delete"
  or "arp -d" (bsc#1056787).
- net/sched: cls_flower: add support for matching on ip tos and
  ttl (bsc#1056787).
- net/flow_dissector: add support for dissection of misc ip
  header fields (bsc#1056787).
- rtnetlink: use the new rtnl_get_event() interface (bsc#1056787).
- rtnl: Add support for netdev event to link messages
  (bsc#1056787).
- net_sched: only create filter chains for new filters/actions
  (bsc#1056787).
- net: sched: cls_api: make reclassify return all the way back
  to the original tp (bsc#1056787).
- net/sched: flower: add support for matching on tcp flags
  (bsc#1056787).
- net: flow_dissector: add support for dissection of tcp flags
  (bsc#1056787).
- net/sched: fix filter flushing (bsc#1056787).
- net/sched: properly assign RCU pointer in
  tcf_chain_tp_insert/remove (bsc#1056787).
- net: allow simultaneous SW and HW transmit timestamping
  (bsc#1056787).
- net: add new control message for incoming HW-timestamped packets
  (bsc#1056787).
- net: add function to retrieve original skb device using NAPI ID
  (bsc#1056787).
- net: ethernet: update drivers to handle HWTSTAMP_FILTER_NTP_ALL
  (bsc#1056787).
- net: define receive timestamp filter for NTP (bsc#1056787).
- sk_buff.h: improve description of CHECKSUM_{COMPLETE,
  UNNECESSARY} (bsc#1056787).
- net: more accurate checksumming in validate_xmit_skb()
  (bsc#1056787).
- net: use skb->csum_not_inet to identify packets needing crc32c
  (bsc#1056787).
- sk_buff: remove support for csum_bad in sk_buff (bsc#1056787).
- net: introduce skb_crc32c_csum_help (bsc#1056787).
- skbuff: add stub to help computing crc32c on SCTP packets
  (bsc#1056787).
- net: fix __skb_try_recv_from_queue to return the old behavior
  (bsc#1056787).
- net: make struct net_device::tx_queue_len unsigned int
  (bsc#1056787).
- sch_dsmark: Fix uninitialized variable warning (bsc#1056787).
- net: sched: add termination action to allow goto chain
  (bsc#1056787).
- net: sched: push tp down to action init (bsc#1056787).
- net: sched: introduce multichain support for filters
  (bsc#1056787).
- net: sched: push chain dump to a separate function
  (bsc#1056787).
- net: sched: introduce helpers to work with filter chains
  (bsc#1056787).
- net: sched: move TC_H_MAJ macro call into tcf_auto_prio
  (bsc#1056787).
- net: sched: replace nprio by a bool to make the function more
  readable (bsc#1056787).
- net: sched: rename tcf_destroy_chain helper (bsc#1056787).
- net: sched: introduce tcf block infractructure (bsc#1056787).
- net: sched: move tc_classify function to cls_api.c
  (bsc#1056787).
- tcp: internal implementation for pacing (bsc#1056787).
- udp: keep the sk_receive_queue held when splicing (bsc#1056787).
- udp: use a separate rx queue for packet reception (bsc#1056787).
- net/sock: factor out dequeue/peek with offset code
  (bsc#1056787).
- net: fix some identation issues at kernel-doc markups
  (bsc#1056787).
- net: skbuff.h: properly escape a macro name on kernel-doc
  (bsc#1056787).
- commit 7232e8e
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Fix SME encryption stack ptr handling (fate#322123).
- commit aea6d23
* Mon Sep  4 2017 bp@suse.de
- acpi, x86/mm: Remove encryption mask from ACPI page protection
  type (fate#322123).
- commit 4d393f7
* Mon Sep  4 2017 bp@suse.de
- x86/mm, kexec: Fix memory corruption with SME on successive
  kexecs (fate#322123).
- commit 261ee7e
* Mon Sep  4 2017 bp@suse.de
- x86/boot: Fix memremap() related build failure (fate#322123).
- commit 04d48c7
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64/clang: Use fixup_pointer() to access
  'next_early_pgt' (fate#322123).
  Subsequently pulled in by git-fixes.
- commit db95bac
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to make use of Secure Memory Encryption
  (fate#322123).
- commit 1ede395
* Mon Sep  4 2017 bp@suse.de
- compiler-gcc.h: Introduce __nostackprotector function attribute
  (fate#322123).
- commit 9b71e69
* Mon Sep  4 2017 bp@suse.de
- x86/boot: Add early cmdline parsing for options with arguments
  (fate#322123).
- commit f880532
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to encrypt the kernel in-place
  (fate#322123).
- commit 7fb1d36
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Create native_make_p4d() for PGTABLE_LEVELS <= 4
  (fate#322123).
- commit 519d43f
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Use proper encryption attributes with /dev/mem
  (fate#322123).
- commit 7e40dec
* Mon Sep  4 2017 bp@suse.de
- xen/x86: Remove SME feature in PV guests (fate#322123).
- commit b2b2f82
* Mon Sep  4 2017 bp@suse.de
- x86/mm, kexec: Allow kexec to be used with SME (fate#322123).
- commit c5ac3b2
* Mon Sep  4 2017 bp@suse.de
- kvm/x86/svm: Support Secure Memory Encryption within KVM
  (fate#322123).
- commit ded3057
* Mon Sep  4 2017 bp@suse.de
- x86, drm, fbdev: Do not specify encrypted memory for video
  mappings (fate#322123).
- commit 3926698
* Mon Sep  4 2017 bp@suse.de
- x86/boot/realmode: Check for memory encryption on the APs
  (fate#322123).
- commit a907124
* Mon Sep  4 2017 bp@suse.de
- iommu/amd: Allow the AMD IOMMU to work with memory encryption
  (fate#322123).
- Refresh
  patches.drivers/0012-iommu-amd-suppress-io_page_faults-in-kdump-kernel.
- Refresh
  patches.drivers/0019-iommu-amd-remove-amd_iommu_disabled-check-from-amd_iommu_detect.
- commit 06efcc5
* Mon Sep  4 2017 tbogendoerfer@suse.de
- Patch will be redone with commits for bsc#1056787
  Delete
  patches.suse/msft-hv-1363-networking-introduce-and-use-skb_put_data.patch.
- commit de2f49a
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Make the microcode level available earlier in
  the boot (fate#322123).
- commit 45da941
* Mon Sep  4 2017 bp@suse.de
- swiotlb: Add warnings for use of bounce buffers with SME
  (fate#322123).
- commit 4b6c991
* Mon Sep  4 2017 bp@suse.de
- x86, swiotlb: Add memory encryption support (fate#322123).
- commit 0dc9b8d
* Mon Sep  4 2017 bp@suse.de
- x86/realmode: Decrypt trampoline area if memory encryption is
  active (fate#322123).
- commit 70f1f35
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support for changing the memory encryption attribute
  (fate#322123).
- commit 5eb9aa3
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to access persistent memory in the clear
  (fate#322123).
- commit 2521a3c
* Mon Sep  4 2017 bp@suse.de
- x86/boot: Use memremap() to map the MPF and MPC data
  (fate#322123).
- commit 40f02a4
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to access boot related data in the clear
  (fate#322123).
- commit e966ee6
* Mon Sep  4 2017 bp@suse.de
- x86/efi: Update EFI pagetable creation to work with SME
  (fate#322123).
- commit ce57435
* Mon Sep  4 2017 bp@suse.de
- efi: Update efi_mem_type() to return an error rather than 0
  (fate#322123).
- commit 91147ec
* Mon Sep  4 2017 bp@suse.de
- efi: Add an EFI table address match function (fate#322123).
- commit 473de56
* Mon Sep  4 2017 bp@suse.de
- x86/boot/e820: Add support to determine the E820 type of an
  address (fate#322123).
- commit a831c04
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Insure that boot memory areas are mapped properly
  (fate#322123).
- commit 7075d9d
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support for early encryption/decryption of memory
  (fate#322123).
- commit c49e594
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Extend early_memremap() support with additional attrs
  (fate#322123).
- commit bffaaa4
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add SME support for read_cr3_pa() (fate#322123).
- commit 8a90820
* Mon Sep  4 2017 tbogendoerfer@suse.de
- nfp: advertise support for NFD ABI 0.5 (bsc#1055968).
- nfp: create control vNICs and wire up rx/tx (bsc#1055968).
- nfp: allow non-equal distribution of IRQs (bsc#1055968).
- nfp: slice the netdev spawning function (bsc#1055968).
- nfp: don't clutter init code passing fw_ver around
  (bsc#1055968).
- nfp: map all queue controllers at once (bsc#1055968).
- nfp: make vNIC ctrl memory mapping function reusable
  (bsc#1055968).
- nfp: add control vNIC datapath (bsc#1055968).
- nfp: prepare config and enable for working without netdevs
  (bsc#1055968).
- nfp: allow allocation and initialization of netdev-less vNICs
  (bsc#1055968).
- nfp: make sure debug accesses don't depend on netdevs
  (bsc#1055968).
- nfp: prepare print macros for use without netdev (bsc#1055968).
- nfp: move nfp_net_vecs_init() (bsc#1055968).
- nfp: reuse ring free code on close (bsc#1055968).
- nfp: split out the allocation part of open (bsc#1055968).
- nfp: reorder open and close functions (bsc#1055968).
- nfp: fix memory leak on FW load error (bsc#1055968).
- nfp: move basic eBPF stats to app-specific code (bsc#1055968).
- nfp: move bpf offload code to the BPF app (bsc#1055968).
- nfp: move eBPF offload files to BPF app directory (bsc#1055968).
- nfp: report app name in ethtool -i (bsc#1055968).
- nfp: move port init to apps (bsc#1055968).
- nfp: turn reading PCIe RTsym parameters into a helper
  (bsc#1055968).
- nfp: add missing fall through statements (bsc#1055968).
- sched: add helper for updating statistics on all actions
  (bsc#1055968).
- nfp: don't keep count for free buffers delayed kick
  (bsc#1055968).
- nfp: don't add ring size to index calculations (bsc#1055968).
- nfp: fix print format for ring pointers in ring dumps
  (bsc#1055968).
- nfp: don't wait for resources indefinitely (bsc#1055968).
- nfp: add hwmon support (bsc#1055968).
- nfp: support variable NSP response lengths (bsc#1055968).
- nfp: shorten CPP core probe logs (bsc#1055968).
- nfp: support long reads and writes with the cpp helpers
  (bsc#1055968).
- nfp: only try to get to PCIe ctrl memory if BARs are wide enough
  (bsc#1055968).
- nfp: don't set aux pointers if ioremap failed (bsc#1055968).
- nfp: set driver VF limit (bsc#1055968).
- nfp: add set_mac_address support while the interface is up
  (bsc#1055968).
- nfp: add MAY_USE_DEVLINK dependency (bsc#1055968).
- nfp: support port splitting via devlink (bsc#1055968).
- nfp: calculate total port lanes for split (bsc#1055968).
- nfp: register ports as devlink ports (bsc#1055968).
- nfp: add helper for cleaning up vNICs (bsc#1055968).
- nfp: add devlink support (bsc#1055968).
- nfp: move mutex init out of net code (bsc#1055968).
- nfp: refresh port state before reporting autonegotiation
  (bsc#1055968).
- nfp: mark port state as stale if update failed (bsc#1055968).
- nfp: mark port state as stale after reconfig (bsc#1055968).
- nfp: provide linking on port structures (bsc#1055968).
- nfp: move refresh tracking into the port structure
  (bsc#1055968).
- nfp: update port state in place (bsc#1055968).
- nfp: introduce nfp_port (bsc#1055968).
- nfp: disallow mixing vNICs with and without NSP port entry
  (bsc#1055968).
- nfp: introduce very minimal nfp_app (bsc#1055968).
- nfp: add nfp_net_pf_free_vnic() function (bsc#1055968).
- nfp: rename netdev/port to vNIC (bsc#1055968).
- nfp: make nfp_net alloc/init/cleanup/free not depend on netdevs
  (bsc#1055968).
- nfp: add nfp_cppcore_pcie_unit() helper (bsc#1055968).
- nfp: eliminate an if statement in calculation of completed
  frames (bsc#1055968).
- nfp: add a helper for wrapping descriptor index (bsc#1055968).
- nfp: complete the XDP TX ring only when it's full (bsc#1055968).
- nfp: add CHECKSUM_COMPLETE support (bsc#1055968).
- nfp: version independent support for chained RSS metadata
  (bsc#1055968).
- nfp: don't assume RSS and IRQ moderation are always enabled
  (bsc#1055968).
- nfp: support LSO2 capability (bsc#1055968).
- nfp: rename l4_offset in struct nfp_net_tx_desc to lso_hdrlen
  (bsc#1055968).
- nfp: don't enable TSO on the device when disabled (bsc#1055968).
- commit c02b1d9
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Provide general kernel support for memory encryption
  (fate#322123).
- commit 0bc99cf
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Simplify pd_page() macros (fate#322123).
- commit 35ace63
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add support to enable SME in early boot processing
  (fate#322123).
- commit 9508f8a
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Remove phys_to_virt() usage in ioremap() (fate#322123).
- commit 371b1fb
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Add Secure Memory Encryption (SME) support
  (fate#322123).
  Update config files with new options.
- commit 1f3aaaf
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Handle SME reduction in physical address size
  (fate#322123).
- commit 88d989f
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Add the Secure Memory Encryption CPU feature
  (fate#322123).
- commit 4e8af2a
* Mon Sep  4 2017 bp@suse.de
- x86, mpparse, x86/acpi, x86/PCI, x86/dmi, SFI: Use memremap()
  for RAM mappings (fate#322123).
- commit fd1bdfe
* Mon Sep  4 2017 bp@suse.de
- x86/mm/pat: Set write-protect cache mode for full PAT support
  (fate#322123).
- commit 9b2584b
* Mon Sep  4 2017 bp@suse.de
- x86/cpu/AMD: Document AMD Secure Memory Encryption (SME)
  (fate#322123).
- commit 112bbc1
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Put __startup_64() into .head.text (fate#322123).
- commit cb63948
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Add support of additional page table level during
  early boot (fate#322123).
- commit c69bf2f
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Rename init_level4_pgt and early_level4_pgt
  (fate#322123).
- commit d75bf42
* Mon Sep  4 2017 bp@suse.de
- x86/ftrace: Exclude functions in head64.c from function-tracing
  (fate#322123).
- commit 6d229da
* Mon Sep  4 2017 tbogendoerfer@suse.de
- Sorted patches in network section
- commit e2cc8e7
* Mon Sep  4 2017 bp@suse.de
- x86/boot/64: Rewrite startup_64() in C (fate#322123).
- commit 935bc66
* Mon Sep  4 2017 bp@suse.de
- x86/mm: Split read_cr3() into read_cr3_pa() and __read_cr3()
  (fate#322123).
- commit c5d71a2
* Mon Sep  4 2017 lhenriques@suse.com
- ceph: fix readpage from fscache (bsc#1057015).
- commit c9e96e6
* Fri Sep  1 2017 dbueso@suse.de
- powerpc: use spin loop primitives in some functions (bsc#1056912).
- commit dfd3f3e
* Fri Sep  1 2017 dbueso@suse.de
- spin loop primitives for busy waiting (bsc#1056912).
- commit cda1f6a
* Fri Sep  1 2017 lduncan@suse.com
- scsi: libcxgbi: add check for valid cxgbi_task_data
  (bsc#1046541).
- scsi: cxgb4i: assign rxqs in round robin mode (bsc#1046541).
- commit 3064c71
* Fri Sep  1 2017 jroedel@suse.de
- iommu/vt-d: Helper function to query if a pasid has any active
  users (fate#322864).
- commit 01214f9
* Fri Sep  1 2017 oneukum@suse.com
- Update config files. (FATE#322631)
- commit 90aeb55
* Fri Sep  1 2017 yousaf.kaukab@suse.com
- ixgbe: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- Revert commit 1a8b6d76dc5b ("net:add one common
  config...") (bsc#1056419).
- net/cxgb4vf: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- net/cxgb4: Use new PCI_DEV_FLAGS_NO_RELAXED_ORDERING flag
  (bsc#1056419).
- commit ce6396a
* Fri Sep  1 2017 bp@suse.de
- supported.conf: Add Goldmont-specific EDAC driver (fate#322662)
- commit eff24c3
* Fri Sep  1 2017 neilb@suse.com
- NFSv4: Fix double frees in nfs4_test_session_trunk()
  (git-fixes).
- xprtrdma: Don't defer MR recovery if ro_map fails (git-fixes).
- xprtrdma: Fix FRWR invalidation error recovery (git-fixes).
- xprtrdma: Fix client lock-up after application signal fires
  (git-fixes).
- xprtrdma: Rename rpcrdma_req::rl_free (git-fixes).
- xprtrdma: Pass only the list of registered MRs to ro_unmap_sync
  (git-fixes).
- xprtrdma: Pre-mark remotely invalidated MRs (git-fixes).
- xprtrdma: On invalidation failure, remove MWs from rl_registered
  (git-fixes).
- commit 7d59497
* Fri Sep  1 2017 mgalbraith@suse.de
- Per IBM request, drop drop IBM specific patches from SLE15 (bnc#1012582)
- Delete patches.suse/sched-disable-FAIR_SLEEPERS-for-S390.patch.
- Delete patches.suse/sched-reinstate-FAIR_SLEEPERS-feature.patch.
- Delete patches.suse/sched-reinstate-sched_compat_yield.patch.
- commit 3ee70fe
* Thu Aug 31 2017 tiwai@suse.de
- rt2800: fix TX_PIN_CFG setting for non MT7620 chips
  (bsc#1055826).
- commit d79ffeb
* Thu Aug 31 2017 oneukum@suse.com
- pinctrl: intel: Add Intel Cannon Lake PCH-H pin controller
  support (FATE#321195).
- spi: pxa2xx: Add support for Intel Cannonlake (FATE#321195).
- pinctrl: intel: Add Intel Cannon Lake PCH pin controller support
  (FATE#321195).
- pinctrl: intel: Make it possible to specify mode per pin in
  a group (FATE#321195).
- pinctrl: intel: Add support for variable size pad groups
  (FATE#321195).
- mmc: sdhci-pci: Add support for Intel CNP (FATE#321195).
- mmc: sdhci-pci: Use macros in pci_ids definition (FATE#321195).
- scsi: ufs: flush eh_work when eh_work scheduled (FATE#321195).
- commit 16f0485
* Thu Aug 31 2017 oneukum@suse.com
- scsi: ufshcd-pci: Add Intel CNL support (FATE#321195).
- scsi: ufshcd-pci: Fix PM config (FATE#321195).
- scsi: ufs: Tidy clocks list head usage (FATE#321195).
- commit f7ba845
* Thu Aug 31 2017 yousaf.kaukab@suse.com
- PCI: Allow PCI express root ports to find themselves
  (bsc#1056419).
- PCI: fix oops when try to find Root Port for a PCI device
  (bsc#1056419).
- PCI: Disable Relaxed Ordering Attributes for AMD A1100
  (bsc#1056419).
- PCI: Disable Relaxed Ordering for some Intel processors
  (bsc#1056419).
- PCI: Disable PCIe Relaxed Ordering if unsupported (bsc#1056419).
- commit 7e5ee6f
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit a9495c3
* Thu Aug 31 2017 jthumshirn@suse.de
- scsi: qla2xxx: Fix an integer overflow in sysfs code
  (bsc#1056588, CVE-2017-14051).
- commit 4fafb75
* Thu Aug 31 2017 oneukum@suse.com
- supported.conf: the old style UCSI for non-x86
- commit ed3ca0b
* Thu Aug 31 2017 jslaby@suse.cz
- blacklist.conf: add one objtool patch
- commit 6f1e31d
* Thu Aug 31 2017 tiwai@suse.de
- supported.conf: Reduce supported sound modules (bsc#1056612,FATE#323981)
- commit a185749
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Fix vlun resize failure in the shrink path
  (fate#322239).
- scsi: cxlflash: Avoid double mutex unlock (fate#322239).
- scsi: cxlflash: Remove unnecessary existence check
  (fate#322239).
- scsi: cxlflash: Fix an error handling path in
  'cxlflash_disk_attach()' (fate#322239).
- scsi: cxlflash: return -EFAULT if copy_from_user() fails
  (fate#322239).
- commit e126787
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Update debug prints in reset handlers
  (fate#322239).
- scsi: cxlflash: Update send_tmf() parameters (fate#322239).
- scsi: cxlflash: Avoid double free of character device
  (fate#322239).
- scsi: cxlflash: Update TMF command processing (fate#322239).
- scsi: cxlflash: Remove zeroing of private command data
  (fate#322239).
- scsi: cxlflash: Support WS16 unmap (fate#322239).
- commit 438c2e8
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Support AFU debug (fate#322239).
- scsi: cxlflash: Support LUN provisioning (fate#322239).
- scsi: cxlflash: Refactor AFU capability checking (fate#322239).
- scsi: cxlflash: Introduce host ioctl support (fate#322239).
- scsi: cxlflash: Separate AFU internal command handling from
  AFU sync specifics (fate#322239).
- commit e1c2471
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Create character device to provide host
  management interface (fate#322239).
- scsi: cxlflash: Add scsi command abort handler (fate#322239).
- scsi: cxlflash: Flush pending commands in cleanup path
  (fate#322239).
- scsi: cxlflash: Track pending scsi commands in each hardware
  queue (fate#322239).
- scsi: cxlflash: Handle AFU sync failures (fate#322239).
- commit aec8db3
* Thu Aug 31 2017 msuchanek@suse.de
- scsi: cxlflash: Schedule asynchronous reset of the host
  (fate#322239).
- scsi: cxlflash: Reset hardware queue context via specified
  register (fate#322239).
- scsi: cxlflash: Update cxlflash_afu_sync() to return errno
  (fate#322239).
- scsi: cxlflash: Combine the send queue locks (fate#322239).
- commit b877eca
* Thu Aug 31 2017 oneukum@suse.com
- supported.conf: add full ucsi support (FATE#322665, FATE#322666)
- commit 893e6d9
* Thu Aug 31 2017 bp@suse.de
- RAS/CEC: Disable CEC (bsc#1056592).
- commit cb2beb8
* Wed Aug 30 2017 mgorman@suse.de
- Fix up over-eager 'wait_queue_t' renaming (bnc#971975 VM
  performance -- page waitqueue).
- commit 92ad9c7
* Wed Aug 30 2017 jslaby@suse.cz
- Linux 4.12.10 (bnc#1012628 bnc#1014351 bnc#1048935 bsc#1020657
  bsc#1050582).
- Delete
  patches.drivers/ALSA-hda-Add-stereo-mic-quirk-for-Lenovo-G50-70-17aa.
- Delete
  patches.fixes/Bluetooth-hidp-fix-possible-might-sleep-error-in-hid.patch.
- Delete
  patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-.
- Delete
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
- commit 030062c
* Wed Aug 30 2017 mgorman@suse.de
- sched/wait: Introduce wakeup boomark in wake_up_page_bit
  (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Break up long wake list walk (bnc#971975 VM
  performance -- page waitqueue).
- page waitqueue: always add new entries at the end (bnc#971975
  VM performance -- page waitqueue).
- sched/wait: Clean up some documentation warnings (bnc#971975
  VM performance -- page waitqueue).
- sched/wait: Disambiguate wq_entry->task_list and
  wq_head->task_list naming (bnc#971975 VM performance --
  page waitqueue).
- sched/wait: Split out the wait_bit*() APIs from <linux/wait.h>
  into <linux/wait_bit.h> (bnc#971975 VM performance -- page
  waitqueue).
- sched/wait: Re-adjust macro line continuation backslashes in
  <linux/wait.h> (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Improve the bit-wait API parameter names in
  the API function prototypes (bnc#971975 VM performance --
  page waitqueue).
- sched/wait: Standardize wait_bit_queue naming (bnc#971975 VM
  performance -- page waitqueue).
- sched/wait: Standardize 'struct wait_bit_queue' wait-queue
  entry field name (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Standardize internal naming of wait-queue heads
  (bnc#971975 VM performance -- page waitqueue).
- sched/wait: Standardize internal naming of wait-queue entries
  (bnc#971975 VM performance -- page waitqueue).
- commit 59134c0
* Wed Aug 30 2017 mgorman@suse.de
- sched/wait: Rename wait_queue_t => wait_queue_entry_t
  (bnc#971975 VM performance -- page waitqueue).
- Refresh
  patches.fixes/Bluetooth-hidp-fix-possible-might-sleep-error-in-hid.patch.
- commit 60bfe92
* Wed Aug 30 2017 jthumshirn@suse.de
- scsi: qla2xxx: Update driver version to 10.00.00.01-k
  (FATE#322910).
- scsi: qla2xxx: Do not call abort handler function during chip
  reset (FATE#322910).
- scsi: qla2xxx: Ability to process multiple SGEs in Command
  SGL for CT passthrough commands (FATE#322910).
- scsi: qla2xxx: Skip zero queue count entry during FW dump
  capture (FATE#322910).
- scsi: qla2xxx: Recheck session state after RSCN (FATE#322910).
- scsi: qla2xxx: Increase ql2xmaxqdepth to 64 (FATE#322910).
- scsi: qla2xxx: Enable Async TMF processing (FATE#322910).
- scsi: qla2xxx: Cleanup NPIV host in target mode during config
  teardown (FATE#322910).
- scsi: qla2xxx: Add LR distance support from nvram bit
  (FATE#322910).
- scsi: qla2xxx: Add support for minimum link speed (FATE#322910).
- scsi: qla2xxx: Remove potential macro parameter side-effect
  in ql_dump_regs() (FATE#322910).
- scsi: qla2xxx: Print correct mailbox registers in failed summary
  (FATE#322910).
- scsi: qla2xxx: Fix task mgmt handling for NPIV (FATE#322910).
- scsi: qla2xxx: Allow SNS fabric login to be retried
  (FATE#322910).
- scsi: qla2xxx: Add timeout ability to wait_for_sess_deletion()
  (FATE#322910).
- scsi: qla2xxx: Move logging default mask to execute once only
  (FATE#322910).
- scsi: qla2xxx: Use sp->free instead of hard coded call
  (FATE#322910).
- scsi: qla2xxx: Prevent sp->free null/uninitialized pointer
  dereference (FATE#322910).
- scsi: qla2xxx: Add ability to autodetect SFP type (FATE#322910).
- scsi: qla2xxx: Use fabric name for Get Port Speed command
  (FATE#322910).
- scsi: qla2xxx: Change ha->wq max_active value to default
  (FATE#322910).
- scsi: qla2xxx: Remove extra register read (FATE#322910).
- scsi: qla2xxx: Fix NPIV host enable after chip reset
  (FATE#322910).
- scsi: qla2xxx: Use BIT_6 to acquire FAWWPN from switch
  (FATE#322910).
- scsi: qla2xxx: Fix system panic due to pointer access problem
  (FATE#322910).
- scsi: qla2xxx: Fix WWPN/WWNN in debug message (FATE#322910).
- scsi: qla2xxx: Add command completion for error path
  (FATE#322910).
- scsi: qla2xxx: Update fw_started flags at qpair creation
  (FATE#322910).
- scsi: qla2xxx: Fix target multiqueue configuration
  (FATE#322910).
- scsi: qla2xxx: Correction to vha->vref_count timeout
  (FATE#322910).
- scsi: qla2xxx: fix spelling mistake of variable
  sfp_additonal_info (FATE#322910).
- scsi: qla2xxx: use dma_mapping_error to check map errors
  (FATE#322910).
- scsi: qla2xxx: Fix remoteport disconnect for FC-NVMe
  (FATE#322910).
- scsi: qla2xxx: Simpify unregistration of FC-NVMe local/remote
  ports (FATE#322910).
- scsi: qla2xxx: Added change to enable ZIO for FC-NVMe devices
  (FATE#322910).
- scsi: qla2xxx: Move function prototype to correct header
  (FATE#322910).
- scsi: qla2xxx: Cleanup FC-NVMe code (FATE#322910).
- scsi: qla2xxx: Off by one in qlt_ctio_to_cmd() (FATE#322910).
- t10-pi: Move opencoded contants to common header (FATE#322910).
- qla2xxx: Fix NVMe entry_type for iocb packet on BE system
  (FATE#322910).
- scsi: qla2xxx: avoid unused-function warning (FATE#322910).
- scsi: qla2xxx: fix a bunch of typos and spelling mistakes
  (FATE#322910).
- scsi: qla2xxx: Protect access to qpair members with
  qpair->qp_lock (FATE#322910).
- scsi: qla2xxx: Update Driver version to 10.00.00.00-k
  (FATE#322910).
- scsi: qla2xxx: Use FC-NVMe FC4 type for FDMI registration
  (FATE#322910).
- scsi: qla2xxx: Send FC4 type NVMe to the management server
  (FATE#322910).
- scsi: qla2xxx: Add FC-NVMe F/W initialization and transport
  registration (FATE#322910).
- scsi: qla2xxx: Add FC-NVMe command handling (FATE#322910).
- scsi: qla2xxx: Add FC-NVMe port discovery and PRLI handling
  (FATE#322910).
- scsi: qla2xxx: Update driver version to 9.01.00.00-k
  (FATE#322910).
- scsi: qla2xxx: Include Exchange offload/Extended Login into
  FW dump (FATE#322910).
- scsi: qla2xxx: Move target stat counters from vha to qpair
  (FATE#322910).
- scsi: qla2xxx: Remove datasegs_per_cmd and datasegs_per_cont
  field (FATE#322910).
- scsi: qla2xxx: Remove unused tgt_enable_64bit_addr flag
  (FATE#322910).
- scsi: qla2xxx: Add debug logging routine for qpair
  (FATE#322910).
- scsi: qla2xxx: Add function call to qpair for door bell
  (FATE#322910).
- scsi: qla2xxx: use shadow register for ISP27XX (FATE#322910).
- scsi: qla2xxx: move fields from qla_hw_data to qla_qpair
  (FATE#322910).
- scsi: qla2xxx: Add fw_started flags to qpair (FATE#322910).
- scsi: qla2xxx: Add debug knob for user control workload
  (FATE#322910).
- scsi: qla2xxx: Fix mailbox failure while deleting Queue pairs
  (FATE#322910).
- scsi: qla2xxx: Enable Target Multi Queue (FATE#322910).
- scsi: qla2xxx: Preparation for Target MQ (FATE#322910).
- scsi: qla2xxx: Combine Active command arrays (FATE#322910).
- scsi: qla2xxx: don't include <generated/utsrelease.h>
  (FATE#322910).
- scsi: qla2xxx: Fix compile warning (FATE#322910).
- scsi: qla2xxx: remove redundant null check on tgt (FATE#322910).
- scsi: qla2xxx: remove writeq/readq function definitions
  (FATE#322910).
- scsi: qla2xxx: Remove extra register read (FATE#322910).
- scsi: qla2xxx: Remove unused irq_cmd_count field (FATE#322910).
- scsi: qla2xxx: Accelerate SCSI BUSY status generation in target
  mode (FATE#322910).
- scsi: qla2xxx: Remove redundant wait when target is stopped
  (FATE#322910).
- scsi: qla2xxx: Add ql2xiniexchg parameter (FATE#322910).
- scsi: qla2xxx: Turn on FW option for exchange check
  (FATE#322910).
- scsi: qla2xxx: Cleanup debug message IDs (FATE#322910).
- scsi: qla2xxx: Fix name server relogin (FATE#322910).
- scsi: qla2xxx: Convert 32-bit LUN usage to 64-bit (FATE#322910).
- scsi: qla2xxx: Use flag PFLG_DISCONNECTED (FATE#322910).
- scsi: tcm_qla2xxx: Do not allow aborted cmd to advance
  (FATE#322910).
- scsi: qla2xxx: Fix path recovery (FATE#322910).
- scsi: qla2xxx: Retain loop test for fwdump length exceeding
  buffer length (FATE#322910).
- scsi: qla2xxx: Replace usage of spin_lock with spin_lock_irqsave
  (FATE#322910).
- scsi: qla2xxx: Remove an unused structure member (FATE#322910).
- commit e1bfb61
* Wed Aug 30 2017 msuchanek@suse.de
- genirq/cpuhotplug: Do not migrated shutdown irqs (bsc#1054935).
- commit 075835d
* Wed Aug 30 2017 msuchanek@suse.de
- genirq/cpuhotplug: Reorder check logic (bsc#1054935).
- commit 1367886
* Wed Aug 30 2017 msuchanek@suse.de
- genirq/cpuhotplug: Dont claim success on error (bsc#1054935).
- commit 4f8cdfc
* Wed Aug 30 2017 oneukum@suse.com
- USB: add usbfs ioctl to retrieve the connection speed
  (FATE#321327).
- xhci: remove endpoint ring cache (FATE#321327, FATE#322665,
  FATE#322666).
- xhci: refactor transfer event errors and completion codes
  (FATE#321327, FATE#322665, FATE#322666).
- xhci: Add support for endpoint soft reset (FATE#321327).
- xhci: support calling cleanup_halted_endpoint with soft retry
  (bFATE#321327).
- xhci: handle transfer events without TRB pointer (FATE#321327).
- xhci: cleanup virtual endoint structure, remove stopped_stream
  (FATE#321327).
- xhci: cleanup finish_td() skip option (FATE#321327).
- usb: typec: Add support for UCSI interface (FATE#322665,
  FATE#322666).
- usb: typec: ucsi: Add ACPI driver (FATE#322665, FATE#322666).
- usb: typec: include linux/device.h in ucsi.h (FATE#322665,
  FATE#322666).
- usb: hcd: constify attribute_group structures (FATE#321327).
- xhci: rename temp and temp1 variables (FATE#321327).
- usb: Increase root hub reset signaling time to prevent retry
  (FATE#321327).
- xhci: rework bus_resume and check ports are suspended before
  resuming them (FATE#321327).
- usb: make device_type const (FATE#321327).
- USB: core: constify vm_operations_struct (FATE#321327).
- usb: xhci: Support enabling of compliance mode for xhci 1.1
  (FATE#321327).
- usb: misc: lvstest: add entry to place port in compliance mode
  (FATE#321327).
- Update config files.
- commit 7e26cc6
* Wed Aug 30 2017 oneukum@suse.com
- usb: typec: Add a sysfs node to manage port type (FATE#322665,
  FATE#322666).
- usb: typec: update partner power delivery support with opmode
  (FATE#322665, FATE#322666).
- xhci: remove unused stopped_td pointer (FATE#321327).
- xhci: Add stream id to xhci_dequeue_state structure
  (FATE#321327).
- xhci: Find out where an endpoint or stream stopped from its
  context (FATE#321327).
- xhci: Add helper to get hardware dequeue pointer for stopped
  rings (FATE#321327).
- usb: typec: Don't prevent using constant typec_mode_desc
  initializers (FATE#322665, FATE#322666).
- commit 80163a3
* Wed Aug 30 2017 mbenes@suse.cz
- Add live patching section to series.conf for future backports
  (fate#323487)
- commit 428055c
* Wed Aug 30 2017 mbenes@suse.cz
- Drop kGraft (fate#323487)
  Upstream live patching infrastructure is going to be used in SLE15
- Delete patches.suse/kgr-0002-livepatch-add-infrastructure.patch.
- Delete
  patches.suse/kgr-0003-livepatch-kgr_in_progress-for-all-threads.patch.
- Delete
  patches.suse/kgr-0004-ftrace-Make-ftrace_is_dead-available-globally.patch.
- Delete patches.suse/kgr-0005-initial-code.patch.
- Delete patches.suse/kgr-0006-add-testing-kgraft-patch.patch.
- Delete patches.suse/kgr-0007-add-Documentation.patch.
- Delete
  patches.suse/kgr-0008-mark-task_safe-in-some-kthreads.patch.
- Delete patches.suse/kgr-0009-kthreads-support.patch.
- Delete patches.suse/kgr-0010-handle-irqs.patch.
- Delete patches.suse/kgr-0011-allow-stacking-of-patches.patch.
- Delete
  patches.suse/kgr-0012-handle-patched-modules-that-are-being-removed.patch.
- Delete
  patches.suse/kgr-0013-try-to-apply-skipped-patches-when-a-module-is-lo.patch.
- Delete patches.suse/kgr-0014-allow-for-forced-module-load.patch.
- Delete patches.suse/kgr-0015-allow-replace_all.patch.
- Delete
  patches.suse/kgr-0016-support-for-forcing-success-of-patching-process.patch.
- Delete
  patches.suse/kgr-0017-correct-error-handling-of-the-first-patching-sta.patch.
- Delete
  patches.suse/kgr-0018-send-a-fake-signal-to-all-blocking-tasks.patch.
- Delete
  patches.suse/kgr-0019-mark-task_safe-in-non-upstream-kthreads.patch.
- Delete
  patches.suse/kgr-0020-kmemleak-really-mark-the-kthread-safe-after-a.patch.
- Delete
  patches.suse/kgr-0021-fix-reversion-of-a-patch-already-reverted-by-a-r.patch.
- Delete
  patches.suse/kgr-0022-add-objname-to-kgr_patch_fun-struct.patch.
- Delete patches.suse/kgr-0023-remove-abort_if_missing-flag.patch.
- Delete
  patches.suse/kgr-0024-do-not-return-and-print-an-error-only-if-the-obj.patch.
- Delete
  patches.suse/kgr-0025-fix-subtle-race-with-kgr_module_init-going-notif.patch.
- Delete
  patches.suse/kgr-0026-fix-an-asymmetric-dealing-with-delayed-module-lo.patch.
- Delete
  patches.suse/kgr-0027-call-kgr_init_ftrace_ops-only-for-loaded-objects.patch.
- Delete
  patches.suse/kgr-0028-change-to-kallsyms_on_each_symbol-iterator.patch.
- Delete
  patches.suse/kgr-0029-add-sympos-as-disambiguator-field-to-kgr_patch_f.patch.
- Delete patches.suse/kgr-0030-add-sympos-to-sysfs.patch.
- Delete
  patches.suse/kgr-0031-add-sympos-and-objname-to-error-and-debug-messag.patch.
- Delete patches.suse/kgr-0032-taint-with-TAINT_LIVEPATCH.patch.
- Delete
  patches.suse/kgr-0033-define-pr_fmt-and-modify-all-pr_-messages.patch.
- Delete
  patches.suse/kgr-0034-kgraft-bcache-Do-not-block-livepatching-in-the-write.patch.
- Delete
  patches.suse/kgr-0035-kgraft-gfs2-Do-not-block-livepatching-in-the-log-dae.patch.
- Delete
  patches.suse/kgr-0036-kgraft-xen-Do-not-block-livepatching-in-the-XEN-blki.patch.
- Delete
  patches.suse/kgr-0037-ignore-zombie-tasks-during-the-patching.patch.
- Delete
  patches.suse/kgr-0038-kgraft-xen-Do-not-block-kGraft-in-xenbus-kthread.patch.
- Delete
  patches.suse/kgr-0039-kgraft-iscsi-target-Do-not-block-kGraft-in-iscsi_np-.patch.
- Delete
  patches.suse/kgr-0040-remove-all-arch-specific-kgraft-header-files.patch.
- Delete
  patches.suse/kgr-0041-make-a-taint-flag-module-specific.patch.
- Delete
  patches.suse/kgr-0042-locking-semaphore-Add-down_interruptible_timeout.patch.
- Delete
  patches.suse/kgr-0043-kgr-Mark-eeh_event_handler-kthread-safe-using-a-time.patch.
- Delete
  patches.suse/kgr-0102-kgr-mark-kernel-unsupported-upon-patch-revert.patch.
- Delete patches.suse/printk-mark_kgr_task_safe.patch.
- commit dde7e1c
* Wed Aug 30 2017 aaptel@suse.com
- CIFS: Fix maximum SMB2 header size (bsc#1056185).
- commit d54f5d7
* Tue Aug 29 2017 tiwai@suse.de
- Refresh patches.suse/iwlwifi-expose-default-fallback-ucode-api.
  The latest firmware matches for iwl7xxx/3168 series, so dropped the changes.
- commit 1447668
* Tue Aug 29 2017 yousaf.kaukab@suse.com
- arm64: update config file for RAS support
- commit 4812033
* Tue Aug 29 2017 yousaf.kaukab@suse.com
- ras: mark stub functions as 'inline' (fate#323583).
- ACPI: APEI: Enable APEI multiple GHES source to share a single
  external IRQ (fate#323583).
- acpi: apei: check for pending errors when probing GHES entries
  (fate#323583).
- arm/arm64: KVM: add guest SEA support (fate#323583).
- trace, ras: add ARM processor error trace event (fate#323583).
- ras: acpi / apei: generate trace event for unrecognized CPER
  section (fate#323583).
- efi: print unrecognized CPER section (fate#323583).
- acpi: apei: panic OS with fatal error status block
  (fate#323583).
- acpi: apei: handle SEA notification type for ARMv8
  (fate#323583).
- arm64: exception: handle Synchronous External Abort
  (fate#323583).
- efi: parse ARM processor error (fate#323583).
- cper: add timestamp print to CPER status printing (fate#323583).
- ras: acpi/apei: cper: add support for generic data v3 structure
  (fate#323583).
- acpi: apei: read ack upon ghes record consumption (fate#323583).
- ACPI / APEI: Switch to use new generic UUID API (fate#323583).
- uuid: fix incorrect uuid_equal conversion in test_uuid_test
  (fate#323583).
- fs: switch ->s_uuid to uuid_t (fate#323583).
- ima/policy: switch to use uuid_t (fate#323583).
- block: remove blk_part_pack_uuid (fate#323583).
- xfs: use the common helper uuid_is_null() (fate#323583).
- xfs: remove uuid_getnodeuniq and xfs_uu_t (fate#323583).
- S390/sysinfo: use uuid_is_null instead of opencoding it
  (fate#323583).
- uuid: hoist uuid_is_null() helper from libnvdimm (fate#323583).
- uuid: hoist helpers uuid_equal() and uuid_copy() from xfs
  (fate#323583).
- uuid: don't export guid_index and uuid_index (fate#323583).
- uuid: rename uuid types (fate#323583).
- uuid: remove uuid_be defintions from the uapi header
  (fate#323583).
- nfsd: namespace-prefix uuid_parse (fate#323583).
- md: namespace private helper names (fate#323583).
- xfs: use uuid_be to implement the uuid_t type (fate#323583).
- xfs: use uuid_copy() helper to abstract uuid_t (fate#323583).
- uuid,afs: move struct uuid_v1 back into afs (fate#323583).
- commit ccd5a8a
* Tue Aug 29 2017 oneukum@suse.com
- i2c: i801: Add support for Intel Cannon Lake (FATE#321195).
- mfd: intel-lpss: Add Intel Cannonlake PCI IDs (FATE#321195).
- HID: intel-ish-hid: Enable Cannon Lake ish driver (FATE#321195).
- commit fe6deda
* Mon Aug 28 2017 mgorman@suse.de
- Avoid page waitqueue race leaving possible page locker waiting
  (bnc#971975 VM performance -- page waitqueue).
- commit fc6592a
* Mon Aug 28 2017 tonyj@suse.de
- powerpc/perf: Fix usage of nest_imc_refc (FATE#322448,
  bsc#1054914).
- powerpc/perf/imc: Fix nest events on muti socket system
  (FATE#322448, bsc#1054914).
- powerpc/perf: Fix double unlock in imc_common_cpuhp_mem_free()
  (FATE#322448, bsc#1054914).
- powerpc/perf: Add thread IMC PMU support (FATE#322448,
  bsc#1054914).
- powerpc/perf: Add core IMC PMU support (FATE#322448,
  bsc#1054914).
- powerpc/perf: Add nest IMC PMU support (FATE#322448,
  bsc#1054914).
- perf vendor events powerpc: Update POWER9 events (FATE#322450,
  bsc#1052213).
- perf vendor events powerpc: remove suffix in mapfile
  (FATE#322450, bsc#1052213).
- commit 3b5ba34
* Mon Aug 28 2017 jroedel@suse.de
- KVM: x86: block guest protection keys unless the host has them
  enabled (bsc#1055935).
- KVM, pkeys: do not use PKRU value in vcpu->arch.guest_fpu.state
  (bsc#1055935).
- KVM: x86: simplify handling of PKRU (bsc#1055935).
- commit da19195
* Mon Aug 28 2017 dbueso@suse.de
- ptr_ring: use kmalloc_array() (bsc#1055945).
- commit f6d643d
* Mon Aug 28 2017 dbueso@suse.de
- blacklist.conf: add more entries (uml, rhashtable tests)
- commit 398a701
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-binary.spec.in: Update drm-kmp obsolete for SLE12-SP3/Leap-42.3
- commit 77ccbd0
* Mon Aug 28 2017 mgorman@suse.de
- Minor page waitqueue cleanups (bnc#971975 VM performance --
  page waitqueue).
- commit 98a2529
* Mon Aug 28 2017 tbogendoerfer@suse.de
- Drop old qed patches, which will be refreshed while doing backports
- Delete
  patches.drivers/qed-sp3-0216-qed-bump-drivers-to-version-8.10.10.63.patch.
- Delete
  patches.drivers/qed-sp3-0264-qed-Enable-RoCE-parser-searching-on-fp-init.patch.
- Delete
  patches.drivers/qed-sp3-0265-qed-Correct-order-of-wwnn-and-wwpn.patch.
- Delete
  patches.drivers/qed-sp3-0266-qed-Share-additional-information-with-qedf.patch.
- Delete
  patches.drivers/qed-sp3-0267-qed-Support-NVM-image-reading-API.patch.
- Delete
  patches.drivers/qed-sp3-0268-qed-Add-support-for-changing-iSCSI-mac.patch.
- Delete
  patches.drivers/qed-sp3-0269-qedi-Add-support-for-offload-iSCSI-Boot.patch.
- commit 8c6203d
* Mon Aug 28 2017 mhocko@suse.cz
- mm, memory_hotplug: do not back off draining pcp free pages
  from kworker context (bnc#1049591).
- commit e362ef6
* Mon Aug 28 2017 tiwai@suse.de
- drm/i915: Disable tv output on i9x5gm (bsc#1055490).
- commit 425d710
* Mon Aug 28 2017 mgorman@suse.de
- mm: consider the number in local CPUs when reading NUMA stats
  (VM Performance, bnc#959436).
- mm: update NUMA counter threshold size (VM Performance,
  bnc#959436).
- mm: change the call sites of numa statistics items (VM
  Performance, bnc#959436).
- commit 451bfd6
* Mon Aug 28 2017 tiwai@suse.de
- Refresh patch tags of patches.fixes/Input-ALPS-Fix-Alps-Touchpad-two-finger-scroll-does-
- commit df5244b
* Mon Aug 28 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again
  ... due to the breakage with the recent TeXLive 2017.
  Also add the missing dependency on texlive-varwidth.
- commit 9f682b5
* Fri Aug 25 2017 hare@suse.de
- S/390: enable CONFIG_KMSG_IDS (bsc#1053718)
- commit a6e1a82
* Fri Aug 25 2017 hare@suse.de
- Drop obsolete S/390 patches (bsc#1053718)
- Delete
  patches.arch/s390-sles12sp2-00-02-s390-dasd-add-query-host-access-to-volume-support.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-01.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-02.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-03.patch.
- Delete
  patches.arch/s390-sles12sp2-00-03-s390-pci-add-report_error-attribute-04.patch.
- Delete
  patches.arch/s390-sles12sp2-00-04-s390-pci-fmb-enhancements-03.patch.
- Delete
  patches.arch/s390-sles12sp2-10-05-kmsg-add-descriptions.patch.
- Delete patches.arch/s390-sles12sp3-00-04-kmsg.patch.
- Delete patches.arch/s390-sles12sp3-00-07-kmsg.patch.
- Delete patches.arch/s390-sles12sp3-00-08-kmsg.patch.
- commit a1f2fe2
* Fri Aug 25 2017 hare@suse.de
- s390: Kernel message catalog (bnc#1053718, LTC#157660).
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Delete patches.arch/kmsg-fix-parameter-limitations.
- Delete patches.arch/s390-message-catalog.diff.
- commit 5df3fc3
* Fri Aug 25 2017 mmarek@suse.com
- rpm/config.sh: Update KOTD build targets
  Build the internal packages against SLE15 and add s390x to the OBS
  builds.
- commit 88cc604
* Fri Aug 25 2017 tbogendoerfer@suse.de
- cxgb4: Fix tids count for ipv6 offload connection (bsc#1046540
  fate#322930).
- cxgb4: implement ndo_set_vf_rate() (bsc#1046540 fate#322930).
- cxgb4: fix incorrect cim_la output for T6 (bsc#1046540
  fate#322930).
- cxgb4: FW upgrade fixes (bsc#1046540 fate#322930).
- cxgb4: add new T5 pci device id (bsc#1046540 fate#322930).
- cxgb4 : retrieve port information from firmware (bsc#1046540
  fate#322930).
- cxgb4: add new T5 pci device id (bsc#1046540 fate#322930).
- commit 407692b
* Fri Aug 25 2017 hare@suse.de
- Drop patches.suse/scsi-netlink-ml (bsc#1055689)
- commit 8e3c10c
* Fri Aug 25 2017 mmarek@suse.com
- supported.conf: Fix malformed entry for n5pf
- commit 22e41e9
* Fri Aug 25 2017 jslaby@suse.cz
- Linux 4.12.9 (bnc#1012628 bsc#1052580 bnc#1049599).
- Delete
  patches.drivers/ALSA-usb-audio-Apply-sample-rate-quirk-to-Sennheiser.
- Delete patches.fixes/debug-fix-WARN_ON_ONCE-for-modules.patch.
- Update config files.
- commit f2ab6ba
* Thu Aug 24 2017 lduncan@suse.com
- lib: test_rhashtable: Fix KASAN warning (bsc#1055359).
- lib: test_rhashtable: fix for large entry counts (bsc#1055359).
- commit 28437b2
* Thu Aug 24 2017 jack@suse.cz
- supported.conf: Remove logfs (does not exist anymore), add orangefs as
  unsupported
- commit 1afee12
* Thu Aug 24 2017 mhocko@suse.cz
- kernel/watchdog: Prevent false positives with turbo modes
  (bnc#1055313).
- Update config files.
- commit 75b22a6
* Thu Aug 24 2017 vbabka@suse.cz
- cma: fix calculation of aligned offset (VM Functionality,
  bsc#1055314).
- commit 8914932
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/idle: Disable LOSE_FULL_CONTEXT states when
  stop-api fails (bsc#1055121).
- commit cf34929
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Simplify lazy IRQ handling in CPU offline
  (bsc#1055121).
- commit 25e5ffb
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/64s/idle: Move soft interrupt mask logic into C code
  (bsc#1055121).
  - fix paste error in previous patch name
- commit 56abbca
* Wed Aug 23 2017 mhocko@suse.cz
- mm, oom: fix potential data corruption when oom_reaper races
  with writer (bnc#1055311).
- mm: fix double mmap_sem unlock on MMF_UNSTABLE enforced SIGBUS
  (bnc#1055311).
- commit 8afe3e4
* Wed Aug 23 2017 msuchanek@suse.de
- rtc: opal: Handle disabled TPO in opal_get_tpo_time()
  (bsc#1055122).
- commit 2cf6a2b
* Wed Aug 23 2017 msuchanek@suse.de
- rtc: interface: Validate alarm-time before handling rollover
  (bsc#1055122).
- commit 61f40d3
* Wed Aug 23 2017 jroedel@suse.de
- x86/cpufeature, kvm/svm: Rename (shorten) the new "virtualized
  VMSAVE/VMLOAD" CPUID flag (fate#323405).
- KVM: SVM: Enable Virtual VMLOAD VMSAVE feature (fate#323405).
- KVM: SVM: Add Virtual VMLOAD VMSAVE feature definition
  (fate#323405).
- KVM: SVM: Rename lbr_ctl field in the vmcb control area
  (fate#323405).
- KVM: SVM: Prepare for new bit definition in lbr_ctl
  (fate#323405).
- commit fda2890
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/pci: Add support for PHB4 diagnostics
  (bsc#1055120).
- commit 8b6d16d
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/pci: Dynamically allocate PHB diag data
  (bsc#1055120).
- commit d796605
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/pci: Reduce spam when dumping PEST
  (bsc#1055120).
- commit a228946
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add support to clear sensor groups data
  (bsc#1055115).
- commit ca4565c
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add support to set power-shifting-ratio
  (bsc#1055115).
- commit 73968cc
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add support for powercap framework
  (bsc#1055115).
- commit 934753a
* Wed Aug 23 2017 msuchanek@suse.de
- hwmon: (ibmpowernv) Add current(A) sensor (bsc#1055115).
- commit f4b3bf5
* Wed Aug 23 2017 msuchanek@suse.de
- hwmon: (ibmpowernv) introduce a legacy_compatibles array
  (bsc#1055115).
- commit 9e071c1
* Wed Aug 23 2017 msuchanek@suse.de
- hwmon: (ibmpowernv) Add highest/lowest attributes to sensors
  (bsc#1055115).
- commit ea5ab64
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Enable PCI peer-to-peer (bsc#1055120).
- commit a6a5452
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Detect and create IMC device (bsc1054914,
  fate#322448).
- commit 7df86cd
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Add IMC OPAL APIs (bsc1054914, fate#322448).
- commit d35ae16
* Wed Aug 23 2017 mhocko@suse.cz
- blacklist.conf: blacklist 1ee1c3f5b5cf
  CONFIG_DEBUG_VM is disabled in all our kernel flavors
- commit 2802e86
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv/idle: Correctly initialize core_idle_state_ptr
  (bsc#1055121).
- powerpc/powernv/idle: Decouple Timebase restore & Per-core
  SPRs restore (bsc#1055121).
- powerpc/powernv/idle: Restore LPCR on wakeup from deep-stop
  (bsc#1055121).
- powerpc/powernv/idle: Restore SPRs for deep idle states via
  stop API (bsc#1055121).
- powerpc/powernv/idle: Use Requested Level for restoring state
  on P9 DD1 (bsc#1055121).
- commit 9ac205d
* Wed Aug 23 2017 msuchanek@suse.de
- cpuidle-powernv: Allow Deep stop states that don't stop time
  (bsc#1055121).
- powerpc/64s/idle: Branch to handler with virtual mode offset
  (bsc#1055121).
- commit a2551db
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Avoid flushing the PWC on every
  flush_tlb_range (bsc#1055186, fate#323286).
- commit 37f137e
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Improve TLB/PWC flushes (bsc#1055186,
  fate#323286).
- commit 7c388fb
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Improve _tlbiel_pid to be usable for PWC
  flushes (bsc#1055186, fate#323286).
- commit c4233df
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Refactor radix__mark_rodata_ro() (bsc#1055186,
  fate#323286).
- commit b3b09ac
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Synchronize updates to the process table
  (bsc#1055186, fate#323286).
- commit d78f2e1
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Implement STRICT_RWX/mark_rodata_ro() for
  Radix (bsc#1055186, fate#323286).
- commit 8abecba
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/hash: Implement mark_rodata_ro() for hash
  (bsc#1055186, fate#323286).
- commit 80a9929
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/64s: Leave interrupts hard enabled in context switch
  for radix (bsc#1055186, fate#323286).
- commit 749d27e
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Fix boot on Power8 bare metal due to
  opal_configure_cores() (bsc#1055117, fate#323286).
- commit 396c5c1
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/powernv: Tell OPAL about our MMU mode on POWER9
  (bsc#1055117, fate#323286).
- commit bc75dc8
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm: Fix pmd/pte_devmap() on non-leaf entries
  (bsc#1055117, fate#323286).
- commit 457e49f
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm: Add devmap support for ppc64 (bsc#1055117,
  fate#323286).
- commit beadf59
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm/radix: Workaround prefetch issue with KVM
  (bsc#1055117, fate#323286).
- commit 34d0082
* Wed Aug 23 2017 msuchanek@suse.de
- powerpc/mm: Trace tlbie(l) instructions (bsc#1055117,
  fate#323286).
- commit f6cd9ad
* Wed Aug 23 2017 tiwai@suse.de
- ALSA: hda - Add stereo mic quirk for Lenovo G50-70 (17aa:3978)
  (bsc#1020657).
- commit d300598
* Wed Aug 23 2017 jslaby@suse.cz
- Bluetooth: hidp: fix possible might sleep error in
  hidp_session_thread (bnc#1014351).
- commit fa3a4f0
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: ice1712: Add support for STAudio ADCIII (bsc#1048934).
- commit 53a20a8
* Tue Aug 22 2017 tiwai@suse.de
- ALSA: hda - Implement mic-mute LED mode enum (bsc#1055013).
- commit b870486
* Tue Aug 22 2017 msuchanek@suse.de
- cxl: Export library to support IBM XSL (bsc#1055014,
  fate#322239).
  Update config files.
- commit 06766f5
* Tue Aug 22 2017 msuchanek@suse.de
- mm/hugetlb: clean up ARCH_HAS_GIGANTIC_PAGE (bsc#1055014,
  fate#322239).
- commit ecf0169
* Tue Aug 22 2017 msuchanek@suse.de
- powerpc/mm/hugetlb: add support for 1G huge pages (bsc#1055014,
  fate#322239).
  Update config files.
- commit 619d9b1
* Tue Aug 22 2017 tiwai@suse.de
- supported.conf: Add Intel HDMI LPE audio to be supported
- commit 7218d85
* Tue Aug 22 2017 bp@suse.de
- supported.conf: Remove microcode loader
  It is not a module anymore.
- commit 6997200
* Tue Aug 22 2017 mhocko@suse.cz
- supported.conf: make z3fold.ko officially unsupported
  We do not have anybody inhouse to be familiar with the code and there
  was no explicit fate to enable it either. Make it available in the
  kernel-extra though.
- commit 5bd98fe
* Mon Aug 21 2017 pmladek@suse.com
- Update TAINT_FLAGS_COUNT for the added taint flags
  This fixes the port for 4.12.
  Refresh patches.suse/supported-flag.
- commit 22a9dcd
* Fri Aug 18 2017 msuchanek@suse.de
- Do not ship firmware (bsc#1054239).
  Pull firmware from kernel-firmware instead.
- commit 0b0b5c9
* Fri Aug 18 2017 tbogendoerfer@suse.de
- supported.conf: mark sfc-falcon as unsupported (fate#323467, bsc#1039860)
- commit 6eb197e
* Fri Aug 18 2017 yousaf.kaukab@suse.com
- tty: pl011: fix initialization order of QDF2400 E44
  (fate#323912).
- commit 1f108a8
* Fri Aug 18 2017 neilb@suse.com
- Delete patches.suse/0017-NFS-nfs4_lookup_revalidate-need-to-report-STALE-inod.patch.
  This has been fixed a different way upstream
- commit 535dc30
* Thu Aug 17 2017 jeffm@suse.com
- supported.conf: clear mistaken external support flag for cifs.ko (bsc#1053802).
- commit a5b6524
* Thu Aug 17 2017 neilb@suse.com
- Refresh patches.fixes/0001-MD-fix-sleep-in-atomic.patch.
- Refresh
  patches.fixes/0001-NFSv4-don-t-let-hanging-mounts-block-other-mounts.patch.
- Refresh
  patches.fixes/0001-loop-Add-PF_LESS_THROTTLE-to-block-loop-device-threa.patch.
- Refresh
  patches.fixes/0001-md-use-a-separate-bio_set-for-synchronous-IO.patch.
- Refresh patches.fixes/d-lookup-fairness.fix.
- Refresh patches.fixes/dm-snap-avoid-deadlock.patch.
- Refresh patches.fixes/nfs4_close.fix.
- Refresh
  patches.suse/0017-NFS-nfs4_lookup_revalidate-need-to-report-STALE-inod.patch.
- Refresh patches.suse/blk-timeout-no-round.
- Delete
  patches.fixes/0001-NFS-don-t-try-to-cross-a-mountpount-when-there-isn-t.patch.
- Delete
  patches.fixes/0001-Revert-SUNRPC-xs_sock_mark_closed-does-not-need-to-t.patch.
- Delete
  patches.fixes/0001-md-handle-read-only-member-devices-better.patch.
- Delete patches.fixes/cifs-optional-treename-prefix.
- Delete patches.fixes/nfs_flush_incompatible.fix.
- Delete patches.fixes/ptrace-in-namespace-perm-check.fix.
- Delete patches.suse/nfs-no-share-transport.
- Delete patches.suse/nfs-no-share-transport-nfsv4.
  Review patches carried forward from SLE12.
  Some not needed, some not wanted, some perserved and refreshed.
- commit 30682b5
* Thu Aug 17 2017 jslaby@suse.cz
- Linux 4.12.8 (bnc#1012628).
- commit 4d7933a
* Thu Aug 17 2017 neilb@suse.com
- SUNRPC: Mask XIDs to prevent replay cache collision
  (fate#322786).
- NFS: Allow multiple connections to NFSv3 and NFSv4.0 servers
  (fate#322786).
- NFS: Display the "nconnect" mount option if it is set
  (fate#322786).
- pNFS: Allow multiple connections to the DS (fate#322786).
- NFSv4: Allow multiple connections to NFSv4.x (x>0) servers
  (fate#322786).
- NFS: Add a mount option to specify number of TCP connections
  to use (fate#322786).
- SUNRPC: Allow creation of RPC clients with multiple connections
  (fate#322786).
- commit e56b097
* Wed Aug 16 2017 tonyj@suse.de
- powerpc/perf/hv-24x7: Aggregate result elements on POWER9 SMT8
  (FATE#323438).
- powerpc/perf/hv-24x7: Support v2 of the hypervisor API
  (FATE#323438).
- powerpc/perf/hv-24x7: Minor improvements (FATE#323438).
- powerpc/perf/hv-24x7: Fix return value of hcalls (FATE#323438).
- powerpc-perf/hx-24x7: Don't log failed hcall twice
  (FATE#323438).
- powerpc/perf/hv-24x7: Properly iterate through results
  (FATE#323438).
- powerpc/perf/hv-24x7: Fix off-by-one error in request_buffer
  check (FATE#323438).
- powerpc/perf/hv-24x7: Fix passing of catalog version number
  (FATE#323438).
- commit 56353ab
* Wed Aug 16 2017 jeffm@suse.com
- supported.conf: mark reiserfs unsupported (FATE#323394).
  ReiserFS is not supported in SLE15.  ReiserFS file systems must be
  transferred or converted before installing.
- commit 5f3f041
* Wed Aug 16 2017 msuchanek@suse.de
- powerpc/mm/hash64: Make vmalloc 56T on hash (bsc#1048914,
  bsc#1054026).
- commit cbc95bf
* Wed Aug 16 2017 msuchanek@suse.de
- powerpc/mm/slb: Move comment next to the code it's referring to
  (bsc#1048914, bsc#1054026).
- commit a120516
* Wed Aug 16 2017 msuchanek@suse.de
- powerpc/mm/book3s64: Make KERN_IO_START a variable (bsc#1048914,
  bsc#1054026).
- commit 7eb1dbb
* Wed Aug 16 2017 tiwai@suse.de
- blacklist.conf: add blacklist entries for drm
- commit 369eed2
* Wed Aug 16 2017 tiwai@suse.de
- drm/i915: Remove assertion from raw __i915_vma_unpin()
  (bsc#1051510).
- drm/i915: Fix out-of-bounds array access in bdw_load_gamma_lut
  (bsc#1051510).
- drm/i915: Unbreak gpu reset vs. modeset locking (bsc#1051510).
- drm/i915: fix backlight invert for non-zero minimum brightness
  (bsc#1051510).
- drm/i915: Fix an error checking test (bsc#1051510).
- drm/msm/hdmi: Use bitwise operators when building register
  values (bsc#1051510).
- drm/imx: fix typo in ipu_plane_formats[] (bsc#1051510).
- drm/bridge: tc358767: fix probe without attached output node
  (bsc#1051510).
- drm/msm/dsi: Calculate link clock rates with updated dsi->lanes
  (bsc#1051510).
- drm: omapdrm: Take GEM object reference when exporting dmabuf
  (bsc#1051510).
- drm/rockchip: fix Kconfig dependencies (bsc#1051510).
- drm/amdkfd: NULL dereference involving create_process()
  (bsc#1051510).
- drm/mediatek: separate color module to fixup error memory
  reallocation (bsc#1051510).
- commit 54d6c62
* Wed Aug 16 2017 oneukum@suse.com
- supported.conf: overzealous destruction of PCMCIA
- commit 1d32c31
* Wed Aug 16 2017 oneukum@suse.com
- supported.conf: added Cavium Nitrox (FATE#323034)
- commit c54e3ea
* Wed Aug 16 2017 msuchanek@suse.de
- s390: export symbols for crash-kmp (bsc#1053915).
- commit dd8539a
* Wed Aug 16 2017 oneukum@suse.com
- Update config files.
  Cavium crypto accelerators
  (FATE#323034, FATE#323051)
- commit 546670e
* Tue Aug 15 2017 tonyj@suse.de
- perf vendor events: Add POWER9 PVRs to mapfile (FATE#322450,
  bsc#1050145).
- perf vendor events: Add POWER9 PMU events (FATE#322450,
  bsc#1050145).
- perf pmu-events: Support additional POWER8+ PVR in mapfile
  (FATE#322450, bsc#1050145 (dependent patch)).
- commit 5191db3
* Tue Aug 15 2017 bpoirier@suse.com
- Refresh patch order in networking section
- commit 5beeea5
* Tue Aug 15 2017 mgorman@suse.de
- Revert "mm: numa: defer TLB flush for THP migration as long
  as possible" (mprotect/madvise theoretical races (bnc#1053919)).
- mm: fix KSM data corruption (mprotect/madvise theoretical races
  (bnc#1053919)).
- mm: fix MADV_[FREE|DONTNEED] TLB flush miss problem
  (mprotect/madvise theoretical races (bnc#1053919)).
- mm: make tlb_flush_pending global (mprotect/madvise theoretical
  races (bnc#1053919)).
- mm: refactor TLB gathering API (mprotect/madvise theoretical
  races (bnc#1053919)).
- mm: migrate: fix barriers around tlb_flush_pending
  (mprotect/madvise theoretical races (bnc#1053919)).
- mm: migrate: prevent racy access to tlb_flush_pending
  (mprotect/madvise theoretical races (bnc#1053919)).
- commit e34ab01
* Tue Aug 15 2017 dbueso@suse.de
- mm, hugetlb: schedule when potentially allocating many hugepages (bsc#971975).
- commit 56cb576
* Tue Aug 15 2017 dbueso@suse.de
- sched/deadline: Zero out positive runtime after throttling
  constrained tasks (bsc#978907).
- sched/core: Allow __sched_setscheduler() in interrupts when
  PI is not used (bsc#978907).
- commit 472d759
* Tue Aug 15 2017 jeffm@suse.com
- Remove legacy overlayfs compatibility layer (FATE#323754).
- commit 276905f
* Tue Aug 15 2017 oneukum@suse.com
- ACPI / PM: Ignore spurious SCI wakeups from suspend-to-idle
  (FATE#323777).
- ACPI / PM: Run wakeup notify handlers synchronously
  (FATE#323777).
- commit 925f2b6
* Tue Aug 15 2017 yousaf.kaukab@suse.com
- i2c: xgene-slimpro: include linux/io.h for memremap
  (bsc#1053633).
- i2c: xgene-slimpro: Add ACPI support by using PCC mailbox
  (bsc#1053633).
- i2c: xgene-slimpro: Use a single function to send command
  message (bsc#1053633).
- ACPI / irq: Fix return code of acpi_gsi_to_irq() (bsc#1053627).
- commit d7a9a50
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.fixes/dm-raid-Do-not-call-BUG-in-__rdev_sectors.patch.
- Delete patches.fixes/md-fix-a-null-dereference.patch.
- commit 88d2447
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/blk-mq-map-all-HWQ-also-in-hyperthreaded-system.patch.
- commit 4b25e5c
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/loop-fix-regression-with-op_is_write.patch.
- commit aadbd32
* Tue Aug 15 2017 hare@suse.de
- Re-enable 'patches.fixes/dm-multipath-Improve-logging.patch'
- commit 7c6e565
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.fixes/dm-mpath-fix-potential-for-dropping-queue_if_no_path.patch.
- commit a103f04
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/watchdog-hpwdt-add-support-for-iLO5.patch.
- commit e86c31d
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/target-fixup-error-message-in-target_tg_pt_gp_alua_a.patch.
- Delete
  patches.drivers/target-fixup-error-message-in-target_tg_pt_gp_tg_pt_.patch.
- commit b9fb445
* Tue Aug 15 2017 hare@suse.de
- megaraid_sas: Fallback to older scanning if no disks are found
  (bnc#870440).
- megaraid_sas: boot hangs while LD is offline (bnc#698102).
- Delete
  patches.suse/megaraid_sas-Fallback-to-older-scanning-if-not-disks.patch.
- Delete
  patches.suse/megaraid_sas-boot-hangs-while-LD-is-offline.patch.
- commit 168240e
* Tue Aug 15 2017 hare@suse.de
- Re-enable 'patches.suse/fcoe-reduce-max_sectors'
- commit 0e279a1
* Tue Aug 15 2017 hare@suse.de
- scsi: fnic: changing queue command to return result
  DID_IMM_RETRY when rport is init (bsc#1035920).
- commit 6c8597b
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/0005-scsi-fnic-Correcting-rport-check-location-in-fnic_qu.patch.
- commit 243f663
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.drivers/mpt3sas-Ensure-the-connector_name-string-is-NUL-term.patch.
- commit 5836852
* Tue Aug 15 2017 hare@suse.de
- Delete patches.fixes/scsi-dh-queuedata-accessors.
- commit 475dab3
* Tue Aug 15 2017 hare@suse.de
- Reshuffle 'patches.drivers/scsi_transport_fc-return-EBUSY-for-deleted-vport.patch'
- commit 2ed0ed3
* Tue Aug 15 2017 hare@suse.de
- Delete
  patches.fixes/block-don-t-check-request-size-in-blk_cloned_rq_chec.patch.
- commit c81e3a2
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-detach-existing-hardware-handler.
- commit 5762cda
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/no-partition-scan (FATE#323406)
- commit 5056c39
* Tue Aug 15 2017 hare@suse.de
- Refresh patches.suse/dm-mpath-accept-failed-paths.
- commit a98933b
* Tue Aug 15 2017 hare@suse.de
- Delete patches.suse/dm-mpath-no-partitions-feature (FATE#323406)
- commit ef1cd4c
* Tue Aug 15 2017 tiwai@suse.de
- ALSA: usb-audio: Apply sample rate quirk to Sennheiser headset
  (bsc#1052580).
- commit a8251af
* Mon Aug 14 2017 msuchanek@suse.de
- genirq: Handle NOAUTOEN interrupt setup proper (fate#322438).
- commit 9650b8d
* Mon Aug 14 2017 msuchanek@suse.de
- powerpc/xive: Fix section mismatch warnings (fate#322438).
- powerpc/xive: Ensure active irqd when setting affinity
  (fate#322438).
- powerpc/xive: Silence message about VP block allocation
  (fate#322438).
- KVM: PPC: Book3S HV: Don't sleep if XIVE interrupt pending on
  POWER9 (fate#322438).
- commit 2b1c5d2
* Mon Aug 14 2017 msuchanek@suse.de
- KVM: PPC: Book3S HV: Don't let VCPU sleep if it has a doorbell
  pending (fate#322438).
- commit f863b85
* Mon Aug 14 2017 mwilck@suse.com
- hpsa/smartpqi: metadata and series.conf update
- moved hpsa patches upwards in series.conf
- hpsa/smartpqi "limit transfer length" patches accepted upstream
- Refresh
  patches.drivers/0001-scsi-hpsa-limit-transfer-length-to-1MB.patch.
- Refresh
  patches.fixes/0001-smartpqi-limit-transfer-length-to-1MB.patch.
- commit c0d744c
* Mon Aug 14 2017 tiwai@suse.de
- ALSA: fm801: Initialize chip after IRQ handler is registered
  (bsc#1051510).
- iwlwifi: mvm: quietly accept non-sta assoc response frames
  (bsc#1051510).
- iwlwifi: mvm: fix deduplication start logic (bsc#1051510).
- iwlwifi: fix TX tracing for non-linear SKBs (bsc#1051510).
- iwlwifi: mvm: change sta_id to u8 (bsc#1051510).
- iwlwifi: mvm: handle IBSS probe_queue in a few missing places
  (bsc#1051510).
- iwlwifi: mvm: remove DQA non-STA client mode special case
  (bsc#1051510).
- iwlwifi: mvm: don't mess the SNAP header in TSO for non-QoS
  packets (bsc#1051510).
- iwlwifi: mvm: fix a NULL pointer dereference of error in
  recovery (bsc#1051510).
- iwlwifi: fix tracing when tx only is enabled (bsc#1051510).
- iwlwifi: mvm: quietly accept non-sta disassoc frames
  (bsc#1051510).
- iwlwifi: mvm: don't send fetch the TID from a non-QoS packet
  in TSO (bsc#1051510).
- iwlwifi: mvm: fix mac80211 queue tracking (bsc#1051510).
- iwlwifi: missing error code in iwl_trans_pcie_alloc()
  (bsc#1051510).
- commit d7ab615
* Sun Aug 13 2017 jslaby@suse.cz
- Linux 4.12.7 (bnc#1012628).
- commit 7dae241
* Sun Aug 13 2017 jslaby@suse.cz
- Refresh
  patches.fixes/netfilter-expect-fix-crash-when-putting-uninited-exp.patch.
  Update upstream status.
- commit cdb9f49
* Sat Aug 12 2017 jslaby@suse.cz
- Linux 4.12.6 (CVE-2017-7542 CVE-2017-8831 bnc#1012628
  bsc#1037994 bsc#1049882).
- Delete
  patches.fixes/ipv6-avoid-overflow-of-offset-in-ip6_find_1stfragopt.patch.
- Delete
  patches.fixes/media-saa7164-fix-double-fetch-PCIe-access-condition.
- commit 29b7412
* Fri Aug 11 2017 dbueso@suse.de
- sched/wait: Remove the lockless swait_active() check in swake_up*() (bsc#1050549).
- commit 5f6d96e
* Fri Aug 11 2017 dbueso@suse.de
- ipc/sem: play nicer with large nsops allocations (bsc#1050323).
- ipc/sem: drop sem_checkid helper (bsc#1050323).
- locking/osq_lock: Fix osq_lock queue corruption (bsc#1050549).
- commit 458731e
* Fri Aug 11 2017 dbueso@suse.de
- update configs
- commit 2295f30
* Thu Aug 10 2017 dbueso@suse.de
- block/cfq: cache rightmost rb_node (bsc#1052639).
- mem/memcg: cache rightmost node (bsc#1052639).
- fs/epoll: use faster rb_first_cached() (bsc#1052639).
- procfs: use faster rb_first_cached() (bsc#1052639).
- lib/interval-tree: correct comment wrt generic flavor
  (bsc#1052639).
- block/cfq: replace cfq_rb_root leftmost caching (bsc#1052639).
- locking/rtmutex: replace top-waiter and pi_waiters leftmost
  caching (bsc#1052639).
- sched/deadline: replace earliest dl and rq leftmost caching
  (bsc#1052639).
- rbtree: add some additional comments for rebalancing cases
  (bsc#1052639).
- rbtree: optimize root-check during rebalancing loop
  (bsc#1052639).
- rbtree: cache leftmost node internally (bsc#1052639).
- lib/interval_tree_test.c: allow full tree search (bsc#1052639).
- lib/interval_tree_test.c: allow users to limit scope of endpoint
  (bsc#1052639).
- lib/interval_tree_test.c: make test options module parameters
  (bsc#1052639).
- lib/interval_tree_test.c: allow the module to be compiled-in
  (bsc#1052639).
- commit 1f8bb6f
* Thu Aug 10 2017 dbueso@suse.de
- bitmap: use memcmp optimisation in more situations
  (bsc#1050549).
- include/linux/bitmap.h: turn bitmap_set and bitmap_clear into
  memset when possible (bsc#1050549).
- commit 1f0d3c0
* Thu Aug 10 2017 dbueso@suse.de
- kcmp: fs/epoll: wrap kcmp code with CONFIG_CHECKPOINT_RESTORE
  (bsc#1052639).
- kcmp: add KCMP_EPOLL_TFD mode to compare epoll target files
  (bsc#1052639).
- procfs: fdinfo: extend information about epoll target files
  (bsc#1052639).
- fs, epoll: short circuit fetching events if thread has been
  killed (bsc#1052639).
- commit 935d249
* Thu Aug 10 2017 dbueso@suse.de
- locking/rtmutex: Don't initialize lockdep when not required
  (bsc#1050549).
- rt_mutex: Add lockdep annotations (bsc#1050549).
- sched/cfs: Make util/load_avg more stable (bnc#978907).
- commit 1933697
* Thu Aug 10 2017 msuchanek@suse.de
- rpm/modules.fips include module list from dracut (bsc#1074984, FATE#323247).
- rpm/modules.fips include module list from dracut
- commit bfa538f
* Thu Aug 10 2017 ohering@suse.de
- Delete stale patches.suse/suse-hv-storvsc-sg_tablesize.patch.
- commit df0c558
* Thu Aug 10 2017 ohering@suse.de
- hv: print extra debug in kvp_on_msg in error paths
  (bnc#1039153).
- netvsc: make sure and unregister datapath (fate#323887,
  bsc#1052899).
- netvsc: fix rtnl deadlock on unregister of vf (fate#323887,
  bsc#1052442).
- netvsc: transparent VF management (fate#323887, bsc#1051979).
- hyperv: netvsc: Neaten netvsc_send_pkt by using a temporary
  (fate#323887).
- netvsc: signal host if receive ring is emptied (fate#323887).
- netvsc: fix error unwind on device setup failure (fate#323887).
- netvsc: optimize receive completions (fate#323887).
- netvsc: remove unnecessary indirection of page_buffer
  (fate#323887).
- netvsc: don't print pointer value in error message
  (fate#323887).
- netvsc: fix warnings reported by lockdep (fate#323887).
- netvsc: fix return value for set_channels (fate#323887).
- Revert "netvsc: optimize calculation of number of slots"
  (fate#323887).
- netvsc: remove no longer used max_num_rss queues (fate#323887).
- netvsc: include rtnetlink.h (fate#323887).
- netvsc: fix netvsc_set_channels (fate#323887).
- netvsc: prefetch the first incoming ring element (fate#323887).
- netvsc: Remove redundant use of ipv6_hdr() (fate#323887).
- netvsc: remove bogus rtnl_unlock (fate#323887).
- netvsc: fix ptr_ret.cocci warnings (fate#323887).
- netvsc: add rtnl annotations in rndis (fate#323887).
- netvsc: save pointer to parent netvsc_device in channel table
  (fate#323887).
- netvsc: need rcu_derefence when accessing internal device info
  (fate#323887).
- netvsc: use ERR_PTR to avoid dereference issues (fate#323887).
- netvsc: change logic for change mtu and set_queues
  (fate#323887).
- netvsc: change order of steps in setting queues (fate#323887).
- netvsc: add some rtnl_dereference annotations (fate#323887).
- netvsc: force link update after MTU change (fate#323887).
- PCI: hv: Use vPCI protocol version 1.2 (fate#323887).
- PCI: hv: Add vPCI version protocol negotiation (fate#323887).
- PCI: hv: Temporary own CPU-number-to-vCPU-number infra
  (fate#323887).
- PCI: hv: Use page allocation for hbus structure (fate#323887).
- PCI: hv: Fix comment formatting and use proper integer fields
  (fate#323887).
- scsi: storvsc: use default I/O timeout handler for FC devices
  (fate#323887).
- hv_netvsc: Fix the carrier state error when data path is off
  (fate#323887).
- hv_netvsc: Remove unnecessary var link_state from struct
  netvsc_device_info (fate#323887).
- x86/hyperv: Read TSC frequency from a synthetic MSR
  (fate#323887).
- x86/hyperv: Check frequency MSRs presence according to the
  specification (fate#323887).
- networking: introduce and use skb_put_data() (fate#323887).
- scsi: storvsc: remove unnecessary channel inbound lock
  (fate#323887).
- scsi: storvsc: use in place iterator function (fate#323887).
- netvsc: fold in get_outbound_net_device (fate#323887).
- netvsc: pass net_device to netvsc_init_buf and
  netvsc_connect_vsp (fate#323887).
- netvsc: mark error cases as unlikely (fate#323887).
- netvsc: use typed pointer for internal state (fate#323887).
- netvsc: use hv_get_bytes_to_read (fate#323887).
- netvsc: optimize calculation of number of slots (fate#323887).
- tools: hv: set hotplug for VF on Suse (fate#323887).
- tools: hv: set allow-hotplug for VF on Ubuntu (fate#323887).
- netvsc: Add #include's for csum_* function declarations
  (fate#323887).
- vmbus: Reuse uuid_le_to_bin() helper (fate#323887).
- drivers: hv: vmbus: Increase the time between retries in
  vmbus_post_msg() (fate#323887).
- hv_utils: fix TimeSync work on pre-TimeSync-v4 hosts
  (fate#323887).
- hv_utils: drop .getcrosststamp() support from PTP driver
  (fate#323887).
- Drivers: hv: vmbus: Get the current time from the current
  clocksource (fate#323887).
- HV: properly delay KVP packets when negotiation is in progress
  (fate#323887).
- Drivers: hv: vmbus: Fix rescind handling (fate#323887).
- Drivers: hv: util: Make hv_poll_channel() a little more
  efficient (fate#323887).
- Drivers: hv: vmbus: Fix error code returned by vmbus_post_msg()
  (fate#323887).
- tools: hv: properly handle long paths (fate#323887).
- Tools: hv: vss: Thaw the filesystem and continue if freeze
  call has timed out (fate#323887).
- tools: hv: Add clean up for included files in Ubuntu net config
  (fate#323887).
- commit 5791482
* Thu Aug 10 2017 msuchanek@suse.de
- powerpc: Only do ERAT invalidate on radix context switch on
  P9 DD1 (bsc#1053131).
- commit b476432
* Thu Aug 10 2017 oneukum@suse.com
- crypto: cavium - make several functions static (FATE#323051,
  FATE#323034).
- crypto: cavium/nitrox - dma_mapping_error() returns bool
  (FATE#323034).
- crypto: cavium - fix spelling mistake "Revsion" -> "Revision"
  (FATE#323034).
- crypto: cavium - Add more algorithms (FATE#323034, FATE#323051).
- commit 7a50f51
* Thu Aug 10 2017 oneukum@suse.com
- crypto: cavium - Remove the individual encrypt/decrypt function
  for each algorithm (FATE#323051, FATE#323034).
- crypto: cavium - Downgrade the annoying misc interrupt print
  from dev_err to dev_dbg (FATE#323034, FATE#323051).
- crypto: cavium - Register the CNN55XX supported crypto
  algorithms (FATE#323034).
- crypto: cavium - Add debugfs support in CNN55XX driver
  (FATE#323034).
- crypto: cavium - Add support for CNN55XX adapters (FATE#323051).
- commit 2b3984f
* Thu Aug 10 2017 brogers@suse.com
- Delete patches.suse/x86-kvm-increase-guest-vcpu-support-count-to-240.patch.
  Obsolete, as it is already in upstream kernel.
  Also reassign a patch to jslaby which was mislabeled as mine.
- commit 62ea3d9
* Wed Aug  9 2017 bpoirier@suse.com
- Refresh patch order in networking section
  Some patches were added out of order.
- commit 314b1ee
* Wed Aug  9 2017 tbogendoerfer@suse.de
- Dropped already present patch
  patches.drivers/ibft-expose-ibft-acpi-header-via-sysfs.patch
- commit ca0f923
* Wed Aug  9 2017 tbogendoerfer@suse.de
- enabled/moved
  patches.suse/module-Inform-user-when-loading-externally-supported.patch
  patches.drivers/i40evf-fix-merge-error-in-older-patch.patch
  Refresh
  patches.drivers/i40evf-fix-merge-error-in-older-patch.patch.
- commit bd094a0
* Wed Aug  9 2017 jbeulich@suse.com
- Delete patches.fixes/xsa216.patch (went into 4.12).
- commit 05e7511
* Wed Aug  9 2017 jgross@suse.com
- re-enable Xen pvusb frontend patches
- commit 6cb7475
* Wed Aug  9 2017 msuchanek@suse.de
- kdump: protect vmcoreinfo data under the crash memory
  (bsc#1051137).
- commit 8c0423d
* Wed Aug  9 2017 msuchanek@suse.de
- kexec: move vmcoreinfo out of the kernel's .bss section
  (bsc#1051137).
- commit b72922b
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: use the correct VMCOREINFO_NOTE_SIZE for phdr
  (bsc#1051137).
- commit 30c6dec
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: Set an upper limit for boot memory size
  (bsc#1051137).
- commit 68223be
* Wed Aug  9 2017 msuchanek@suse.de
- powerpc/fadump: Update comment about offset where fadump is
  reserved (bsc#1051137).
- commit eb88722
* Wed Aug  9 2017 msuchanek@suse.de
- Refresh fadump patches metadata and change to upstream order.
- commit a85ebb8
* Wed Aug  9 2017 ohering@suse.de
- Delete stale patches.fixes/scsi-ibmvscsi-module_alias.patch.
- Delete stale patches.suse/suse-ppc64-branding.
- commit 6b6f95c
* Wed Aug  9 2017 tiwai@suse.de
- [media] saa7164: fix double fetch PCIe access condition
  (CVE-2017-8831 bsc#1037994).
- commit 4d38c27
* Wed Aug  9 2017 dbueso@suse.de
- x86/tsc: Fold set_cyc2ns_scale() into caller (bsc#1052904).
- commit d94e9ff
* Wed Aug  9 2017 dbueso@suse.de
- bitmap: optimise bitmap_set and bitmap_clear of a single bit
  (bsc#1050549).
- lib/test_bitmap.c: add optimisation tests (bsc#1050549).
- commit a98aaca
* Wed Aug  9 2017 dbueso@suse.de
- cpuidle: Fix idle time tracking (bsc#1052904).
- x86/tsc: Call check_system_tsc_reliable() before
  unsynchronized_tsc() (bsc#1052904).
- sched/clock: Fix early boot preempt assumption in
  __set_sched_clock_stable() (bsc#1052904).
- sched/clock: Print a warning recommending 'tsc=unstable'
  (bsc#1052904).
- sched/clock: Use late_initcall() instead of sched_init_smp()
  (bsc#1052904).
- sched/clock: Remove watchdog touching (bsc#1052904).
- sched/clock: Remove unused argument to
  sched_clock_idle_wakeup_event() (bsc#1052904).
- x86/tsc: Provide 'tsc=unstable' boot parameter (bsc#1052904).
- x86/tsc: Feed refined TSC calibration into sched_clock()
  (bsc#1052904).
- x86/tsc: Fix sched_clock() sync (bsc#1052904).
- x86/tsc, sched/clock, clocksource: Use clocksource watchdog
  to provide stable sync points (bsc#1052904).
- x86/tsc: Remodel cyc2ns to use seqcount_latch() (bsc#1052904).
- sched/clock: Initialize all per-CPU state before switching
  (back) to unstable (bsc#1052904).
- commit 521cce8
* Wed Aug  9 2017 dbueso@suse.de
- ipc: add missing container_of()s for randstruct (bsc#1050323).
- kernel/locking: Fix compile error with qrwlock.c (bsc#1050549).
- commit 62276d3
* Tue Aug  8 2017 msuchanek@suse.de
- ibmvnic: Report rx buffer return codes as netdev_dbg
  (bsc#1052794).
- commit 3bd6034
* Tue Aug  8 2017 msuchanek@suse.de
- ibmvnic: Check for transport event on driver resume
  (bsc#1051556, bsc#1052709).
- commit fefc352
* Tue Aug  8 2017 msuchanek@suse.de
- ibmvnic: Initialize SCRQ's during login renegotiation
  (bsc#1052223).
- commit 9454da2
* Tue Aug  8 2017 jack@suse.cz
- ext4: Don't clear SGID when inheriting ACLs (bsc#1052766).
- ext4: preserve i_mode if __ext4_set_acl() fails (bsc#1052766).
- commit 0e8e28d
* Mon Aug  7 2017 jroedel@suse.de
- iommu/amd: Fix schedule-while-atomic BUG in initialization code
  (bsc1052533).
- iommu/amd: Enable ga_log_intr when enabling guest_mode
  (bsc1052533).
- commit 645d9f3
* Mon Aug  7 2017 jslaby@suse.cz
- Linux 4.12.5 (bnc#1012628 bsc#1049483 bsc#1049599).
- Delete patches.fixes/dentry-name-snapshots.patch.
- Delete
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit e6109ef
* Fri Aug  4 2017 ohering@suse.de
- Remove merged hyperv patches that lacked an upstream tag
- commit a39c1e7
* Fri Aug  4 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Disable PDF build again.
  4.12.x still seems having some issues.  Temporarily disabled again.
- commit 472526a
* Fri Aug  4 2017 tiwai@suse.de
- ALSA: hda/realtek - There is no loopback mixer in the
  ALC234/274/294 (bsc#1052235).
- ALSA: hda/realtek - Fix typo of pincfg for Dell quirk
  (bsc#1052235).
- ALSA: hda/realtek - Support Dell headset mode for ALC3271
  (bsc#1052235).
- ALSA: hda/realtek - No loopback on ALC225/ALC295 codec
  (bsc#1052235).
- ALSA: hda/realtek - Update headset mode for ALC225
  (bsc#1052235).
- ALSA: hda/realtek - Update headset mode for ALC298
  (bsc#1052235).
- ALSA: hda/realtek - Support headset mode for
  ALC234/ALC274/ALC294 (bsc#1052235).
- ALSA: hda/realtek - Add default procedure for suspend and
  resume state (bsc#1052235).
- ALSA: hda/realtek - Add ALC256 HP depop function (bsc#1052235).
- ALSA: hda/realtek - New codec device ID for ALC1220
  (bsc#1052235).
- ALSA: hda/realtek - New codecs support for ALC215/ALC285/ALC289
  (bsc#1052235).
- ALSA: hda/realtek - Remove ALC285 device ID (bsc#1052235).
- commit 876d653
* Fri Aug  4 2017 tiwai@suse.de
- Re-enable xmlto for 4.12 build
  Otherwise the doc-build complains and aborts.
- commit de2cf2a
* Thu Aug  3 2017 jkosina@suse.cz
- supported.conf: add Intel ISH support (FATE#322842)
- commit 129f345
* Wed Aug  2 2017 jroedel@suse.de
- kvm: nVMX: Fix nested_vmx_check_msr_bitmap_controls
  (bsc#1051478).
- commit 56b5cb8
* Wed Aug  2 2017 jroedel@suse.de
- blacklist.conf: Blacklist c133c7615751 ('x86/nmi: Fix timeout test in test_nmi_ipi()')
  Fixes just a test-case.
- commit a4200a2
* Wed Aug  2 2017 jroedel@suse.de
- PCI / PM: Fix native PME handling during system suspend/resume
  (bsc#1051478).
- PCI: Enable ECRC only if device supports it (bsc#1051478).
- PCI: dwc: dra7xx: Use RW1C for IRQSTATUS_MSI and IRQSTATUS_MAIN
  (bsc#1051478).
- PCI: Correct PCI_STD_RESOURCE_END usage (bsc#1051478).
- commit 9891a80
* Wed Aug  2 2017 jkosina@suse.cz
- series.conf: patches.suse/sched-optimize-latency-defaults.patch has been
  enabled by Mel Gorman already, drop the one with mgalbraith guard
- commit 75879d1
* Wed Aug  2 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix package list and enable building PDFs
  Finally it works!  Added some missing pieces (ImageMagick, some texlive
  subpkgs) in addition to use explicitly python3-Sphinx stuff.
- commit c117a0c
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete
  patches.drivers/0002-iommu-arm-smmu-Plumb-in-new-ACPI-identifiers.patch.
  6dbeea7da557 iommu/arm-smmu: Plumb in new ACPI identifiers in v4.12.4
- commit 39ce84a
* Wed Aug  2 2017 mbrugger@suse.com
- Refresh
  patches.arch/arm64-drivers-char-kmem-disable-on-arm64.patch.
- Delete patches.arch/0001-arm64-Define-Cortex-A73-MIDR.patch.
- Delete
  patches.arch/0001-arm64-arch_timer-Add-infrastructure-for-multiple-err.patch.
- Delete
  patches.arch/0002-arm64-arch_timer-Add-erratum-handler-for-globally-de.patch.
- Delete
  patches.arch/0002-arm64-cpu_errata-Allow-an-erratum-to-be-match-for-al.patch.
- Delete
  patches.arch/0003-arm64-arch_timer-Add-erratum-handler-for-CPU-specifi.patch.
- Delete
  patches.arch/0004-arm64-arch_timer-Move-arch_timer_reg_read-write-arou.patch.
- Delete
  patches.arch/0005-arm64-arch_timer-Get-rid-of-erratum_workaround_set_s.patch.
- Delete
  patches.arch/0006-arm64-arch_timer-Rework-the-set_next_event-workaroun.patch.
- Delete
  patches.arch/0007-arm64-arch_timer-Make-workaround-methods-optional.patch.
- Delete
  patches.arch/0008-arm64-arch_timer-Allows-a-CPU-specific-erratum-to-on.patch.
- Delete
  patches.arch/0009-arm64-arch_timer-Move-clocksource_counter-and-co-aro.patch.
- Delete
  patches.arch/0010-arm64-arch_timer-Enable-CNTVCT_EL0-trap-if-workaroun.patch.
- Delete
  patches.arch/0011-arm64-arch_timer-Workaround-for-Cortex-A73-erratum-8.patch.
- Delete
  patches.arch/0012-arm64-arch_timer-Allow-erratum-matching-with-ACPI-OE.patch.
- Delete
  patches.arch/0013-arm64-arch_timer-Add-HISILICON_ERRATUM_161010101-ACP.patch.
- Delete
  patches.arch/arm64-0001-iommu-arm-smmu-Invalidate-TLBs-properly.patch.
- Delete
  patches.arch/arm64-1-6-Documentation-arm64-pmu-Add-Broadcom-Vulcan-PMU-binding.patch.
- Delete
  patches.arch/arm64-2-6-arm64-dts-Add-Broadcom-Vulcan-PMU-in-dts.patch.
- Delete
  patches.arch/arm64-3-4-perf-xgene-Add-APM-X-Gene-SoC-Performance-Monitoring-Unit-driver.patch.
- Delete
  patches.arch/arm64-3-6-arm64-perf-Changed-events-naming-as-per-ARM-ARM.patch.
- Delete
  patches.arch/arm64-4-6-arm64-perf-Define-complete-ARMv8-recommended-implementation-defined-events.patch.
- Delete
  patches.arch/arm64-5-6-arm64-perf-Filter-common-events-based-on-PMCEIDn_EL0.patch.
- Delete
  patches.arch/arm64-6-6-arm64-perf-Add-Broadcom-Vulcan-PMU-support.patch.
- Delete
  patches.arch/arm64-Documentation-gpio-Update-description-for-X-Gene-standby-GPIO-controller-DTS-binding.patch.
- Delete
  patches.arch/arm64-dts-Update-X-Gene-standby-GPIO-controller-DTS-entries.patch.
- Delete patches.arch/arm64-fix-includes-for-smp.patch.
- Delete
  patches.arch/arm64-gpio-xgene-Enable-X-Gene-standby-GPIO-as-interrupt-controller.patch.
- Delete
  patches.arch/arm64-irqdomain-Export-irq_domain_free_irqs_common.patch.
- Delete
  patches.arch/arm64-pci-numa-adding-helper-functions-as-requiered.patch.
- Delete
  patches.arch/arm64-thd-0002-pci-Add-is_pcierc-element-to-struct-pci_bus.patch.
- Delete
  patches.arch/arm64-thd-gicv3-its-increase-FOREC_MAX_ZONEORDER-for-Cav.patch.
- Delete
  patches.arch/crypto-arm64-crc32-detect-crc32-support-in-assembler.patch.
- Delete patches.arch/x86-boot-rename-reserve_bios_regions.patch.
- Delete
  patches.drivers/0001-clk-mvebu-mark-root-clocks-in-AP806-CP110-system-con.patch.
- commit 36915c9
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- arm64: iommu/arm-smmu-v3: Increase CMDQ drain timeout value (bsc#1035479).
- Delete
  patches.drivers/0005-iommu-arm-smmu-v3-Increase-SMMU-CMD-queue-poll-timeo.patch.
  Switch to solution accepted upstream.
- commit 591ddbd
* Wed Aug  2 2017 hare@suse.de
- Drop obsolete SCSI patches
- Delete
  patches.drivers/cciss-set-cciss_allow_hpsa-per-default.patch.
- Delete
  patches.fixes/scsi-Do-not-use-synchronous-ALUA-submission-for-NetA.patch.
- Delete
  patches.fixes/scsi-Retry-failfast-commands-after-EH.patch.
- commit 714a4bc
* Wed Aug  2 2017 hare@suse.de
- st: fix blk_get_queue usage (bnc#834808).
- commit ea540b7
* Wed Aug  2 2017 hare@suse.de
- Update loop patches to upstream submission
- loop: Remove unused 'bdev' argument from loop_set_capacity
  (bsc#931634, FATE#319010).
- loop: fix error handling regression (bsc#931634, FATE#319010).
- loop: support 4k physical blocksize (bsc#931634, FATE#319010).
- Refresh patches.suse/loop-Compability-for-older-releases.patch.
- Delete patches.suse/loop-Add-lo_logical_blocksize.patch.
- Delete
  patches.suse/loop-Enable-correct-physical-blocksize.patch.
- Delete
  patches.suse/loop-Pass-logical-blocksize-in-lo_init-0-ioctl-field.patch.
- Delete
  patches.suse/loop-Remove-unused-bdev-argument-from-loop_set_capac.patch.
- commit 3d19f6c
* Wed Aug  2 2017 hare@suse.de
- Drop obsolete lpfc patches
- Delete
  patches.drivers/0428-lpfc-Add-nvme-initiator-devloss-support.patch.
- Delete
  patches.drivers/0429-lpfc-Fix-transition-nvme-i-rport-handling-to-nport-o.patch.
- Delete
  patches.drivers/0430-lpfc-Fix-nvme-port-role-handling-in-sysfs-and-debugf.patch.
- Delete
  patches.drivers/0431-lpfc-Add-changes-to-assist-in-NVMET-debugging.patch.
- Delete
  patches.drivers/0432-lpfc-Fix-Lun-Priority-level-shown-as-NA.patch.
- Delete
  patches.drivers/0433-lpfc-Fix-nvmet-node-ref-count-handling.patch.
- Delete
  patches.drivers/0434-lpfc-Fix-Port-going-offline-after-multiple-resets.patch.
- Delete
  patches.drivers/0435-lpfc-Fix-counters-so-outstandng-NVME-IO-count-is-acc.patch.
- Delete
  patches.drivers/0436-lpfc-Fix-return-value-of-board_mode-store-routine-in.patch.
- Delete
  patches.drivers/0437-lpfc-Fix-crash-on-powering-off-BFS-VM-with-passthrou.patch.
- Delete
  patches.drivers/0438-lpfc-Fix-System-panic-after-loading-the-driver.patch.
- Delete
  patches.drivers/0439-lpfc-Null-pointer-dereference-when-log_verbose-is-se.patch.
- Delete
  patches.drivers/0440-lpfc-Fix-PRLI-retry-handling-when-target-rejects-it.patch.
- Delete
  patches.drivers/0441-lpfc-Fix-vports-not-logging-into-target.patch.
- Delete
  patches.drivers/0442-lpfc-update-to-revision-to-11.4.0.0.patch.
- Delete
  patches.drivers/0443-lpfc-tie-lpfc-dev_loss_tmo-dynamic-changes-to-transp.patch.
- commit b536d39
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0004-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- commit a112130
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0003-iommu-arm-smmu-v3-Add-workaround-for-Cavium-ThunderX.patch.
- commit 1f0b409
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0002-ACPI-IORT-Fixup-SMMUv3-resource-size-for-Cavium-Thun.patch.
- commit ec446ff
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- ACPICA: IORT: Update SMMU models for revision C (bsc#1036060).
- commit a283c6f
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0013-PCI-ACPI-Add-ThunderX-pass2.x-2nd-node-MCFG-quirk.patch.
  cd183740480f PCI/ACPI: Add ThunderX pass2.x 2nd node MCFG quirk in v4.12
- commit 8af3b43
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0012-PCI-ACPI-Tidy-up-MCFG-quirk-whitespace.patch.
  ced414a14f70 PCI/ACPI: Tidy up MCFG quirk whitespace in v4.12
- commit b8dfc46
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0017-MAINTAINERS-Add-entry-for-Cavium-MMC-driver.patch.
  25fc84650373 MAINTAINERS: Add entry for Cavium MMC driver in v4.12
- commit 58bf6f3
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0016-mmc-cavium-Support-DDR-mode-for-eMMC-devices.patch.
  4ce944074e5e mmc: cavium: Support DDR mode for eMMC devices in v4.12
- commit 7ead2d8
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0015-mmc-cavium-Add-scatter-gather-DMA-support.patch.
  cd76e5c565e8 mmc: cavium: Add scatter-gather DMA support in v4.12
- commit 4c792e1
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0014-mmc-cavium-Add-MMC-PCI-driver-for-ThunderX-SOCs.patch.
  166bac38c3c5 mmc: cavium: Add MMC PCI driver for ThunderX SOCs in v4.12
- commit 018a1e3
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0013-mmc-cavium-Add-core-MMC-driver-for-Cavium-SOCs.patch.
  ba3869ff32e4 mmc: cavium: Add core MMC driver for Cavium SOCs in v4.12
- commit 947dfdf
* Wed Aug  2 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0012-dt-bindings-mmc-Add-Cavium-SOCs-MMC-bindings.patch.
  dc5aee3f9f45 dt-bindings: mmc: Add Cavium SOCs MMC bindings in v4.12
- commit b4b7a95
* Wed Aug  2 2017 mgalbraith@suse.de
- Refresh patches.fixes/sched-Fix-up-proc-sched_debug-to-print-only-runnable-tasks-again.patch.
- Refresh patches.suse/sched-optimize-latency-defaults.patch.
- Refresh patches.suse/sched-reinstate-FAIR_SLEEPERS-feature.patch.
- Refresh patches.suse/sched-reinstate-sched_compat_yield.patch.
- Delete patches.suse/sched-domain-flags-proc-handler.patch.
- Delete patches.suse/sched-provide-nortsched-boot-option.patch.
- Delete patches.suse/sched-provide-rtkthreads-rtworkqueues-boot-options.patch.
- commit 823b493
* Wed Aug  2 2017 mgorman@suse.de
- sched,numa: scale scan period with tasks in group and
  shared/private (Automatic NUMA Balancing (fate#315482)).
- commit cccc123
* Wed Aug  2 2017 mgorman@suse.de
- numa,sched: slow down scan rate if shared faults dominate
  (Automatic NUMA Balancing (fate#315482)).
- commit bd6ebee
* Wed Aug  2 2017 mgorman@suse.de
- Refresh patches.suse/sched-optimize-latency-defaults.patch.
- commit 3a3fa45
* Tue Aug  1 2017 rgoldwyn@suse.com
- Apparmor for FATE#323500 (namespace, ptrace etc.)
  The networking patches are applied after the upstream patches
  because they are not upstreamed. It was simpler to change
  the networking patches later because of the changes in core(LSM)
  in the upstream patches.
- securityfs: add the ability to support symlinks (FATE#323500).
- apparmorfs: Combine two function calls into one in
  aa_fs_seq_raw_abi_show() (FATE#323500).
- doc: ReSTify apparmor.txt (FATE#323500).
- apparmorfs: Use seq_putc() (FATE#323500).
- apparmor: Fix error cod in __aa_fs_profile_mkdir()
  (FATE#323500).
- security/apparmor: Use POSIX-compatible "printf '%%s'"
  (FATE#323500).
- apparmor: move file context into file.h (FATE#323500).
- apparmor: make internal lib fn skipn_spaces available to the
  rest of apparmor (FATE#323500).
- apparmor: allow profiles to provide info to disconnected paths
  (FATE#323500).
- apparmor: Move path lookup to using preallocated buffers
  (FATE#323500).
- apparmor: move to per loaddata files, instead of replicating
  in profiles (FATE#323500).
- apparmor: use macro template to simplify profile seq_files
  (FATE#323500).
- apparmor: use macro template to simplify namespace seq_files
  (FATE#323500).
- apparmor: add custom apparmorfs that will be used by policy
  namespace files (FATE#323500).
- apparmor: rename apparmor file fns and data to indicate use
  (FATE#323500).
- apparmor: allow specifying an already created dir to create
  ns entries in (FATE#323500).
- apparmor: convert from securityfs to apparmorfs for policy ns
  files (FATE#323500).
- apparmor: move permissions into their own file to be more
  easily shared (FATE#323500).
- apparmor: rework perm mapping to a slightly broader set
  (FATE#323500).
- apparmor: provide finer control over policy management
  (FATE#323500).
- apparmor: add policy revision file interface (FATE#323500).
- apparmor: add mkdir/rmdir interface to manage policy namespaces
  (FATE#323500).
- apparmor: add label data availability to the feature set
  (FATE#323500).
- apparmor: speed up transactional queries (FATE#323500).
- apparmor: add fn to test if profile supports a given mediation
  class (FATE#323500).
- apparmor: add gerneric permissions struct and support fns
  (FATE#323500).
- apparmor: switch from file_perms to aa_perms (FATE#323500).
- apparmor: add profile permission query ability (FATE#323500).
- apparmor: provide information about path buffer size at boot
  (FATE#323500).
- apparmor: cleanup __find_child( (FATE#323500).
- apparmor: add namespace lookup fns() (FATE#323500).
- apparmor: fix policy load/remove semantics (FATE#323500).
- apparmor: fix apparmor_query data (FATE#323500).
- apparmor: fix display of ns name (FATE#323500).
- apparmor: move bprm_committing_creds/committed_creds to lsm.c
  (FATE#323500).
- apparmor: convert to profile block critical sections
  (FATE#323500).
- apparmor: share profile name on replacement (FATE#323500).
- apparmor: refactor updating profiles to the newest parent
  (FATE#323500).
- apparmor: cleanup remove unused and not fully implemented
  profile rename (FATE#323500).
- apparmor: convert aa_change_XXX bool parameters to flags
  (FATE#323500).
- apparmor: cleanup rename XXX_file_context() to XXX_file_ctx()
  (FATE#323500).
- apparmor: revalidate files during exec (FATE#323500).
- apparmor: add the base fns() for domain labels (FATE#323500).
- apparmor: switch from profiles to using labels on contexts
  (FATE#323500).
- apparmor: switch getprocattr to using label_print fns(
  (FATE#323500).
- apparmor: update query interface to support label queries
  (FATE#323500).
- apparmor: move capability checks to using labels (FATE#323500).
- apparmor: move resource checks to using labels (FATE#323500).
- apparmor: add cross check permission helper macros
  (FATE#323500).
- apparmor: move ptrace checks to using labels (FATE#323500).
- apparmor: allow ptrace checks to be finer grained than just
  capability (FATE#323500).
- apparmor: move aa_file_perm() to use labels (FATE#323500).
- apparmor: update aa_audit_file() to use labels (FATE#323500).
- apparmor: refactor path name lookup and permission checks
  around labels (FATE#323500).
- apparmor: move path_link mediation to using labels
  (FATE#323500).
- apparmor: rework file permission to cache file access in
  file->ctx (FATE#323500).
- apparmor: mediate files when they are received (FATE#323500).
- apparmor: support v7 transition format compatible with
  label_parse (FATE#323500).
- apparmor: move exec domain mediation to using labels
  (FATE#323500).
- apparmor: move change_hat mediation to using labels
  (FATE#323500).
- apparmor: move change_profile mediation to using labels
  (FATE#323500).
- apparmor: add domain label stacking info to apparmorfs
  (FATE#323500).
- apparmor: add stacked domain labels interface (FATE#323500).
- apparmor: export that basic profile namespaces are supported
  (FATE#323500).
- apparmor: put back designators in struct initialisers
  (FATE#323500).
- Refresh
  patches.apparmor/apparmor-basic-networking-rules-4.11-rc1.patch.
- Refresh patches.apparmor/apparmor-basic-networking-rules.patch.
- Refresh
  patches.apparmor/apparmor-fix-quieting-of-audit-messages-for-network-mediation.patch.
- commit e310a9d
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0071-mmc-dw_mmc-improve-dw_mci_reset-a-bit.patch.
  bc2dcc1a2a5e mmc: dw_mmc: improve dw_mci_reset a bit in v4.12
- commit 847a0dd
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0070-mmc-dw_mmc-move-mci_send_cmd-forward-to-avoid-declar.patch.
  4dba18defb4c mmc: dw_mmc: move mci_send_cmd forward to avoid declaration in v4.12
- commit edcfef2
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0069-mmc-dw_mmc-remove-declaration-of-dw_mci_card_busy.patch.
  132b3b6aa618 mmc: dw_mmc: remove declaration of dw_mci_card_busy in v4.12
- commit 346a64d
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0068-mmc-dw_mmc-move-dw_mci_get_cd-forward-to-avoid-decla.patch.
  671fa142fc03 mmc: dw_mmc: move dw_mci_get_cd forward to avoid declaration in v4.12
- commit e7920fa
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0067-mmc-dw_mmc-move-dw_mci_ctrl_reset-forward-to-avoid-d.patch.
  8e6db1f65510 mmc: dw_mmc: move dw_mci_ctrl_reset forward to avoid declaration in v4.12
- commit 72c131b
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0066-mmc-dw_mmc-move-dw_mci_reset-forward-to-avoid-declar.patch.
  8e6db1f65510 mmc: dw_mmc: move dw_mci_ctrl_reset forward to avoid declaration in v4.12
- commit e993d40
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0065-mmc-dw_mmc-improve-the-timeout-polling-code.patch.
  b6d2d81c5c2d mmc: dw_mmc: improve the timeout polling code in v4.12
- commit 1d3f660
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0010-arm64-Add-CNTFRQ_EL0-trap-handler.patch.
  9842119a238b arm64: Add CNTFRQ_EL0 trap handler in v4.12
- commit 32e4ad4
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0008-arm64-add-ESR_ELx_SYS64_ISS_SYS_OP_MASK-define.patch.
  116c81f427ff arm64: Work around systems with mismatched cache line sizes in v4.9
- commit 02dfdaa
* Tue Aug  1 2017 hare@suse.de
- Drop cciss driver (FATE#323833)
- Update config files.
- supported.conf:
- commit cac232d
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0003-arm64-cpu_errata-Add-capability-to-advertise-Cortex-.patch.
  eeb1efbcb83c arm64: cpu_errata: Add capability to advertise Cortex-A73 erratum 858921 in v4.12
- commit 22fb6fa
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.arch/0001-irqdomain-add-empty-irq_domain_check_msi_remap.patch.
  b3e228473e6c irqdomain: Add empty irq_domain_check_msi_remap in v4.12
- commit ba2255e
* Tue Aug  1 2017 jthumshirn@suse.de
- Delete
  patches.drivers/0444-nvme_fc-fix-confused-queue-size-handling.patch.
- Delete
  patches.drivers/0445-nvme_fc-on-lldd-transport-io-error-terminate-associa.patch.
- Delete
  patches.drivers/0446-lpfc-Fix-defects-reported-by-Coverity-Scan.patch.
- Delete patches.drivers/0447-lpfc-Add-auto-EQ-delay-logic.patch.
- Delete
  patches.drivers/0448-lpfc-fix-irq_affinity-relative-to-older-irq-interfaces.patch.
- Delete
  patches.drivers/0451-scatterlist-add-sg_zero_buffer-helper.patch.
- Delete
  patches.drivers/0452-nvmet-use-NVME_IDENTIFY_DATA_SIZE.patch.
- Delete
  patches.drivers/0453-nvme-introduce-NVMe-Namespace-Identification-Descrip.patch.
- Delete
  patches.drivers/0454-nvme-rename-uuid-to-nguid-in-nvme_ns.patch.
- Delete
  patches.drivers/0455-nvme-get-list-of-namespace-descriptors.patch.
- Delete
  patches.drivers/0456-nvme-provide-UUID-value-to-userspace.patch.
- Delete
  patches.drivers/0457-nvmet-implement-namespace-identify-descriptor-list.patch.
- Delete
  patches.drivers/0458-nvmet-add-uuid-field-to-nvme_ns-and-populate-via-con.patch.
- Delete
  patches.drivers/0459-nvmet-allow-overriding-the-NVMe-VS-via-configfs.patch.
- Delete
  patches.drivers/0460-nvme-add-fields-into-identify-controller-data-struct.patch.
- Delete
  patches.drivers/0461-Fix-system-panic-when-express-lane-enabled.patch.
- Delete
  patches.drivers/0462-Vport-creation-is-failing-with-Link-Down-error.patch.
- Delete
  patches.drivers/0463-Reduce-time-spent-in-IRQ-for-received-NVME-commands.patch.
- Delete
  patches.drivers/0464-Fix-SLI3-drivers-attempting-NVME-ELS-commands.patch.
- Delete
  patches.drivers/0465-Fix-crash-after-firmware-flash-when-IO-is-running.patch.
- Delete
  patches.drivers/0466-Fix-crash-doing-IO-with-resets.patch.
- Delete
  patches.drivers/0467-Fix-crash-in-lpfc_sli_ringtxcmpl_put-when-nvmet-gets.patch.
- Delete
  patches.drivers/0468-Driver-responds-LS_RJT-to-Beacon-Off-ELS.patch.
- Delete
  patches.drivers/0469-lpfc-update-to-revision-to-11.4.0.1.patch.
- Delete
  patches.drivers/0469-nvme_fc-Fix-crash-when-nvme-controller-connection-fa.patch.
- Delete
  patches.drivers/0470-nvmet_fc-fix-crashes-on-bad-opcodes.patch.
- Delete
  patches.drivers/0471-nvme_fc-Fix-hard-lockup-in-nvme-host-transport-on-co.patch.
- Delete
  patches.drivers/0473-nvme_fc-fix-double-calls-to-nvme_cleanup_cmd.patch.
- Delete
  patches.drivers/0474-nvme_fc-fix-error-recovery-on-link-down.patch.
- Delete
  patches.drivers/0475-lpfc-Fix-nvme-io-stoppage-after-link-bounce.patch.
- Delete
  patches.drivers/0476-lpfc-fix-refcount-error-on-node-list.patch.
- Delete
  patches.drivers/nvme-submit-nvme_admin_activate_fw-to-admin-queue.patch.
- commit 0d0b596
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Refresh patches.drivers/0001-ARM64-PCI-Set-root-bus-NUMA-node-on-ACPI-systems.patch.
- commit bb1bc41
* Tue Aug  1 2017 yousaf.kaukab@suse.com
- Delete patches.drivers/0008-drivers-net-xgene-fix-build-after-change_mtu-functio.patch.
  Not required for kernel v4.12
- commit 7a10760
* Tue Aug  1 2017 agraf@suse.de
- Clean up upstreamed patches list. Annotate the remaining ones
  with their current status.
- Delete patches.arch/arm-exynos-dwmmc-modalias.patch.
- Delete patches.arch/arm-xen-fixup.patch.
- Delete
  patches.arch/arm64-Allow-for-different-DMA-and-CPU-bus-offsets.patch.
- Delete
  patches.arch/arm64-PCI-xilinx-nwl-Add-support-for-Xilinx-NWL-PCIe-Host-.patch.
- Delete
  patches.arch/arm64-Relocate-screen_info.lfb_base-on-PCI-BAR-alloc.patch.
- Delete
  patches.arch/arm64-bcm2837-0070-ARM-bcm2835-Add-VC4-to-the-device-tree.patch.
- Delete
  patches.arch/arm64-bcm2837-0071-drm-vc4-Add-DPI-driver.patch.
- Delete
  patches.arch/arm64-bcm2837-0073-irqchip-bcm2836-Drop-smp_set_ops-on-arm64-builds.patch.
- Delete
  patches.arch/arm64-bcm2837-0074-irqchip-bcm2836-Fix-compiler-warning-on-64-bit-build.patch.
- Delete
  patches.arch/arm64-bcm2837-0075-irqchip-bcm2836-Use-a-more-generic-memory-barrier-ca.patch.
- Delete
  patches.arch/arm64-bcm2837-0076-clk-bcm2835-Fix-compiler-warnings-on-64-bit-builds.patch.
- Delete
  patches.arch/arm64-bcm2837-0078-ARM-bcm2835-Add-devicetree-for-the-Raspberry-Pi-3.patch.
- Delete
  patches.arch/arm64-bcm2837-0079-drm-vc4-Fix-NULL-deref-in-HDMI-init-error-path.patch.
- Delete
  patches.arch/arm64-bcm2837-0081-don-t-force-serial-pins-to-uart0.patch.
- Delete
  patches.arch/arm64-bcm2837-0088-arm64-Add-platform-selection-for-BCM2835.patch.
- Delete
  patches.arch/arm64-bcm2837-0103-ARM-bcm2835-dt-Add-the-ethernet-to-the-device-trees.patch.
- Delete
  patches.arch/arm64-bcm2837-0104-ARM-bcm2837-dt-Add-the-ethernet-to-the-device-trees.patch.
- Delete
  patches.arch/arm64-bcm2837-0106-rtc-efi-Fail-probing-if-RTC-reads-don-t-work.patch.
- Delete
  patches.arch/arm64-bcm2837-0112-clk-bcm2835-Mark-the-VPU-clock-as-critical.patch.
- Delete
  patches.arch/arm64-bcm2837-0113-clk-bcm2835-Mark-GPIO-clocks-enabled-at-boot-as-crit.patch.
- Delete
  patches.arch/arm64-bcm2837-0114-clk-bcm2835-Skip-PLLC-clocks-when-deciding-on-a-new-.patch.
- Delete
  patches.arch/arm64-bcm2837-0115-clk-bcm2835-Mark-the-CM-SDRAM-clock-s-parent-as-crit.patch.
- Delete
  patches.arch/arm64-bcm2837-0195-bcm2835-Add-Raspberry-Pi-thermal-sensor-to-the-device-tree.patch.
- Delete
  patches.arch/arm64-bcm2837-0197-thermal-Add-Raspberry-Pi-BCM2835-thermal-driver.patch.
- Delete
  patches.arch/arm64-ls1043-0101-fsl-fman-Convert-to-long.patch.
- Delete
  patches.arch/arm64-ls1043-0129-phy-Add-an-mdio_device-structure.patch.
- Delete
  patches.arch/arm64-ls1043-0130-arm64-Export-arch_setup_dma_ops.patch.
- Delete
  patches.arch/arm64-ls1043-0215-caam-Declare-PER_CPU-variable-outside-function-scope.patch.
- Delete
  patches.arch/arm64-ls1043-0221-caam-Use-old-attrs-interface.patch.
- Delete
  patches.arch/ppc64le-ile-0001-powerpc-Add-global-exports-for-all-interrupt-vectors.patch.
- Delete
  patches.arch/ppc64le-ile-0002-powerpc-Add-relocation-code-for-fixups.patch.
- Delete
  patches.arch/ppc64le-ile-0003-powerpc-Add-hack-to-make-ppc64le-work-on-hosts-witho.patch.
- Delete
  patches.arch/ppc64le-ile-0004-powerpc-Don-t-return-to-BE-mode-when-we-are-already-.patch.
- commit ab1a7d7
* Tue Aug  1 2017 nborisov@suse.com
- series.conf: Remove commented out line
  While pushing my for-next to SLE15 i got the following warning:
  remote: Warning: multiple uses in /tmp/githook.T8ujQR04YV/series.conf:
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch
  This was due to aforementioned patch being disabled during the transition of the
  branch. In the meantime JeffM has already triaged/enabled the patch. So let's
  remove the extra line
- commit 19d3938
* Mon Jul 31 2017 mgorman@suse.de
- Remove patches for review that must be reimplemented from scratch if still required
- commit abf83a9
* Mon Jul 31 2017 tiwai@suse.de
- mwifiex: do not update MCS set from hostapd (bsc#1051510).
- iwlwifi: pcie: reconfigure MSI-X HW on resume (bsc#1051510).
- iwlwifi: pcie: fix command completion name debug (bsc#1051510).
- iwlwifi: pcie: fix TVQM queue ID range check (bsc#1051510).
- iwlwifi: mvm: unconditionally stop device after init
  (bsc#1051510).
- iwlwifi: mvm: reset the fw_dump_desc pointer after ASSERT
  (bsc#1051510).
- drm/tegra: dc: Avoid reset asserts on Tegra20 (bsc#1051510).
- drm/panel: add backlight dependency for sitronix-st7789v
  (bsc#1051510).
- drm/panel: S6E3HA2 needs backlight code (bsc#1051510).
- drm/nouveau: use proper prototype in nouveau_pmops_runtime()
  definition (bsc#1051510).
- drm/nouveau/disp/nv50-: bump max chans to 21 (bsc#1051510).
- drm/i915: Fix scaler init during CRTC HW state readout
  (bsc#1051510).
- drm: exynos: mark pm functions as __maybe_unused (bsc#1051510).
- drm/doc: Fix missing @ctx documentation (bsc#1051510).
- commit d5522f6
* Mon Jul 31 2017 nborisov@suse.com
- Btrfs: incremental send, fix invalid path for link  commands
  (bsc#1051479).
- Btrfs: incremental send, fix invalid path for unlink  commands
  (bsc#1051479).
- Btrfs: send, fix invalid path after renaming and linking  file
  (bsc#1051479).
- commit 86ebf6c
* Mon Jul 31 2017 jgross@suse.com
- Move XEN patches to dedicated section
- commit aef3ab9
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-allocate-page-for-shared-info-page-from-low-mem.patch to 4.12
- commit 221ffe0
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-balloon-don-t-online-new-memory-initially.patch to 4.12
- commit 4009e51
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-mce-dont-issue-error-message.patch to 4.12
- commit d5fc01c
* Mon Jul 31 2017 jgross@suse.com
- Rebased patches.fixes/xen-add-sysfs-node-for-guest-type.patch to 4.12
- commit 90f8a3b
* Mon Jul 31 2017 jgross@suse.com
- Removed patches.fixes/xen-use-machine-addresses-in-vmcoreinfo-when-pv.patch,
  already contained in upstream 4.12
- commit b385b8c
* Mon Jul 31 2017 rgoldwyn@suse.com
- Refresh
  patches.fixes/0002-fs-fcntl-f_setown-avoid-undefined-behaviour.patch.
  Correct the patch according to SLE15 (as opposed to SLE12SP2) because
  patches.fixes/0001-fs-fcntl-f_setown-allow-returning-error.patch
  changed the function prototype.
- commit ca46fac
* Sun Jul 30 2017 mgorman@suse.de
- Remove comment about patches merged via -stable
- commit 0cb4556
* Fri Jul 28 2017 hare@suse.de
- Drop obsolete patches and update patch description
- Refresh
  patches.drivers/scsi_transport_fc-return-EBUSY-for-deleted-vport.patch.
- Delete
  patches.drivers/libfc-do-not-flood-console-with-messages-libfc-queue.patch.
- Delete
  patches.drivers/scsi_transport_fc-do-not-call-queue_work-under-lock.patch.
- Delete
  patches.drivers/scsi_transport_fc-fixup-race-condition-in-fc_rport_f.patch.
- commit 4ca214c
* Fri Jul 28 2017 glin@suse.com
- bpf: fix mixed signed/unsigned derived min/max value bounds
  (bsc#1050081).
- commit c6eeed6
* Fri Jul 28 2017 jslaby@suse.cz
- Update config files.
  Fix vanillas after the orc update.
- commit 2a27bf2
* Fri Jul 28 2017 jslaby@suse.cz
- Linux 4.12.4 (bnc#1012628).
- commit f2e2c0a
* Thu Jul 27 2017 mgorman@suse.de
- Review and document sched-Further-improve-spurious-CPU_IDLE-active-migrations.patch
- commit 36d9aef
* Thu Jul 27 2017 rgoldwyn@suse.com
- btrfs: nowait aio: Correct assignment of pos (FATE#321994).
- btrfs: nowait aio support (FATE#321994).
- xfs: nowait aio support (FATE#321994).
- ext4: nowait aio support (FATE#321994).
- block: return on congested block device (FATE#321994).
- fs: Introduce IOMAP_NOWAIT (FATE#321994).
- fs: return if direct I/O will trigger writeback (FATE#321994).
- fs: Introduce RWF_NOWAIT and FMODE_AIO_NOWAIT (FATE#321994).
- fs: Use RWF_* flags for AIO operations (FATE#321994).
- fs: Introduce filemap_range_has_page() (FATE#321994).
- fs: Separate out kiocb flags setup based on RWF_* flags
  (FATE#321994).
- commit d1dfe7b
* Thu Jul 27 2017 bpoirier@suse.com
- supported.conf: Update network drivers
- commit 49a23df
* Thu Jul 27 2017 mkubecek@suse.cz
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (CVE-2017-7542 bsc#1049882).
- commit 00c5961
* Thu Jul 27 2017 mgorman@suse.de
- Enable sched-ratelimit-nohz.patch
- commit f691847
* Thu Jul 27 2017 jthumshirn@suse.de
- Delete
  patches.drivers/0043-lightnvm-fix-warning-ret-may-be-used-uninitialized.patch.
- commit e2eabec
* Thu Jul 27 2017 jthumshirn@suse.de
- Re-enable patches.drivers/scsi-bnx2i-missing-error-code-in-bnx2i_ep_connect
- commit 90b3cea
* Thu Jul 27 2017 mgorman@suse.de
- exports from rcu_idle_exit() and rcu_idle_enter() (bnc#978907
  Scheduler performance -- idle).
- rcu_idle_enter() rely on callers disabling irqs (bnc#978907
  Scheduler performance -- idle).
- commit d4e79a7
* Thu Jul 27 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-md-remove-idx-from-struct-resync_pages.patch.
- commit b11fd5b
* Thu Jul 27 2017 jslaby@suse.cz
- objtool: Fix sibling call detection logic (bnc#1018348).
- x86/kconfig: Make it easier to switch to the new ORC unwinder
  (bnc#1018348).
- x86/kconfig: Consolidate unwinders into multiple choice
  selection (bnc#1018348).
- Refresh
- Refresh patches.suse/0001-x86-unwind-Add-the-ORC-unwinder.patch.
- Refresh
  patches.suse/0002-dwarf-do-not-throw-away-unwind-info.patch.
- Refresh
  patches.suse/0002-objtool-x86-Add-several-functions-and-files-to-the-o.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0002-x86-kconfig-Make-it-easier-to-switch-to-the-new-ORC-.patch.
- Refresh
  patches.suse/0003-objtool-Implement-stack-validation-2.0.patch.
- Refresh
  patches.suse/0003-x86-kconfig-Consolidate-unwinders-into-multiple-choi.patch.
- Refresh
  patches.suse/0007-x86-entry-64-Add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-Add-unwind-hint-annotations-to-sync_core.patch.
- Update config files.
  Update to version from -tip. ORC is in -tip completely. So make sure
  we use the upstream version.
- commit 34dd0f5
* Thu Jul 27 2017 bpoirier@suse.com
- net: ena: update ena driver to version 1.2.0 (bsc#1047121).
- net: ena: update driver's rx drop statistics (bsc#1047121).
- net: ena: use lower_32_bits()/upper_32_bits() to split dma
  address (bsc#1047121).
- net: ena: separate skb allocation to dedicated function
  (bsc#1047121).
- net: ena: use napi_schedule_irqoff when possible (bsc#1047121).
- net: ena: allow the driver to work with small number of msix
  vectors (bsc#1047121).
- net: ena: add support for out of order rx buffers refill
  (bsc#1047121).
- net: ena: add reset reason for each device FLR (bsc#1047121).
- net: ena: change sizeof() argument to be the type pointer
  (bsc#1047121).
- net: ena: add hardware hints capability to the driver
  (bsc#1047121).
- net: ena: change return value for unsupported features
  unsupported return value (bsc#1047121).
- commit 025123f
* Thu Jul 27 2017 enadolski@suse.com
- btrfs: remove outdated version of backrefs rbtree patch set
  These patches are superceded by the version that was submitted
  to upstream. This commit removes the outdated files and their
  corresponding entries in series.conf.
- Delete
  patches.suse/btrfs-add-a-node-counter-to-each-of-the-rbtrees.
- Delete
  patches.suse/btrfs-add-cond_resched-calls-when-resolving-backrefs.
- Delete
  patches.suse/btrfs-allow-backref-search-checks-for-shared-extents.
- Delete
  patches.suse/btrfs-backref-add-tracepoints-for-prelim_ref-insertion-and-merging.
- Delete
  patches.suse/btrfs-backref-add-unode_aux_to_inode_list-helper.
- Delete patches.suse/btrfs-backref-cleanup-_-namespace-abuse.
- Delete patches.suse/btrfs-backref-constify-some-arguments.
- Delete
  patches.suse/btrfs-btrfs_check_shared-should-manage-its-own-transaction.
- Delete
  patches.suse/btrfs-clean-up-extraneous-computations-in-add_delayed_refs.
- Delete patches.suse/btrfs-constify-tracepoint-arguments.
- Delete
  patches.suse/btrfs-convert-prelimary-reference-tracking-to-use-rbtrees.
- Delete
  patches.suse/btrfs-remove-ref_tree-implementation-from-backref-c.
- Delete patches.suse/btrfs-struct-funcs-constify-readers.
- commit 7a9c5fb
* Thu Jul 27 2017 enadolski@suse.com
- btrfs: clean up extraneous computations in add_delayed_refs
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: allow backref search checks for shared extents
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: add cond_resched() calls when resolving backrefs
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, add tracepoints for prelim_ref insertion and
  merging (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: add a node counter to each of the rbtrees (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: convert prelimary reference tracking to use rbtrees
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: remove ref_tree implementation from backref.c (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: btrfs_check_shared should manage its own transaction
  (bsc#974590 bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, cleanup __ namespace abuse (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, add unode_aux_to_inode_list helper (bsc#974590
  bsc#1030061 bsc#1022914 bsc#1017461).
- btrfs: backref, constify some arguments (bsc#974590 bsc#1030061
  bsc#1022914 bsc#1017461).
- btrfs: constify tracepoint arguments (bsc#974590 bsc#1030061
  bsc#1022914 bsc#1017461).
- btrfs: struct-funcs, constify readers (bsc#974590 bsc#1030061
  bsc#1022914 bsc#1017461).
- commit 68ccc54
* Wed Jul 26 2017 mcgrof@suse.com
- mm: kmemleak: treat vm_struct as alternative reference to
  vmalloc'ed objects (bsc#1027456).
- mm: kmemleak: factor object reference updating out of
  scan_block() (bsc#1027456).
- mm: kmemleak: slightly reduce the size of some structures on
  64-bit architectures (bsc#1027456).
- commit bc42ba6
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit f7ebe40
* Wed Jul 26 2017 mcgrof@suse.com
- Refresh
  patches.suse/0001-mm-kmemleak-slightly-reduce-the-size-of-some-structu.patch.
- Refresh
  patches.suse/0002-mm-kmemleak-factor-object-reference-updating-out-of-.patch.
- Refresh
  patches.suse/0003-mm-kmemleak-treat-vm_struct-as-alternative-reference.patch.
- commit eb41516
* Wed Jul 26 2017 mgorman@suse.de
- audit: Reduce overhead using a coarse clock (bnc#1050724).
- commit e3464f2
* Wed Jul 26 2017 mgorman@suse.de
- Remove architecture heading that is no longer supported
- commit e5e149e
* Wed Jul 26 2017 mgorman@suse.de
- rcu: Use RCU_NOCB_WAKE rather than RCU_NOGP_WAKE (bnc#978907
  Scheduler performance -- idle).
- doc: Take tail recursion into account in RCU requirements
  (bnc#978907 Scheduler performance -- idle).
- srcu: Document auto-expediting requirement (bnc#978907 Scheduler
  performance -- idle).
- rcu: Remove obsolete reference to synchronize_kernel()
  (bnc#978907 Scheduler performance -- idle).
- srcu: Eliminate possibility of destructive counter overflow
  (bnc#978907 Scheduler performance -- idle).
- rcu: Prevent rcu_barrier() from starting needless grace periods
  (bnc#978907 Scheduler performance -- idle).
- commit 7f11b71
* Wed Jul 26 2017 mkubecek@suse.cz
- ipv6: avoid overflow of offset in ip6_find_1stfragopt
  (CVE-2017-7542 bsc#1049882).
- commit 399d4a0
* Wed Jul 26 2017 mkubecek@suse.cz
- bpf/verifier: fix min/max handling in BPF_SUB (bsc#1050081).
- bpf: fix mixed signed/unsigned derived min/max value bounds
  (bsc#1050081).
- commit f90c358
* Wed Jul 26 2017 mkubecek@suse.cz
- supported.conf: mark nf_log_bridge as supported
  This was the only netfilter module not marked as supported. There is no
  apparent reason except that nobody marked it when the functionality was
  separated into its own module.
- commit c5e825b
* Wed Jul 26 2017 mkubecek@suse.cz
- supported.conf: mark nftables related modules as supported (fate#323407)
- commit 0fbfb00
* Wed Jul 26 2017 tiwai@suse.de
- Input: ALPS - Fix Alps Touchpad two finger scroll does not
  work on right side (bsc#1050582).
- commit 93ed5e8
* Wed Jul 26 2017 tiwai@suse.de
- Delete patches.drivers/0088-dma-buf-sync_file-Add-back-the-u64_to_user_ptr-macro.patch
  It's a stop-gap fix in SLE12-SP3 for 4.9 dmabuf API.
- commit 678704a
* Wed Jul 26 2017 tiwai@suse.de
- Delete patches.drivers/vgaarb-Add-more-context-to-error-messages.patch
  It's no longer needed as we AMD binary-only stuff is dead.
- commit 78dd994
* Wed Jul 26 2017 dbueso@suse.de
- configs: update defaults for REFCOUNT_FULL
  Such that it is always disabled, with the exception
  of x86-64 debug.
- commit ddb821a
* Wed Jul 26 2017 dbueso@suse.de
- mm: update callers to use HASH_ZERO flag (bsc#971975).
- mm: zero hash tables in allocator (bsc#971975).
- locking/qspinlock: Explicitly include asm/prefetch.h
  (bsc#1050549).
- locking/rtmutex: Remove unnecessary priority adjustment
  (bsc#1050549).
- locking/refcount: Create unchecked atomic_t implementation
  (bsc#1050549).
- commit ca0d066
* Tue Jul 25 2017 jeffm@suse.com
- Refresh patches.suse/squashfs-3.4.patch.
  Restore fixes from:
  patches.suse/squashfs3-properly-handle-dir_emit-failures.patch.
- commit 03d0582
* Tue Jul 25 2017 jthumshirn@suse.de
- Forward port v4.13-rc qedf patches from SLE12-SP3
- commit 4512e77
* Tue Jul 25 2017 fvogt@suse.com
- Reassign some bcm283x patches
  patches.arch/arm64-bcm2837-0195-bcm2835-Add-Raspberry-Pi-thermal-sensor-to-the-device-tree.patch
  and patches.arch/arm64-bcm2837-0197-thermal-Add-Raspberry-Pi-BCM2835-thermal-driver.patch
  are now upstream, but due to a bug in Kconfig not enabled in arm64 builds. Needs a proper fix
  with proper testing which I currently can't do.
- commit d6fe1c5
* Tue Jul 25 2017 mgorman@suse.de
- Enable hpsa patch that avoids bypassing the controller cache
- commit 1c4e9ea
* Tue Jul 25 2017 jthumshirn@suse.de
- Update v4.13-rc2 bnxt_re patches
- commit 41b7731
* Tue Jul 25 2017 oneukum@suse.com
- Update config files.
  Kill the ancient PCMCIA/CardBus . (bsc#323267)
- commit 6b5ad53
* Tue Jul 25 2017 msuchanek@suse.de
- blacklist 2400fd822f46 powerpc/asm: Mark cr0 as clobbered in mftb()
- commit 0f1ad8b
* Mon Jul 24 2017 dbueso@suse.de
- ipc/util.h: update documentation for ipc_getref() and
  ipc_putref() (bsc#1050323).
- ipc/sem: drop __sem_free() (bsc#1050323).
- ipc/msg: remove special msg_alloc/free (bsc#1050323).
- ipc/shm: remove special shm_alloc/free (bsc#1050323).
- ipc: move atomic_set() to where it is needed (bsc#1050323).
- ipc/msg.c: avoid ipc_rcu_putref for failed ipc_addid()
  (bsc#1050323).
- ipc/shm.c: avoid ipc_rcu_putref for failed ipc_addid()
  (bsc#1050323).
- ipc/sem.c: avoid ipc_rcu_putref for failed ipc_addid()
  (bsc#1050323).
- ipc/util: drop ipc_rcu_alloc() (bsc#1050323).
- ipc/msg: avoid ipc_rcu_alloc() (bsc#1050323).
- ipc/shm: avoid ipc_rcu_alloc() (bsc#1050323).
- ipc/sem: avoid ipc_rcu_alloc() (bsc#1050323).
- ipc/util: drop ipc_rcu_free() (bsc#1050323).
- ipc/msg: do not use ipc_rcu_free() (bsc#1050323).
- ipc/shm: do not use ipc_rcu_free() (bsc#1050323).
- ipc/sem: do not use ipc_rcu_free() (bsc#1050323).
- ipc: drop non-RCU allocation (bsc#1050323).
- include/linux/sem.h: correctly document sem_ctime (bsc#1050323).
- ipc: merge ipc_rcu and kern_ipc_perm (bsc#1050323).
- ipc/sem.c: remove sem_base, embed struct sem (bsc#1050323).
- fs: remove call_fsync helper function (bsc#1050323).
- mqueue: move compat syscalls to native ones (bsc#1050323).
- commit c68517a
* Mon Jul 24 2017 tiwai@suse.de
- Apply the upstreamed (submitted) DRM patches, drop a couple of them
  (bnc#746883,bnc#895608,bnc#871134,bnc#893040,bnc#806990).
  patches.drivers/drm-radeon-limit-bpp-for-low-vram.patch
  patches.drivers/drm-ast-Actually-load-DP501-firmware-when-required.patch
  patches.drivers/drm-ast-Add-an-crtc_disable-callback-to-the-crtc-helper-funcs.patch
  patches.drivers/drm-ast-Fix-memleak-in-error-path-in-ast_bo_create.patch
  patches.drivers/drm-ast-Free-container-instead-of-member-in-ast_user_framebuffer_destroy.patch
  patches.drivers/drm-ast-Simplify-function-ast_bo_unpin.patch
  patches.drivers/drm-mgag200-Add-additional-limits-for-certain-G200-variants.patch
  patches.drivers/drm-mgag200-Add-command-line-option-to-specify-preferred-depth.patch
  patches.drivers/drm-mgag200-Add-doublescan-and-interlace-support.patch
  patches.drivers/drm-mgag200-Add-mode-validation-debugging-code.patch
  patches.drivers/drm-mgag200-Add-support-for-MATROX-PCI-device-IDs-0x520-and-0x521.patch
  patches.drivers/drm-mgag200-Cleanup-cursor-BOs-properly.patch
  patches.drivers/drm-mgag200-Consolidate-depth-bpp-handling.patch
  patches.drivers/drm-mgag200-Don-t-use-crtc_-parameters-for-validation.patch
  patches.drivers/drm-mgag200-Fix-memleak-in-error-path-in-mgag200_bo_create.patch
  patches.drivers/drm-mgag200-Free-container-instead-of-member-in-mga_user_framebuffer_destroy.patch
  patches.drivers/drm-mgag200-Implement-basic-PM-support
  patches.drivers/drm-mgag200-Initialize-data-needed-to-map-fbdev-memory.patch
  patches.drivers/drm-mgag200-Simplify-function-mgag200_ttm_placement.patch
  Dropped:
  patches.drivers/drm-cirrus-Add-missing-drm_connector_unregister.patch
  patches.drivers/drm-mgag200-Add-missing-drm_connector_unregister.patch
- commit b11e49b
* Mon Jul 24 2017 mgorman@suse.de
- writeback: rework wb_[dec|inc]_stat family of functions
  (bnc#971975 VM performance -- statistics).
- percpu_counter: Rename __percpu_counter_add to
  percpu_counter_add_batch (bnc#971975 VM performance --
  statistics).
- commit 960acce
* Mon Jul 24 2017 mgorman@suse.de
- kernel/fork.c: virtually mapped stacks: do not disable
  interrupts (bnc#978907 Scheduler performance -- fork).
- commit e0d9b89
* Mon Jul 24 2017 mgorman@suse.de
- sched/fair: Fix load_balance() affinity redo path (bnc#978907
  Scheduler performance -- load balancer).
- sched/cputime: Accumulate vtime on top of nsec clocksource
  (bnc#978907 Scheduler performance -- nohz_full, accounting).
- sched/cputime: Move the vtime task fields to their own struct
  (bnc#978907 Scheduler performance -- nohz_full, accounting).
- sched/cputime: Rename vtime fields (bnc#978907 Scheduler
  performance -- nohz_full, accounting).
- sched/cputime: Always set tsk->vtime_snap_whence after
  accounting vtime (bnc#978907 Scheduler performance -- nohz_full,
  accounting).
- vtime, sched/cputime: Remove vtime_account_user() (bnc#978907
  Scheduler performance -- nohz_full, accounting).
- commit 835d782
* Mon Jul 24 2017 mgorman@suse.de
- sched/topology: Rename sched_group_cpus() (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Rename sched_group_mask() (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Simplify sched_group_mask() usage (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Rewrite get_group() (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Add a few comments (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Fix overlapping sched_group_capacity (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Add sched_group_capacity debugging (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Small cleanup (bnc#978907 Scheduler performance
  - - topology).
- sched/topology: Remove FORCE_SD_OVERLAP (bnc#978907 Scheduler
  performance -- topology).
- sched/topology: Move comment about asymmetric node setups
  (bnc#978907 Scheduler performance -- topology).
- sched/topology: Verify the first group matches the child domain
  (bnc#978907 Scheduler performance -- topology).
- sched/debug: Print the scheduler topology group mask (bnc#978907
  Scheduler performance -- topology).
- sched/topology: Simplify build_overlap_sched_groups()
  (bnc#978907 Scheduler performance -- topology).
- sched/topology: Refactor function build_overlap_sched_groups()
  (bnc#978907 Scheduler performance -- topology).
- commit bccf165
* Mon Jul 24 2017 mkubecek@suse.cz
- supported.conf: update core networking
  Add missing modules, drop those not built anymore.
- commit 017c4e5
* Mon Jul 24 2017 msuchanek@suse.de
- powerpc/fadump: Add a warning when 'fadump_reserve_mem='
  is used (bsc#1049231).
- commit f59fefd
* Mon Jul 24 2017 msuchanek@suse.de
- s390/crash: Remove unused KEXEC_NOTE_BYTES (bsc#1049706).
- commit f3e8437
* Mon Jul 24 2017 mkubecek@suse.cz
- Refresh and enable
  patches.drivers/i40e-add-private-flag-to-control-source-pruning.patch.
- commit d3ea4f6
* Mon Jul 24 2017 mkubecek@suse.cz
- Delete patches.suse/AF_MAX.patch.
  This patch reserved space for adding AF_HYPERV and AF_SMC constants as
  implementations of both families were not upstreamed at the moment of
  SLE12-SP2 kABI freeze. AF_SMC was accepted in the meantime (which turned
  out to be a bad thing, BtW), AF_HYPERV submission was rejected in July 2016
  and no attempt to resubmit it was made since.
  In other words, there doesn't seem to be any reason to keep the patch, it
  can be reintroduced later (in updated form) if there is a need.
- commit 4e036bb
* Mon Jul 24 2017 mkubecek@suse.cz
- Update upstream reference:
  patches.fixes/usb-early-Remove-trace_printk-callers-in-xhci-dbc.patch.
- commit 0162ee3
* Mon Jul 24 2017 mhocko@suse.cz
- blacklist.conf: blacklist 5d6dec6fba38 (we do not have any users)
- commit 7131165
* Mon Jul 24 2017 mhocko@suse.cz
- blacklist.conf: 3bc1630774bc (compilation fix for config which we do not
  care)
- commit e1ee65a
* Mon Jul 24 2017 mhocko@suse.cz
- blacklist.conf: 38cb266ad1a2 (trivial doc formatting)
- commit 4fa3930
* Sat Jul 22 2017 bpoirier@suse.com
- Sort network patch section and rename accordingly
- commit 8588a81
* Sat Jul 22 2017 bpoirier@suse.com
- Refresh
  patches.drivers/e1000e-Don-t-return-uninitialized-stats.patch.
  It was a local commit id.
- commit 4c5c3f9
* Fri Jul 21 2017 colyli@suse.de
- md: remove 'idx' from 'struct resync_pages' (bsc#1049599).
- commit 515f14e
* Fri Jul 21 2017 lhenriques@suse.com
- Patch has been merged into 4.12
  Delete
  patches.fixes/ceph-check-i_nlink-while-converting-a-file-handle-to-dentry.patch.
- commit d60ca32
* Fri Jul 21 2017 tbogendoerfer@suse.de
- enabled and moved patches present in SLE12-SP3 and still needed in SLE15
- commit 597b029
* Fri Jul 21 2017 duwe@suse.de
- Be prepared to enable ARM64 live patching during SLE15 lifetime
  (FATE#322421).
- Delete
  patches.arch/powerpc-add-kernel-parameter-iommu_alloc_quiet.patch.
  DMA_ATTR_NO_WARN is now incorporated.
- Delete patches.fixes/fix-stop-machine.
  Proper mainline fix is now in.
- Remove FIPS patches:
- Delete patches.suse/allow-cmac_3des_ede-for-FIPS-140-2.
- Delete patches.suse/allow-cmac_aes-for-FIPS-140-2.
- Delete patches.suse/disallow-ansi_cprng-for-FIPS-140-2.
- Delete patches.suse/fips-remove-hmac-crc32-add-nullcipher-hack.
- commit cd28b1d
* Fri Jul 21 2017 jroedel@suse.de
- x86/acpi: Prevent out of bound access caused by broken ACPI
  tables (CVE-2017-11473 bsc#1049603).
- commit cc7b51e
* Fri Jul 21 2017 oneukum@suse.com
- Update config files.
  Remove WUSB (FATE#323423)
- commit 2257fee
* Fri Jul 21 2017 oneukum@suse.com
- supported.conf:
  remove support for IRDA (FATE#323263)
- commit bdaf793
* Fri Jul 21 2017 oneukum@suse.com
- supported.conf:
  removed support for ISDN (FATE#323266)
- commit 4265d36
* Fri Jul 21 2017 oneukum@suse.com
- Update config files.
  Exterminate ISDN (FATE#323266)
- commit f13b205
* Fri Jul 21 2017 oneukum@suse.com
- Update config files.
  Exterminate IRDA (FATE#323263)
- commit ef690e1
* Fri Jul 21 2017 jslaby@suse.cz
- Linux 4.12.3 (CVE-2017-7541 bnc#1012628 bsc#1049645).
- Refresh patches.suse/pstore-backend-autoaction.
- Delete
  patches.fixes/brcmfmac-fix-possible-buffer-overflow-in-brcmf_cfg80.
- commit 409edbf
* Fri Jul 21 2017 jthumshirn@suse.de
- Delete
  patches.drivers/0051-Missing-bio_put-following-submit_bio_wait.patch.
- Delete
  patches.drivers/0127-scsi-lpfc-Fix-crash-on-PCI-hotplug-remove-path.patch.
- Delete patches.drivers/0426-nvmet_fc-fix-list-corruption.patch.
- Delete
  patches.drivers/0427-nvmet_fc-cap-amount-of-work-allowed-in-workqueue.patch.
  Delete superseded patches and re-attribute PM patch to Joey
- commit 492279e
* Fri Jul 21 2017 mcgrof@suse.com
- Delete
  patches.fixes/xfs-fix-buffer-overflow-dm_get_dirattrs.patch.
- Delete
  patches.fixes/xfs_dmapi-fix-the-debug-compilation-of-xfs_dmapi.patch.
- commit 2f7c909
* Fri Jul 21 2017 mcgrof@suse.com
- Refresh
  patches.drivers/0001-module-warn-if-module-init-probe-takes-long.patch.
- commit c47c847
* Thu Jul 20 2017 jack@suse.cz
- dentry name snapshots (bsc#1049483).
- commit 76ea0ca
* Thu Jul 20 2017 mwilck@suse.com
- Delete
  patches.drivers/ipmi_si-create-hardware-independent-softdep-for-ipmi.patch.
  upstream now.
- commit c4eb19d
* Thu Jul 20 2017 mwilck@suse.com
- Refresh
  patches.drivers/0001-hpsa-update-identify-physical-device-structure.patch.
- Refresh
  patches.drivers/0002-hpsa-do-not-get-enclosure-info-for-external-devices.patch.
- Refresh patches.drivers/0003-hpsa-update-reset-handler.patch.
- Refresh patches.drivers/0004-hpsa-do-not-reset-enclosures.patch.
- Refresh
  patches.drivers/0005-hpsa-rescan-later-if-reset-in-progress.patch.
- Refresh
  patches.drivers/0006-hpsa-correct-resets-on-retried-commands.patch.
- Refresh patches.drivers/0007-hpsa-cleanup-reset-handler.patch.
- Refresh
  patches.drivers/0008-hpsa-correct-queue-depth-for-externals.patch.
- Refresh
  patches.drivers/0009-hpsa-separate-monitor-events-from-rescan-worker.patch.
- Refresh
  patches.drivers/0010-hpsa-send-ioaccel-requests-with-0-length-down-raid-path.patch.
- Update patches.drivers/0011-hpsa-remove-abort-handler.patch
  (bsc#1022600 fate#321928 bsc#1016119).
- Refresh patches.drivers/0012-hpsa-bump-driver-version.patch.
- Delete
  patches.drivers/hpsa-fallback-to-use-legacy-REPORT-PHYS-command.patch.
- Delete
  patches.drivers/hpsa-use-correct-DID_NO_CONNECT-hostbyte.patch.
- commit 3a174f7
* Thu Jul 20 2017 nborisov@suse.com
- Add Omar's total_bytes_pinned patches from upstream and delete old backports
- Btrfs: always account pinned bytes when dropping a tree block
  ref (bsc#1040182).
- Btrfs: make add_pinned_bytes() take an s64 num_bytes instead
  of u64 (bsc#1040182).
- Btrfs: make BUG_ON() in add_pinned_bytes() an ASSERT()
  (bsc#1040182).
- Btrfs: return old and new total ref mods when adding delayed
  refs (bsc#1040182).
- Btrfs: rework delayed ref total_bytes_pinned accounting
  (bsc#1040182).
- Btrfs: update total_bytes_pinned when pinning down extents
  (bsc#1040182).
- Delete
  patches.suse/0001-Btrfs-make-add_pinned_bytes-take-an-s64-num_bytes-in.patch.
- Delete
  patches.suse/0002-Btrfs-make-BUG_ON-in-add_pinned_bytes-an-ASSERT.patch.
- Delete
  patches.suse/0003-Btrfs-update-total_bytes_pinned-when-pinning-down-ex.patch.
- Delete
  patches.suse/0004-Btrfs-always-account-pinned-bytes-when-dropping-a-tr.patch.
- Delete
  patches.suse/0005-Btrfs-return-old-and-new-total-ref-mods-when-adding-.patch.
- Delete
  patches.suse/0006-Btrfs-rework-delayed-ref-total_bytes_pinned-accounti.patch.
- Delete
  patches.suse/0007-Btrfs-warn-if-total_bytes_pinned-is-non-zero-on-unmo.patch.
- commit 97e177b
* Thu Jul 20 2017 tbogendoerfer@suse.de
- Patch is already part of 4.12.
  Delete
  patches.drivers/cxgb4-0157-cxgb4-notify-uP-to-route-ctrlq-compl-to-rdma-rspq.patch.
- commit c3e3c5d
* Thu Jul 20 2017 jeffm@suse.com
- btrfs: fix lockup in find_free_extent with read-only block
  groups (bsc#1046682).
- commit fa3b074
* Thu Jul 20 2017 jslaby@suse.cz
- debug: fix WARN_ON_ONCE() for modules (bnc#1049599).
- commit b1e9bab
* Thu Jul 20 2017 mhocko@suse.cz
- patches.fixes/mm-mmap.c-do-not-blow-on-PROT_NONE-MAP_FIXED-holes-i.patch
  forward port
- commit e188cbc
* Thu Jul 20 2017 tbogendoerfer@suse.de
- Deleted outdated patches.
- Delete
  patches.drivers/staging-rdma-0001-Commit-507f6afa3ab6-struct-ib_class_port_info-this-c.patch.
- Delete
  patches.drivers/staging-rdma-0002-Fix-changed-get_user_pages-arguments.patch.
- Delete
  patches.drivers/staging-rdma-0003-Adapt-staging-rdma-drivers-to-IB-core-Let-create_ah.patch.
- commit 357b909
* Thu Jul 20 2017 tiwai@suse.de
- brcmfmac: fix possible buffer overflow in
  brcmf_cfg80211_mgmt_tx() (CVE-2017-7541,bsc#1049645).
- commit 9f05680
* Thu Jul 20 2017 mhocko@suse.cz
- series.conf - move some MM patches to the proper section
- commit d78e77f
* Wed Jul 19 2017 mmarek@suse.cz
- rpm/kernel-binary.spec.in: find-debuginfo.sh should not touch build-id
  This needs rpm-4.14+ (bsc#964063).
- commit f622d60
* Wed Jul 19 2017 lduncan@suse.com
- Removing gaurded patch from SLE12 not needed.
- commit 0d62b5e
* Wed Jul 19 2017 jack@suse.cz
- ext4: avoid unnecessary stalls in ext4_evict_inode()
  (bsc#1049486).
- commit 47dc213
* Wed Jul 19 2017 mmarek@suse.cz
- Reassign some of the to be reviewed patches
- commit 7431a6f
* Wed Jul 19 2017 oneukum@suse.com
- Refresh
  patches.suse/0003-kabi-Add-placeholders-to-a-couple-of-important-struc.patch.
  Taking all the kABI placeholders, as teh rational for them has not changed.
- commit 72e50ae
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-call-in-set_user_n.patch:
  Merged as 2fb8d36787affe26f3536c3d8ec094995a48037d in v4.11-rc1.
- commit f2bba64
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-call-for-task_hot.patch:
  Merged as 3bed5e2166a5e433bf62162f3cd3c5174d335934 as v4.11-rc1.
- commit 23e5248
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-in-detach_task_cfs.patch:
  Merged as 80f5c1b84baa8180c3c27b7e227429712cd967b6 in v4.11-rc1.
- commit 85dec32
* Wed Jul 19 2017 mfleming@suse.de
- Delete
  patches.suse/sched-Add-missing-update_rq_clock-in-post_init_entit.patch:
  Merged as 4126bad6717336abe5d666440ae15555563ca53f in v4.11-rc1.
- commit d31a75d
* Wed Jul 19 2017 mmarek@suse.cz
- Delete patches.suse/split-package, the specfile does not use this anymore
- commit f265fd3
* Wed Jul 19 2017 jkosina@suse.cz
- supported.conf: import supported.conf from SLE12-SP3 and add missing entries
- commit 22aaf02
* Wed Jul 19 2017 jthumshirn@suse.de
- Renumber SmartPQI patches, as we're restarting from 1 now
- commit 9737cb7
* Wed Jul 19 2017 jthumshirn@suse.de
- Refresh
  patches.drivers/0041-scsi-smartpqi-correct-aio-error-path.patch.
- Refresh
  patches.drivers/0048-scsi-smartpqi-make-ioaccel-references-consistent.patch.
- Delete patches.drivers/0001-scsi-fcoe-convert-to-kworker.patch.
- commit 2cee378
* Wed Jul 19 2017 oneukum@suse.com
- Delete
  patches.drivers/0001-USB-add-descriptors-from-USB-Power-Delivery-spec.patch.
- Delete
  patches.drivers/0001-cdc-acm-added-sanity-checking-for-probe.patch.
- Delete patches.drivers/0001-gspca-correct-speed-testing.patch.
- Delete
  patches.drivers/0002-USB-PD-define-specific-requests.patch.
- Delete patches.drivers/0002-uvc-correct-speed-testing.patch.
- Delete
  patches.drivers/0003-USB-PD-additional-feature-selectors.patch.
- Delete
  patches.suse/0001-usb-quirk-to-stop-runtime-PM-for-Intel-7260.patch.
- commit 2b88672
* Wed Jul 19 2017 jroedel@suse.de
- iommu/amd: Free already flushed ring-buffer entries before
  full-check (bsc#1045709).
- iommu/amd: Remove amd_iommu_disabled check from
  amd_iommu_detect() (bsc#1045715 bsc#1043261).
- iommu/amd: Free IOMMU resources when disabled on command line
  (bsc#1045715 bsc#1043261).
- iommu/amd: Set global pointers to NULL after freeing them
  (bsc#1045715 bsc#1043261).
- iommu/amd: Check for error states first in iommu_go_to_state()
  (bsc#1045715 bsc#1043261).
- iommu/amd: Add new init-state IOMMU_CMDLINE_DISABLED
  (bsc#1045715 bsc#1043261).
- iommu/amd: Rename free_on_init_error() (bsc#1045715
  bsc#1043261).
- iommu/amd: Disable IOMMUs at boot if they are enabled
  (bsc#1045715 bsc#1043261).
- iommu/amd: Suppress IO_PAGE_FAULTs in kdump kernel (bsc#1045715
  bsc#1043261).
- iommu/amd: Remove queue_release() function (bsc#1045709).
- iommu/amd: Add per-domain timer to flush per-cpu queues
  (bsc#1045709).
- iommu/amd: Add flush counters to struct dma_ops_domain
  (bsc#1045709).
- iommu/amd: Add locking to per-domain flush-queue (bsc#1045709).
- iommu/amd: Make use of the per-domain flush queue (bsc#1045709).
- iommu/amd: Add per-domain flush-queue data structures
  (bsc#1045709).
- iommu/amd: Rip out old queue flushing code (bsc#1045709).
- iommu/amd: Reduce delay waiting for command buffer space
  (bsc#1045709).
- iommu/amd: Reduce amount of MMIO when submitting commands
  (bsc#1045709).
- iommu/amd: Constify irq_domain_ops (bsc#1045709).
- iommu/amd: Ratelimit io-page-faults per device (bsc#1045709).
- commit f012b19
* Wed Jul 19 2017 hare@suse.de
- Delete upstreamed patches
- Delete
  patches.drivers/0097-NVMe-Only-release-requested-regions.patch.
- Delete
  patches.drivers/0385-nvme-fc-correct-port-role-bits.patch.
- Delete
  patches.drivers/0386-nvme-fc-require-target-or-discovery-role-for-fc-nvme.patch.
- Delete
  patches.drivers/0387-nvme-fc-stop-queues-on-error-detection.patch.
- Delete
  patches.drivers/0388-nvmet-fc-remove-target-cpu-scheduling-flag.patch.
- Delete
  patches.drivers/0389-nvmet-release-the-sq-ref-on-rdma-read-errors.patch.
- Delete
  patches.drivers/0390-nvme_fc-get-rid-of-local-reconnect_delay.patch.
- Delete patches.drivers/0391-nvme_fc-Support-ctrl_loss_tmo.patch.
- Delete
  patches.drivers/0392-nvme_fc-replace-ioabort-msleep-loop-with-completion.patch.
- Delete
  patches.drivers/0393-nvme_fc-revise-comment-on-teardown.patch.
- Delete
  patches.drivers/0394-nvme_fc-set-logging-level-on-resets-deletes.patch.
- Delete patches.drivers/0395-nvmet_fc-Reduce-work_q-count.patch.
- Delete
  patches.drivers/0396-nvmet_fc-Add-queue-create-and-delete-callbacks-in-LL.patch.
- Delete
  patches.drivers/0397-nvme_fc-remove-extra-controller-reference-taken-on-r.patch.
- Delete
  patches.drivers/0398-nvme_fcloop-fix-port-deletes-and-callbacks.patch.
- Delete
  patches.drivers/0399-nvme_fc-correct-nvme-status-set-on-abort.patch.
- Delete
  patches.drivers/0400-nvme_fc-create-fc-class-and-transport-device.patch.
- Delete
  patches.drivers/0401-nvme_fc-add-uevent-for-auto-connect.patch.
- Delete
  patches.drivers/0402-nvme-core-allow-controller-RESETTING-to-RECONNECTING.patch.
- Delete
  patches.drivers/0403-nvme_fc-change-ctlr-state-assignments-during-reset-r.patch.
- Delete
  patches.drivers/0404-nvme_fc-add-a-dev_loss_tmo-field-to-the-remoteport.patch.
- Delete
  patches.drivers/0405-nvme_fc-add-dev_loss_tmo-to-controller.patch.
- Delete
  patches.drivers/0406-nvme_fc-check-connectivity-before-initiating-reconne.patch.
- Delete
  patches.drivers/0407-nvme_fc-change-failure-code-on-remoteport-connectivi.patch.
- Delete
  patches.drivers/0408-nvme_fc-move-remote-port-get-put-free-location.patch.
- Delete
  patches.drivers/0409-nvme_fc-add-dev_loss_tmo-timeout-and-remoteport-resu.patch.
- Delete
  patches.drivers/lpfc-Revert-patch-lpfc-Delete-unnecessary-checks-bef.patch.
- Delete
  patches.drivers/lpfc-driver-update-for-SLES12-SP2-11.1.0.1.patch.
- Delete
  patches.fixes/fc-add-missing-ELS-explanation-values.patch.
- Delete patches.fixes/fc_rport-PRLI-fixes.patch.
- Delete
  patches.fixes/fc_rport-Return-LS_RJT_BUSY-for-PRLI-in-status-PLOGI.patch.
- Delete
  patches.fixes/fcoe-Add-FIP-responder-on-the-real-network-device.patch.
- Delete patches.fixes/fcoe-FIP-debugging.patch.
- Delete patches.fixes/fcoe-Use-kfree_skb-instead-of-kfree.patch.
- Delete
  patches.fixes/fcoe-correct-sending-FIP-VLAN-packets-on-VLAN-0.patch.
- Delete
  patches.fixes/fcoe-filter-out-frames-from-invalid-vlans.patch.
- Delete
  patches.fixes/fcoe-inhibit-writing-invalid-values-into-the-enabled.patch.
- Delete
  patches.fixes/fcoe-make-R_A_TOV-and-E_D_TOV-configurable.patch.
- Delete patches.fixes/fcoe-set-default-TC-priority.patch.
- Delete
  patches.fixes/fcoe_ctlr-fix-potential-deadlock-when-re-adding-port.patch.
- Delete patches.fixes/libfc-Clarify-ramp-down-messages.patch.
- Delete
  patches.fixes/libfc-Correctly-set-E_D_TOV-and-R_A_TOV-values-in-RT.patch.
- Delete patches.fixes/libfc-Debug-PRLI-failures.patch.
- Delete
  patches.fixes/libfc-Do-not-attempt-to-login-if-the-port-is-already.patch.
- Delete
  patches.fixes/libfc-Do-not-drop-down-to-FLOGI-for-fc_rport_login.patch.
- Delete
  patches.fixes/libfc-Do-not-drop-out-of-order-frames.patch.
- Delete
  patches.fixes/libfc-Do-not-take-rdata-rp_mutex-when-processing-a-F.patch.
- Delete
  patches.fixes/libfc-Fix-PRLI-response-handling-yet-again.patch.
- Delete patches.fixes/libfc-Fixup-disc_mutex-handling.patch.
- Delete
  patches.fixes/libfc-Fixup-fixup-disc_mutex-handling.patch.
- Delete patches.fixes/libfc-Implement-RTV-responder.patch.
- Delete
  patches.fixes/libfc-Issue-PRLI-after-a-PRLO-has-been-received.patch.
- Delete patches.fixes/libfc-Revisit-kref-handling.patch.
- Delete
  patches.fixes/libfc-Send-LS_RJT-responses-on-frame-allocation-fail.patch.
- Delete
  patches.fixes/libfc-Update-rport-reference-counting.patch.
- Delete
  patches.fixes/libfc-additional-debugging-in-fc_rport.patch.
- Delete patches.fixes/libfc-additional-debugging-messages.patch.
- Delete
  patches.fixes/libfc-do-not-overwrite-DID_TIME_OUT-status.patch.
- Delete
  patches.fixes/libfc-do-not-send-ABTS-when-resetting-exchanges.patch.
- Delete
  patches.fixes/libfc-don-t-advance-state-machine-for-incoming-FLOGI.patch.
- Delete
  patches.fixes/libfc-don-t-fail-sequence-abort-for-completed-exchan.patch.
- Delete
  patches.fixes/libfc-fc_fcp-wait-for-E_D_TOV-when-out-of-order-sequ.patch.
- Delete patches.fixes/libfc-fixup-RTV-handling.patch.
- Delete patches.fixes/libfc-fixup-locking-of-ptp_setup.patch.
- Delete patches.fixes/libfc-frame-alloc-failure-messages.patch.
- Delete patches.fixes/libfc-quarantine-timed-out-xids.patch.
- Delete
  patches.fixes/libfc-reset-exchange-manager-during-LOGO-handling.patch.
- Delete patches.fixes/libfc-reset-timeout-on-queue-full.patch.
- Delete
  patches.fixes/libfc-safeguard-against-invalid-exchange-index.patch.
- Delete patches.fixes/libfc-sanitize-E_D_TOV-setting.patch.
- Delete patches.fixes/libfc-send-LOGO-for-PLOGI-failure.patch.
- Delete
  patches.fixes/libfc-spurious-I-O-error-under-high-load.patch.
- Delete
  patches.fixes/libfc-use-configured-e_d_tov-for-remote-port-state-r.patch.
- Delete
  patches.fixes/libfc-use-configured-lport-R_A_TOV-when-sending-exch.patch.
- Delete
  patches.fixes/libfc-use-error-code-for-fc_rport_error.patch.
- Delete patches.fixes/scsi-Fix-RCU-handling-for-VPD-pages.patch.
- Delete
  patches.fixes/scsi-vpd-pages-are-mandatory-for-SPC-2.patch.
- Delete
  patches.fixes/scsi_dh_alua-Do-not-modify-the-interval-value-for-re.patch.
- Delete
  patches.fixes/scsi_dh_alua-Do-not-retry-for-unmapped-device.patch.
- Delete
  patches.fixes/scsi_dh_alua-Retry-RTPG-on-SCSI-host_bytes-values.patch.
- Delete
  patches.fixes/scsi_dh_alua-do-not-call-BUG_ON-when-updating-port-g.patch.
- Delete
  patches.fixes/scsi_transport_sas-add-scsi_target_id-sysfs-attribut.patch.
- commit 292a8cf
* Wed Jul 19 2017 tbogendoerfer@suse.de
- Update Patch-mainline tags.
- Refresh
  patches.drivers/cxgb4-0151-cxgb4-reduce-resource-allocation-in-kdump-kernel.patch.
- Refresh
  patches.drivers/cxgb4-0152-cxgb4-Fix-netdev_features-flag.patch.
- Refresh
  patches.drivers/cxgb4-0153-cxgb4-keep-carrier-off-before-registering-netdev.patch.
- Refresh
  patches.drivers/cxgb4-0157-cxgb4-notify-uP-to-route-ctrlq-compl-to-rdma-rspq.patch.
- Refresh
  patches.drivers/qed-sp3-0264-qed-Enable-RoCE-parser-searching-on-fp-init.patch.
- Refresh
  patches.drivers/qed-sp3-0265-qed-Correct-order-of-wwnn-and-wwpn.patch.
- Refresh
  patches.drivers/qed-sp3-0266-qed-Share-additional-information-with-qedf.patch.
- Refresh
  patches.drivers/qed-sp3-0267-qed-Support-NVM-image-reading-API.patch.
- Refresh
  patches.drivers/qed-sp3-0268-qed-Add-support-for-changing-iSCSI-mac.patch.
- Refresh
  patches.drivers/xgene-sp3-0001-phy-Add-helper-function-to-check-phy-interface-mode.patch.
- Refresh
  patches.drivers/xgene-sp3-0011-drivers-net-xgene-Protect-indirect-MAC-access.patch.
- Refresh
  patches.drivers/xgene-sp3-0012-drivers-net-phy-xgene-Add-lock-to-protect-mac-access.patch.
- Refresh
  patches.drivers/xgene-sp3-0013-drivers-net-xgene-Use-rgmii-mdio-mac-access.patch.
- Refresh
  patches.drivers/xgene-sp3-0014-drivers-net-xgene-Remove-redundant-local-stats.patch.
- Refresh
  patches.drivers/xgene-sp3-0015-drivers-net-xgene-Refactor-statistics-error-parsing-.patch.
- Refresh
  patches.drivers/xgene-sp3-0016-drivers-net-xgene-Remove-unused-macros.patch.
- Refresh
  patches.drivers/xgene-sp3-0017-drivers-net-xgene-Extend-ethtool-statistics.patch.
- Refresh
  patches.drivers/xgene-sp3-0018-drivers-net-xgene-Add-rx_overrun-tx_underrun-statist.patch.
- Refresh
  patches.drivers/xgene-sp3-0019-drivers-net-xgene-Workaround-for-HW-errata-10GE_4.patch.
- Refresh
  patches.drivers/xgene-sp3-0020-drivers-net-xgene-Add-frame-recovered-statistics-cou.patch.
- Refresh
  patches.drivers/xgene-sp3-0021-drivers-net-xgene-Workaround-for-HW-errata-10GE_10-E.patch.
- Refresh
  patches.drivers/xgene-sp3-0022-drivers-net-xgene-Fix-redundant-prefetch-buffer-clea.patch.
- Refresh
  patches.drivers/xgene-sp3-0023-xgene-Check-all-RGMII-phy-mode-variants.patch.
- commit b012c38
* Wed Jul 19 2017 jroedel@suse.de
- Delete
  patches.drivers/0001-iommu-amd-ratelimit-io-page-faults-per-device.
- Delete
  patches.drivers/0001-iommu-amd-suppress-io_page_faults-in-kdump-kernel.
- Delete patches.drivers/0002-iommu-amd-constify-irq_domain_ops.
- Delete
  patches.drivers/0002-iommu-amd-disable-iommus-at-boot-if-they-are-enabled.
- Delete
  patches.drivers/0003-iommu-amd-reduce-amount-of-mmio-when-submitting-commands.
- Delete patches.drivers/0003-iommu-amd-rename-free_on_init_error.
- Delete
  patches.drivers/0004-iommu-amd-add-new-init-state-iommu_cmdline_disabled.
- Delete
  patches.drivers/0004-iommu-amd-reduce-delay-waiting-for-command-buffer-space.
- Delete
  patches.drivers/0005-iommu-amd-check-for-error-states-first-in-iommu_go_to_state.
- Delete
  patches.drivers/0005-iommu-amd-rip-out-old-queue-flushing-code.
- Delete
  patches.drivers/0006-iommu-amd-add-per-domain-flush-queue-data-structures.
- Delete
  patches.drivers/0006-iommu-amd-set-global-pointers-to-null-after-freeing-them.
- Delete
  patches.drivers/0007-iommu-amd-free-iommu-resources-when-disabled-on-command-line.
- Delete
  patches.drivers/0007-iommu-amd-make-use-of-the-per-domain-flush-queue.
- Delete
  patches.drivers/0008-iommu-amd-add-locking-to-per-domain-flush-queue.
- Delete
  patches.drivers/0008-iommu-amd-remove-amd_iommu_disabled-check-from-amd_iommu_detect.
- Delete
  patches.drivers/0009-iommu-amd-add-flush-counters-to-struct-dma_ops_domain.
- Delete
  patches.drivers/0010-iommu-amd-add-per-domain-timer-to-flush-per-cpu-queues.
- Delete
  patches.drivers/0011-iommu-amd-remove-queue_release-function.
- Delete
  patches.drivers/0012-iommu-amd-free-already-flushed-ring-buffer-entries-before-full-check.
- commit abd2aa7
* Wed Jul 19 2017 jbohac@suse.cz
- Drop bridge-remove-br_netfilter-warning.patch
  patches.suse/bridge-remove-br_netfilter-warning.patch was intended for
  SLE12-SPx only. For SLE15 we want to follow the upstream behaviour of bridge /
  br_netfilter.
- commit d00a8a0
* Wed Jul 19 2017 jthumshirn@suse.de
- series.conf: Delete already upstreamed patches.
- commit d8c5404
* Wed Jul 19 2017 jroedel@suse.de
- Re-assign patches.suse/0009-PM-hibernate-Reserve-hibernation-key-and-erase-footp.patch
- commit 1d767fc
* Wed Jul 19 2017 gqjiang@suse.com
- Delete
  patches.suse/0004-md-cluster-use-sync-way-to-handle-METADATA_UPDATED-m.patch.
- Delete
  patches.suse/0005-md-move-bitmap_destroy-to-the-beginning-of-__md_stop.patch.
- Delete
  patches.suse/0006-md-cluster-add-CHANGE_CAPACITY-message-type.patch.
- Delete
  patches.suse/0007-md-cluster-introduce-cluster_check_sync_size.patch.
- Delete
  patches.suse/0008-md-cluster-add-the-support-for-resize.patch.
- commit ef41919
* Tue Jul 18 2017 mhocko@suse.cz
- Added patches.fixes/0001-mm-memory_hotplug-simplify-empty-node-mask-handling-.patch
  Added patches.fixes/0002-hugetlb-memory_hotplug-prefer-to-use-reserved-pages-.patch
  Added patches.fixes/0003-mm-unify-new_node_page-and-alloc_migrate_target.patch.
  forward ported
- commit d5e8bf8
* Tue Jul 18 2017 mhocko@suse.cz
- patches.suse/0001-mm-memory_hotplug-support-movable_node-for-hotplugab.patch
  forward port
- commit 3426276
* Tue Jul 18 2017 mhocko@suse.cz
- Update
  patches.suse/0004-mm-memory_hotplug-get-rid-of-is_zone_device_section.patch
  (bnc#1027153, bnc#1030659, bnc#1047595, fate#323634).
- Delete
  patches.fixes/004-mm-memory_hotplug-get-rid-of-is_zone_device_section-fix.patch.
- commit 9b458ae
* Tue Jul 18 2017 mhocko@suse.cz
- mm: remove return value from init_currently_empty_zone
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: consider offline memblocks removable
  (bnc#1027153, bnc#1030659, fate#323634).
- mm: consider zone which is not fully populated to have holes
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, compaction: skip over holes in __reset_isolation_suitable
  (bnc#1027153, bnc#1030659, fate#323634).
- mm: __first_valid_page skip over offline pages (bnc#1027153,
  bnc#1030659, fate#323634).
- mm, vmstat: skip reporting offline pages in pagetypeinfo
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: do not associate hotadded memory to
  zones until online (bnc#1027153, bnc#1030659, bnc#1047506,
  fate#323634).
- mm, memory_hotplug: fix MMOP_ONLINE_KEEP behavior (bnc#1027153,
  bnc#1030659, fate#323634).
- mm, memory_hotplug: do not assume ZONE_NORMAL is default kernel
  zone (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: replace for_device by want_memblock in
  arch_add_memory (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: fix the section mismatch warning
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: remove unused cruft after memory hotplug
  rework (bnc#1027153, bnc#1030659, fate#323634).
- Update
  patches.suse/0002-mm-memory_hotplug-use-node-instead-of-zone-in-can_on.patch
  (bnc#1027153, bnc#1030659, fate#323634).
- Update
  patches.suse/0003-mm-drop-page_initialized-check-from-get_nid_for_pfn.patch
  (bnc#1027153, bnc#1030659, fate#323634).
- Update
  patches.suse/0004-mm-memory_hotplug-get-rid-of-is_zone_device_section.patch
  (bnc#1027153, bnc#1030659, fate#323634).
- mm, memory_hotplug: split up register_one_node() (bnc#1027153,
  bnc#1030659, fate#323634).
- Delete
  patches.fixes/0001-mm-memory_hotplug-fix-MMOP_ONLINE_KEEP-behavior.patch.
- Delete
  patches.fixes/0002-mm-memory_hotplug-do-not-assume-ZONE_NORMAL-is-defau.patch.
- Delete
  patches.fixes/include-linux-mmzone.h-simplify-zone_intersects.patch.
- Delete
  patches.suse/0006-mm-memory_hotplug-do-not-associate-hotadded-memory-t.patch.
- Delete
  patches.suse/0008-mm-memory_hotplug-fix-the-section-mismatch-warning.patch.
- Delete
  patches.suse/0009-mm-memory_hotplug-remove-unused-cruft-after-memory-h.patch.
- Delete
  patches.suse/mm-memory_hotplug-consider-offline-memblocks-removable.patch.
  Replace the SLE12-SP2 based implementation by the upstream commits. Take
  the whole series but in principle there are no large changes between the
  two.
- commit 5fdd3c7
* Tue Jul 18 2017 bpoirier@suse.com
- Move all networking patches in one section
  Driver and core changes are intertwined upstream. Trying to separate them
  leads to an unbisectable series.
- commit dc0dd37
* Tue Jul 18 2017 bpoirier@suse.com
- Delete
  patches.drivers/qed-bump-driver-versions-to-8.7.1.62.patch.
  Specific to SLE12SP2 backport, see bsc#966318 comment 16
- Delete
  patches.fixes/scsi-bfa-Increase-requested-firmware-version-to-3.2..patch.
  Upstream as
  2d1148f0f450 scsi: bfa: Increase requested firmware version to 3.2.5.1 (v4.10-rc4)
- commit 31b4006
* Tue Jul 18 2017 tiwai@suse.de
- Adjust guard prefix in series.conf, no functional change
- commit f09e36f
* Tue Jul 18 2017 tiwai@suse.de
- Enable patches.fixes/iio-hid-sensor-fix-return-of-EINVAL-on-invalid-value
  It's a trivial fix from 4.13-rc1 and still valid.
- commit 4daf55f
* Tue Jul 18 2017 tiwai@suse.de
- Enable patches.drivers/kernel-Export-mm_access.patch.
  This patch is still required for supporting AMD ROCm.
- commit d9a4c03
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-do-not-loop-on-GFP_REPEAT-when-no-reclaim-progress.patch.
  fixed as a part of 0a0337e0d1d134465778a16f5cbea95086e8e9e0 (4.7)
- commit a38fe09
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.drivers/drm-Print-EDID-errors-less-obviously.patch
  This change is no longer needed with the recent upstream code.
- commit 30a521d
* Tue Jul 18 2017 mhocko@suse.cz
- patches.suse/mm-inform-about-enabling-mirrored-memory.patch
  enable because the concern with the mirrored memory still holds
- commit b059f43
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/powerpc-implement-arch_reserved_kernel_pages.patch.
  merged 1e76609cc1646c5222feefe86a3433a79be4fb73 (4.9)
- commit cbafebe
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-memblock-expose-total-reserved-memory.patch.
  merged as 8907de5dc6e9d5925cf3b0a698cc3a4272fda073 (4.9)
- commit 7eb2ba2
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-introduce-arch_reserved_kernel_pages.patch.
  merged as f6f34b4387d9e18304451a131b35d7c4f27a0b5a (4.9)
- commit c8145c8
* Tue Jul 18 2017 mhocko@suse.cz
- patches.suse/mm-Warn-users-of-node-memory-hot-remove-if-the-memory-ratio-is-a-high-risk.patch
  enable the patch as we want to have an idea that somebody overuses
  movable memory.
- commit 490b154
* Tue Jul 18 2017 mgorman@suse.de
- Delete
  patches.suse/mm-fadvise-avoid-expensive-remote-LRU-cache-draining-after-FADV_DONTNEED.patch.
- Delete patches.suse/mm-fix-remote-numa-hits-statistics.patch.
- Delete patches.suse/mm-get-rid-of-__GFP_OTHER_NODE.patch.
- Delete
  patches.suse/mm-mmzone.c-swap-likely-to-unlikely-as-code-logic-is-different-for-next_zones_zonelist.patch.
- Delete
  patches.suse/mm-mprotect.c-don-t-touch-single-threaded-PTEs-which-are-on-the-right-node.patch.
- Delete patches.suse/sched-debug-always-show-nr_migrations.patch.
- Delete
  patches.suse/thp-fix-MADV_DONTNEED-vs.-numa-balancing-race.patch.
- Delete
  patches.suse/thp-reduce-indentation-level-in-change_huge_pmd.patch.
- commit 165d34d
* Tue Jul 18 2017 mhocko@suse.cz
- Refresh patches.suse/memcg-deprecate-memory.force_empty-knob.patch.
  forward ported. We still want to catch users who might depend on the
  knob
- commit a082540
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/memcg-introduce-low-limit-for-cgroupv1.patch.
  cgroup v2 is no longer in devel mode since
  34a9304a96d6351c2d35dcdc9293258378fc0bd8 (4.5)
- commit 3ed04d3
* Tue Jul 18 2017 nborisov@suse.com
- Disable CONFIG_XFS_RT (fate#321934)
- commit fede9b2
* Tue Jul 18 2017 jack@suse.cz
- Enable patches.fixes/fs-speedup-clean-bdev-aliases.patch: The issue has
  not been sorted out upstream yet.
- commit f565355
* Tue Jul 18 2017 jack@suse.cz
- Delete patches.fixes/md-Make-flush-bios-explicitely-sync.patch: Merged
  as commit 5a8948f8a32ba56c17b3fb75d318ac98157f3ba5 to 4.12-rc4.
- commit 064de7f
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/btrfs-Make-flush-bios-explicitely-sync.patch: Merged as
  commit 8d91012528b3c95c159e6b6779e367421df9cbb5 to 4.12-rc5.
- commit 199953b
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/reiserfs-Make-flush-bios-explicitely-sync.patch: Merged as
  commit d8747d642ec4ce96adf17ae35652a5e4015cfe02 to 4.12-rc4.
- commit 74f0ec4
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/gfs2-Make-flush-bios-explicitely-sync.patch: Merged as
  0f0b9b63e14fc3f66e4d342df016c9b071c5abed to 4.12-rc4.
- commit 5260255
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/proc-show-MADV_FREE-pages-info-in-smaps.patch.
  merged as cf8496ea8020792ea32d0fbec0c140d8de93011a (4.12)
- commit 622d942
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.fixes/x86-mm-fix-gup_pte_range-vs-DAX-mappings.patch: Merged as
  commit ef947b2529f918d9606533eb9c32b187ed6a5ede to 4.11-rc2
- commit 8edaf40
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-enable-MADV_FREE-for-swapless-system.patch.
  merged as 93e06c7a645343d222c9a838834a51042eebbbf7 (4.12)
- commit f290c11
* Tue Jul 18 2017 msuchanek@suse.de
- Refresh ibmvnic patch metadata
  Also rename patches to 3 digit scheme.
- commit 1de7e2b
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-reclaim-MADV_FREE-pages.patch.
  merged as 802a3a92ad7ac0b9be9df229dee530a1f0a8039b (4.12)
- commit 0086a29
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-move-MADV_FREE-pages-into-LRU_INACTIVE_FILE-list.patch.
  merged as f7ad2a6cb9f7c4040004bedee84a70a9b985583e (4.12)
- commit 0d6a174
* Tue Jul 18 2017 jack@suse.cz
- Printk patches will be handled by Petr Mladek.
- commit 7aa5f41
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-dont-assume-anonymous-pages-have-SwapBacked-flag.patch.
  merged as d44d363f65780f2ac2ec672164555af54896d40d (4.12)
- commit 66d14fb
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/mm-delete-unnecessary-TTU_-flags.patch
  merged as a128ca71fb29ed4444b80f38a0148b468826e19b (4.12)
- commit aa5cda3
* Tue Jul 18 2017 mhocko@suse.cz
- Refresh patches.fixes/mm-make-PR_SET_THP_DISABLE-immediately-active.patch
  forward-port
- commit 35db809
* Tue Jul 18 2017 jack@suse.cz
- Delete patches.suse/cgroup-Export-cgroup_is_descendant.patch: Commit
  b11cfb5807e30 in 4.5-rc1 made this obsolete.
- commit 229d877
* Tue Jul 18 2017 jack@suse.cz
- Delete
  patches.suse/xfs-silence-warnings-in-xfs-vm-releasepage.patch: Merged as
  commit 0a417b8dc1f10 to 4.10-rc4
- commit e4fddb8
* Tue Jul 18 2017 jack@suse.cz
- Delete patches.suse/kabi-Add-placeholder-to-vm_fault.patch: kABI
  placeholder not needed anymore since DAX patches are already in
  4.12.
- commit 7c85cca
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.fixes/mm-fix-classzone_idx-underflow-in-shrink_zones.patch.
  obsolete by b2e18757f2c9
- commit 054b718
* Tue Jul 18 2017 mhocko@suse.cz
- Delete patches.suse/x86-mm-sched-make-lazy-TLB-mode-even-lazier-kabi.patch
  we do not need kabi workaround anymore
- commit a1b7ca1
* Tue Jul 18 2017 mhocko@suse.cz
- Refresh patches.fixes/mm-adaptive-hash-table-scaling.patch to the
  upstream version
- Delete patches.fixes/mm-adaptive-hash-table-scaling-fix.patch.
- Delete patches.fixes/mm-drop-HASH_ADAPT.patch.
  those were follow up fixes for the patch taken from the mmotm tree
- commit e8e2fc2
* Tue Jul 18 2017 jeffm@suse.com
- Refresh
  patches.suse/btrfs-8888-add-allow_unsupported-module-parameter.patch.
- commit dcc0c57
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/squashfs-3.4.patch.
- Delete
  patches.suse/squashfs3-properly-handle-dir_emit-failures.patch.
- commit d3a07b1
* Tue Jul 18 2017 nborisov@suse.com
- Refresh
  patches.suse/0001-Btrfs-skip-commit-transaction-if-we-don-t-have-enoug.patch.
- commit e762284
* Tue Jul 18 2017 msuchanek@suse.de
- Enable POWER patches from 4.13
- commit b709393
* Tue Jul 18 2017 msuchanek@suse.de
- Enable ibmvnic patches.
- commit 759126f
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/xfs-unsupported-features.patch.
- commit 02d7e1f
* Tue Jul 18 2017 jroedel@suse.de
- Delete patches.suse/x86-mm-sched-make-lazy-TLB-mode-even-lazier-kabi.patch.
- commit 178d687
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/ext4-unsupported-features.patch.
- commit 70b7452
* Tue Jul 18 2017 jeffm@suse.com
- Delete patches.suse/8250-sysrq-ctrl_o.patch.
  The SLE15 merge re-added this patch.  It was removed in:
  05568ac53a9 (Delete POWER4 specific patches.suse/8250-sysrq-ctrl_o.patch.)
- commit cf3419b
* Tue Jul 18 2017 jeffm@suse.com
- Refresh patches.suse/unsupported-features.patch.
- commit 658708b
* Tue Jul 18 2017 jeffm@suse.com
- Delete patches.rpmify/lustre-lloop-dont-change-logical-size.
  This patch was incomplete and LUSTRE_FS=n in any case.
- commit 0ba6419
* Tue Jul 18 2017 jeffm@suse.com
- Remove DMAPI patches (fate#320591).
- Delete
  patches.fixes/xfs-fix-buffer-overflow-dm_get_dirattrs.patch.
- Delete
  patches.fixes/xfs_dmapi-fix-the-debug-compilation-of-xfs_dmapi.patch.
- Delete patches.suse/dmapi-Make-NFSD-DMAPI-aware.patch.
- Delete patches.suse/dmapi-source.patch.
- Delete patches.suse/dmapi-support-for-xfs.patch.
- commit a1b6653
* Tue Jul 18 2017 jslaby@suse.cz
- series: turn away from some patches
  Once upon a time, I only touched those. Turn away from them now.
- commit 3b9f2a5
* Tue Jul 18 2017 jslaby@suse.cz
- Refresh
  patches.suse/0001-x86-entry-64-Refactor-IRQ-stacks-and-make-them-NMI-s.patch.
- Refresh
  patches.suse/0002-x86-entry-64-Initialize-the-top-of-the-IRQ-stack-bef.patch.
- Refresh
  patches.suse/0003-x86-dumpstack-fix-occasionally-missing-registers.patch.
- Refresh
  patches.suse/0004-x86-dumpstack-fix-interrupt-and-exception-stack-boun.patch.
- Refresh
  patches.suse/0005-objtool-add-ORC-unwind-table-generation.patch.
- Refresh
  patches.suse/0006-objtool-x86-add-facility-for-asm-code-to-provide-unw.patch.
- Refresh
  patches.suse/0007-x86-entry-64-add-unwind-hint-annotations.patch.
- Refresh
  patches.suse/0008-x86-asm-add-unwind-hint-annotations-to-sync_core.patch.
  Update upstream information.
- commit 8db850a
* Tue Jul 18 2017 msuchanek@suse.de
- Delete fadump patches which are in 4.12 and enable the rest.
- commit 53bf06b
* Tue Jul 18 2017 msuchanek@suse.de
- Refresh fadump patch metadata
- Refresh patches.arch/ia64-remove-multiple-definitions-of-append-elf.patch.
- Refresh patches.arch/move-crashkernel-and-vmcore-related-code-under-config_crash_dump.patch.
- Refresh patches.arch/powerpc-fadump-remove-dependency-with-kexec.patch.
- Refresh patches.arch/powerpc-fadump-reuse-crashkernel-parameter-to-reserve-memory.patch.
- Refresh patches.arch/powerpc-fadump-update-fadump-kernel-documentation.patch.
- commit 12d1968
* Tue Jul 18 2017 jkosina@suse.cz
- series.conf: manually fixup some of the missess of the automatic
  guard generation
- series.conf: move IOMMU AMD to Joerg
- commit 0900ac0
* Tue Jul 18 2017 msuchanek@suse.de
- Delete patches.arch/ACPICA-Update-TPM2-ACPI-table.patch.
  in 4.12
- commit 8224558
* Tue Jul 18 2017 jkosina@suse.cz
- series.conf: move intel_pstate-Increase-hold-off-time-before-samples-are-scaled.patch
  over to Mel as requested
- commit 8bc2621
* Tue Jul 18 2017 jkosina@suse.cz
- series.conf: make the forward-porting patch guards per-login (scripted)
- commit d3987bc
* Tue Jul 18 2017 msuchanek@suse.de
- Refresh metadata on recent powerpc patches.
- Refresh patches.arch/powerpc-Fix-proc-cpuinfo-revision-for-POWER9-DD2.patch.
- Refresh patches.arch/powerpc-perf-0026-Fix-branch-event-code-for-power9.patch.
- commit 54227b1
* Tue Jul 18 2017 msuchanek@suse.de
- Remove post-4.12 tpm patches.
  Should get these from stable updates.
- commit b857f37
* Tue Jul 18 2017 mmarek@suse.com
- Refresh and trim ppc64le and x86_64 debug configs
- commit 2f8eb87
* Tue Jul 18 2017 tiwai@suse.de
- Refresh and apply patches.drivers/b43-Add-missing-MODULE_FIRMWARE.
- commit 6878788
* Tue Jul 18 2017 tiwai@suse.de
- Delete patches.fixes/drm-i915-Fix-S4-resume-breakage.
  The workaround wasn't merged to upstream, and it seems becoming
  superfluous with the recent i915 driver, so let's drop this one.
- commit f5a35ab
* Tue Jul 18 2017 tiwai@suse.de
- Delete upstreamed or SLE12-specific patches
- commit c0b786f
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Drop unnecessary xmlto for 4.13+
- commit e47dc84
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Correct kernel-docs package summary/description
- commit 697b763
* Tue Jul 18 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: refresh dependencies for PDF build (bsc#1048129)
  But it still doesn't work with Tex Live 2017, thus disabled yet.
  Also add texlive-anyfontsize for HTML math handling.
- commit ead44a1
* Tue Jul 18 2017 jkosina@suse.cz
- Update config files: temporarily disable module signature verification (bsc#1049122)
- commit 59b1abb
* Tue Jul 18 2017 jslaby@suse.cz
- Delete
  patches.suse/kgr-0001-s390-livepatch-reorganize-TIF-bits.patch.
  This was in upstream as 30d64f1904d44a7e52a93d711d57aabbac2efd72.
- commit 2b93b5d
* Tue Jul 18 2017 jslaby@suse.cz
- Delete
  patches.arch/stack-unwind-cfi_ignore-takes-more-arguments.
- Delete patches.arch/x86_64-unwind-annotations.
- Delete
  patches.suse/revert-x86-remove-warning-and-warning_symbol-from-struct-stacktrace_ops.
- Delete patches.suse/stack-unwind.patch.
  Kill the old stack unwinding crap.
- commit 8eb0aae
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/drm-i915-disable-KASAN-for-handlers.patch.
  It was never accepted, is under discussion. But we disabled
  CONFIG_DRM_I915_WERROR in commit 5fc7b327348b, so we are safe anyway.
- commit 09fc05f
* Tue Jul 18 2017 jslaby@suse.cz
- Delete patches.rpmify/get_builtin_firmware-gcc-7.patch.
  This was never accepted. Instead this seems to be fixed in gcc.
- commit c486b10
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.drivers/ppc64-adb.
  This hardware was discontinued in 2006 and the patch was never accepted
  upstream.
- commit 38f5b34
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-prom-nodisplay.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit 44570ac
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.arch/ppc-pegasos-console-autodetection.patch.
  We no longer support 32-bit ppc and this hardware only existed with a
  32-bit CPU.
- commit 9a9213c
* Mon Jul 17 2017 jeffm@suse.com
- Delete patches.suse/ppc-powerbook-usb-fn-key-default.patch.
  We no longer support 32-bit ppc and there were no 64-bit powerbooks.
- commit 550dc2e
* Mon Jul 17 2017 jkosina@suse.cz
- README.BRANCH: update branch information
- commit 895cf17
* Mon Jul 17 2017 jkosina@suse.cz
- Create SLE15 branch
- Branch off from stable
- Import all the patches from SLE12 codestream with unclear
  upstream status and mark them with 'needs_review' guard at
  the end of series.conf
- Initial import/merge configs from SLE12 codestream; needs verification
  to make sure no SLE12-enabled options are lost
- Patches which were left intact (conflict as they were in both
  branches):
  patches.suse/supported-flag
  patches.suse/genksyms-add-override-flag.diff
  patches.suse/vfs-add-super_operations-get_inode_dev
  patches.suse/suse-hv-guest-os-id.patch
  patches.suse/btrfs-fs-super.c-add-new-super-block-devices-super_block_d.patch
  patches.suse/btrfs-btrfs-use-the-new-VFS-super_block_dev.patch
  patches.drivers/pstore_disable_efi_backend_by_default.patch
  patches.suse/pstore-backend-autoaction
  patches.fixes/scsi-ibmvscsi-module_alias.patch
  patches.fixes/drm-i915-Fix-S4-resume-breakage
  patches.suse/iwlwifi-expose-default-fallback-ucode-api
  patches.suse/crasher.patch
  patches.suse/ftrace-x86-xen-use-kernel-identity-mapping-only-when.patch
- config.conf replaced from SLE12 codebase
- drop 'needs_review'-marked variants of patches which are already present and
  do apply cleanly from -stable branch already.
-  patches.arch/acpi_thermal_passive_blacklist.patch: update with version from
  stable branch to fix build.
- update README.BRANCH
- commit 2028ed7
* Mon Jul 17 2017 msuchanek@suse.de
- Refresh metadata of fadump patches
- Refresh patches.arch/powerpc-fadump-add-reschedule-point-while-releasing-memory.patch.
- Refresh patches.arch/powerpc-fadump-avoid-duplicates-in-crash-memory-ranges.patch.
- Refresh patches.arch/powerpc-fadump-avoid-holes-in-boot-memory-area-when-fadump-is-registered.patch.
- Refresh patches.arch/powerpc-fadump-provide-a-helpful-error-message.patch.
- commit 6f71027
* Mon Jul 17 2017 msuchanek@suse.de
- Refresh TPM and CXL patch metadata.
- Refresh patches.arch/ACPICA-Update-TPM2-ACPI-table.patch.
- Refresh patches.arch/cxl-Unlock-on-error-in-probe.patch.
- commit f1e3eba
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: expect: fix crash when putting uninited expectation
  (bnc#1048935).
- Delete
  patches.fixes/netfilter-nf_ct_expect-fix-expect-removal.patch.
  Replace by upstream fix (from a subsys repo).
- commit abad31d
* Mon Jul 17 2017 jslaby@suse.cz
- netfilter: nf_ct_expect: fix expect removal (bnc#1048935).
- commit 28fe876
* Mon Jul 17 2017 mmarek@suse.cz
- Drop multiversion(kernel) from the KMP template (fate#323189)
- commit 71504d8
* Tue Jul 11 2017 tiwai@suse.de
- rpm/kernel-docs.spec.in: Fix and cleanup for 4.13 doc build (bsc#1048129)
  The whole DocBook stuff has been deleted.  The PDF build still non-working
  thus the sub-packaging disabled so far.
- commit 8e7de10
* Mon Jun 19 2017 mcgrof@suse.com
- mm: kmemleak: treat vm_struct as alternative reference to vmalloc'ed objects (bsc#1027456).
- mm: kmemleak: factor object reference updating out of scan_block() (bsc#1027456).
- mm: kmemleak: slightly reduce the size of some structures on 64-bit architectures (bsc#1027456).
- commit 880dbd7
* Fri Jun  2 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Fix new include path
  Commit 89de3db69113d58cdab14d2c777de6080eac49dc ("rpm/dtb.spec.in.in:
  Update include path for dt-bindings") introduced an additional include
  path for 4.12. The commit message had it correct, but the spec file
  template lacked a path component, breaking the aarch64 build while
  succeeding on armv7hl. Fix that.
- commit c8d853a
* Wed May 31 2017 afaerber@suse.de
- rpm/dtb.spec.in.in: Update include path for dt-bindings
  Kernels before 4.12 had arch/{arm,arm64}/boot/dts/include/ directories
  with a symlink to include/dt-bindings/.
  In 4.12 those include/ directories were dropped.
  Therefore use include/ directly.
  Additionally some cross-architecture .dtsi reuse was introduced, which
  requires scripts/dtc/include-prefixes/ that didn't exist on older kernels.
- commit 466f108
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-zte subpackage
  4.9 added arch/arm64/boot/dts/zte/.
- commit 073d831
* Fri Jan  6 2017 afaerber@suse.de
- rpm: Add arm64 dtb-allwinner subpackage
  4.10 added arch/arm64/boot/dts/allwinner/.
- commit dfeb94a
* Tue Dec 20 2016 xxxxxmichl@googlemail.com
- added De0-Nanos-SoC board support (and others based on Altera SOC).
- commit 9278339
